# 本版本更新包含以下内容：

## 数据安全治理中心(dsgc) 版本：2019-07-23

### 第 17 次发布

发布时间：2024-08-06 01:35:34

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [ModifyDSPAAssessmentRiskLatest](https://cloud.tencent.com/document/api/1087/97199)

	* <font color="#dd0000">**修改入参**：</font>RiskLatestTableId




## 私有网络(vpc) 版本：2017-03-12

### 第 198 次发布

发布时间：2024-08-06 02:28:26

本次发布包含了以下内容：

改善已有的文档。

新增数据结构：

* [PrivateNatCrossDomainInfo](https://cloud.tencent.com/document/api/215/15824#PrivateNatCrossDomainInfo)

修改数据结构：

* [PrivateNatGateway](https://cloud.tencent.com/document/api/215/15824#PrivateNatGateway)

	* 新增成员：DirectConnectGatewayIds, NatType, CrossDomainInfo, VpcType, CcnId




# 历次版本更新如下：

## 活动防刷(aa) 版本：2020-02-24

### 第 7 次发布

发布时间：2022-08-08 06:02:45

本次发布包含了以下内容：

改善已有的文档。

<font color="#dd0000">**删除接口**：</font>

* ManageMarketingRisk
* QueryActivityAntiRushAdvanced

<font color="#dd0000">**删除数据结构**：</font>

* AccountInfo
* CrowdAntiRushInfo
* InputActivityAntiRushAdvanced
* InputDetails
* InputManageMarketingRisk
* OnlineScamInfo
* OtherAccountInfo
* OutputActivityAntiRushAdvanced
* OutputActivityAntiRushAdvancedValue
* OutputManageMarketingRisk
* OutputManageMarketingRiskValue
* QQAccountInfo
* SponsorInfo
* WeChatAccountInfo

### 第 6 次发布

发布时间：2020-08-31 08:00:21

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [InputManageMarketingRisk](https://cloud.tencent.com/document/api/1189/45888#InputManageMarketingRisk)

	* 新增成员：DeviceType

	* <font color="#dd0000">**删除成员**：</font>VendorId


### 第 5 次发布

发布时间：2020-08-27 08:00:21

本次发布包含了以下内容：

改善已有的文档。

新增数据结构：

* [InputDetails](https://cloud.tencent.com/document/api/1189/45888#InputDetails)

修改数据结构：

* [InputManageMarketingRisk](https://cloud.tencent.com/document/api/1189/45888#InputManageMarketingRisk)

	* 新增成员：SceneCode, Details

	* <font color="#dd0000">**修改成员**：</font>SceneType


### 第 4 次发布

发布时间：2020-07-17 08:00:33

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [QQAccountInfo](https://cloud.tencent.com/document/api/1189/45888#QQAccountInfo)

	* <font color="#dd0000">**修改成员**：</font>DeviceId


### 第 3 次发布

发布时间：2020-07-03 08:00:32

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [ManageMarketingRisk](https://cloud.tencent.com/document/api/1189/45962)

新增数据结构：

* [CrowdAntiRushInfo](https://cloud.tencent.com/document/api/1189/45888#CrowdAntiRushInfo)
* [InputManageMarketingRisk](https://cloud.tencent.com/document/api/1189/45888#InputManageMarketingRisk)
* [OutputManageMarketingRisk](https://cloud.tencent.com/document/api/1189/45888#OutputManageMarketingRisk)
* [OutputManageMarketingRiskValue](https://cloud.tencent.com/document/api/1189/45888#OutputManageMarketingRiskValue)

### 第 2 次发布

发布时间：2020-07-01 08:00:35

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [QueryActivityAntiRushAdvanced](https://cloud.tencent.com/document/api/1189/45887)

新增数据结构：

* [AccountInfo](https://cloud.tencent.com/document/api/1189/45888#AccountInfo)
* [InputActivityAntiRushAdvanced](https://cloud.tencent.com/document/api/1189/45888#InputActivityAntiRushAdvanced)
* [OnlineScamInfo](https://cloud.tencent.com/document/api/1189/45888#OnlineScamInfo)
* [OtherAccountInfo](https://cloud.tencent.com/document/api/1189/45888#OtherAccountInfo)
* [OutputActivityAntiRushAdvanced](https://cloud.tencent.com/document/api/1189/45888#OutputActivityAntiRushAdvanced)
* [OutputActivityAntiRushAdvancedValue](https://cloud.tencent.com/document/api/1189/45888#OutputActivityAntiRushAdvancedValue)
* [QQAccountInfo](https://cloud.tencent.com/document/api/1189/45888#QQAccountInfo)
* [SponsorInfo](https://cloud.tencent.com/document/api/1189/45888#SponsorInfo)
* [WeChatAccountInfo](https://cloud.tencent.com/document/api/1189/45888#WeChatAccountInfo)

### 第 1 次发布

发布时间：2020-04-28 15:03:20

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [QueryActivityAntiRush](https://cloud.tencent.com/document/api/1189/43965)




## 智能语音(aai) 版本：2018-05-22

### 第 9 次发布

发布时间：2019-06-20 16:21:46

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [TextToVoice](https://cloud.tencent.com/document/api/441/18086)

	* 新增入参：Codec


### 第 8 次发布

发布时间：2018-08-30 15:40:25

本次发布包含了以下内容：

改善已有的文档。

### 第 7 次发布

发布时间：2018-08-23 22:15:03

本次发布包含了以下内容：

改善已有的文档。

### 第 6 次发布

发布时间：2018-08-17 18:31:37

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [Chat](https://cloud.tencent.com/document/api/441/19016)
* [SimultaneousInterpreting](https://cloud.tencent.com/document/api/441/19015)

### 第 5 次发布

发布时间：2018-07-26 12:16:45

本次发布包含了以下内容：

改善已有的文档。

### 第 4 次发布

发布时间：2018-07-12 15:29:35

本次发布包含了以下内容：

改善已有的文档。

### 第 3 次发布

发布时间：2018-07-05 14:31:43

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [TextToVoice](https://cloud.tencent.com/document/api/441/18086)

	* <font color="#dd0000">**修改入参**：</font>ProjectId


### 第 2 次发布

发布时间：2018-06-28 15:15:08

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [TextToVoice](https://cloud.tencent.com/document/api/441/18086)

### 第 1 次发布

发布时间：2018-05-24 17:04:19

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [SentenceRecognition](https://cloud.tencent.com/document/api/441/19453)




## 应用合规平台(acp) 版本：2022-01-05

### 第 6 次发布

发布时间：2023-01-10 15:15:42

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeChannelTaskReportUrl](https://cloud.tencent.com/document/api/1553/85576)

### 第 5 次发布

发布时间：2022-09-19 11:21:50

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateAppScanTask](https://cloud.tencent.com/document/api/1553/75166)

	* 新增入参：AppSha1, PrivacyTextMD5

* [CreateAppScanTaskRepeat](https://cloud.tencent.com/document/api/1553/75165)

	* 新增入参：AppSha1, PrivacyTextMD5


### 第 4 次发布

发布时间：2022-08-24 06:06:48

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeResourceUsageInfo](https://cloud.tencent.com/document/api/1553/75518)

	* 新增入参：Source

* [DescribeScanTaskReportUrl](https://cloud.tencent.com/document/api/1553/75162)

	* 新增出参：ReportResult


### 第 3 次发布

发布时间：2022-07-29 06:01:57

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeResourceUsageInfo](https://cloud.tencent.com/document/api/1553/75518)

	* 新增入参：TaskType, Platform

	* <font color="#dd0000">**修改入参**：</font>PriceName


### 第 2 次发布

发布时间：2022-06-14 11:16:27

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeResourceUsageInfo](https://cloud.tencent.com/document/api/1553/75518)

新增数据结构：

* [ResourceUsageInfoData](https://cloud.tencent.com/document/api/1553/75167#ResourceUsageInfoData)

### 第 1 次发布

发布时间：2022-06-08 15:18:26

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateAppScanTask](https://cloud.tencent.com/document/api/1553/75166)
* [CreateAppScanTaskRepeat](https://cloud.tencent.com/document/api/1553/75165)
* [DescribeFileTicket](https://cloud.tencent.com/document/api/1553/75164)
* [DescribeScanTaskList](https://cloud.tencent.com/document/api/1553/75163)
* [DescribeScanTaskReportUrl](https://cloud.tencent.com/document/api/1553/75162)
* [DescribeScanTaskStatus](https://cloud.tencent.com/document/api/1553/75161)

新增数据结构：

* [AppInfoItem](https://cloud.tencent.com/document/api/1553/75167#AppInfoItem)
* [AppTaskData](https://cloud.tencent.com/document/api/1553/75167#AppTaskData)
* [TaskFlowStepsInfo](https://cloud.tencent.com/document/api/1553/75167#TaskFlowStepsInfo)




## 云顾问(advisor) 版本：2020-07-21

### 第 5 次发布

发布时间：2023-09-14 01:05:50

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeStrategies](https://cloud.tencent.com/document/api/1264/63110)

	* <font color="#dd0000">**修改出参**：</font>Strategies


新增数据结构：

* [Conditions](https://cloud.tencent.com/document/api/1264/63113#Conditions)
* [Strategies](https://cloud.tencent.com/document/api/1264/63113#Strategies)

<font color="#dd0000">**删除数据结构**：</font>

* DescribeStrategie
* DescribeStrategiesCondition

### 第 4 次发布

发布时间：2022-06-08 06:03:05

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeTaskStrategyRisks](https://cloud.tencent.com/document/api/1264/63112)

	* 新增入参：Env, TaskType

	* 新增出参：ResourceCount


### 第 3 次发布

发布时间：2021-11-09 08:05:53

本次发布包含了以下内容：

改善已有的文档。

新增数据结构：

* [KeyValue](https://cloud.tencent.com/document/api/1264/63113#KeyValue)

修改数据结构：

* [RiskFieldsDesc](https://cloud.tencent.com/document/api/1264/63113#RiskFieldsDesc)

	* 新增成员：FieldDict


### 第 2 次发布

发布时间：2021-10-29 08:00:17

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeTaskStrategyRisks](https://cloud.tencent.com/document/api/1264/63112)

	* 新增出参：Risks


### 第 1 次发布

发布时间：2021-10-20 16:41:59

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeStrategies](https://cloud.tencent.com/document/api/1264/63110)
* [DescribeTaskStrategyRisks](https://cloud.tencent.com/document/api/1264/63112)

新增数据结构：

* [DescribeStrategie](https://cloud.tencent.com/document/api/1264/63113#DescribeStrategie)
* [DescribeStrategiesCondition](https://cloud.tencent.com/document/api/1264/63113#DescribeStrategiesCondition)
* [RiskFieldsDesc](https://cloud.tencent.com/document/api/1264/63113#RiskFieldsDesc)




## 借贷反欺诈(af) 版本：2020-02-26

### 第 6 次发布

发布时间：2023-07-18 01:05:51

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [SimpleKindRiskDetail](https://cloud.tencent.com/document/api/668/44002#SimpleKindRiskDetail)

	* <font color="#dd0000">**修改成员**：</font>RiskCode, RiskCodeValue


### 第 5 次发布

发布时间：2022-04-15 06:01:22

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [AntiFraudFilter](https://cloud.tencent.com/document/api/668/44002#AntiFraudFilter)

	* 新增成员：OldResponseType


### 第 4 次发布

发布时间：2021-11-18 08:02:15

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [GetAntiFraud](https://cloud.tencent.com/document/api/668/64230)

新增数据结构：

* [AntiFraudCryptoFilter](https://cloud.tencent.com/document/api/668/44002#AntiFraudCryptoFilter)
* [AntiFraudFilter](https://cloud.tencent.com/document/api/668/44002#AntiFraudFilter)
* [AntiFraudRecord](https://cloud.tencent.com/document/api/668/44002#AntiFraudRecord)
* [OtherModelScoresDetail](https://cloud.tencent.com/document/api/668/44002#OtherModelScoresDetail)
* [SimpleKindRiskDetail](https://cloud.tencent.com/document/api/668/44002#SimpleKindRiskDetail)

### 第 3 次发布

发布时间：2021-09-15 08:02:06

本次发布包含了以下内容：

改善已有的文档。

新增数据结构：

* [FinanceOtherModelScores](https://cloud.tencent.com/document/api/668/44002#FinanceOtherModelScores)

修改数据结构：

* [FinanceAntiFraudRecord](https://cloud.tencent.com/document/api/668/44002#FinanceAntiFraudRecord)

	* 新增成员：OtherModelScores


### 第 2 次发布

发布时间：2021-09-14 08:01:47

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeAntiFraud](https://cloud.tencent.com/document/api/668/61477)

新增数据结构：

* [FinanceAntiFraudCryptoFilter](https://cloud.tencent.com/document/api/668/44002#FinanceAntiFraudCryptoFilter)
* [FinanceAntiFraudFilter](https://cloud.tencent.com/document/api/668/44002#FinanceAntiFraudFilter)
* [FinanceAntiFraudRecord](https://cloud.tencent.com/document/api/668/44002#FinanceAntiFraudRecord)
* [RiskDetailInfo](https://cloud.tencent.com/document/api/668/44002#RiskDetailInfo)

### 第 1 次发布

发布时间：2020-04-28 15:20:07

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [QueryAntiFraud](https://cloud.tencent.com/document/api/668/44001)

新增数据结构：

* [RiskDetail](https://cloud.tencent.com/document/api/668/44002#RiskDetail)




## 定制建模(afc) 版本：2020-02-26

### 第 4 次发布

发布时间：2023-07-18 01:05:54

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [SimpleKindRiskDetail](https://cloud.tencent.com/document/api/1029/44018#SimpleKindRiskDetail)

	* <font color="#dd0000">**修改成员**：</font>RiskCode, RiskCodeValue


### 第 3 次发布

发布时间：2022-11-14 06:09:18

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [TransportGeneralInterface](https://cloud.tencent.com/document/api/1029/82738)

新增数据结构：

* [TransportGeneralInterfaceInput](https://cloud.tencent.com/document/api/1029/44018#TransportGeneralInterfaceInput)
* [TransportGeneralInterfaceOutput](https://cloud.tencent.com/document/api/1029/44018#TransportGeneralInterfaceOutput)

### 第 2 次发布

发布时间：2021-11-18 08:02:17

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [GetAntiFraudVip](https://cloud.tencent.com/document/api/1029/64231)

新增数据结构：

* [AntiFraudVipCryptoFilter](https://cloud.tencent.com/document/api/1029/44018#AntiFraudVipCryptoFilter)
* [AntiFraudVipFilter](https://cloud.tencent.com/document/api/1029/44018#AntiFraudVipFilter)
* [AntiFraudVipRecord](https://cloud.tencent.com/document/api/1029/44018#AntiFraudVipRecord)
* [OtherModelScores](https://cloud.tencent.com/document/api/1029/44018#OtherModelScores)
* [SimpleKindRiskDetail](https://cloud.tencent.com/document/api/1029/44018#SimpleKindRiskDetail)

### 第 1 次发布

发布时间：2020-04-28 16:31:18

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [QueryAntiFraudVip](https://cloud.tencent.com/document/api/1029/44017)

新增数据结构：

* [RiskDetail](https://cloud.tencent.com/document/api/1029/44018#RiskDetail)




## 大模型图像创作引擎(aiart) 版本：2022-12-29

### 第 9 次发布

发布时间：2024-08-01 01:08:13

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [ReplaceBackground](https://cloud.tencent.com/document/api/1668/107957)

	* <font color="#dd0000">**修改入参**：</font>Prompt


### 第 8 次发布

发布时间：2024-07-11 01:07:23

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [ChangeClothes](https://cloud.tencent.com/document/api/1668/108532)

### 第 7 次发布

发布时间：2024-07-03 11:28:36

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [ReplaceBackground](https://cloud.tencent.com/document/api/1668/107957)

### 第 6 次发布

发布时间：2024-06-28 01:03:50

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [GenerateAvatar](https://cloud.tencent.com/document/api/1668/107799)

### 第 5 次发布

发布时间：2024-04-23 15:48:38

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [QueryDrawPortraitJob](https://cloud.tencent.com/document/api/1668/105581)
* [QueryTrainPortraitModelJob](https://cloud.tencent.com/document/api/1668/105580)
* [SubmitDrawPortraitJob](https://cloud.tencent.com/document/api/1668/105579)
* [SubmitTrainPortraitModelJob](https://cloud.tencent.com/document/api/1668/105578)
* [UploadTrainPortraitImages](https://cloud.tencent.com/document/api/1668/105577)

新增数据结构：

* [Filter](https://cloud.tencent.com/document/api/1668/88067#Filter)

### 第 4 次发布

发布时间：2024-04-16 01:03:52

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [QueryTextToImageProJob](https://cloud.tencent.com/document/api/1668/104584)

	* 新增出参：RevisedPrompt

* [SubmitTextToImageProJob](https://cloud.tencent.com/document/api/1668/104583)

	* 新增入参：Revise


### 第 3 次发布

发布时间：2024-03-26 10:43:03

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [QueryTextToImageProJob](https://cloud.tencent.com/document/api/1668/104584)
* [SubmitTextToImageProJob](https://cloud.tencent.com/document/api/1668/104583)

### 第 2 次发布

发布时间：2023-07-25 10:37:02

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [ImageToImage](https://cloud.tencent.com/document/api/1668/88066)

	* 新增入参：RspImgType

* [TextToImage](https://cloud.tencent.com/document/api/1668/88064)

	* 新增入参：RspImgType


### 第 1 次发布

发布时间：2023-03-09 15:10:44

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [ImageToImage](https://cloud.tencent.com/document/api/1668/88066)
* [TextToImage](https://cloud.tencent.com/document/api/1668/88064)

新增数据结构：

* [LogoParam](https://cloud.tencent.com/document/api/1668/88067#LogoParam)
* [LogoRect](https://cloud.tencent.com/document/api/1668/88067#LogoRect)
* [ResultConfig](https://cloud.tencent.com/document/api/1668/88067#ResultConfig)




## 正版曲库直通车(ame) 版本：2019-09-16

### 第 36 次发布

发布时间：2023-05-26 01:01:42

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [TRTCJoinRoomInput](https://cloud.tencent.com/document/api/1155/40113#TRTCJoinRoomInput)

	* 新增成员：RoomIdType


### 第 35 次发布

发布时间：2023-02-23 01:01:50

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [SyncKTVRobotCommand](https://cloud.tencent.com/document/api/1155/68348)

	* 新增入参：SetRealVolumeCommandInput


新增数据结构：

* [SetRealVolumeCommandInput](https://cloud.tencent.com/document/api/1155/40113#SetRealVolumeCommandInput)

修改数据结构：

* [KTVRobotInfo](https://cloud.tencent.com/document/api/1155/40113#KTVRobotInfo)

	* 新增成员：SetRealVolumeInput

* [SyncRobotCommand](https://cloud.tencent.com/document/api/1155/40113#SyncRobotCommand)

	* 新增成员：SetRealVolumeCommandInput


### 第 34 次发布

发布时间：2023-02-20 01:06:05

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [SetPlaylistCommandInput](https://cloud.tencent.com/document/api/1155/40113#SetPlaylistCommandInput)

	* 新增成员：MusicURLs

* [TRTCJoinRoomInput](https://cloud.tencent.com/document/api/1155/40113#TRTCJoinRoomInput)

	* 新增成员：PrivateMapKey, Role


### 第 33 次发布

发布时间：2022-04-15 06:01:25

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateKTVRobot](https://cloud.tencent.com/document/api/1155/68351)

	* 新增入参：SyncRobotCommands


新增数据结构：

* [SyncRobotCommand](https://cloud.tencent.com/document/api/1155/40113#SyncRobotCommand)

### 第 32 次发布

发布时间：2022-04-04 06:03:13

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeKTVPlaylists](https://cloud.tencent.com/document/api/1155/60295)

	* 新增入参：Type


### 第 31 次发布

发布时间：2022-03-21 08:06:03

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [SyncKTVRobotCommand](https://cloud.tencent.com/document/api/1155/68348)

	* 新增入参：SetVolumeCommandInput


新增数据结构：

* [SetVolumeCommandInput](https://cloud.tencent.com/document/api/1155/40113#SetVolumeCommandInput)

修改数据结构：

* [KTVRobotInfo](https://cloud.tencent.com/document/api/1155/40113#KTVRobotInfo)

	* 新增成员：SetVolumeInput


### 第 30 次发布

发布时间：2022-03-10 08:03:53

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeKTVMusicTags](https://cloud.tencent.com/document/api/1155/70856)
* [DescribeKTVSuggestions](https://cloud.tencent.com/document/api/1155/70855)

修改接口：

* [CreateKTVRobot](https://cloud.tencent.com/document/api/1155/68351)

	* 新增入参：ApplicationLicenseInput

* [SearchKTVMusics](https://cloud.tencent.com/document/api/1155/56401)

	* 新增入参：TagIds


新增数据结构：

* [ApplicationLicenseInput](https://cloud.tencent.com/document/api/1155/40113#ApplicationLicenseInput)
* [KTVMusicTagGroup](https://cloud.tencent.com/document/api/1155/40113#KTVMusicTagGroup)
* [KTVMusicTagInfo](https://cloud.tencent.com/document/api/1155/40113#KTVMusicTagInfo)
* [KTVSuggestionInfo](https://cloud.tencent.com/document/api/1155/40113#KTVSuggestionInfo)

### 第 29 次发布

发布时间：2022-02-28 08:05:12

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [SetPlaylistCommandInput](https://cloud.tencent.com/document/api/1155/40113#SetPlaylistCommandInput)

	* 新增成员：ChangedIndex

	* <font color="#dd0000">**修改成员**：</font>Index


### 第 28 次发布

发布时间：2022-02-25 08:03:09

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeKTVMusicDetail](https://cloud.tencent.com/document/api/1155/56402)

	* 新增出参：PreludeInterval


修改数据结构：

* [KTVMusicDetailInfo](https://cloud.tencent.com/document/api/1155/40113#KTVMusicDetailInfo)

	* 新增成员：PreludeInterval


### 第 27 次发布

发布时间：2022-02-23 08:01:52

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [BatchDescribeKTVMusicDetails](https://cloud.tencent.com/document/api/1155/70248)

新增数据结构：

* [KTVMusicDetailInfo](https://cloud.tencent.com/document/api/1155/40113#KTVMusicDetailInfo)

### 第 26 次发布

发布时间：2022-02-15 08:02:33

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [SyncKTVRobotCommand](https://cloud.tencent.com/document/api/1155/68348)

	* 新增入参：SetDestroyModeCommandInput


新增数据结构：

* [SetDestroyModeCommandInput](https://cloud.tencent.com/document/api/1155/40113#SetDestroyModeCommandInput)

### 第 25 次发布

发布时间：2022-02-14 08:04:52

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [SearchKTVMusics](https://cloud.tencent.com/document/api/1155/56401)

	* 新增入参：Sort


### 第 24 次发布

发布时间：2022-01-28 08:00:20

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeKTVTopList](https://cloud.tencent.com/document/api/1155/68908)

新增数据结构：

* [KTVMusicTopInfo](https://cloud.tencent.com/document/api/1155/40113#KTVMusicTopInfo)

### 第 23 次发布

发布时间：2022-01-27 08:04:32

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeKTVSingerCategories](https://cloud.tencent.com/document/api/1155/68860)
* [DescribeKTVSingerMusics](https://cloud.tencent.com/document/api/1155/68859)
* [DescribeKTVSingers](https://cloud.tencent.com/document/api/1155/68858)

修改接口：

* [DescribeKTVMusicDetail](https://cloud.tencent.com/document/api/1155/56402)

	* 新增出参：MidiJsonUrl, ChorusClipSet


新增数据结构：

* [ChorusClip](https://cloud.tencent.com/document/api/1155/40113#ChorusClip)
* [KTVSingerBaseInfo](https://cloud.tencent.com/document/api/1155/40113#KTVSingerBaseInfo)
* [KTVSingerCategoryInfo](https://cloud.tencent.com/document/api/1155/40113#KTVSingerCategoryInfo)
* [KTVSingerInfo](https://cloud.tencent.com/document/api/1155/40113#KTVSingerInfo)
* [SortBy](https://cloud.tencent.com/document/api/1155/40113#SortBy)

修改数据结构：

* [KTVMusicBaseInfo](https://cloud.tencent.com/document/api/1155/40113#KTVMusicBaseInfo)

	* 新增成员：SingerInfoSet


### 第 22 次发布

发布时间：2022-01-26 08:02:19

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeKTVRobots](https://cloud.tencent.com/document/api/1155/68350)

	* 新增入参：CreateTime


新增数据结构：

* [TimeRange](https://cloud.tencent.com/document/api/1155/40113#TimeRange)

### 第 21 次发布

发布时间：2022-01-24 08:04:15

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [SyncKTVRobotCommand](https://cloud.tencent.com/document/api/1155/68348)

	* 新增入参：SetPlayModeCommandInput


新增数据结构：

* [SetPlayModeCommandInput](https://cloud.tencent.com/document/api/1155/40113#SetPlayModeCommandInput)

修改数据结构：

* [KTVRobotInfo](https://cloud.tencent.com/document/api/1155/40113#KTVRobotInfo)

	* 新增成员：SetPlayModeInput


### 第 20 次发布

发布时间：2022-01-18 08:03:18

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateKTVRobot](https://cloud.tencent.com/document/api/1155/68351)
* [DescribeKTVRobots](https://cloud.tencent.com/document/api/1155/68350)
* [DestroyKTVRobot](https://cloud.tencent.com/document/api/1155/68349)
* [SyncKTVRobotCommand](https://cloud.tencent.com/document/api/1155/68348)

新增数据结构：

* [JoinRoomInput](https://cloud.tencent.com/document/api/1155/40113#JoinRoomInput)
* [KTVRobotInfo](https://cloud.tencent.com/document/api/1155/40113#KTVRobotInfo)
* [PlayCommandInput](https://cloud.tencent.com/document/api/1155/40113#PlayCommandInput)
* [SeekCommandInput](https://cloud.tencent.com/document/api/1155/40113#SeekCommandInput)
* [SendMessageCommandInput](https://cloud.tencent.com/document/api/1155/40113#SendMessageCommandInput)
* [SetAudioParamCommandInput](https://cloud.tencent.com/document/api/1155/40113#SetAudioParamCommandInput)
* [SetPlaylistCommandInput](https://cloud.tencent.com/document/api/1155/40113#SetPlaylistCommandInput)
* [TRTCJoinRoomInput](https://cloud.tencent.com/document/api/1155/40113#TRTCJoinRoomInput)

### 第 19 次发布

发布时间：2021-12-03 08:01:26

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [PackageItem](https://cloud.tencent.com/document/api/1155/40113#PackageItem)

	* 新增成员：Tags


### 第 18 次发布

发布时间：2021-10-13 08:02:42

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeKTVMusicDetail](https://cloud.tencent.com/document/api/1155/56402)

	* 新增出参：DefinitionInfoSet


新增数据结构：

* [KTVMusicDefinitionInfo](https://cloud.tencent.com/document/api/1155/40113#KTVMusicDefinitionInfo)

### 第 17 次发布

发布时间：2021-09-06 08:10:10

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribePkgOfflineMusic](https://cloud.tencent.com/document/api/1155/61164)

新增数据结构：

* [OfflineMusicDetail](https://cloud.tencent.com/document/api/1155/40113#OfflineMusicDetail)

### 第 16 次发布

发布时间：2021-08-25 08:10:23

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeMusicSaleStatus](https://cloud.tencent.com/document/api/1155/60689)

新增数据结构：

* [MusicStatus](https://cloud.tencent.com/document/api/1155/40113#MusicStatus)

### 第 15 次发布

发布时间：2021-08-24 08:11:45

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [DataInfo](https://cloud.tencent.com/document/api/1155/40113#DataInfo)

	* 新增成员：TagNames


### 第 14 次发布

发布时间：2021-08-17 08:10:54

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [MusicOpenDetail](https://cloud.tencent.com/document/api/1155/40113#MusicOpenDetail)

	* 新增成员：WaveformUrl


### 第 13 次发布

发布时间：2021-08-16 08:10:16

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeKTVPlaylistDetail](https://cloud.tencent.com/document/api/1155/60296)
* [DescribeKTVPlaylists](https://cloud.tencent.com/document/api/1155/60295)

新增数据结构：

* [KTVPlaylistBaseInfo](https://cloud.tencent.com/document/api/1155/40113#KTVPlaylistBaseInfo)

### 第 12 次发布

发布时间：2021-07-14 08:10:35

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [KTVMusicBaseInfo](https://cloud.tencent.com/document/api/1155/40113#KTVMusicBaseInfo)

	* 新增成员：Duration


### 第 11 次发布

发布时间：2021-06-22 08:11:20

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeKTVMusicDetail](https://cloud.tencent.com/document/api/1155/56402)

	* 新增出参：LyricsUrl


### 第 10 次发布

发布时间：2021-05-31 08:10:00

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeKTVMusicDetail](https://cloud.tencent.com/document/api/1155/56402)
* [SearchKTVMusics](https://cloud.tencent.com/document/api/1155/56401)

新增数据结构：

* [KTVMusicBaseInfo](https://cloud.tencent.com/document/api/1155/40113#KTVMusicBaseInfo)

### 第 9 次发布

发布时间：2021-05-28 08:09:40

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [MusicDetailInfo](https://cloud.tencent.com/document/api/1155/40113#MusicDetailInfo)

	* 新增成员：Scene, Region, AuthPeriod, Commercialization, Platform, Channel


### 第 8 次发布

发布时间：2021-04-27 08:10:58

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [ModifyMusicOnShelves](https://cloud.tencent.com/document/api/1155/54692)

	* 新增入参：AmeKey


### 第 7 次发布

发布时间：2021-04-14 08:09:38

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [ModifyMusicOnShelves](https://cloud.tencent.com/document/api/1155/54692)
* [PutMusicOnTheShelves](https://cloud.tencent.com/document/api/1155/54691)
* [TakeMusicOffShelves](https://cloud.tencent.com/document/api/1155/54690)

新增数据结构：

* [MusicDetailInfo](https://cloud.tencent.com/document/api/1155/40113#MusicDetailInfo)
* [TakeMusicOffShelves](https://cloud.tencent.com/document/api/1155/40113#TakeMusicOffShelves)

### 第 6 次发布

发布时间：2021-01-07 08:10:08

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeAuthInfo](https://cloud.tencent.com/document/api/1155/51791)
* [DescribeCloudMusic](https://cloud.tencent.com/document/api/1155/51790)
* [DescribeCloudMusicPurchased](https://cloud.tencent.com/document/api/1155/51789)

新增数据结构：

* [AuthInfo](https://cloud.tencent.com/document/api/1155/40113#AuthInfo)
* [MusicOpenDetail](https://cloud.tencent.com/document/api/1155/40113#MusicOpenDetail)

### 第 5 次发布

发布时间：2020-08-13 08:22:27

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribePackageItems](https://cloud.tencent.com/document/api/1155/47400)
* [DescribePackages](https://cloud.tencent.com/document/api/1155/47399)

新增数据结构：

* [Package](https://cloud.tencent.com/document/api/1155/40113#Package)
* [PackageItem](https://cloud.tencent.com/document/api/1155/40113#PackageItem)
* [UseRange](https://cloud.tencent.com/document/api/1155/40113#UseRange)

修改数据结构：

* [Item](https://cloud.tencent.com/document/api/1155/40113#Item)

	* 新增成员：Status


### 第 4 次发布

发布时间：2020-06-02 08:21:12

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeItemById](https://cloud.tencent.com/document/api/1155/45094)

### 第 3 次发布

发布时间：2020-02-18 14:36:11

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [Music](https://cloud.tencent.com/document/api/1155/40113#Music)

	* 新增成员：FullUrl


### 第 2 次发布

发布时间：2020-01-15 21:47:50

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [ReportData](https://cloud.tencent.com/document/api/1155/41114)

### 第 1 次发布

发布时间：2019-12-05 20:17:39

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeItems](https://cloud.tencent.com/document/api/1155/40112)
* [DescribeLyric](https://cloud.tencent.com/document/api/1155/40111)
* [DescribeMusic](https://cloud.tencent.com/document/api/1155/40110)
* [DescribeStations](https://cloud.tencent.com/document/api/1155/40109)

新增数据结构：

* [Album](https://cloud.tencent.com/document/api/1155/40113#Album)
* [Artist](https://cloud.tencent.com/document/api/1155/40113#Artist)
* [DataInfo](https://cloud.tencent.com/document/api/1155/40113#DataInfo)
* [ImagePath](https://cloud.tencent.com/document/api/1155/40113#ImagePath)
* [Item](https://cloud.tencent.com/document/api/1155/40113#Item)
* [Lyric](https://cloud.tencent.com/document/api/1155/40113#Lyric)
* [Music](https://cloud.tencent.com/document/api/1155/40113#Music)
* [Station](https://cloud.tencent.com/document/api/1155/40113#Station)




## 音频内容安全(ams) 版本：2020-06-08

### 第 8 次发布

发布时间：2021-01-07 08:00:32

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [AmsDetailInfo](https://cloud.tencent.com/document/api/1219/46478#AmsDetailInfo)

	* 新增成员：Status


### 第 7 次发布

发布时间：2020-12-18 15:18:40

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [MediaInfo](https://cloud.tencent.com/document/api/1219/46478#MediaInfo)

	* 新增成员：Thumbnail


### 第 6 次发布

发布时间：2020-12-16 08:01:02

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeAmsList](https://cloud.tencent.com/document/api/1219/51007)
* [DescribeAudioStat](https://cloud.tencent.com/document/api/1219/51006)

新增数据结构：

* [AmsDetailInfo](https://cloud.tencent.com/document/api/1219/46478#AmsDetailInfo)
* [EvilCount](https://cloud.tencent.com/document/api/1219/46478#EvilCount)
* [Filter](https://cloud.tencent.com/document/api/1219/46478#Filter)
* [Filters](https://cloud.tencent.com/document/api/1219/46478#Filters)
* [Overview](https://cloud.tencent.com/document/api/1219/46478#Overview)
* [TrendCount](https://cloud.tencent.com/document/api/1219/46478#TrendCount)

### 第 5 次发布

发布时间：2020-09-28 08:00:20

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CancelTask](https://cloud.tencent.com/document/api/1219/48801)

### 第 4 次发布

发布时间：2020-08-07 08:00:32

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeTaskDetail](https://cloud.tencent.com/document/api/1219/46476)

	* 新增出参：AudioText


### 第 3 次发布

发布时间：2020-07-27 11:46:05

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateBizConfig](https://cloud.tencent.com/document/api/1219/46889)
* [DescribeBizConfig](https://cloud.tencent.com/document/api/1219/46888)

新增数据结构：

* [FileOutput](https://cloud.tencent.com/document/api/1219/46478#FileOutput)
* [MediaModerationConfig](https://cloud.tencent.com/document/api/1219/46478#MediaModerationConfig)

### 第 2 次发布

发布时间：2020-07-27 08:00:20

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [AudioResultDetailLanguageResult](https://cloud.tencent.com/document/api/1219/46478#AudioResultDetailLanguageResult)

	* 新增成员：SubLabelCode

* [AudioResultDetailMoanResult](https://cloud.tencent.com/document/api/1219/46478#AudioResultDetailMoanResult)

	* 新增成员：SubLabelCode

* [ImageResultsResultDetail](https://cloud.tencent.com/document/api/1219/46478#ImageResultsResultDetail)

	* 新增成员：SubLabelCode


### 第 1 次发布

发布时间：2020-07-20 10:46:48

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateAudioModerationTask](https://cloud.tencent.com/document/api/1219/46477)
* [DescribeTaskDetail](https://cloud.tencent.com/document/api/1219/46476)

新增数据结构：

* [AudioResult](https://cloud.tencent.com/document/api/1219/46478#AudioResult)
* [AudioResultDetailLanguageResult](https://cloud.tencent.com/document/api/1219/46478#AudioResultDetailLanguageResult)
* [AudioResultDetailMoanResult](https://cloud.tencent.com/document/api/1219/46478#AudioResultDetailMoanResult)
* [AudioResultDetailTextResult](https://cloud.tencent.com/document/api/1219/46478#AudioResultDetailTextResult)
* [AudioSegments](https://cloud.tencent.com/document/api/1219/46478#AudioSegments)
* [BucketInfo](https://cloud.tencent.com/document/api/1219/46478#BucketInfo)
* [ImageResult](https://cloud.tencent.com/document/api/1219/46478#ImageResult)
* [ImageResultResult](https://cloud.tencent.com/document/api/1219/46478#ImageResultResult)
* [ImageResultsResultDetail](https://cloud.tencent.com/document/api/1219/46478#ImageResultsResultDetail)
* [ImageResultsResultDetailLocation](https://cloud.tencent.com/document/api/1219/46478#ImageResultsResultDetailLocation)
* [ImageSegments](https://cloud.tencent.com/document/api/1219/46478#ImageSegments)
* [InputInfo](https://cloud.tencent.com/document/api/1219/46478#InputInfo)
* [MediaInfo](https://cloud.tencent.com/document/api/1219/46478#MediaInfo)
* [StorageInfo](https://cloud.tencent.com/document/api/1219/46478#StorageInfo)
* [TaskInput](https://cloud.tencent.com/document/api/1219/46478#TaskInput)
* [TaskLabel](https://cloud.tencent.com/document/api/1219/46478#TaskLabel)
* [TaskResult](https://cloud.tencent.com/document/api/1219/46478#TaskResult)



## 音频内容安全(ams) 版本：2020-12-29

### 第 11 次发布

发布时间：2024-07-26 01:08:05

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeTaskDetail](https://cloud.tencent.com/document/api/1219/53256)

	* 新增出参：MediaInfo


新增数据结构：

* [LabelResults](https://cloud.tencent.com/document/api/1219/53259#LabelResults)
* [SpeakerResults](https://cloud.tencent.com/document/api/1219/53259#SpeakerResults)
* [TravelResults](https://cloud.tencent.com/document/api/1219/53259#TravelResults)

修改数据结构：

* [AudioResult](https://cloud.tencent.com/document/api/1219/53259#AudioResult)

	* 新增成员：SpeakerResults, LabelResults, TravelResults

* [AudioResultDetailMoanResult](https://cloud.tencent.com/document/api/1219/53259#AudioResultDetailMoanResult)

* [AudioSegments](https://cloud.tencent.com/document/api/1219/53259#AudioSegments)

	* 新增成员：CreatedAt

* [TaskData](https://cloud.tencent.com/document/api/1219/53259#TaskData)

	* 新增成员：InputInfo


### 第 10 次发布

发布时间：2023-12-22 01:06:11

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateAudioModerationTask](https://cloud.tencent.com/document/api/1219/53257)

	* 新增入参：User


新增数据结构：

* [User](https://cloud.tencent.com/document/api/1219/53259#User)

### 第 9 次发布

发布时间：2022-12-29 10:01:58

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateAudioModerationSyncTask](https://cloud.tencent.com/document/api/1219/56755)

	* 新增出参：Duration


### 第 8 次发布

发布时间：2022-08-16 06:06:52

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [AudioResultDetailMoanResult](https://cloud.tencent.com/document/api/1219/53259#AudioResultDetailMoanResult)

	* 新增成员：Suggestion


### 第 7 次发布

发布时间：2022-08-15 06:07:00

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateAudioModerationSyncTask](https://cloud.tencent.com/document/api/1219/56755)

	* 新增出参：SubLabel, LanguageResults, SpeakerResults, RecognitionResults


新增数据结构：

* [AudioResultDetailSpeakerResult](https://cloud.tencent.com/document/api/1219/53259#AudioResultDetailSpeakerResult)

### 第 6 次发布

发布时间：2022-06-17 06:02:19

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeTaskDetail](https://cloud.tencent.com/document/api/1219/53256)

	* 新增出参：Label


### 第 5 次发布

发布时间：2022-06-09 06:05:24

本次发布包含了以下内容：

改善已有的文档。

新增数据结构：

* [RecognitionResult](https://cloud.tencent.com/document/api/1219/53259#RecognitionResult)
* [Tag](https://cloud.tencent.com/document/api/1219/53259#Tag)

修改数据结构：

* [AudioResult](https://cloud.tencent.com/document/api/1219/53259#AudioResult)

	* 新增成员：RecognitionResults


### 第 4 次发布

发布时间：2022-04-01 06:03:20

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [MoanResult](https://cloud.tencent.com/document/api/1219/53259#MoanResult)

	* 新增成员：SubLabel

* [TextResult](https://cloud.tencent.com/document/api/1219/53259#TextResult)

	* 新增成员：SubLabel


### 第 3 次发布

发布时间：2021-12-20 08:02:28

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [AudioResult](https://cloud.tencent.com/document/api/1219/53259#AudioResult)

	* 新增成员：SubLabel

* [AudioResultDetailMoanResult](https://cloud.tencent.com/document/api/1219/53259#AudioResultDetailMoanResult)

	* 新增成员：SubLabel

* [AudioResultDetailTextResult](https://cloud.tencent.com/document/api/1219/53259#AudioResultDetailTextResult)

	* 新增成员：SubLabel

* [TaskLabel](https://cloud.tencent.com/document/api/1219/53259#TaskLabel)

	* 新增成员：SubLabel


### 第 2 次发布

发布时间：2021-06-04 16:38:43

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateAudioModerationSyncTask](https://cloud.tencent.com/document/api/1219/56755)

新增数据结构：

* [MoanResult](https://cloud.tencent.com/document/api/1219/53259#MoanResult)
* [TextResult](https://cloud.tencent.com/document/api/1219/53259#TextResult)

### 第 1 次发布

发布时间：2021-02-01 08:00:37

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CancelTask](https://cloud.tencent.com/document/api/1219/53258)
* [CreateAudioModerationTask](https://cloud.tencent.com/document/api/1219/53257)
* [DescribeTaskDetail](https://cloud.tencent.com/document/api/1219/53256)
* [DescribeTasks](https://cloud.tencent.com/document/api/1219/53255)

新增数据结构：

* [AudioResult](https://cloud.tencent.com/document/api/1219/53259#AudioResult)
* [AudioResultDetailLanguageResult](https://cloud.tencent.com/document/api/1219/53259#AudioResultDetailLanguageResult)
* [AudioResultDetailMoanResult](https://cloud.tencent.com/document/api/1219/53259#AudioResultDetailMoanResult)
* [AudioResultDetailTextResult](https://cloud.tencent.com/document/api/1219/53259#AudioResultDetailTextResult)
* [AudioSegments](https://cloud.tencent.com/document/api/1219/53259#AudioSegments)
* [BucketInfo](https://cloud.tencent.com/document/api/1219/53259#BucketInfo)
* [InputInfo](https://cloud.tencent.com/document/api/1219/53259#InputInfo)
* [MediaInfo](https://cloud.tencent.com/document/api/1219/53259#MediaInfo)
* [StorageInfo](https://cloud.tencent.com/document/api/1219/53259#StorageInfo)
* [TaskData](https://cloud.tencent.com/document/api/1219/53259#TaskData)
* [TaskFilter](https://cloud.tencent.com/document/api/1219/53259#TaskFilter)
* [TaskInput](https://cloud.tencent.com/document/api/1219/53259#TaskInput)
* [TaskLabel](https://cloud.tencent.com/document/api/1219/53259#TaskLabel)
* [TaskResult](https://cloud.tencent.com/document/api/1219/53259#TaskResult)




## 动效素材服务(anicloud) 版本：2022-09-23

### 第 1 次发布

发布时间：2022-12-21 17:12:35

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CheckAppidExist](https://cloud.tencent.com/document/api/1641/84445)
* [QueryResource](https://cloud.tencent.com/document/api/1641/84444)
* [QueryResourceInfo](https://cloud.tencent.com/document/api/1641/84443)

新增数据结构：

* [GoodsDetail](https://cloud.tencent.com/document/api/1641/84446#GoodsDetail)
* [Resource](https://cloud.tencent.com/document/api/1641/84446#Resource)




## T-Sec-DDoS防护(Anti-DDoS)(antiddos) 版本：2020-03-09

### 第 67 次发布

发布时间：2024-06-04 01:07:52

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeListBGPInstances](https://cloud.tencent.com/document/api/297/95346)

	* 新增入参：FilterZoneIdList


修改数据结构：

* [BGPInstance](https://cloud.tencent.com/document/api/297/95396#BGPInstance)

	* 新增成员：ZoneId


### 第 66 次发布

发布时间：2024-04-19 01:07:51

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeListBGPInstances](https://cloud.tencent.com/document/api/297/95346)

	* 新增入参：FilterTransRegionFlag


修改数据结构：

* [BGPInstance](https://cloud.tencent.com/document/api/297/95396#BGPInstance)

	* 新增成员：TransRegionFlag


### 第 65 次发布

发布时间：2024-04-12 01:07:18

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [BGPInstance](https://cloud.tencent.com/document/api/297/95396#BGPInstance)

	* 新增成员：SuperPackFlag


### 第 64 次发布

发布时间：2024-01-19 01:06:05

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeBGPIPL7Rules](https://cloud.tencent.com/document/api/297/103093)

新增数据结构：

* [BGPIPL7RuleEntry](https://cloud.tencent.com/document/api/297/95396#BGPIPL7RuleEntry)

### 第 63 次发布

发布时间：2024-01-12 01:06:10

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeListBGPInstances](https://cloud.tencent.com/document/api/297/95346)

	* 新增入参：FilterPlanCntFlag


修改数据结构：

* [BGPInstance](https://cloud.tencent.com/document/api/297/95396#BGPInstance)

	* 新增成员：PlanCntFlag


### 第 62 次发布

发布时间：2023-12-13 01:06:45

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeIpBlockList](https://cloud.tencent.com/document/api/297/102444)

新增数据结构：

* [IpBlockData](https://cloud.tencent.com/document/api/297/95396#IpBlockData)

### 第 61 次发布

发布时间：2023-11-28 01:06:04

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeBasicDeviceStatus](https://cloud.tencent.com/document/api/297/95386)

	* 新增入参：CnameWafIdList

	* 新增出参：CnameWafData


### 第 60 次发布

发布时间：2023-10-10 01:05:53

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [BGPInstance](https://cloud.tencent.com/document/api/297/95396#BGPInstance)

	* 新增成员：FreeServiceBandwidth

	* <font color="#dd0000">**修改成员**：</font>GiftServiceBandWidth, ModifyTime, BasicPlusFlag


### 第 59 次发布

发布时间：2023-09-19 01:05:58

本次发布包含了以下内容：

改善已有的文档。

<font color="#dd0000">**预下线接口**：</font>

* DescribeBlackWhiteIpList
* DescribeListProtectThresholdConfig

### 第 58 次发布

发布时间：2023-07-26 01:01:23

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeBizMonitorTrend](https://cloud.tencent.com/document/api/297/95517)

### 第 57 次发布

发布时间：2023-06-27 01:01:43

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeListBGPInstances](https://cloud.tencent.com/document/api/297/95346)

	* 新增入参：FilterBasicPlusFlag


修改数据结构：

* [BGPInstance](https://cloud.tencent.com/document/api/297/95396#BGPInstance)

	* 新增成员：BasicPlusFlag


### 第 56 次发布

发布时间：2023-05-19 01:02:07

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateBoundIP](https://cloud.tencent.com/document/api/297/95349)

	* 新增入参：FilterRegion

* [DescribeBasicDeviceStatus](https://cloud.tencent.com/document/api/297/95386)

	* 新增入参：IdList, FilterRegion

	* <font color="#dd0000">**修改入参**：</font>IpList

	* 新增出参：CLBData

* [DescribeNewL7Rules](https://cloud.tencent.com/document/api/297/95344)

	* 新增入参：Export


修改数据结构：

* [BoundIpInfo](https://cloud.tencent.com/document/api/297/95396#BoundIpInfo)

	* 新增成员：Domain


### 第 55 次发布

发布时间：2023-04-21 01:01:52

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeBizTrend](https://cloud.tencent.com/document/api/297/95359)

	* 新增入参：BusinessType

	* 新增出参：MaxData

* [DescribeListBGPInstances](https://cloud.tencent.com/document/api/297/95346)

	* 新增入参：FilterAssetIpList

* [DescribeListSchedulingDomain](https://cloud.tencent.com/document/api/297/95364)

	* 新增入参：Status

* [DescribeOverviewCCTrend](https://cloud.tencent.com/document/api/297/95355)

	* <font color="#dd0000">**修改入参**：</font>Business

* [DescribeOverviewDDoSTrend](https://cloud.tencent.com/document/api/297/95353)

	* <font color="#dd0000">**修改入参**：</font>Business


修改数据结构：

* [BGPInstance](https://cloud.tencent.com/document/api/297/95396#BGPInstance)

	* 新增成员：ModifyTime

* [EipProductInfo](https://cloud.tencent.com/document/api/297/95396#EipProductInfo)

	* 新增成员：Domain

* [IPLineInfo](https://cloud.tencent.com/document/api/297/95396#IPLineInfo)

	* 新增成员：Domain


### 第 54 次发布

发布时间：2023-03-10 01:01:32

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [BGPInstanceSpecification](https://cloud.tencent.com/document/api/297/95396#BGPInstanceSpecification)

	* 新增成员：DownGradeProtect


### 第 53 次发布

发布时间：2023-02-22 01:02:37

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [BGPInstance](https://cloud.tencent.com/document/api/297/95396#BGPInstance)

	* 新增成员：GiftServiceBandWidth


### 第 52 次发布

发布时间：2023-02-10 01:02:06

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [Layer7Rule](https://cloud.tencent.com/document/api/297/95396#Layer7Rule)

	* 新增成员：Protocol, Vport

* [SourceServer](https://cloud.tencent.com/document/api/297/95396#SourceServer)

	* 新增成员：Port


### 第 51 次发布

发布时间：2023-01-13 01:02:31

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeListBGPInstances](https://cloud.tencent.com/document/api/297/95346)

	* 新增入参：ExcludeAdvancedInfo


修改数据结构：

* [L7RuleHealth](https://cloud.tencent.com/document/api/297/95396#L7RuleHealth)

	* 新增成员：PassiveStatus


### 第 50 次发布

发布时间：2023-01-06 01:02:00

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [BGPIPInstance](https://cloud.tencent.com/document/api/297/95396#BGPIPInstance)

	* 新增成员：ElasticBandwidth, EOFlag

* [NewL7RuleEntry](https://cloud.tencent.com/document/api/297/95396#NewL7RuleEntry)

	* 新增成员：Version


### 第 49 次发布

发布时间：2022-12-20 11:47:08

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeBizHttpStatus](https://cloud.tencent.com/document/api/297/95360)

新增数据结构：

* [HttpStatusMap](https://cloud.tencent.com/document/api/297/95396#HttpStatusMap)

### 第 48 次发布

发布时间：2022-12-16 01:05:43

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [SwitchWaterPrintConfig](https://cloud.tencent.com/document/api/297/95299)

	* 新增入参：CloudSdkProxy


修改数据结构：

* [BGPInstance](https://cloud.tencent.com/document/api/297/95396#BGPInstance)

	* 新增成员：Line, ElasticServiceBandwidth

* [WaterPrintConfig](https://cloud.tencent.com/document/api/297/95396#WaterPrintConfig)

	* 新增成员：CloudSdkProxy


### 第 47 次发布

发布时间：2022-12-12 01:06:27

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeListBGPIPInstances](https://cloud.tencent.com/document/api/297/95347)

	* 新增入参：FilterConvoy

* [DescribeListBGPInstances](https://cloud.tencent.com/document/api/297/95346)

	* 新增入参：FilterTrialFlag, FilterConvoy


修改数据结构：

* [BGPIPInstance](https://cloud.tencent.com/document/api/297/95396#BGPIPInstance)

	* 新增成员：ConvoyId


### 第 46 次发布

发布时间：2022-11-23 06:03:44

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [ModifyDDoSThreshold](https://cloud.tencent.com/document/api/297/95394)

	* 新增入参：AckFloodThreshold, AckFloodPktThreshold, SynAckFloodThreshold, SynAckFloodPktThreshold, RstFloodThreshold, RstFloodPktThreshold


修改数据结构：

* [ProtectThresholdRelation](https://cloud.tencent.com/document/api/297/95396#ProtectThresholdRelation)

	* 新增成员：AckFloodThreshold, AckFloodPktThreshold, SynAckFloodThreshold, SynAckFloodPktThreshold, RstFloodThreshold, RstFloodPktThreshold


### 第 45 次发布

发布时间：2022-11-09 06:08:09

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [ModifyDDoSThreshold](https://cloud.tencent.com/document/api/297/95394)

	* 新增入参：OtherThresholdFlag, SynFloodThreshold, SynFloodPktThreshold, UdpFloodThreshold, UdpFloodPktThreshold


修改数据结构：

* [PacketFilterConfig](https://cloud.tencent.com/document/api/297/95396#PacketFilterConfig)

	* 新增成员：PktLenGT

* [ProtectThresholdRelation](https://cloud.tencent.com/document/api/297/95396#ProtectThresholdRelation)

	* 新增成员：SynFloodThreshold, SynFloodPktThreshold, UdpFloodThreshold, UdpFloodPktThreshold

* [ProtocolBlockConfig](https://cloud.tencent.com/document/api/297/95396#ProtocolBlockConfig)

	* 新增成员：PingOfDeath, TearDrop


### 第 44 次发布

发布时间：2022-11-01 06:06:58

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribePendingRiskInfo](https://cloud.tencent.com/document/api/297/95351)

### 第 43 次发布

发布时间：2022-10-26 06:07:49

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeListBGPInstances](https://cloud.tencent.com/document/api/297/95346)

	* 新增入参：FilterLightFlag, FilterChannelFlag


### 第 42 次发布

发布时间：2022-09-12 06:07:03

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [BGPInstance](https://cloud.tencent.com/document/api/297/95396#BGPInstance)

	* 新增成员：VitalityVersion


### 第 41 次发布

发布时间：2022-09-06 06:07:26

本次发布包含了以下内容：

改善已有的文档。

<font color="#dd0000">**删除接口**：</font>

* ModifyL7RulesEdge

### 第 40 次发布

发布时间：2022-08-29 13:11:21

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeNewL7RulesErrHealth](https://cloud.tencent.com/document/api/297/95368)

### 第 39 次发布

发布时间：2022-08-09 10:41:42

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeBgpBizTrend](https://cloud.tencent.com/document/api/297/95361)

<font color="#dd0000">**删除接口**：</font>

* DeleteBlackWhiteIpList

### 第 38 次发布

发布时间：2022-07-27 06:03:19

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [BGPIPInstance](https://cloud.tencent.com/document/api/297/95396#BGPIPInstance)

	* 新增成员：InstanceVersion

* [L4RuleSource](https://cloud.tencent.com/document/api/297/95396#L4RuleSource)

	* 新增成员：Backup

* [L7RuleHealth](https://cloud.tencent.com/document/api/297/95396#L7RuleHealth)

	* 新增成员：ProtocolFlag, PassiveEnable, BlockInter, FailedCountInter, FailedThreshold, PassiveStatusCode


### 第 37 次发布

发布时间：2022-07-15 06:03:07

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [L7RuleEntry](https://cloud.tencent.com/document/api/297/95396#L7RuleEntry)

	* 新增成员：CCAIEnable


### 第 36 次发布

发布时间：2022-07-11 11:21:01

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateNewL7Rules](https://cloud.tencent.com/document/api/297/95369)

### 第 35 次发布

发布时间：2022-07-11 06:05:26

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeNewL7Rules](https://cloud.tencent.com/document/api/297/95344)

新增数据结构：

* [L7RuleHealth](https://cloud.tencent.com/document/api/297/95396#L7RuleHealth)

### 第 34 次发布

发布时间：2022-07-01 06:05:20

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeListBGPIPInstances](https://cloud.tencent.com/document/api/297/95347)

	* 新增入参：FilterPackType


新增数据结构：

* [AnycastOutPackRelation](https://cloud.tencent.com/document/api/297/95396#AnycastOutPackRelation)

修改数据结构：

* [BGPIPInstance](https://cloud.tencent.com/document/api/297/95396#BGPIPInstance)

	* 新增成员：AnycastOutPackRelation

* [BGPInstance](https://cloud.tencent.com/document/api/297/95396#BGPInstance)

	* 新增成员：IpCountNewFlag


### 第 33 次发布

发布时间：2022-06-16 06:00:42

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateCCReqLimitPolicy](https://cloud.tencent.com/document/api/297/95391)

	* 新增入参：IsGlobal

* [DescribeListBGPIPInstances](https://cloud.tencent.com/document/api/297/95347)

	* 新增入参：FilterTag

* [DescribeListBGPInstances](https://cloud.tencent.com/document/api/297/95346)

	* 新增入参：FilterTag


新增数据结构：

* [TagFilter](https://cloud.tencent.com/document/api/297/95396#TagFilter)
* [TagInfo](https://cloud.tencent.com/document/api/297/95396#TagInfo)

修改数据结构：

* [BGPIPInstance](https://cloud.tencent.com/document/api/297/95396#BGPIPInstance)

	* 新增成员：TagInfoList

* [BGPInstance](https://cloud.tencent.com/document/api/297/95396#BGPInstance)

	* 新增成员：TagInfoList

* [BlackWhiteIpRelation](https://cloud.tencent.com/document/api/297/95396#BlackWhiteIpRelation)

	* 新增成员：ModifyTime

* [PacketFilterRelation](https://cloud.tencent.com/document/api/297/95396#PacketFilterRelation)

	* 新增成员：ModifyTime


### 第 32 次发布

发布时间：2022-05-17 06:03:35

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeListBGPInstances](https://cloud.tencent.com/document/api/297/95346)

	* 新增入参：FilterEnterpriseFlag


### 第 31 次发布

发布时间：2022-05-12 06:05:03

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeOverviewDDoSEventList](https://cloud.tencent.com/document/api/297/95354)

修改接口：

* [DescribeListBGPIPInstances](https://cloud.tencent.com/document/api/297/95347)

	* 新增入参：FilterCname, FilterInstanceIdList

* [DescribeListIPAlarmConfig](https://cloud.tencent.com/document/api/297/95372)

	* 新增入参：FilterCname


新增数据结构：

* [OverviewDDoSEvent](https://cloud.tencent.com/document/api/297/95396#OverviewDDoSEvent)

修改数据结构：

* [BGPIPInstance](https://cloud.tencent.com/document/api/297/95396#BGPIPInstance)

	* 新增成员：BGPIPChannelFlag

* [BGPInstanceSpecification](https://cloud.tencent.com/document/api/297/95396#BGPInstanceSpecification)

	* 新增成员：EnterpriseFlag, ElasticLimit

* [IPLineInfo](https://cloud.tencent.com/document/api/297/95396#IPLineInfo)

	* 新增成员：Cname, ResourceFlag


### 第 30 次发布

发布时间：2022-05-11 06:03:57

本次发布包含了以下内容：

改善已有的文档。

新增数据结构：

* [RuleInstanceRelation](https://cloud.tencent.com/document/api/297/95396#RuleInstanceRelation)

修改数据结构：

* [Layer4Rule](https://cloud.tencent.com/document/api/297/95396#Layer4Rule)

	* 新增成员：InstanceDetailRule

* [Layer7Rule](https://cloud.tencent.com/document/api/297/95396#Layer7Rule)

	* 新增成员：InstanceDetailRule


### 第 29 次发布

发布时间：2022-05-06 06:04:11

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeOverviewAttackTrend](https://cloud.tencent.com/document/api/297/95356)
* [DescribeOverviewCCTrend](https://cloud.tencent.com/document/api/297/95355)
* [DescribeOverviewDDoSTrend](https://cloud.tencent.com/document/api/297/95353)
* [DescribeOverviewIndex](https://cloud.tencent.com/document/api/297/95352)

### 第 28 次发布

发布时间：2022-04-26 06:04:03

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [BGPInstanceSpecification](https://cloud.tencent.com/document/api/297/95396#BGPInstanceSpecification)

	* 新增成员：BattleEditionFlag, ChannelEditionFlag


### 第 27 次发布

发布时间：2022-04-18 06:05:37

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [NewL7RuleEntry](https://cloud.tencent.com/document/api/297/95396#NewL7RuleEntry)

	* 新增成员：RewriteHttps, ErrCode


### 第 26 次发布

发布时间：2022-04-07 06:04:07

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateSchedulingDomain](https://cloud.tencent.com/document/api/297/95365)

	* 新增入参：Product


### 第 25 次发布

发布时间：2022-03-24 23:15:57

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeListBGPInstances](https://cloud.tencent.com/document/api/297/95346)

	* 新增入参：FilterInstanceIdList


修改数据结构：

* [BGPInstanceSpecification](https://cloud.tencent.com/document/api/297/95396#BGPInstanceSpecification)

	* 新增成员：ServiceBandWidth


### 第 24 次发布

发布时间：2022-03-15 08:03:22

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [BGPInstanceSpecification](https://cloud.tencent.com/document/api/297/95396#BGPInstanceSpecification)

	* 新增成员：UnionPackFlag


### 第 23 次发布

发布时间：2022-03-02 08:04:36

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateCcBlackWhiteIpList](https://cloud.tencent.com/document/api/297/95341)
* [DeleteCCLevelPolicy](https://cloud.tencent.com/document/api/297/95390)
* [DeleteCCThresholdPolicy](https://cloud.tencent.com/document/api/297/95387)
* [DescribeCCLevelList](https://cloud.tencent.com/document/api/297/95385)
* [DescribeCCLevelPolicy](https://cloud.tencent.com/document/api/297/95384)
* [DescribeCCThresholdList](https://cloud.tencent.com/document/api/297/95381)

新增数据结构：

* [CCLevelPolicy](https://cloud.tencent.com/document/api/297/95396#CCLevelPolicy)
* [CCThresholdPolicy](https://cloud.tencent.com/document/api/297/95396#CCThresholdPolicy)

### 第 22 次发布

发布时间：2022-02-28 08:05:20

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [AssociateDDoSEipLoadBalancer](https://cloud.tencent.com/document/api/297/95296)

	* 新增入参：Vip


### 第 21 次发布

发布时间：2022-02-14 08:04:59

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateCCPrecisionPolicy](https://cloud.tencent.com/document/api/297/95392)
* [CreateCCReqLimitPolicy](https://cloud.tencent.com/document/api/297/95391)
* [CreateCcGeoIPBlockConfig](https://cloud.tencent.com/document/api/297/95340)
* [DeleteCCPrecisionPolicy](https://cloud.tencent.com/document/api/297/95389)
* [DeleteCCRequestLimitPolicy](https://cloud.tencent.com/document/api/297/95388)
* [DeleteCcBlackWhiteIpList](https://cloud.tencent.com/document/api/297/95328)
* [DeleteCcGeoIPBlockConfig](https://cloud.tencent.com/document/api/297/95327)
* [DeletePortAclConfig](https://cloud.tencent.com/document/api/297/95322)
* [DescribeCCPrecisionPlyList](https://cloud.tencent.com/document/api/297/95383)
* [DescribeCCReqLimitPolicyList](https://cloud.tencent.com/document/api/297/95382)
* [DescribeCcBlackWhiteIpList](https://cloud.tencent.com/document/api/297/95318)
* [DescribeCcGeoIPBlockConfigList](https://cloud.tencent.com/document/api/297/95317)
* [ModifyCCLevelPolicy](https://cloud.tencent.com/document/api/297/95380)
* [ModifyCCPrecisionPolicy](https://cloud.tencent.com/document/api/297/95379)
* [ModifyCCReqLimitPolicy](https://cloud.tencent.com/document/api/297/95378)
* [ModifyCCThresholdPolicy](https://cloud.tencent.com/document/api/297/95377)
* [ModifyCcBlackWhiteIpList](https://cloud.tencent.com/document/api/297/95305)
* [ModifyDDoSBlackWhiteIpList](https://cloud.tencent.com/document/api/297/95304)
* [ModifyDDoSLevel](https://cloud.tencent.com/document/api/297/95395)
* [ModifyDDoSThreshold](https://cloud.tencent.com/document/api/297/95394)
* [ModifyPortAclConfig](https://cloud.tencent.com/document/api/297/95300)

新增数据结构：

* [CCPrecisionPlyRecord](https://cloud.tencent.com/document/api/297/95396#CCPrecisionPlyRecord)
* [CCPrecisionPolicy](https://cloud.tencent.com/document/api/297/95396#CCPrecisionPolicy)
* [CCReqLimitPolicy](https://cloud.tencent.com/document/api/297/95396#CCReqLimitPolicy)
* [CCReqLimitPolicyRecord](https://cloud.tencent.com/document/api/297/95396#CCReqLimitPolicyRecord)
* [CcBlackWhiteIpPolicy](https://cloud.tencent.com/document/api/297/95396#CcBlackWhiteIpPolicy)
* [CcGeoIPBlockConfig](https://cloud.tencent.com/document/api/297/95396#CcGeoIPBlockConfig)
* [CcGeoIpPolicyNew](https://cloud.tencent.com/document/api/297/95396#CcGeoIpPolicyNew)

### 第 20 次发布

发布时间：2022-01-19 08:04:47

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeDDoSConnectLimitList](https://cloud.tencent.com/document/api/297/95315)
* [DescribeListPortAclList](https://cloud.tencent.com/document/api/297/95309)

新增数据结构：

* [AclConfigRelation](https://cloud.tencent.com/document/api/297/95396#AclConfigRelation)
* [ConnectLimitRelation](https://cloud.tencent.com/document/api/297/95396#ConnectLimitRelation)

### 第 19 次发布

发布时间：2022-01-18 08:03:27

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateDDoSConnectLimit](https://cloud.tencent.com/document/api/297/95337)

新增数据结构：

* [ConnectLimitConfig](https://cloud.tencent.com/document/api/297/95396#ConnectLimitConfig)

### 第 18 次发布

发布时间：2022-01-17 08:02:24

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreatePortAclConfig](https://cloud.tencent.com/document/api/297/95333)
* [CreatePortAclConfigList](https://cloud.tencent.com/document/api/297/95332)

新增数据结构：

* [AclConfig](https://cloud.tencent.com/document/api/297/95396#AclConfig)

### 第 17 次发布

发布时间：2021-12-20 17:09:09

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateDDoSBlackWhiteIpList](https://cloud.tencent.com/document/api/297/95338)
* [DeleteDDoSBlackWhiteIpList](https://cloud.tencent.com/document/api/297/95326)
* [DescribeDDoSBlackWhiteIpList](https://cloud.tencent.com/document/api/297/95316)

新增数据结构：

* [IpSegment](https://cloud.tencent.com/document/api/297/95396#IpSegment)

### 第 16 次发布

发布时间：2021-12-15 08:02:37

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeListBGPIPInstances](https://cloud.tencent.com/document/api/297/95347)

	* 新增入参：FilterStatus

* [DescribeListBGPInstances](https://cloud.tencent.com/document/api/297/95346)

	* 新增入参：FilterStatus, FilterBoundStatus


### 第 15 次发布

发布时间：2021-12-02 08:02:10

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [BGPIPInstance](https://cloud.tencent.com/document/api/297/95396#BGPIPInstance)

	* 新增成员：V6Flag


### 第 14 次发布

发布时间：2021-11-23 08:02:33

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [ModifyNewDomainRules](https://cloud.tencent.com/document/api/297/95367)

新增数据结构：

* [NewL7RuleEntry](https://cloud.tencent.com/document/api/297/95396#NewL7RuleEntry)

### 第 13 次发布

发布时间：2021-11-22 08:01:25

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeListBGPIPInstances](https://cloud.tencent.com/document/api/297/95347)

	* 新增入参：FilterDamDDoSStatus


修改数据结构：

* [BGPIPInstance](https://cloud.tencent.com/document/api/297/95396#BGPIPInstance)

	* 新增成员：DamDDoSStatus


### 第 12 次发布

发布时间：2021-08-31 08:00:10

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [L4RuleSource](https://cloud.tencent.com/document/api/297/95396#L4RuleSource)

	* 新增成员：Port


### 第 11 次发布

发布时间：2021-08-18 08:00:08

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [L7RuleEntry](https://cloud.tencent.com/document/api/297/95396#L7RuleEntry)

	* 新增成员：Id


### 第 10 次发布

发布时间：2021-08-12 08:00:06

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeBizTrend](https://cloud.tencent.com/document/api/297/95359)
* [DescribeCCTrend](https://cloud.tencent.com/document/api/297/95358)
* [DescribeDDoSTrend](https://cloud.tencent.com/document/api/297/95357)

新增数据结构：

* [ProtocolPort](https://cloud.tencent.com/document/api/297/95396#ProtocolPort)

### 第 9 次发布

发布时间：2021-08-11 08:00:07

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [BGPIPInstance](https://cloud.tencent.com/document/api/297/95396#BGPIPInstance)

	* 新增成员：Domain


### 第 8 次发布

发布时间：2021-08-06 08:00:07

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [AssociateDDoSEipLoadBalancer](https://cloud.tencent.com/document/api/297/95296)

### 第 7 次发布

发布时间：2021-08-05 08:00:06

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [ModifyL7RulesEdge](https://cloud.tencent.com/document/api/#/#)

新增数据结构：

* [L4RuleSource](https://cloud.tencent.com/document/api/297/95396#L4RuleSource)
* [L7RuleEntry](https://cloud.tencent.com/document/api/297/95396#L7RuleEntry)

### 第 6 次发布

发布时间：2021-07-28 08:00:07

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeBasicDeviceStatus](https://cloud.tencent.com/document/api/297/95386)

新增数据结构：

* [KeyValue](https://cloud.tencent.com/document/api/297/95396#KeyValue)

### 第 5 次发布

发布时间：2021-07-21 08:00:04

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [SwitchWaterPrintConfig](https://cloud.tencent.com/document/api/297/95299)

修改数据结构：

* [ForwardListener](https://cloud.tencent.com/document/api/297/95396#ForwardListener)

	* 新增成员：FrontendPortEnd

* [WaterPrintConfig](https://cloud.tencent.com/document/api/297/95396#WaterPrintConfig)

	* 新增成员：Verify


### 第 4 次发布

发布时间：2021-06-24 08:00:04

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateBoundIP](https://cloud.tencent.com/document/api/297/95349)

修改接口：

* [CreateL7RuleCerts](https://cloud.tencent.com/document/api/297/95370)

	* 新增入参：CertId, L7Rules

* [DescribeL7RulesBySSLCertId](https://cloud.tencent.com/document/api/297/95348)

	* 新增入参：Status, CertIds


新增数据结构：

* [BoundIpInfo](https://cloud.tencent.com/document/api/297/95396#BoundIpInfo)

### 第 3 次发布

发布时间：2021-06-23 11:26:33

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateL7RuleCerts](https://cloud.tencent.com/document/api/297/95370)
* [DescribeL7RulesBySSLCertId](https://cloud.tencent.com/document/api/297/95348)

新增数据结构：

* [CertIdInsL7Rules](https://cloud.tencent.com/document/api/297/95396#CertIdInsL7Rules)
* [InsL7Rules](https://cloud.tencent.com/document/api/297/95396#InsL7Rules)
* [SuccessCode](https://cloud.tencent.com/document/api/297/95396#SuccessCode)

### 第 2 次发布

发布时间：2021-06-22 08:00:04

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [BGPInstance](https://cloud.tencent.com/document/api/297/95396#BGPInstance)

	* 新增成员：DDoSLevel, CCEnable


### 第 1 次发布

发布时间：2021-06-18 10:36:41

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [AssociateDDoSEipAddress](https://cloud.tencent.com/document/api/297/95297)
* [CreateBlackWhiteIpList](https://cloud.tencent.com/document/api/297/95342)
* [CreateDDoSAI](https://cloud.tencent.com/document/api/297/95339)
* [CreateDDoSGeoIPBlockConfig](https://cloud.tencent.com/document/api/297/95336)
* [CreateDDoSSpeedLimitConfig](https://cloud.tencent.com/document/api/297/95335)
* [CreateDefaultAlarmThreshold](https://cloud.tencent.com/document/api/297/95375)
* [CreateIPAlarmThresholdConfig](https://cloud.tencent.com/document/api/297/95374)
* [CreatePacketFilterConfig](https://cloud.tencent.com/document/api/297/95334)
* [CreateProtocolBlockConfig](https://cloud.tencent.com/document/api/297/95331)
* [CreateSchedulingDomain](https://cloud.tencent.com/document/api/297/95365)
* [CreateWaterPrintConfig](https://cloud.tencent.com/document/api/297/95330)
* [CreateWaterPrintKey](https://cloud.tencent.com/document/api/297/95329)
* [DeleteBlackWhiteIpList](https://cloud.tencent.com/document/api/#/#)
* [DeleteDDoSGeoIPBlockConfig](https://cloud.tencent.com/document/api/297/95325)
* [DeleteDDoSSpeedLimitConfig](https://cloud.tencent.com/document/api/297/95324)
* [DeletePacketFilterConfig](https://cloud.tencent.com/document/api/297/95323)
* [DeleteWaterPrintConfig](https://cloud.tencent.com/document/api/297/95321)
* [DeleteWaterPrintKey](https://cloud.tencent.com/document/api/297/95320)
* [DescribeBlackWhiteIpList](https://cloud.tencent.com/document/api/297/95319)
* [DescribeDefaultAlarmThreshold](https://cloud.tencent.com/document/api/297/95373)
* [DescribeListBGPIPInstances](https://cloud.tencent.com/document/api/297/95347)
* [DescribeListBGPInstances](https://cloud.tencent.com/document/api/297/95346)
* [DescribeListBlackWhiteIpList](https://cloud.tencent.com/document/api/297/95314)
* [DescribeListDDoSAI](https://cloud.tencent.com/document/api/297/95313)
* [DescribeListDDoSGeoIPBlockConfig](https://cloud.tencent.com/document/api/297/95312)
* [DescribeListDDoSSpeedLimitConfig](https://cloud.tencent.com/document/api/297/95311)
* [DescribeListIPAlarmConfig](https://cloud.tencent.com/document/api/297/95372)
* [DescribeListListener](https://cloud.tencent.com/document/api/297/95345)
* [DescribeListPacketFilterConfig](https://cloud.tencent.com/document/api/297/95310)
* [DescribeListProtectThresholdConfig](https://cloud.tencent.com/document/api/297/95308)
* [DescribeListProtocolBlockConfig](https://cloud.tencent.com/document/api/297/95307)
* [DescribeListSchedulingDomain](https://cloud.tencent.com/document/api/297/95364)
* [DescribeListWaterPrintConfig](https://cloud.tencent.com/document/api/297/95306)
* [DisassociateDDoSEipAddress](https://cloud.tencent.com/document/api/297/95295)
* [ModifyDDoSGeoIPBlockConfig](https://cloud.tencent.com/document/api/297/95303)
* [ModifyDDoSSpeedLimitConfig](https://cloud.tencent.com/document/api/297/95302)
* [ModifyDomainUsrName](https://cloud.tencent.com/document/api/297/95363)
* [ModifyPacketFilterConfig](https://cloud.tencent.com/document/api/297/95301)

新增数据结构：

* [BGPIPInstance](https://cloud.tencent.com/document/api/297/95396#BGPIPInstance)
* [BGPIPInstanceSpecification](https://cloud.tencent.com/document/api/297/95396#BGPIPInstanceSpecification)
* [BGPIPInstanceUsages](https://cloud.tencent.com/document/api/297/95396#BGPIPInstanceUsages)
* [BGPInstance](https://cloud.tencent.com/document/api/297/95396#BGPInstance)
* [BGPInstanceSpecification](https://cloud.tencent.com/document/api/297/95396#BGPInstanceSpecification)
* [BGPInstanceUsages](https://cloud.tencent.com/document/api/297/95396#BGPInstanceUsages)
* [BlackWhiteIpRelation](https://cloud.tencent.com/document/api/297/95396#BlackWhiteIpRelation)
* [DDoSAIRelation](https://cloud.tencent.com/document/api/297/95396#DDoSAIRelation)
* [DDoSGeoIPBlockConfig](https://cloud.tencent.com/document/api/297/95396#DDoSGeoIPBlockConfig)
* [DDoSGeoIPBlockConfigRelation](https://cloud.tencent.com/document/api/297/95396#DDoSGeoIPBlockConfigRelation)
* [DDoSSpeedLimitConfig](https://cloud.tencent.com/document/api/297/95396#DDoSSpeedLimitConfig)
* [DDoSSpeedLimitConfigRelation](https://cloud.tencent.com/document/api/297/95396#DDoSSpeedLimitConfigRelation)
* [DefaultAlarmThreshold](https://cloud.tencent.com/document/api/297/95396#DefaultAlarmThreshold)
* [EipAddressPackRelation](https://cloud.tencent.com/document/api/297/95396#EipAddressPackRelation)
* [EipAddressRelation](https://cloud.tencent.com/document/api/297/95396#EipAddressRelation)
* [EipProductInfo](https://cloud.tencent.com/document/api/297/95396#EipProductInfo)
* [ForwardListener](https://cloud.tencent.com/document/api/297/95396#ForwardListener)
* [IPAlarmThresholdRelation](https://cloud.tencent.com/document/api/297/95396#IPAlarmThresholdRelation)
* [IPLineInfo](https://cloud.tencent.com/document/api/297/95396#IPLineInfo)
* [InstanceRelation](https://cloud.tencent.com/document/api/297/95396#InstanceRelation)
* [Layer4Rule](https://cloud.tencent.com/document/api/297/95396#Layer4Rule)
* [Layer7Rule](https://cloud.tencent.com/document/api/297/95396#Layer7Rule)
* [ListenerCcThreholdConfig](https://cloud.tencent.com/document/api/297/95396#ListenerCcThreholdConfig)
* [PackInfo](https://cloud.tencent.com/document/api/297/95396#PackInfo)
* [PacketFilterConfig](https://cloud.tencent.com/document/api/297/95396#PacketFilterConfig)
* [PacketFilterRelation](https://cloud.tencent.com/document/api/297/95396#PacketFilterRelation)
* [PortSegment](https://cloud.tencent.com/document/api/297/95396#PortSegment)
* [ProtectThresholdRelation](https://cloud.tencent.com/document/api/297/95396#ProtectThresholdRelation)
* [ProtocolBlockConfig](https://cloud.tencent.com/document/api/297/95396#ProtocolBlockConfig)
* [ProtocolBlockRelation](https://cloud.tencent.com/document/api/297/95396#ProtocolBlockRelation)
* [ProxyTypeInfo](https://cloud.tencent.com/document/api/297/95396#ProxyTypeInfo)
* [RegionInfo](https://cloud.tencent.com/document/api/297/95396#RegionInfo)
* [SchedulingDomainInfo](https://cloud.tencent.com/document/api/297/95396#SchedulingDomainInfo)
* [SourceServer](https://cloud.tencent.com/document/api/297/95396#SourceServer)
* [SpeedValue](https://cloud.tencent.com/document/api/297/95396#SpeedValue)
* [StaticPackRelation](https://cloud.tencent.com/document/api/297/95396#StaticPackRelation)
* [WaterPrintConfig](https://cloud.tencent.com/document/api/297/95396#WaterPrintConfig)
* [WaterPrintKey](https://cloud.tencent.com/document/api/297/95396#WaterPrintKey)
* [WaterPrintRelation](https://cloud.tencent.com/document/api/297/95396#WaterPrintRelation)




## 汽车精准获客服务(apcas) 版本：2020-11-27

### 第 1 次发布

发布时间：2021-01-14 14:56:09

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [GetTaskDetail](https://cloud.tencent.com/document/api/1244/52029)
* [GetTaskList](https://cloud.tencent.com/document/api/1244/52028)
* [PredictRating](https://cloud.tencent.com/document/api/1244/52031)
* [QueryCallDetails](https://cloud.tencent.com/document/api/1244/52025)
* [QueryCallStat](https://cloud.tencent.com/document/api/1244/52023)
* [QueryGeneralStat](https://cloud.tencent.com/document/api/1244/52022)
* [UploadId](https://cloud.tencent.com/document/api/1244/52027)

新增数据结构：

* [CallDetailItem](https://cloud.tencent.com/document/api/1244/52032#CallDetailItem)
* [CallDetails](https://cloud.tencent.com/document/api/1244/52032#CallDetails)
* [CallStatItem](https://cloud.tencent.com/document/api/1244/52032#CallStatItem)
* [GeneralStat](https://cloud.tencent.com/document/api/1244/52032#GeneralStat)
* [LabelDetailData](https://cloud.tencent.com/document/api/1244/52032#LabelDetailData)
* [LabelValue](https://cloud.tencent.com/document/api/1244/52032#LabelValue)
* [ListModel](https://cloud.tencent.com/document/api/1244/52032#ListModel)
* [RatingData](https://cloud.tencent.com/document/api/1244/52032#RatingData)
* [TaskData](https://cloud.tencent.com/document/api/1244/52032#TaskData)
* [TaskDetailData](https://cloud.tencent.com/document/api/1244/52032#TaskDetailData)
* [TaskListData](https://cloud.tencent.com/document/api/1244/52032#TaskListData)




## 正版图库直通车(ape) 版本：2020-05-13

### 第 6 次发布

发布时间：2021-04-20 08:00:30

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [ImageInfo](https://cloud.tencent.com/document/api/1181/49689#ImageInfo)

	* 新增成员：DownloadPrice, DownloadType


### 第 5 次发布

发布时间：2021-03-29 08:00:22

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [ImageInfo](https://cloud.tencent.com/document/api/1181/49689#ImageInfo)

	* 新增成员：UserId


### 第 4 次发布

发布时间：2021-02-03 08:00:23

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateOrderAndDownloads](https://cloud.tencent.com/document/api/1181/52716)
* [DescribeDownloadInfos](https://cloud.tencent.com/document/api/1181/52715)

修改接口：

* [DescribeImage](https://cloud.tencent.com/document/api/1181/49688)

	* 新增出参：Width, Height, ImageFormat, ImageSenseType, Keywords, LayeredGalleryId, Orientation


新增数据结构：

* [DownloadInfo](https://cloud.tencent.com/document/api/1181/49689#DownloadInfo)
* [ImageInfo](https://cloud.tencent.com/document/api/1181/49689#ImageInfo)

修改数据结构：

* [ImageItem](https://cloud.tencent.com/document/api/1181/49689#ImageItem)

	* 新增成员：Width, Height

* [ImageMarshal](https://cloud.tencent.com/document/api/1181/49689#ImageMarshal)

	* 新增成员：LicenseScopeId, DimensionsName, DimensionsNameId


### 第 3 次发布

发布时间：2021-01-26 08:00:24

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [ImageItem](https://cloud.tencent.com/document/api/1181/49689#ImageItem)

	* 新增成员：Keywords


### 第 2 次发布

发布时间：2021-01-19 08:00:18

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeImages](https://cloud.tencent.com/document/api/1181/49687)

	* 新增入参：LayeredGalleryIds


### 第 1 次发布

发布时间：2020-11-05 10:38:34

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [BatchDescribeOrderCertificate](https://cloud.tencent.com/document/api/1181/49683)
* [BatchDescribeOrderImage](https://cloud.tencent.com/document/api/1181/49682)
* [CreateOrderAndPay](https://cloud.tencent.com/document/api/1181/49681)
* [DescribeAuthUsers](https://cloud.tencent.com/document/api/1181/49685)
* [DescribeImage](https://cloud.tencent.com/document/api/1181/49688)
* [DescribeImages](https://cloud.tencent.com/document/api/1181/49687)

新增数据结构：

* [AuthInfo](https://cloud.tencent.com/document/api/1181/49689#AuthInfo)
* [ImageItem](https://cloud.tencent.com/document/api/1181/49689#ImageItem)
* [ImageMarshal](https://cloud.tencent.com/document/api/1181/49689#ImageMarshal)




## 云 API(api) 版本：2020-11-06

### 第 3 次发布

发布时间：2023-01-05 01:02:52

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [RegionInfo](https://cloud.tencent.com/document/api/1278/55256#RegionInfo)

	* 新增成员：RegionTypeMC, LocationMC, RegionNameMC, RegionIdMC

	* <font color="#dd0000">**修改成员**：</font>Region, RegionName, RegionState

* [ZoneInfo](https://cloud.tencent.com/document/api/1278/55256#ZoneInfo)

	* 新增成员：ParentZone, ParentZoneId, ParentZoneName, ZoneType, MachineRoomTypeMC, ZoneIdMC


### 第 2 次发布

发布时间：2022-03-03 08:00:37

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeProducts](https://cloud.tencent.com/document/api/1278/70575)

新增数据结构：

* [RegionProduct](https://cloud.tencent.com/document/api/1278/55256#RegionProduct)

### 第 1 次发布

发布时间：2021-04-25 10:09:57

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeRegions](https://cloud.tencent.com/document/api/1278/55255)
* [DescribeZones](https://cloud.tencent.com/document/api/1278/55254)

新增数据结构：

* [RegionInfo](https://cloud.tencent.com/document/api/1278/55256#RegionInfo)
* [ZoneInfo](https://cloud.tencent.com/document/api/1278/55256#ZoneInfo)




## API 网关(apigateway) 版本：2018-08-08

### 第 48 次发布

发布时间：2024-01-31 01:06:22

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [Environment](https://cloud.tencent.com/document/api/628/45244#Environment)

	* 新增成员：CreateTime


### 第 47 次发布

发布时间：2023-11-16 01:06:33

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateAPIDoc](https://cloud.tencent.com/document/api/628/54951)

	* 新增入参：Tags

* [CreateApiKey](https://cloud.tencent.com/document/api/628/45213)

	* 新增入参：Tags

* [CreateUsagePlan](https://cloud.tencent.com/document/api/628/45224)

	* 新增入参：Tags


修改数据结构：

* [APIDoc](https://cloud.tencent.com/document/api/628/45244#APIDoc)

	* 新增成员：Tags

* [APIDocInfo](https://cloud.tencent.com/document/api/628/45244#APIDocInfo)

	* 新增成员：Tags

* [ApiKey](https://cloud.tencent.com/document/api/628/45244#ApiKey)

	* 新增成员：Tags

* [ApiUsagePlan](https://cloud.tencent.com/document/api/628/45244#ApiUsagePlan)

	* 新增成员：Tags

* [UsagePlanInfo](https://cloud.tencent.com/document/api/628/45244#UsagePlanInfo)

	* 新增成员：Tags

* [UsagePlanStatusInfo](https://cloud.tencent.com/document/api/628/45244#UsagePlanStatusInfo)

	* 新增成员：Tags


### 第 46 次发布

发布时间：2023-10-18 01:09:16

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [ModifyAPIDoc](https://cloud.tencent.com/document/api/628/54947)

	* <font color="#dd0000">**修改入参**：</font>ApiDocName, ServiceId, Environment, ApiIds


### 第 45 次发布

发布时间：2023-10-12 01:07:58

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateApi](https://cloud.tencent.com/document/api/628/45243)

	* 新增入参：ServiceScfEventIsAsyncCall

* [ModifyApi](https://cloud.tencent.com/document/api/628/45238)

	* 新增入参：ServiceScfEventIsAsyncCall


修改数据结构：

* [ApiInfo](https://cloud.tencent.com/document/api/628/45244#ApiInfo)

	* 新增成员：ServiceScfEventIsAsyncCall


### 第 44 次发布

发布时间：2023-09-14 01:07:23

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [InstanceInfo](https://cloud.tencent.com/document/api/628/45244#InstanceInfo)

	* 新增成员：OuterIpList, InnerIpList, InstanceChargePrepaid, UniqVpcId


### 第 43 次发布

发布时间：2023-08-31 01:06:05

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeService](https://cloud.tencent.com/document/api/628/45199)

	* 新增出参：UniqVpcId

* [ModifyService](https://cloud.tencent.com/document/api/628/45193)

	* 新增入参：UniqVpcId


### 第 42 次发布

发布时间：2023-07-27 01:06:01

本次发布包含了以下内容：

改善已有的文档。

<font color="#dd0000">**删除接口**：</font>

* GenerateApiDocument

<font color="#dd0000">**删除数据结构**：</font>

* DocumentSDK

### 第 41 次发布

发布时间：2023-07-14 01:02:00

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeApiEnvironmentStrategy](https://cloud.tencent.com/document/api/628/45181)

	* <font color="#dd0000">**修改出参**：</font>Result

* [DescribeIPStrategysStatus](https://cloud.tencent.com/document/api/628/45230)

	* <font color="#dd0000">**修改出参**：</font>Result


新增数据结构：

* [ApiEnvironmentStrategyStatus](https://cloud.tencent.com/document/api/628/45244#ApiEnvironmentStrategyStatus)
* [IPStrategiesStatus](https://cloud.tencent.com/document/api/628/45244#IPStrategiesStatus)

<font color="#dd0000">**删除数据结构**：</font>

* ApiEnvironmentStrategyStataus
* IPStrategysStatus

### 第 40 次发布

发布时间：2023-07-13 01:02:00

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeLogSearch](https://cloud.tencent.com/document/api/628/45203)


### 第 39 次发布

发布时间：2023-07-10 01:06:50

本次发布包含了以下内容：

改善已有的文档。

<font color="#dd0000">**预下线接口**：</font>

* GenerateApiDocument

### 第 38 次发布

发布时间：2023-07-05 01:06:51

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeServiceEnvironmentReleaseHistory](https://cloud.tencent.com/document/api/628/45197)

	* <font color="#dd0000">**修改入参**：</font>EnvironmentName


### 第 37 次发布

发布时间：2023-06-29 01:02:05

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateService](https://cloud.tencent.com/document/api/628/45201)

	* <font color="#dd0000">**删除入参**：</font>ExclusiveSetName

* [DescribeService](https://cloud.tencent.com/document/api/628/45199)

	* <font color="#dd0000">**删除出参**：</font>ExclusiveSetName

* [DescribeServiceForApiApp](https://cloud.tencent.com/document/api/628/58632)

	* <font color="#dd0000">**删除出参**：</font>ExclusiveSetName


修改数据结构：

* [InstanceDetail](https://cloud.tencent.com/document/api/628/45244#InstanceDetail)

	* <font color="#dd0000">**修改成员**：</font>Zones


### 第 36 次发布

发布时间：2023-06-27 01:02:21

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [ApiIdStatus](https://cloud.tencent.com/document/api/628/45244#ApiIdStatus)

	* <font color="#dd0000">**修改成员**：</font>RelationBuniessApiIds

* [DesApisStatus](https://cloud.tencent.com/document/api/628/45244#DesApisStatus)

	* <font color="#dd0000">**修改成员**：</font>RelationBuniessApiIds

* [DescribeApisStatusResultApiIdStatusSetInfo](https://cloud.tencent.com/document/api/628/45244#DescribeApisStatusResultApiIdStatusSetInfo)

* [ParameterInfo](https://cloud.tencent.com/document/api/628/45244#ParameterInfo)


### 第 35 次发布

发布时间：2023-06-08 16:31:03

本次发布包含了以下内容：

改善已有的文档。

新增数据结构：

* [ApigatewayTags](https://cloud.tencent.com/document/api/628/45244#ApigatewayTags)
* [DescribeApisStatusResultApiIdStatusSetInfo](https://cloud.tencent.com/document/api/628/45244#DescribeApisStatusResultApiIdStatusSetInfo)

修改数据结构：

* [DescribeApisStatusResultInfo](https://cloud.tencent.com/document/api/628/45244#DescribeApisStatusResultInfo)

	* 新增成员：ApiIdStatusSet


### 第 34 次发布

发布时间：2023-06-06 01:02:35

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [BindSubDomain](https://cloud.tencent.com/document/api/628/45188)

	* <font color="#dd0000">**删除出参**：</font>Result

* [CreateApi](https://cloud.tencent.com/document/api/628/45243)

	* <font color="#dd0000">**修改出参**：</font>Result

* [DescribeApisStatus](https://cloud.tencent.com/document/api/628/45239)

	* <font color="#dd0000">**修改出参**：</font>Result

* [DescribeExclusiveInstances](https://cloud.tencent.com/document/api/628/63805)

	* <font color="#dd0000">**修改出参**：</font>Result

* [ModifyUpstream](https://cloud.tencent.com/document/api/628/70410)

	* <font color="#dd0000">**修改出参**：</font>Result


新增数据结构：

* [CreateApiResultInfo](https://cloud.tencent.com/document/api/628/45244#CreateApiResultInfo)
* [DescribeApiResultServiceParametersInfo](https://cloud.tencent.com/document/api/628/45244#DescribeApiResultServiceParametersInfo)
* [DescribeApisStatusResultInfo](https://cloud.tencent.com/document/api/628/45244#DescribeApisStatusResultInfo)
* [DescribeExclusiveInstancesResult](https://cloud.tencent.com/document/api/628/45244#DescribeExclusiveInstancesResult)
* [DescribeServiceReleaseVersionResultVersionListInfo](https://cloud.tencent.com/document/api/628/45244#DescribeServiceReleaseVersionResultVersionListInfo)
* [ModifyUpstreamResultInfo](https://cloud.tencent.com/document/api/628/45244#ModifyUpstreamResultInfo)

<font color="#dd0000">**删除数据结构**：</font>

* ApisStatus

修改数据结构：

* [ApiInfo](https://cloud.tencent.com/document/api/628/45244#ApiInfo)

	* <font color="#dd0000">**修改成员**：</font>ServiceParameters

* [EnvironmentStrategy](https://cloud.tencent.com/document/api/628/45244#EnvironmentStrategy)

	* <font color="#dd0000">**删除成员**：</font>MaxQuota

* [ServiceReleaseVersion](https://cloud.tencent.com/document/api/628/45244#ServiceReleaseVersion)

	* <font color="#dd0000">**修改成员**：</font>VersionList

* [UsagePlanInfo](https://cloud.tencent.com/document/api/628/45244#UsagePlanInfo)

	* <font color="#dd0000">**删除成员**：</font>InitQuota, IsHide


### 第 33 次发布

发布时间：2022-11-09 06:09:16

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribePluginsByApi](https://cloud.tencent.com/document/api/628/82587)

新增数据结构：

* [AttachedPluginInfo](https://cloud.tencent.com/document/api/628/45244#AttachedPluginInfo)
* [AttachedPluginSummary](https://cloud.tencent.com/document/api/628/45244#AttachedPluginSummary)

### 第 32 次发布

发布时间：2022-08-24 06:08:44

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [ImportOpenApi](https://cloud.tencent.com/document/api/628/79383)

新增数据结构：

* [CreateApiRspSet](https://cloud.tencent.com/document/api/628/45244#CreateApiRspSet)

### 第 31 次发布

发布时间：2022-06-14 06:05:10

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeExclusiveInstancesStatus](https://cloud.tencent.com/document/api/628/75503)

新增数据结构：

* [InstanceSummary](https://cloud.tencent.com/document/api/628/45244#InstanceSummary)

### 第 30 次发布

发布时间：2022-04-21 06:05:25

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreatePlugin](https://cloud.tencent.com/document/api/628/58234)

	* 新增入参：Tags

* [CreateUpstream](https://cloud.tencent.com/document/api/628/70414)

	* 新增入参：UpstreamType, Tags, HealthChecker

* [ModifyUpstream](https://cloud.tencent.com/document/api/628/70410)

	* 新增入参：UpstreamType, HealthChecker


### 第 29 次发布

发布时间：2022-04-20 06:02:43

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateApi](https://cloud.tencent.com/document/api/628/45243)

	* 新增入参：Owner


修改数据结构：

* [ServiceConfig](https://cloud.tencent.com/document/api/628/45244#ServiceConfig)

	* 新增成员：UpstreamId


### 第 28 次发布

发布时间：2022-03-17 08:01:42

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [CosConfig](https://cloud.tencent.com/document/api/628/45244#CosConfig)

	* 新增成员：PathMatchMode

* [CreateApiRsp](https://cloud.tencent.com/document/api/628/45244#CreateApiRsp)

	* 新增成员：Status, ErrMsg, ApiName


### 第 27 次发布

发布时间：2022-03-03 08:00:40

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateService](https://cloud.tencent.com/document/api/628/45201)

	* 新增入参：UniqVpcId


### 第 26 次发布

发布时间：2022-03-01 08:00:39

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateUpstream](https://cloud.tencent.com/document/api/628/70414)
* [DeleteUpstream](https://cloud.tencent.com/document/api/628/70413)
* [DescribeUpstreamBindApis](https://cloud.tencent.com/document/api/628/70412)
* [DescribeUpstreams](https://cloud.tencent.com/document/api/628/70411)
* [ModifyUpstream](https://cloud.tencent.com/document/api/628/70410)

新增数据结构：

* [BindApiInfo](https://cloud.tencent.com/document/api/628/45244#BindApiInfo)
* [DescribeUpstreamBindApis](https://cloud.tencent.com/document/api/628/45244#DescribeUpstreamBindApis)
* [DescribeUpstreamInfo](https://cloud.tencent.com/document/api/628/45244#DescribeUpstreamInfo)
* [K8sLabel](https://cloud.tencent.com/document/api/628/45244#K8sLabel)
* [K8sService](https://cloud.tencent.com/document/api/628/45244#K8sService)
* [UpstreamHealthChecker](https://cloud.tencent.com/document/api/628/45244#UpstreamHealthChecker)
* [UpstreamHealthCheckerReqHeaders](https://cloud.tencent.com/document/api/628/45244#UpstreamHealthCheckerReqHeaders)
* [UpstreamInfo](https://cloud.tencent.com/document/api/628/45244#UpstreamInfo)
* [UpstreamNode](https://cloud.tencent.com/document/api/628/45244#UpstreamNode)

### 第 25 次发布

发布时间：2022-01-24 08:04:33

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [ParameterInfo](https://cloud.tencent.com/document/api/628/45244#ParameterInfo)

	* 新增成员：ValueString, DefaultValueString, Range


### 第 24 次发布

发布时间：2022-01-14 08:05:13

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateApi](https://cloud.tencent.com/document/api/628/45243)

	* 新增入参：EventBusId

* [ModifyApi](https://cloud.tencent.com/document/api/628/45238)

	* 新增入参：EventBusId, ServiceScfFunctionType, EIAMAppType, EIAMAuthType, EIAMAppId, TokenTimeout


### 第 23 次发布

发布时间：2022-01-10 08:05:32

本次发布包含了以下内容：

改善已有的文档。

新增数据结构：

* [CosConfig](https://cloud.tencent.com/document/api/628/45244#CosConfig)

修改数据结构：

* [ServiceConfig](https://cloud.tencent.com/document/api/628/45244#ServiceConfig)

	* 新增成员：CosConfig


### 第 22 次发布

发布时间：2021-12-06 08:00:59

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateApi](https://cloud.tencent.com/document/api/628/45243)

	* 新增入参：EIAMAppType, EIAMAuthType, TokenTimeout, EIAMAppId


### 第 21 次发布

发布时间：2021-11-10 08:02:05

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeExclusiveInstanceDetail](https://cloud.tencent.com/document/api/628/63806)
* [DescribeExclusiveInstances](https://cloud.tencent.com/document/api/628/63805)
* [ModifyExclusiveInstance](https://cloud.tencent.com/document/api/628/63804)

新增数据结构：

* [InstanceChargePrepaid](https://cloud.tencent.com/document/api/628/45244#InstanceChargePrepaid)
* [InstanceDetail](https://cloud.tencent.com/document/api/628/45244#InstanceDetail)
* [InstanceInfo](https://cloud.tencent.com/document/api/628/45244#InstanceInfo)
* [InstanceParameterInput](https://cloud.tencent.com/document/api/628/45244#InstanceParameterInput)
* [NetworkConfig](https://cloud.tencent.com/document/api/628/45244#NetworkConfig)
* [ParameterInfo](https://cloud.tencent.com/document/api/628/45244#ParameterInfo)
* [VpcConfig](https://cloud.tencent.com/document/api/628/45244#VpcConfig)

### 第 20 次发布

发布时间：2021-11-04 08:03:57

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeService](https://cloud.tencent.com/document/api/628/45199)

	* 新增出参：DeploymentType, SpecialUse


修改数据结构：

* [Service](https://cloud.tencent.com/document/api/628/45244#Service)

	* 新增成员：DeploymentType


### 第 19 次发布

发布时间：2021-07-29 08:11:45

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeApiForApiApp](https://cloud.tencent.com/document/api/628/59276)

修改接口：

* [CreateApi](https://cloud.tencent.com/document/api/628/45243)

	* 新增入参：ServiceScfFunctionType


### 第 18 次发布

发布时间：2021-07-15 08:10:56

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [BindApiApp](https://cloud.tencent.com/document/api/628/58639)
* [CreateApiApp](https://cloud.tencent.com/document/api/628/58638)
* [DeleteApiApp](https://cloud.tencent.com/document/api/628/58637)
* [DescribeApiApp](https://cloud.tencent.com/document/api/628/58636)
* [DescribeApiAppBindApisStatus](https://cloud.tencent.com/document/api/628/58635)
* [DescribeApiAppsStatus](https://cloud.tencent.com/document/api/628/58634)
* [DescribeApiBindApiAppsStatus](https://cloud.tencent.com/document/api/628/58633)
* [DescribeServiceForApiApp](https://cloud.tencent.com/document/api/628/58632)
* [ModifyApiApp](https://cloud.tencent.com/document/api/628/58631)
* [UnbindApiApp](https://cloud.tencent.com/document/api/628/58630)
* [UpdateApiAppKey](https://cloud.tencent.com/document/api/628/58629)

新增数据结构：

* [ApiAppApiInfo](https://cloud.tencent.com/document/api/628/45244#ApiAppApiInfo)
* [ApiAppApiInfos](https://cloud.tencent.com/document/api/628/45244#ApiAppApiInfos)
* [ApiAppInfo](https://cloud.tencent.com/document/api/628/45244#ApiAppInfo)
* [ApiAppInfos](https://cloud.tencent.com/document/api/628/45244#ApiAppInfos)

### 第 17 次发布

发布时间：2021-07-08 08:10:45

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [AttachPlugin](https://cloud.tencent.com/document/api/628/58276)
* [DeletePlugin](https://cloud.tencent.com/document/api/628/58275)
* [DescribeAllPluginApis](https://cloud.tencent.com/document/api/628/58274)
* [DescribePlugin](https://cloud.tencent.com/document/api/628/58273)
* [DescribePluginApis](https://cloud.tencent.com/document/api/628/58272)
* [DetachPlugin](https://cloud.tencent.com/document/api/628/58271)
* [ModifyPlugin](https://cloud.tencent.com/document/api/628/58270)

新增数据结构：

* [ApiInfoSummary](https://cloud.tencent.com/document/api/628/45244#ApiInfoSummary)
* [AttachedApiSummary](https://cloud.tencent.com/document/api/628/45244#AttachedApiSummary)
* [AvailableApiInfo](https://cloud.tencent.com/document/api/628/45244#AvailableApiInfo)

### 第 16 次发布

发布时间：2021-07-07 10:05:40

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreatePlugin](https://cloud.tencent.com/document/api/628/58234)

### 第 15 次发布

发布时间：2021-06-24 08:16:26

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [DomainSetList](https://cloud.tencent.com/document/api/628/45244#DomainSetList)

	* 新增成员：IsForcedHttps, RegistrationStatus


### 第 14 次发布

发布时间：2021-05-10 08:09:55

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DeleteService](https://cloud.tencent.com/document/api/628/45200)

	* 新增入参：SkipVerification


### 第 13 次发布

发布时间：2021-04-23 08:09:46

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateService](https://cloud.tencent.com/document/api/628/45201)

	* 新增入参：InstanceId

* [DescribeService](https://cloud.tencent.com/document/api/628/45199)

	* 新增出参：InstanceId, InstanceName, SetType


修改数据结构：

* [EnvironmentStrategy](https://cloud.tencent.com/document/api/628/45244#EnvironmentStrategy)

	* 新增成员：MaxQuota

* [Service](https://cloud.tencent.com/document/api/628/45244#Service)

	* 新增成员：InstanceId, SetType

* [ServiceEnvironmentStrategy](https://cloud.tencent.com/document/api/628/45244#ServiceEnvironmentStrategy)

	* 新增成员：MaxStrategy


### 第 12 次发布

发布时间：2021-04-22 08:10:09

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [BuildAPIDoc](https://cloud.tencent.com/document/api/628/54952)
* [CreateAPIDoc](https://cloud.tencent.com/document/api/628/54951)
* [DeleteAPIDoc](https://cloud.tencent.com/document/api/628/54950)
* [DescribeAPIDocDetail](https://cloud.tencent.com/document/api/628/54949)
* [DescribeAPIDocs](https://cloud.tencent.com/document/api/628/54948)
* [ModifyAPIDoc](https://cloud.tencent.com/document/api/628/54947)
* [ResetAPIDocPassword](https://cloud.tencent.com/document/api/628/54946)

新增数据结构：

* [APIDoc](https://cloud.tencent.com/document/api/628/45244#APIDoc)
* [APIDocInfo](https://cloud.tencent.com/document/api/628/45244#APIDocInfo)
* [APIDocs](https://cloud.tencent.com/document/api/628/45244#APIDocs)

修改数据结构：

* [ResponseErrorCodeReq](https://cloud.tencent.com/document/api/628/45244#ResponseErrorCodeReq)

	* <font color="#dd0000">**修改成员**：</font>Code, Msg, Desc, ConvertedCode, NeedConvert


### 第 11 次发布

发布时间：2021-02-03 08:09:18

本次发布包含了以下内容：

改善已有的文档。

新增数据结构：

* [AttachedApiInfo](https://cloud.tencent.com/document/api/628/45244#AttachedApiInfo)

修改数据结构：

* [Plugin](https://cloud.tencent.com/document/api/628/45244#Plugin)

	* 新增成员：AttachedApiTotalCount, AttachedApis


### 第 10 次发布

发布时间：2021-01-26 08:11:01

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribePlugins](https://cloud.tencent.com/document/api/628/52505)

新增数据结构：

* [Plugin](https://cloud.tencent.com/document/api/628/45244#Plugin)
* [PluginSummary](https://cloud.tencent.com/document/api/628/45244#PluginSummary)

### 第 9 次发布

发布时间：2021-01-21 08:09:06

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateApi](https://cloud.tencent.com/document/api/628/45243)

	* 新增入参：IsBase64Encoded

* [ModifyApi](https://cloud.tencent.com/document/api/628/45238)

	* 新增入参：IsBase64Encoded, IsBase64Trigger, Base64EncodedTriggerRules


新增数据结构：

* [Base64EncodedTriggerRule](https://cloud.tencent.com/document/api/628/45244#Base64EncodedTriggerRule)

修改数据结构：

* [ApiInfo](https://cloud.tencent.com/document/api/628/45244#ApiInfo)

	* 新增成员：IsBase64Encoded, IsBase64Trigger, Base64EncodedTriggerRules


### 第 8 次发布

发布时间：2020-12-24 08:09:09

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [BindSubDomain](https://cloud.tencent.com/document/api/628/45188)

	* 新增入参：IsForcedHttps

	* 新增出参：Result

* [ModifySubDomain](https://cloud.tencent.com/document/api/628/45184)

	* 新增入参：IsForcedHttps


### 第 7 次发布

发布时间：2020-11-27 08:08:28

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [ApiInfo](https://cloud.tencent.com/document/api/628/45244#ApiInfo)

	* 新增成员：Environments


### 第 6 次发布

发布时间：2020-11-05 08:08:12

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateService](https://cloud.tencent.com/document/api/628/45201)

	* 新增出参：ServiceId, ServiceName, ServiceDesc, OuterSubDomain, InnerSubDomain, CreatedTime, NetTypes, IpVersion


### 第 5 次发布

发布时间：2020-10-29 08:08:25

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateService](https://cloud.tencent.com/document/api/628/45201)

	* 新增入参：Tags

	* <font color="#dd0000">**删除出参**：</font>ServiceId, ServiceName, ServiceDesc, OuterSubDomain, InnerSubDomain, CreatedTime, NetTypes, IpVersion


### 第 4 次发布

发布时间：2020-08-05 08:23:54

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeService](https://cloud.tencent.com/document/api/628/45199)

	* 新增出参：Tags


### 第 3 次发布

发布时间：2020-08-04 08:25:53

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [Service](https://cloud.tencent.com/document/api/628/45244#Service)

	* 新增成员：Tags


### 第 2 次发布

发布时间：2020-06-11 08:22:10

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeLogSearch](https://cloud.tencent.com/document/api/628/45203)

	* 新增入参：LogQuerys


新增数据结构：

* [LogQuery](https://cloud.tencent.com/document/api/628/45244#LogQuery)

### 第 1 次发布

发布时间：2020-06-03 10:59:52

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [BindEnvironment](https://cloud.tencent.com/document/api/628/45226)
* [BindIPStrategy](https://cloud.tencent.com/document/api/628/45235)
* [BindSecretIds](https://cloud.tencent.com/document/api/628/45225)
* [BindSubDomain](https://cloud.tencent.com/document/api/628/45188)
* [CreateApi](https://cloud.tencent.com/document/api/628/45243)
* [CreateApiKey](https://cloud.tencent.com/document/api/628/45213)
* [CreateIPStrategy](https://cloud.tencent.com/document/api/628/45234)
* [CreateService](https://cloud.tencent.com/document/api/628/45201)
* [CreateUsagePlan](https://cloud.tencent.com/document/api/628/45224)
* [DeleteApi](https://cloud.tencent.com/document/api/628/45242)
* [DeleteApiKey](https://cloud.tencent.com/document/api/628/45212)
* [DeleteIPStrategy](https://cloud.tencent.com/document/api/628/45233)
* [DeleteService](https://cloud.tencent.com/document/api/628/45200)
* [DeleteServiceSubDomainMapping](https://cloud.tencent.com/document/api/628/45187)
* [DeleteUsagePlan](https://cloud.tencent.com/document/api/628/45223)
* [DemoteServiceUsagePlan](https://cloud.tencent.com/document/api/628/45222)
* [DescribeApi](https://cloud.tencent.com/document/api/628/45241)
* [DescribeApiEnvironmentStrategy](https://cloud.tencent.com/document/api/628/45181)
* [DescribeApiKey](https://cloud.tencent.com/document/api/628/45211)
* [DescribeApiKeysStatus](https://cloud.tencent.com/document/api/628/45210)
* [DescribeApiUsagePlan](https://cloud.tencent.com/document/api/628/45240)
* [DescribeApisStatus](https://cloud.tencent.com/document/api/628/45239)
* [DescribeIPStrategy](https://cloud.tencent.com/document/api/628/45232)
* [DescribeIPStrategyApisStatus](https://cloud.tencent.com/document/api/628/45231)
* [DescribeIPStrategysStatus](https://cloud.tencent.com/document/api/628/45230)
* [DescribeLogSearch](https://cloud.tencent.com/document/api/628/45203)
* [DescribeService](https://cloud.tencent.com/document/api/628/45199)
* [DescribeServiceEnvironmentList](https://cloud.tencent.com/document/api/628/45198)
* [DescribeServiceEnvironmentReleaseHistory](https://cloud.tencent.com/document/api/628/45197)
* [DescribeServiceEnvironmentStrategy](https://cloud.tencent.com/document/api/628/45180)
* [DescribeServiceReleaseVersion](https://cloud.tencent.com/document/api/628/45196)
* [DescribeServiceSubDomainMappings](https://cloud.tencent.com/document/api/628/45186)
* [DescribeServiceSubDomains](https://cloud.tencent.com/document/api/628/45185)
* [DescribeServiceUsagePlan](https://cloud.tencent.com/document/api/628/45195)
* [DescribeServicesStatus](https://cloud.tencent.com/document/api/628/45194)
* [DescribeUsagePlan](https://cloud.tencent.com/document/api/628/45221)
* [DescribeUsagePlanEnvironments](https://cloud.tencent.com/document/api/628/45220)
* [DescribeUsagePlanSecretIds](https://cloud.tencent.com/document/api/628/45219)
* [DescribeUsagePlansStatus](https://cloud.tencent.com/document/api/628/45218)
* [DisableApiKey](https://cloud.tencent.com/document/api/628/45209)
* [EnableApiKey](https://cloud.tencent.com/document/api/628/45208)
* [GenerateApiDocument](https://cloud.tencent.com/document/api/628/45205)
* [ModifyApi](https://cloud.tencent.com/document/api/628/45238)
* [ModifyApiEnvironmentStrategy](https://cloud.tencent.com/document/api/628/45179)
* [ModifyApiIncrement](https://cloud.tencent.com/document/api/628/45237)
* [ModifyIPStrategy](https://cloud.tencent.com/document/api/628/45229)
* [ModifyService](https://cloud.tencent.com/document/api/628/45193)
* [ModifyServiceEnvironmentStrategy](https://cloud.tencent.com/document/api/628/45178)
* [ModifySubDomain](https://cloud.tencent.com/document/api/628/45184)
* [ModifyUsagePlan](https://cloud.tencent.com/document/api/628/45217)
* [ReleaseService](https://cloud.tencent.com/document/api/628/45192)
* [UnBindEnvironment](https://cloud.tencent.com/document/api/628/45216)
* [UnBindIPStrategy](https://cloud.tencent.com/document/api/628/45228)
* [UnBindSecretIds](https://cloud.tencent.com/document/api/628/45215)
* [UnBindSubDomain](https://cloud.tencent.com/document/api/628/45183)
* [UnReleaseService](https://cloud.tencent.com/document/api/628/45191)
* [UpdateApiKey](https://cloud.tencent.com/document/api/628/45207)
* [UpdateService](https://cloud.tencent.com/document/api/628/45190)

新增数据结构：

* [ApiEnvironmentStrategy](https://cloud.tencent.com/document/api/628/45244#ApiEnvironmentStrategy)
* [ApiEnvironmentStrategyStataus](https://cloud.tencent.com/document/api/628/45244#ApiEnvironmentStrategyStataus)
* [ApiIdStatus](https://cloud.tencent.com/document/api/628/45244#ApiIdStatus)
* [ApiInfo](https://cloud.tencent.com/document/api/628/45244#ApiInfo)
* [ApiKey](https://cloud.tencent.com/document/api/628/45244#ApiKey)
* [ApiKeysStatus](https://cloud.tencent.com/document/api/628/45244#ApiKeysStatus)
* [ApiRequestConfig](https://cloud.tencent.com/document/api/628/45244#ApiRequestConfig)
* [ApiUsagePlan](https://cloud.tencent.com/document/api/628/45244#ApiUsagePlan)
* [ApiUsagePlanSet](https://cloud.tencent.com/document/api/628/45244#ApiUsagePlanSet)
* [ApisStatus](https://cloud.tencent.com/document/api/628/45244#ApisStatus)
* [ConstantParameter](https://cloud.tencent.com/document/api/628/45244#ConstantParameter)
* [CreateApiRsp](https://cloud.tencent.com/document/api/628/45244#CreateApiRsp)
* [DesApisStatus](https://cloud.tencent.com/document/api/628/45244#DesApisStatus)
* [DocumentSDK](https://cloud.tencent.com/document/api/628/45244#DocumentSDK)
* [DomainSetList](https://cloud.tencent.com/document/api/628/45244#DomainSetList)
* [DomainSets](https://cloud.tencent.com/document/api/628/45244#DomainSets)
* [Environment](https://cloud.tencent.com/document/api/628/45244#Environment)
* [EnvironmentStrategy](https://cloud.tencent.com/document/api/628/45244#EnvironmentStrategy)
* [ErrorCodes](https://cloud.tencent.com/document/api/628/45244#ErrorCodes)
* [Filter](https://cloud.tencent.com/document/api/628/45244#Filter)
* [HealthCheckConf](https://cloud.tencent.com/document/api/628/45244#HealthCheckConf)
* [IPStrategy](https://cloud.tencent.com/document/api/628/45244#IPStrategy)
* [IPStrategyApi](https://cloud.tencent.com/document/api/628/45244#IPStrategyApi)
* [IPStrategyApiStatus](https://cloud.tencent.com/document/api/628/45244#IPStrategyApiStatus)
* [IPStrategysStatus](https://cloud.tencent.com/document/api/628/45244#IPStrategysStatus)
* [MicroService](https://cloud.tencent.com/document/api/628/45244#MicroService)
* [MicroServiceReq](https://cloud.tencent.com/document/api/628/45244#MicroServiceReq)
* [OauthConfig](https://cloud.tencent.com/document/api/628/45244#OauthConfig)
* [PathMapping](https://cloud.tencent.com/document/api/628/45244#PathMapping)
* [ReleaseService](https://cloud.tencent.com/document/api/628/45244#ReleaseService)
* [ReqParameter](https://cloud.tencent.com/document/api/628/45244#ReqParameter)
* [RequestConfig](https://cloud.tencent.com/document/api/628/45244#RequestConfig)
* [RequestParameter](https://cloud.tencent.com/document/api/628/45244#RequestParameter)
* [ResponseErrorCodeReq](https://cloud.tencent.com/document/api/628/45244#ResponseErrorCodeReq)
* [Service](https://cloud.tencent.com/document/api/628/45244#Service)
* [ServiceConfig](https://cloud.tencent.com/document/api/628/45244#ServiceConfig)
* [ServiceEnvironmentSet](https://cloud.tencent.com/document/api/628/45244#ServiceEnvironmentSet)
* [ServiceEnvironmentStrategy](https://cloud.tencent.com/document/api/628/45244#ServiceEnvironmentStrategy)
* [ServiceEnvironmentStrategyStatus](https://cloud.tencent.com/document/api/628/45244#ServiceEnvironmentStrategyStatus)
* [ServiceParameter](https://cloud.tencent.com/document/api/628/45244#ServiceParameter)
* [ServiceReleaseHistory](https://cloud.tencent.com/document/api/628/45244#ServiceReleaseHistory)
* [ServiceReleaseHistoryInfo](https://cloud.tencent.com/document/api/628/45244#ServiceReleaseHistoryInfo)
* [ServiceReleaseVersion](https://cloud.tencent.com/document/api/628/45244#ServiceReleaseVersion)
* [ServiceSubDomainMappings](https://cloud.tencent.com/document/api/628/45244#ServiceSubDomainMappings)
* [ServiceUsagePlanSet](https://cloud.tencent.com/document/api/628/45244#ServiceUsagePlanSet)
* [ServicesStatus](https://cloud.tencent.com/document/api/628/45244#ServicesStatus)
* [Tag](https://cloud.tencent.com/document/api/628/45244#Tag)
* [TargetServicesReq](https://cloud.tencent.com/document/api/628/45244#TargetServicesReq)
* [TsfLoadBalanceConfResp](https://cloud.tencent.com/document/api/628/45244#TsfLoadBalanceConfResp)
* [UsagePlan](https://cloud.tencent.com/document/api/628/45244#UsagePlan)
* [UsagePlanBindEnvironment](https://cloud.tencent.com/document/api/628/45244#UsagePlanBindEnvironment)
* [UsagePlanBindSecret](https://cloud.tencent.com/document/api/628/45244#UsagePlanBindSecret)
* [UsagePlanBindSecretStatus](https://cloud.tencent.com/document/api/628/45244#UsagePlanBindSecretStatus)
* [UsagePlanEnvironment](https://cloud.tencent.com/document/api/628/45244#UsagePlanEnvironment)
* [UsagePlanEnvironmentStatus](https://cloud.tencent.com/document/api/628/45244#UsagePlanEnvironmentStatus)
* [UsagePlanInfo](https://cloud.tencent.com/document/api/628/45244#UsagePlanInfo)
* [UsagePlanStatusInfo](https://cloud.tencent.com/document/api/628/45244#UsagePlanStatusInfo)
* [UsagePlansStatus](https://cloud.tencent.com/document/api/628/45244#UsagePlansStatus)




## 应用性能监控(apm) 版本：2021-06-22

### 第 24 次发布

发布时间：2024-07-31 01:04:59

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeMetricRecords](https://cloud.tencent.com/document/api/1463/68254)

	* 新增入参：Type


### 第 23 次发布

发布时间：2024-04-25 01:09:12

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeGeneralApmApplicationConfig](https://cloud.tencent.com/document/api/1463/105647)
* [DescribeTagValues](https://cloud.tencent.com/document/api/1463/105645)
* [ModifyGeneralApmApplicationConfig](https://cloud.tencent.com/document/api/1463/105646)

新增数据结构：

* [ApmApplicationConfigView](https://cloud.tencent.com/document/api/1463/64927#ApmApplicationConfigView)
* [Instrument](https://cloud.tencent.com/document/api/1463/64927#Instrument)

### 第 22 次发布

发布时间：2023-12-08 01:08:53

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateApmInstance](https://cloud.tencent.com/document/api/1463/65347)

	* 新增入参：PayMode

* [ModifyApmInstance](https://cloud.tencent.com/document/api/1463/89002)

	* 新增入参：PayMode


修改数据结构：

* [ApmInstanceDetail](https://cloud.tencent.com/document/api/1463/64927#ApmInstanceDetail)

	* 新增成员：PayMode, PayModeEffective


### 第 21 次发布

发布时间：2023-10-27 01:10:12

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [Span](https://cloud.tencent.com/document/api/1463/64927#Span)

	* 新增成员：ParentSpanID


### 第 20 次发布

发布时间：2023-09-21 01:15:22

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeGeneralSpanList](https://cloud.tencent.com/document/api/1463/98725)

新增数据结构：

* [Span](https://cloud.tencent.com/document/api/1463/64927#Span)
* [SpanLog](https://cloud.tencent.com/document/api/1463/64927#SpanLog)
* [SpanProcess](https://cloud.tencent.com/document/api/1463/64927#SpanProcess)
* [SpanReference](https://cloud.tencent.com/document/api/1463/64927#SpanReference)
* [SpanTag](https://cloud.tencent.com/document/api/1463/64927#SpanTag)

### 第 19 次发布

发布时间：2023-07-18 01:07:24

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [ModifyApmInstance](https://cloud.tencent.com/document/api/1463/89002)

	* 新增入参：CustomShowTags


修改数据结构：

* [ApmInstanceDetail](https://cloud.tencent.com/document/api/1463/64927#ApmInstanceDetail)

	* 新增成员：CustomShowTags


### 第 18 次发布

发布时间：2023-06-28 01:02:05

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeMetricRecords](https://cloud.tencent.com/document/api/1463/68254)

	* 新增入参：OrFilters


### 第 17 次发布

发布时间：2023-06-21 01:02:56

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeApmInstances](https://cloud.tencent.com/document/api/1463/65103)

	* 新增入参：AllRegionsFlag


### 第 16 次发布

发布时间：2023-04-21 01:08:25

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [ApmInstanceDetail](https://cloud.tencent.com/document/api/1463/64927#ApmInstanceDetail)

	* 新增成员：LogSet, MetricDuration


### 第 15 次发布

发布时间：2023-03-21 01:03:36

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [ModifyApmInstance](https://cloud.tencent.com/document/api/1463/89002)
* [TerminateApmInstance](https://cloud.tencent.com/document/api/1463/89001)

### 第 14 次发布

发布时间：2022-12-06 06:16:29

本次发布包含了以下内容：

改善已有的文档。

新增数据结构：

* [APMKV](https://cloud.tencent.com/document/api/1463/64927#APMKV)

修改数据结构：

* [ApmField](https://cloud.tencent.com/document/api/1463/64927#ApmField)

	* 新增成员：LastPeriodValue


### 第 13 次发布

发布时间：2022-08-03 06:04:22

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeMetricRecords](https://cloud.tencent.com/document/api/1463/68254)

	* 新增入参：PageIndex, PageSize

	* 新增出参：TotalCount


### 第 12 次发布

发布时间：2022-07-12 06:04:29

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeGeneralMetricData](https://cloud.tencent.com/document/api/1463/73791)

	* 新增入参：OrderBy, PageSize


### 第 11 次发布

发布时间：2022-06-21 06:01:15

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [ApmInstanceDetail](https://cloud.tencent.com/document/api/1463/64927#ApmInstanceDetail)

	* 新增成员：ClientCount, TotalCount


### 第 10 次发布

发布时间：2022-06-20 06:02:33

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeApmAgent](https://cloud.tencent.com/document/api/1463/64926)

	* 新增入参：ReportMethod


### 第 9 次发布

发布时间：2022-05-17 10:51:16

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeGeneralMetricData](https://cloud.tencent.com/document/api/1463/73791)

新增数据结构：

* [GeneralFilter](https://cloud.tencent.com/document/api/1463/64927#GeneralFilter)
* [Line](https://cloud.tencent.com/document/api/1463/64927#Line)

### 第 8 次发布

发布时间：2022-04-26 06:04:31

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeServiceOverview](https://cloud.tencent.com/document/api/1463/73094)

### 第 7 次发布

发布时间：2022-03-30 06:01:18

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeApmInstances](https://cloud.tencent.com/document/api/1463/65103)

	* 新增入参：DemoInstanceFlag


### 第 6 次发布

发布时间：2022-01-19 08:05:14

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeMetricRecords](https://cloud.tencent.com/document/api/1463/68254)

	* 新增入参：BusinessName


### 第 5 次发布

发布时间：2022-01-17 08:02:51

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeMetricRecords](https://cloud.tencent.com/document/api/1463/68254)

新增数据结构：

* [APMKVItem](https://cloud.tencent.com/document/api/1463/64927#APMKVItem)
* [ApmField](https://cloud.tencent.com/document/api/1463/64927#ApmField)
* [ApmMetricRecord](https://cloud.tencent.com/document/api/1463/64927#ApmMetricRecord)
* [Filter](https://cloud.tencent.com/document/api/1463/64927#Filter)
* [OrderBy](https://cloud.tencent.com/document/api/1463/64927#OrderBy)
* [QueryMetricItem](https://cloud.tencent.com/document/api/1463/64927#QueryMetricItem)

### 第 4 次发布

发布时间：2022-01-05 08:03:38

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [ApmInstanceDetail](https://cloud.tencent.com/document/api/1463/64927#ApmInstanceDetail)

	* 新增成员：LogRegion, LogSource, IsRelatedLog, LogTopicID


### 第 3 次发布

发布时间：2021-12-02 08:02:32

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateApmInstance](https://cloud.tencent.com/document/api/1463/65347)

### 第 2 次发布

发布时间：2021-12-01 08:02:58

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeApmInstances](https://cloud.tencent.com/document/api/1463/65103)

新增数据结构：

* [ApmInstanceDetail](https://cloud.tencent.com/document/api/1463/64927#ApmInstanceDetail)
* [ApmTag](https://cloud.tencent.com/document/api/1463/64927#ApmTag)

### 第 1 次发布

发布时间：2021-11-29 14:39:11

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeApmAgent](https://cloud.tencent.com/document/api/1463/64926)

新增数据结构：

* [ApmAgentInfo](https://cloud.tencent.com/document/api/1463/64927#ApmAgentInfo)




## 弹性伸缩(as) 版本：2018-04-19

### 第 71 次发布

发布时间：2024-07-23 01:04:47

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [DataDisk](https://cloud.tencent.com/document/api/377/20453#DataDisk)

	* 新增成员：BurstPerformance

* [InstanceNameSettings](https://cloud.tencent.com/document/api/377/20453#InstanceNameSettings)

	* 新增成员：InstanceNameSuffix


### 第 70 次发布

发布时间：2024-01-31 01:06:41

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [LaunchConfiguration](https://cloud.tencent.com/document/api/377/20453#LaunchConfiguration)

	* 新增成员：DisasterRecoverGroupIds


### 第 69 次发布

发布时间：2023-11-10 01:06:51

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateAutoScalingGroup](https://cloud.tencent.com/document/api/377/20440)

	* 新增入参：InstanceNameIndexSettings

* [ModifyAutoScalingGroup](https://cloud.tencent.com/document/api/377/20433)

	* 新增入参：InstanceNameIndexSettings


新增数据结构：

* [InstanceNameIndexSettings](https://cloud.tencent.com/document/api/377/20453#InstanceNameIndexSettings)

修改数据结构：

* [AutoScalingGroup](https://cloud.tencent.com/document/api/377/20453#AutoScalingGroup)

	* 新增成员：InstanceNameIndexSettings


### 第 68 次发布

发布时间：2023-09-28 01:06:16

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CancelInstanceRefresh](https://cloud.tencent.com/document/api/377/99176)
* [DescribeRefreshActivities](https://cloud.tencent.com/document/api/377/99175)
* [ExitStandby](https://cloud.tencent.com/document/api/377/99177)
* [ResumeInstanceRefresh](https://cloud.tencent.com/document/api/377/99174)
* [RollbackInstanceRefresh](https://cloud.tencent.com/document/api/377/99173)
* [StartInstanceRefresh](https://cloud.tencent.com/document/api/377/99172)
* [StopInstanceRefresh](https://cloud.tencent.com/document/api/377/99171)

新增数据结构：

* [RefreshActivity](https://cloud.tencent.com/document/api/377/20453#RefreshActivity)
* [RefreshBatch](https://cloud.tencent.com/document/api/377/20453#RefreshBatch)
* [RefreshBatchRelatedInstance](https://cloud.tencent.com/document/api/377/20453#RefreshBatchRelatedInstance)
* [RefreshSettings](https://cloud.tencent.com/document/api/377/20453#RefreshSettings)
* [RollingUpdateSettings](https://cloud.tencent.com/document/api/377/20453#RollingUpdateSettings)

### 第 67 次发布

发布时间：2023-09-12 01:09:06

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [ModifyLaunchConfigurationAttributes](https://cloud.tencent.com/document/api/377/31298)

	* 新增入参：LoginSettings


### 第 66 次发布

发布时间：2023-08-25 01:08:59

本次发布包含了以下内容：

改善已有的文档。

<font color="#dd0000">**预下线接口**：</font>

* UpgradeLaunchConfiguration

### 第 65 次发布

发布时间：2023-07-19 01:07:14

本次发布包含了以下内容：

改善已有的文档。

新增数据结构：

* [RelatedInstance](https://cloud.tencent.com/document/api/377/20453#RelatedInstance)

修改数据结构：

* [Activity](https://cloud.tencent.com/document/api/377/20453#Activity)

	* 新增成员：RelatedInstanceSet


### 第 64 次发布

发布时间：2023-06-15 01:02:32

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [EnhancedService](https://cloud.tencent.com/document/api/377/20453#EnhancedService)


### 第 63 次发布

发布时间：2023-06-13 01:02:52

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [Advice](https://cloud.tencent.com/document/api/377/20453#Advice)

	* 新增成员：Level


### 第 62 次发布

发布时间：2023-03-24 01:03:57

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [ClearLaunchConfigurationAttributes](https://cloud.tencent.com/document/api/377/54255)

	* 新增入参：ClearDisasterRecoverGroupIds

* [CreateLaunchConfiguration](https://cloud.tencent.com/document/api/377/20447)

	* 新增入参：DisasterRecoverGroupIds

* [ModifyLaunchConfigurationAttributes](https://cloud.tencent.com/document/api/377/31298)

	* 新增入参：DisasterRecoverGroupIds


修改数据结构：

* [Instance](https://cloud.tencent.com/document/api/377/20453#Instance)

	* 新增成员：DisasterRecoverGroupIds


### 第 61 次发布

发布时间：2023-03-23 01:04:00

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateScalingPolicy](https://cloud.tencent.com/document/api/377/33180)

	* 新增入参：ScalingPolicyType, PredefinedMetricType, TargetValue, EstimatedInstanceWarmup, DisableScaleIn

	* <font color="#dd0000">**修改入参**：</font>AdjustmentType, AdjustmentValue, MetricAlarm

* [ModifyScalingPolicy](https://cloud.tencent.com/document/api/377/33177)

	* 新增入参：PredefinedMetricType, TargetValue, EstimatedInstanceWarmup, DisableScaleIn


修改数据结构：

* [Instance](https://cloud.tencent.com/document/api/377/20453#Instance)

	* 新增成员：WarmupStatus

* [MetricAlarm](https://cloud.tencent.com/document/api/377/20453#MetricAlarm)

	* 新增成员：PreciseThreshold

* [ScalingPolicy](https://cloud.tencent.com/document/api/377/20453#ScalingPolicy)

	* 新增成员：ScalingPolicyType, PredefinedMetricType, TargetValue, EstimatedInstanceWarmup, DisableScaleIn, MetricAlarms


### 第 60 次发布

发布时间：2022-11-18 06:08:39

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateLaunchConfiguration](https://cloud.tencent.com/document/api/377/20447)

	* 新增入参：IPv6InternetAccessible

* [ModifyLaunchConfigurationAttributes](https://cloud.tencent.com/document/api/377/31298)

	* 新增入参：IPv6InternetAccessible

* [UpgradeLaunchConfiguration](https://cloud.tencent.com/document/api/377/35199)

	* 新增入参：IPv6InternetAccessible


新增数据结构：

* [IPv6InternetAccessible](https://cloud.tencent.com/document/api/377/20453#IPv6InternetAccessible)

修改数据结构：

* [LaunchConfiguration](https://cloud.tencent.com/document/api/377/20453#LaunchConfiguration)

	* 新增成员：IPv6InternetAccessible


### 第 59 次发布

发布时间：2022-11-16 06:08:16

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [EnhancedService](https://cloud.tencent.com/document/api/377/20453#EnhancedService)

	* 新增成员：AutomationToolsService


### 第 58 次发布

发布时间：2022-11-03 06:08:22

本次发布包含了以下内容：

改善已有的文档。

新增数据结构：

* [RunAutomationServiceEnabled](https://cloud.tencent.com/document/api/377/20453#RunAutomationServiceEnabled)

修改数据结构：

* [EnhancedService](https://cloud.tencent.com/document/api/377/20453#EnhancedService)

	* 新增成员：AutomationService


### 第 57 次发布

发布时间：2022-09-02 06:09:13

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [ModifyLifecycleHook](https://cloud.tencent.com/document/api/377/73060)

	* 新增入参：LifecycleCommand

* [UpgradeLifecycleHook](https://cloud.tencent.com/document/api/377/34451)

	* 新增入参：LifecycleCommand


### 第 56 次发布

发布时间：2022-09-01 06:08:45

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [LifecycleCommand](https://cloud.tencent.com/document/api/377/20453#LifecycleCommand)

	* <font color="#dd0000">**修改成员**：</font>Parameters


### 第 55 次发布

发布时间：2022-08-30 06:08:56

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateLifecycleHook](https://cloud.tencent.com/document/api/377/34454)

	* 新增入参：LifecycleCommand


新增数据结构：

* [LifecycleCommand](https://cloud.tencent.com/document/api/377/20453#LifecycleCommand)

修改数据结构：

* [LifecycleActionResultInfo](https://cloud.tencent.com/document/api/377/20453#LifecycleActionResultInfo)

	* 新增成员：InvocationId, InvokeCommandResult

* [LifecycleHook](https://cloud.tencent.com/document/api/377/20453#LifecycleHook)

	* 新增成员：LifecycleCommand


### 第 54 次发布

发布时间：2022-08-11 06:10:05

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateLaunchConfiguration](https://cloud.tencent.com/document/api/377/20447)

	* 新增入参：HpcClusterId

* [ModifyLaunchConfigurationAttributes](https://cloud.tencent.com/document/api/377/31298)

	* 新增入参：HpcClusterId


修改数据结构：

* [LaunchConfiguration](https://cloud.tencent.com/document/api/377/20453#LaunchConfiguration)

	* 新增成员：HpcClusterId


### 第 53 次发布

发布时间：2022-07-26 06:06:18

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateLaunchConfiguration](https://cloud.tencent.com/document/api/377/20447)

	* 新增入参：Tags


新增数据结构：

* [InvocationResult](https://cloud.tencent.com/document/api/377/20453#InvocationResult)

修改数据结构：

* [Activity](https://cloud.tencent.com/document/api/377/20453#Activity)

	* 新增成员：InvocationResultSet

* [LaunchConfiguration](https://cloud.tencent.com/document/api/377/20453#LaunchConfiguration)

	* 新增成员：Tags


### 第 52 次发布

发布时间：2022-04-28 06:06:38

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [DataDisk](https://cloud.tencent.com/document/api/377/20453#DataDisk)

	* 新增成员：ThroughputPerformance


### 第 51 次发布

发布时间：2022-04-25 06:01:06

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [ModifyLifecycleHook](https://cloud.tencent.com/document/api/377/73060)

修改数据结构：

* [AutoScalingAdvice](https://cloud.tencent.com/document/api/377/20453#AutoScalingAdvice)

	* 新增成员：Level


### 第 50 次发布

发布时间：2022-04-04 06:07:52

本次发布包含了以下内容：

改善已有的文档。

<font color="#dd0000">**删除接口**：</font>

* DescribePaiInstances

<font color="#dd0000">**删除数据结构**：</font>

* PaiInstance

### 第 49 次发布

发布时间：2022-03-30 06:01:19

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [DataDisk](https://cloud.tencent.com/document/api/377/20453#DataDisk)

	* 新增成员：Encrypt


### 第 48 次发布

发布时间：2022-03-11 08:03:26

本次发布包含了以下内容：

改善已有的文档。

<font color="#dd0000">**删除接口**：</font>

* PreviewPaiDomainName

### 第 47 次发布

发布时间：2022-03-09 08:05:55

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [DataDisk](https://cloud.tencent.com/document/api/377/20453#DataDisk)

	* 新增成员：DeleteWithInstance

* [ScheduledAction](https://cloud.tencent.com/document/api/377/20453#ScheduledAction)

	* 新增成员：ScheduledType


### 第 46 次发布

发布时间：2022-02-23 08:02:26

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [ModifyDesiredCapacity](https://cloud.tencent.com/document/api/377/20432)

	* 新增入参：MinSize, MaxSize


### 第 45 次发布

发布时间：2022-01-07 08:03:22

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [ModifyLaunchConfigurationAttributes](https://cloud.tencent.com/document/api/377/31298)

	* 新增入参：CamRoleName


### 第 44 次发布

发布时间：2022-01-05 08:03:39

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [AttachLoadBalancers](https://cloud.tencent.com/document/api/377/67354)
* [DetachLoadBalancers](https://cloud.tencent.com/document/api/377/67353)
* [ModifyLoadBalancerTargetAttributes](https://cloud.tencent.com/document/api/377/67352)

新增数据结构：

* [ForwardLoadBalancerIdentification](https://cloud.tencent.com/document/api/377/20453#ForwardLoadBalancerIdentification)

### 第 43 次发布

发布时间：2021-12-14 08:05:13

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeAutoScalingAdvices](https://cloud.tencent.com/document/api/377/65901)

新增数据结构：

* [Advice](https://cloud.tencent.com/document/api/377/20453#Advice)
* [AutoScalingAdvice](https://cloud.tencent.com/document/api/377/20453#AutoScalingAdvice)

### 第 42 次发布

发布时间：2021-11-15 08:04:22

本次发布包含了以下内容：

改善已有的文档。

<font color="#dd0000">**删除接口**：</font>

* CreatePaiInstance

### 第 41 次发布

发布时间：2021-10-27 08:02:46

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [ModifyLaunchConfigurationAttributes](https://cloud.tencent.com/document/api/377/31298)

	* 新增入参：EnhancedService


### 第 40 次发布

发布时间：2021-10-21 11:15:03

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateNotificationConfiguration](https://cloud.tencent.com/document/api/377/33185)

	* 新增入参：TargetType, QueueName, TopicName

	* <font color="#dd0000">**修改入参**：</font>NotificationUserGroupIds

* [ModifyNotificationConfiguration](https://cloud.tencent.com/document/api/377/33182)

	* 新增入参：QueueName, TopicName


修改数据结构：

* [AutoScalingNotification](https://cloud.tencent.com/document/api/377/20453#AutoScalingNotification)

	* 新增成员：TargetType, QueueName, TopicName


### 第 39 次发布

发布时间：2021-09-06 08:03:06

本次发布包含了以下内容：

改善已有的文档。

新增数据结构：

* [DetailedStatusMessage](https://cloud.tencent.com/document/api/377/20453#DetailedStatusMessage)

修改数据结构：

* [Activity](https://cloud.tencent.com/document/api/377/20453#Activity)

	* 新增成员：DetailedStatusMessageSet


### 第 38 次发布

发布时间：2021-08-06 08:03:03

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateAutoScalingGroup](https://cloud.tencent.com/document/api/377/20440)

	* 新增入参：CapacityRebalance

* [ModifyAutoScalingGroup](https://cloud.tencent.com/document/api/377/20433)

	* 新增入参：CapacityRebalance


### 第 37 次发布

发布时间：2021-07-20 08:04:50

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateAutoScalingGroup](https://cloud.tencent.com/document/api/377/20440)

	* 新增入参：InstanceAllocationPolicy, SpotMixedAllocationPolicy

* [ModifyAutoScalingGroup](https://cloud.tencent.com/document/api/377/20433)

	* 新增入参：InstanceAllocationPolicy, SpotMixedAllocationPolicy


新增数据结构：

* [SpotMixedAllocationPolicy](https://cloud.tencent.com/document/api/377/20453#SpotMixedAllocationPolicy)

修改数据结构：

* [AutoScalingGroup](https://cloud.tencent.com/document/api/377/20453#AutoScalingGroup)

	* 新增成员：InstanceAllocationPolicy, SpotMixedAllocationPolicy, CapacityRebalance


### 第 36 次发布

发布时间：2021-07-09 08:02:59

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [ClearLaunchConfigurationAttributes](https://cloud.tencent.com/document/api/377/54255)

	* 新增入参：ClearHostNameSettings, ClearInstanceNameSettings

* [ModifyLaunchConfigurationAttributes](https://cloud.tencent.com/document/api/377/31298)

	* 新增入参：HostNameSettings, InstanceNameSettings


修改数据结构：

* [AutoScalingGroup](https://cloud.tencent.com/document/api/377/20453#AutoScalingGroup)

	* 新增成员：HealthCheckType, LoadBalancerHealthCheckGracePeriod


### 第 35 次发布

发布时间：2021-06-17 08:02:54

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateAutoScalingGroup](https://cloud.tencent.com/document/api/377/20440)

	* 新增入参：HealthCheckType, LoadBalancerHealthCheckGracePeriod

* [ModifyAutoScalingGroup](https://cloud.tencent.com/document/api/377/20433)

	* 新增入参：HealthCheckType, LoadBalancerHealthCheckGracePeriod


修改数据结构：

* [ServiceSettings](https://cloud.tencent.com/document/api/377/20453#ServiceSettings)

	* 新增成员：ReplaceLoadBalancerUnhealthy


### 第 34 次发布

发布时间：2021-05-28 08:02:36

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [ScaleInInstances](https://cloud.tencent.com/document/api/377/56370)
* [ScaleOutInstances](https://cloud.tencent.com/document/api/377/56369)

### 第 33 次发布

发布时间：2021-05-11 08:02:28

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [LaunchConfiguration](https://cloud.tencent.com/document/api/377/20453#LaunchConfiguration)

	* 新增成员：DiskTypePolicy


### 第 32 次发布

发布时间：2021-04-01 08:02:04

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [ClearLaunchConfigurationAttributes](https://cloud.tencent.com/document/api/377/54255)

修改接口：

* [ModifyLaunchConfigurationAttributes](https://cloud.tencent.com/document/api/377/31298)

	* 新增入参：SystemDisk, DataDisks


### 第 31 次发布

发布时间：2021-03-22 08:02:16

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateLaunchConfiguration](https://cloud.tencent.com/document/api/377/20447)

	* 新增入参：DiskTypePolicy

* [ModifyLaunchConfigurationAttributes](https://cloud.tencent.com/document/api/377/31298)

	* 新增入参：DiskTypePolicy

* [UpgradeLaunchConfiguration](https://cloud.tencent.com/document/api/377/35199)

	* 新增入参：DiskTypePolicy


### 第 30 次发布

发布时间：2021-01-14 08:01:59

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [ModifyLaunchConfigurationAttributes](https://cloud.tencent.com/document/api/377/31298)

	* 新增入参：SecurityGroupIds, InternetAccessible, InstanceChargeType, InstanceChargePrepaid, InstanceMarketOptions


### 第 29 次发布

发布时间：2020-06-10 08:03:37

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [ExecuteScalingPolicy](https://cloud.tencent.com/document/api/377/35477)

	* 新增入参：TriggerSource


### 第 28 次发布

发布时间：2020-06-09 08:04:26

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [InternetAccessible](https://cloud.tencent.com/document/api/377/20453#InternetAccessible)

	* 新增成员：BandwidthPackageId


### 第 27 次发布

发布时间：2020-04-20 08:03:10

本次发布包含了以下内容：

改善已有的文档。

新增数据结构：

* [LifecycleActionResultInfo](https://cloud.tencent.com/document/api/377/20453#LifecycleActionResultInfo)

修改数据结构：

* [Activity](https://cloud.tencent.com/document/api/377/20453#Activity)

	* 新增成员：LifecycleActionResultSet


### 第 26 次发布

发布时间：2020-03-06 14:06:29

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateLifecycleHook](https://cloud.tencent.com/document/api/377/34454)

	* 新增入参：LifecycleTransitionType

* [UpgradeLifecycleHook](https://cloud.tencent.com/document/api/377/34451)

	* 新增入参：LifecycleTransitionType


### 第 25 次发布

发布时间：2020-02-26 21:50:31

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [LifecycleHook](https://cloud.tencent.com/document/api/377/20453#LifecycleHook)

	* 新增成员：LifecycleTransitionType


### 第 24 次发布

发布时间：2020-02-20 10:07:02

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [UpgradeLaunchConfiguration](https://cloud.tencent.com/document/api/377/35199)

	* <font color="#dd0000">**修改入参**：</font>InstanceNameSettings


修改数据结构：

* [ForwardLoadBalancer](https://cloud.tencent.com/document/api/377/20453#ForwardLoadBalancer)

	* 新增成员：Region

* [LaunchConfiguration](https://cloud.tencent.com/document/api/377/20453#LaunchConfiguration)

	* <font color="#dd0000">**修改成员**：</font>InstanceNameSettings


### 第 23 次发布

发布时间：2020-01-09 11:28:08

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateAutoScalingGroup](https://cloud.tencent.com/document/api/377/20440)

	* 新增入参：MultiZoneSubnetPolicy

* [CreateLaunchConfiguration](https://cloud.tencent.com/document/api/377/20447)

	* 新增入参：InstanceNameSettings, InstanceChargePrepaid

* [ModifyAutoScalingGroup](https://cloud.tencent.com/document/api/377/20433)

	* 新增入参：MultiZoneSubnetPolicy

* [UpgradeLaunchConfiguration](https://cloud.tencent.com/document/api/377/35199)

	* 新增入参：InstanceNameSettings, InstanceChargePrepaid


新增数据结构：

* [InstanceNameSettings](https://cloud.tencent.com/document/api/377/20453#InstanceNameSettings)

修改数据结构：

* [AutoScalingGroup](https://cloud.tencent.com/document/api/377/20453#AutoScalingGroup)

	* 新增成员：MultiZoneSubnetPolicy

* [LaunchConfiguration](https://cloud.tencent.com/document/api/377/20453#LaunchConfiguration)

	* 新增成员：InstanceNameSettings, InstanceChargePrepaid


### 第 22 次发布

发布时间：2019-12-17 12:00:22

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [StartAutoScalingInstances](https://cloud.tencent.com/document/api/377/40287)
* [StopAutoScalingInstances](https://cloud.tencent.com/document/api/377/40286)

修改接口：

* [CreateAutoScalingGroup](https://cloud.tencent.com/document/api/377/20440)

	* 新增入参：Ipv6AddressCount

* [ModifyAutoScalingGroup](https://cloud.tencent.com/document/api/377/20433)

	* 新增入参：Ipv6AddressCount


修改数据结构：

* [AutoScalingGroup](https://cloud.tencent.com/document/api/377/20453#AutoScalingGroup)

	* 新增成员：Ipv6AddressCount

* [ServiceSettings](https://cloud.tencent.com/document/api/377/20453#ServiceSettings)

	* 新增成员：ScalingMode


### 第 21 次发布

发布时间：2019-11-28 22:15:47

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateAutoScalingGroupFromInstance](https://cloud.tencent.com/document/api/377/39773)

修改数据结构：

* [PaiInstance](https://cloud.tencent.com/document/api/377/20453#PaiInstance)

	* 新增成员：PaiMateUrl


### 第 20 次发布

发布时间：2019-11-21 19:39:04

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateLaunchConfiguration](https://cloud.tencent.com/document/api/377/20447)

	* 新增入参：HostNameSettings

* [UpgradeLaunchConfiguration](https://cloud.tencent.com/document/api/377/35199)

	* 新增入参：HostNameSettings


新增数据结构：

* [HostNameSettings](https://cloud.tencent.com/document/api/377/20453#HostNameSettings)

修改数据结构：

* [LaunchConfiguration](https://cloud.tencent.com/document/api/377/20453#LaunchConfiguration)

	* 新增成员：HostNameSettings


### 第 19 次发布

发布时间：2019-09-26 21:43:04

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [ModifyLoadBalancers](https://cloud.tencent.com/document/api/377/32868)

	* 新增入参：LoadBalancersCheckPolicy


修改数据结构：

* [LaunchConfiguration](https://cloud.tencent.com/document/api/377/20453#LaunchConfiguration)

	* 新增成员：LastOperationInstanceTypesCheckPolicy


### 第 18 次发布

发布时间：2019-08-29 20:13:44

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeAutoScalingGroupLastActivities](https://cloud.tencent.com/document/api/377/37652)

### 第 17 次发布

发布时间：2019-08-01 14:33:42

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [Instance](https://cloud.tencent.com/document/api/377/20453#Instance)

	* 新增成员：AutoScalingGroupName


### 第 16 次发布

发布时间：2019-07-12 11:37:21

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateAutoScalingGroup](https://cloud.tencent.com/document/api/377/20440)

	* 新增入参：ServiceSettings

* [CreateLaunchConfiguration](https://cloud.tencent.com/document/api/377/20447)

	* 新增入参：CamRoleName

* [ModifyAutoScalingGroup](https://cloud.tencent.com/document/api/377/20433)

	* 新增入参：ServiceSettings

* [UpgradeLaunchConfiguration](https://cloud.tencent.com/document/api/377/35199)

	* 新增入参：CamRoleName


新增数据结构：

* [ServiceSettings](https://cloud.tencent.com/document/api/377/20453#ServiceSettings)

修改数据结构：

* [AutoScalingGroup](https://cloud.tencent.com/document/api/377/20453#AutoScalingGroup)

	* 新增成员：ServiceSettings

* [LaunchConfiguration](https://cloud.tencent.com/document/api/377/20453#LaunchConfiguration)

	* 新增成员：CamRoleName


### 第 15 次发布

发布时间：2019-06-13 16:13:04

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [ExecuteScalingPolicy](https://cloud.tencent.com/document/api/377/35477)

### 第 14 次发布

发布时间：2019-06-06 20:15:07

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateAutoScalingGroup](https://cloud.tencent.com/document/api/377/20440)

	* 新增入参：Tags


新增数据结构：

* [Tag](https://cloud.tencent.com/document/api/377/20453#Tag)

修改数据结构：

* [AutoScalingGroup](https://cloud.tencent.com/document/api/377/20453#AutoScalingGroup)

	* 新增成员：Tags


### 第 13 次发布

发布时间：2019-05-30 19:51:36

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [UpgradeLaunchConfiguration](https://cloud.tencent.com/document/api/377/35199)

修改接口：

* [AttachInstances](https://cloud.tencent.com/document/api/377/20441)

	* 新增出参：ActivityId

* [DetachInstances](https://cloud.tencent.com/document/api/377/20436)

	* 新增出参：ActivityId

* [RemoveInstances](https://cloud.tencent.com/document/api/377/20431)

	* 新增出参：ActivityId


修改数据结构：

* [LifecycleHook](https://cloud.tencent.com/document/api/377/20453#LifecycleHook)

	* <font color="#dd0000">**修改成员**：</font>NotificationTarget

* [ScalingPolicy](https://cloud.tencent.com/document/api/377/20453#ScalingPolicy)

	* <font color="#dd0000">**修改成员**：</font>AdjustmentValue


### 第 12 次发布

发布时间：2019-05-16 19:38:05

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [Instance](https://cloud.tencent.com/document/api/377/20453#Instance)

	* 新增成员：VersionNumber

* [LaunchConfiguration](https://cloud.tencent.com/document/api/377/20453#LaunchConfiguration)

	* 新增成员：VersionNumber, UpdatedTime


### 第 11 次发布

发布时间：2019-04-25 19:24:45

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CompleteLifecycleAction](https://cloud.tencent.com/document/api/377/34455)
* [CreateLifecycleHook](https://cloud.tencent.com/document/api/377/34454)
* [CreatePaiInstance](https://cloud.tencent.com/document/api/377/34459)
* [DeleteLifecycleHook](https://cloud.tencent.com/document/api/377/34453)
* [DescribeLifecycleHooks](https://cloud.tencent.com/document/api/377/34452)
* [DescribePaiInstances](https://cloud.tencent.com/document/api/377/34458)
* [PreviewPaiDomainName](https://cloud.tencent.com/document/api/377/34457)
* [UpgradeLifecycleHook](https://cloud.tencent.com/document/api/377/34451)

修改接口：

* [CreateLaunchConfiguration](https://cloud.tencent.com/document/api/377/20447)

	* 新增入参：InstanceTags


新增数据结构：

* [InstanceChargePrepaid](https://cloud.tencent.com/document/api/377/20453#InstanceChargePrepaid)
* [InstanceTag](https://cloud.tencent.com/document/api/377/20453#InstanceTag)
* [LifecycleHook](https://cloud.tencent.com/document/api/377/20453#LifecycleHook)
* [NotificationTarget](https://cloud.tencent.com/document/api/377/20453#NotificationTarget)
* [PaiInstance](https://cloud.tencent.com/document/api/377/20453#PaiInstance)

修改数据结构：

* [LaunchConfiguration](https://cloud.tencent.com/document/api/377/20453#LaunchConfiguration)

	* 新增成员：InstanceTags


### 第 10 次发布

发布时间：2019-03-08 17:33:58

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [AutoScalingGroup](https://cloud.tencent.com/document/api/377/20453#AutoScalingGroup)

	* 新增成员：InActivityStatus


### 第 9 次发布

发布时间：2019-02-22 14:42:40

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateNotificationConfiguration](https://cloud.tencent.com/document/api/377/33185)
* [CreateScalingPolicy](https://cloud.tencent.com/document/api/377/33180)
* [DeleteNotificationConfiguration](https://cloud.tencent.com/document/api/377/33184)
* [DeleteScalingPolicy](https://cloud.tencent.com/document/api/377/33179)
* [DescribeNotificationConfigurations](https://cloud.tencent.com/document/api/377/33183)
* [DescribeScalingPolicies](https://cloud.tencent.com/document/api/377/33178)
* [ModifyNotificationConfiguration](https://cloud.tencent.com/document/api/377/33182)
* [ModifyScalingPolicy](https://cloud.tencent.com/document/api/377/33177)
* [SetInstancesProtection](https://cloud.tencent.com/document/api/377/33175)

修改接口：

* [DescribeAutoScalingActivities](https://cloud.tencent.com/document/api/377/31735)

	* 新增入参：StartTime, EndTime


新增数据结构：

* [AutoScalingNotification](https://cloud.tencent.com/document/api/377/20453#AutoScalingNotification)
* [MetricAlarm](https://cloud.tencent.com/document/api/377/20453#MetricAlarm)
* [ScalingPolicy](https://cloud.tencent.com/document/api/377/20453#ScalingPolicy)

### 第 8 次发布

发布时间：2019-02-14 16:01:19

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [AutoScalingGroup](https://cloud.tencent.com/document/api/377/20453#AutoScalingGroup)

	* <font color="#dd0000">**修改成员**：</font>DefaultCooldown, DesiredCapacity, InstanceCount, InServiceInstanceCount, MaxSize, MinSize, ProjectId


### 第 7 次发布

发布时间：2019-01-24 17:23:35

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [ModifyLoadBalancers](https://cloud.tencent.com/document/api/377/32868)

修改接口：

* [ModifyLaunchConfigurationAttributes](https://cloud.tencent.com/document/api/377/31298)

	* 新增入参：UserData


### 第 6 次发布

发布时间：2018-12-27 19:18:13

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [DataDisk](https://cloud.tencent.com/document/api/377/20453#DataDisk)

	* 新增成员：SnapshotId


### 第 5 次发布

发布时间：2018-12-19 10:09:33

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeAutoScalingActivities](https://cloud.tencent.com/document/api/377/31735)

新增数据结构：

* [Activity](https://cloud.tencent.com/document/api/377/20453#Activity)
* [ActivtyRelatedInstance](https://cloud.tencent.com/document/api/377/20453#ActivtyRelatedInstance)

### 第 4 次发布

发布时间：2018-12-06 18:57:45

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [ModifyLaunchConfigurationAttributes](https://cloud.tencent.com/document/api/377/31298)

修改接口：

* [CreateAutoScalingGroup](https://cloud.tencent.com/document/api/377/20440)

	* 新增入参：ZonesCheckPolicy

* [CreateLaunchConfiguration](https://cloud.tencent.com/document/api/377/20447)

	* 新增入参：InstanceTypesCheckPolicy

* [ModifyAutoScalingGroup](https://cloud.tencent.com/document/api/377/20433)

	* 新增入参：ZonesCheckPolicy


### 第 3 次发布

发布时间：2018-11-15 15:42:48

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateAutoScalingGroup](https://cloud.tencent.com/document/api/377/20440)

	* 新增入参：RetryPolicy

* [CreateLaunchConfiguration](https://cloud.tencent.com/document/api/377/20447)

	* 新增入参：InstanceTypes

	* <font color="#dd0000">**修改入参**：</font>InstanceType

* [ModifyAutoScalingGroup](https://cloud.tencent.com/document/api/377/20433)

	* 新增入参：RetryPolicy


修改数据结构：

* [AutoScalingGroup](https://cloud.tencent.com/document/api/377/20453#AutoScalingGroup)

	* 新增成员：RetryPolicy

* [Instance](https://cloud.tencent.com/document/api/377/20453#Instance)

	* 新增成员：InstanceType

* [LaunchConfiguration](https://cloud.tencent.com/document/api/377/20453#LaunchConfiguration)

	* 新增成员：InstanceTypes


### 第 2 次发布

发布时间：2018-10-19 17:44:13

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateLaunchConfiguration](https://cloud.tencent.com/document/api/377/20447)

	* 新增入参：InstanceChargeType, InstanceMarketOptions


新增数据结构：

* [InstanceMarketOptionsRequest](https://cloud.tencent.com/document/api/377/20453#InstanceMarketOptionsRequest)
* [SpotMarketOptions](https://cloud.tencent.com/document/api/377/20453#SpotMarketOptions)

修改数据结构：

* [Instance](https://cloud.tencent.com/document/api/377/20453#Instance)

	* <font color="#dd0000">**修改成员**：</font>CreationType

* [LaunchConfiguration](https://cloud.tencent.com/document/api/377/20453#LaunchConfiguration)

	* 新增成员：InstanceChargeType, InstanceMarketOptions


### 第 1 次发布

发布时间：2018-10-11 15:37:12

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [AttachInstances](https://cloud.tencent.com/document/api/377/20441)
* [CreateAutoScalingGroup](https://cloud.tencent.com/document/api/377/20440)
* [CreateLaunchConfiguration](https://cloud.tencent.com/document/api/377/20447)
* [CreateScheduledAction](https://cloud.tencent.com/document/api/377/20452)
* [DeleteAutoScalingGroup](https://cloud.tencent.com/document/api/377/20439)
* [DeleteLaunchConfiguration](https://cloud.tencent.com/document/api/377/20446)
* [DeleteScheduledAction](https://cloud.tencent.com/document/api/377/20451)
* [DescribeAccountLimits](https://cloud.tencent.com/document/api/377/20443)
* [DescribeAutoScalingGroups](https://cloud.tencent.com/document/api/377/20438)
* [DescribeAutoScalingInstances](https://cloud.tencent.com/document/api/377/20437)
* [DescribeLaunchConfigurations](https://cloud.tencent.com/document/api/377/20445)
* [DescribeScheduledActions](https://cloud.tencent.com/document/api/377/20450)
* [DetachInstances](https://cloud.tencent.com/document/api/377/20436)
* [DisableAutoScalingGroup](https://cloud.tencent.com/document/api/377/20435)
* [EnableAutoScalingGroup](https://cloud.tencent.com/document/api/377/20434)
* [ModifyAutoScalingGroup](https://cloud.tencent.com/document/api/377/20433)
* [ModifyDesiredCapacity](https://cloud.tencent.com/document/api/377/20432)
* [ModifyScheduledAction](https://cloud.tencent.com/document/api/377/20449)
* [RemoveInstances](https://cloud.tencent.com/document/api/377/20431)

新增数据结构：

* [AutoScalingGroup](https://cloud.tencent.com/document/api/377/20453#AutoScalingGroup)
* [AutoScalingGroupAbstract](https://cloud.tencent.com/document/api/377/20453#AutoScalingGroupAbstract)
* [DataDisk](https://cloud.tencent.com/document/api/377/20453#DataDisk)
* [EnhancedService](https://cloud.tencent.com/document/api/377/20453#EnhancedService)
* [Filter](https://cloud.tencent.com/document/api/377/20453#Filter)
* [ForwardLoadBalancer](https://cloud.tencent.com/document/api/377/20453#ForwardLoadBalancer)
* [Instance](https://cloud.tencent.com/document/api/377/20453#Instance)
* [InternetAccessible](https://cloud.tencent.com/document/api/377/20453#InternetAccessible)
* [LaunchConfiguration](https://cloud.tencent.com/document/api/377/20453#LaunchConfiguration)
* [LimitedLoginSettings](https://cloud.tencent.com/document/api/377/20453#LimitedLoginSettings)
* [LoginSettings](https://cloud.tencent.com/document/api/377/20453#LoginSettings)
* [RunMonitorServiceEnabled](https://cloud.tencent.com/document/api/377/20453#RunMonitorServiceEnabled)
* [RunSecurityServiceEnabled](https://cloud.tencent.com/document/api/377/20453#RunSecurityServiceEnabled)
* [ScheduledAction](https://cloud.tencent.com/document/api/377/20453#ScheduledAction)
* [SystemDisk](https://cloud.tencent.com/document/api/377/20453#SystemDisk)
* [TargetAttribute](https://cloud.tencent.com/document/api/377/20453#TargetAttribute)




## 语音识别(asr) 版本：2019-06-14

### 第 37 次发布

发布时间：2024-06-27 01:05:14

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateRecTask](https://cloud.tencent.com/document/api/1093/37823)

	* 新增入参：HotwordList


### 第 36 次发布

发布时间：2024-06-25 01:07:52

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [VoicePrintGroupVerify](https://cloud.tencent.com/document/api/1093/107668)

修改接口：

* [VoicePrintCount](https://cloud.tencent.com/document/api/1093/96061)

	* 新增入参：GroupId, CountMod

* [VoicePrintDelete](https://cloud.tencent.com/document/api/1093/94484)

	* 新增入参：GroupId, DelMod

* [VoicePrintEnroll](https://cloud.tencent.com/document/api/1093/94483)

	* 新增入参：GroupId


新增数据结构：

* [VerifyTop](https://cloud.tencent.com/document/api/1093/37824#VerifyTop)
* [VerifyTopResult](https://cloud.tencent.com/document/api/1093/37824#VerifyTopResult)

修改数据结构：

* [VoicePrintCountData](https://cloud.tencent.com/document/api/1093/37824#VoicePrintCountData)

	* 新增成员：VoicePrintList


### 第 35 次发布

发布时间：2024-06-21 01:10:11

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [VoicePrintDelete](https://cloud.tencent.com/document/api/1093/94484)

	* <font color="#dd0000">**修改入参**：</font>VoicePrintId


### 第 34 次发布

发布时间：2024-04-11 01:07:46

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateRecTask](https://cloud.tencent.com/document/api/1093/37823)

* [SentenceRecognition](https://cloud.tencent.com/document/api/1093/35646)


### 第 33 次发布

发布时间：2024-02-23 01:07:51

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateCustomization](https://cloud.tencent.com/document/api/1093/48601)

* [GetCustomizationList](https://cloud.tencent.com/document/api/1093/48498)


### 第 32 次发布

发布时间：2024-02-02 01:05:31

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [VoicePrintCompare](https://cloud.tencent.com/document/api/1093/103720)

新增数据结构：

* [VoicePrintCompareData](https://cloud.tencent.com/document/api/1093/37824#VoicePrintCompareData)

### 第 31 次发布

发布时间：2023-09-22 01:10:19

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [SentenceDetail](https://cloud.tencent.com/document/api/1093/37824#SentenceDetail)

	* 新增成员：WrittenText

	* <font color="#dd0000">**修改成员**：</font>EmotionType


### 第 30 次发布

发布时间：2023-08-08 01:06:35

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [VoicePrintCount](https://cloud.tencent.com/document/api/1093/96061)

新增数据结构：

* [VoicePrintCountData](https://cloud.tencent.com/document/api/1093/37824#VoicePrintCountData)

### 第 29 次发布

发布时间：2023-07-18 01:07:49

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [SentenceRecognition](https://cloud.tencent.com/document/api/1093/35646)

	* 新增入参：InputSampleRate


### 第 28 次发布

发布时间：2023-07-05 01:07:50

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [VoicePrintDelete](https://cloud.tencent.com/document/api/1093/94484)
* [VoicePrintEnroll](https://cloud.tencent.com/document/api/1093/94483)
* [VoicePrintUpdate](https://cloud.tencent.com/document/api/1093/94482)
* [VoicePrintVerify](https://cloud.tencent.com/document/api/1093/94481)

新增数据结构：

* [VoicePrintBaseData](https://cloud.tencent.com/document/api/1093/37824#VoicePrintBaseData)
* [VoicePrintVerifyData](https://cloud.tencent.com/document/api/1093/37824#VoicePrintVerifyData)

### 第 27 次发布

发布时间：2023-05-22 01:03:30

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [SentenceRecognition](https://cloud.tencent.com/document/api/1093/35646)


### 第 26 次发布

发布时间：2023-05-11 01:03:26

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [SentenceRecognition](https://cloud.tencent.com/document/api/1093/35646)

	* 新增入参：HotwordList


### 第 25 次发布

发布时间：2023-05-08 01:07:44

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [GetModelInfo](https://cloud.tencent.com/document/api/1093/90813)

### 第 24 次发布

发布时间：2023-04-05 01:07:23

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [SentenceRecognition](https://cloud.tencent.com/document/api/1093/35646)

	* <font color="#dd0000">**修改入参**：</font>ProjectId, SubServiceType, UsrAudioKey


### 第 23 次发布

发布时间：2023-02-09 01:04:17

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateRecTask](https://cloud.tencent.com/document/api/1093/37823)

	* 新增入参：EmotionRecognition


修改数据结构：

* [SentenceDetail](https://cloud.tencent.com/document/api/1093/37824#SentenceDetail)

	* 新增成员：EmotionType


### 第 22 次发布

发布时间：2022-12-28 01:04:09

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateRecTask](https://cloud.tencent.com/document/api/1093/37823)

	* 新增入参：SentenceMaxLength


### 第 21 次发布

发布时间：2022-11-28 06:10:45

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateRecTask](https://cloud.tencent.com/document/api/1093/37823)

	* 新增入参：EmotionalEnergy, ReinforceHotword

* [SentenceRecognition](https://cloud.tencent.com/document/api/1093/35646)

	* 新增入参：ReinforceHotword


修改数据结构：

* [SentenceDetail](https://cloud.tencent.com/document/api/1093/37824#SentenceDetail)

	* 新增成员：EmotionalEnergy, SilenceTime


### 第 20 次发布

发布时间：2022-09-02 06:09:54

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [SentenceRecognition](https://cloud.tencent.com/document/api/1093/35646)

	* 新增入参：CustomizationId


### 第 19 次发布

发布时间：2022-04-12 06:06:07

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [SentenceDetail](https://cloud.tencent.com/document/api/1093/37824#SentenceDetail)

	* 新增成员：SpeakerId


### 第 18 次发布

发布时间：2022-03-18 08:06:40

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateRecTask](https://cloud.tencent.com/document/api/1093/37823)

	* 新增入参：CustomizationId


### 第 17 次发布

发布时间：2021-12-22 08:06:39

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateAsyncRecognitionTask](https://cloud.tencent.com/document/api/1093/52061)

	* 新增入参：AudioData


### 第 16 次发布

发布时间：2021-12-09 08:01:20

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [TaskStatus](https://cloud.tencent.com/document/api/1093/37824#TaskStatus)

	* 新增成员：AudioDuration


### 第 15 次发布

发布时间：2021-01-18 08:00:30

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CloseAsyncRecognitionTask](https://cloud.tencent.com/document/api/1093/52130)

### 第 14 次发布

发布时间：2021-01-15 08:00:22

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateAsyncRecognitionTask](https://cloud.tencent.com/document/api/1093/52061)
* [DescribeAsyncRecognitionTasks](https://cloud.tencent.com/document/api/1093/52060)

新增数据结构：

* [AsyncRecognitionTaskInfo](https://cloud.tencent.com/document/api/1093/37824#AsyncRecognitionTaskInfo)
* [AsyncRecognitionTasks](https://cloud.tencent.com/document/api/1093/37824#AsyncRecognitionTasks)

### 第 13 次发布

发布时间：2020-09-24 08:00:03

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [SentenceDetail](https://cloud.tencent.com/document/api/1093/37824#SentenceDetail)

	* 新增成员：SpeechSpeed


### 第 12 次发布

发布时间：2020-09-23 08:00:03

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateCustomization](https://cloud.tencent.com/document/api/1093/48601)
* [DeleteCustomization](https://cloud.tencent.com/document/api/1093/48600)
* [DownloadCustomization](https://cloud.tencent.com/document/api/1093/48599)
* [ModifyCustomization](https://cloud.tencent.com/document/api/1093/48598)
* [ModifyCustomizationState](https://cloud.tencent.com/document/api/1093/48597)

### 第 11 次发布

发布时间：2020-09-18 08:00:03

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [GetCustomizationList](https://cloud.tencent.com/document/api/1093/48498)

修改接口：

* [GetAsrVocabList](https://cloud.tencent.com/document/api/1093/41484)

	* 新增入参：TagInfos, Offset, Limit

	* 新增出参：TotalCount

* [SentenceRecognition](https://cloud.tencent.com/document/api/1093/35646)

	* 新增入参：WordInfo

	* 新增出参：WordSize, WordList


新增数据结构：

* [Model](https://cloud.tencent.com/document/api/1093/37824#Model)
* [SentenceWord](https://cloud.tencent.com/document/api/1093/37824#SentenceWord)

修改数据结构：

* [Vocab](https://cloud.tencent.com/document/api/1093/37824#Vocab)

	* 新增成员：TagInfos


### 第 10 次发布

发布时间：2020-08-11 08:00:18

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateRecTask](https://cloud.tencent.com/document/api/1093/37823)

	* 新增入参：FilterPunc


### 第 9 次发布

发布时间：2020-07-27 08:00:08

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateRecTask](https://cloud.tencent.com/document/api/1093/37823)

	* 新增入参：Extra, SpeakerDiarization, SpeakerNumber

* [SentenceRecognition](https://cloud.tencent.com/document/api/1093/35646)

	* 新增出参：AudioDuration


### 第 8 次发布

发布时间：2020-04-30 08:03:49

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateRecTask](https://cloud.tencent.com/document/api/1093/37823)

	* 新增入参：ConvertNumMode

* [SentenceRecognition](https://cloud.tencent.com/document/api/1093/35646)

	* 新增入参：ConvertNumMode


### 第 7 次发布

发布时间：2020-03-19 08:03:01

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateRecTask](https://cloud.tencent.com/document/api/1093/37823)

	* 新增入参：FilterDirty, FilterModal

* [SentenceRecognition](https://cloud.tencent.com/document/api/1093/35646)

	* 新增入参：FilterDirty, FilterModal, FilterPunc


### 第 6 次发布

发布时间：2020-02-26 14:16:23

本次发布包含了以下内容：

改善已有的文档。

新增数据结构：

* [SentenceDetail](https://cloud.tencent.com/document/api/1093/37824#SentenceDetail)
* [SentenceWords](https://cloud.tencent.com/document/api/1093/37824#SentenceWords)

修改数据结构：

* [TaskStatus](https://cloud.tencent.com/document/api/1093/37824#TaskStatus)

	* 新增成员：ResultDetail


### 第 5 次发布

发布时间：2020-02-24 14:41:30

本次发布包含了以下内容：

改善已有的文档。

<font color="#dd0000">**删除数据结构**：</font>

* SentenceDetail
* SentenceWords

修改数据结构：

* [TaskStatus](https://cloud.tencent.com/document/api/1093/37824#TaskStatus)

	* <font color="#dd0000">**删除成员**：</font>ResultDetail


### 第 4 次发布

发布时间：2020-02-24 14:04:06

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DownloadAsrVocab](https://cloud.tencent.com/document/api/1093/41485)
* [GetAsrVocabList](https://cloud.tencent.com/document/api/1093/41484)
* [SetVocabState](https://cloud.tencent.com/document/api/1093/41483)

新增数据结构：

* [SentenceDetail](https://cloud.tencent.com/document/api/1093/37824#SentenceDetail)
* [SentenceWords](https://cloud.tencent.com/document/api/1093/37824#SentenceWords)
* [Vocab](https://cloud.tencent.com/document/api/1093/37824#Vocab)

修改数据结构：

* [TaskStatus](https://cloud.tencent.com/document/api/1093/37824#TaskStatus)

	* 新增成员：ResultDetail


### 第 3 次发布

发布时间：2020-01-15 19:33:53

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateAsrVocab](https://cloud.tencent.com/document/api/1093/41111)
* [DeleteAsrVocab](https://cloud.tencent.com/document/api/1093/41110)
* [GetAsrVocab](https://cloud.tencent.com/document/api/1093/41109)
* [UpdateAsrVocab](https://cloud.tencent.com/document/api/1093/41108)

修改接口：

* [CreateRecTask](https://cloud.tencent.com/document/api/1093/37823)

	* 新增入参：HotwordId

* [SentenceRecognition](https://cloud.tencent.com/document/api/1093/35646)

	* 新增入参：HotwordId


新增数据结构：

* [HotWord](https://cloud.tencent.com/document/api/1093/37824#HotWord)

### 第 2 次发布

发布时间：2019-09-06 08:30:06

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateRecTask](https://cloud.tencent.com/document/api/1093/37823)
* [DescribeTaskStatus](https://cloud.tencent.com/document/api/1093/37822)

新增数据结构：

* [Task](https://cloud.tencent.com/document/api/1093/37824#Task)
* [TaskStatus](https://cloud.tencent.com/document/api/1093/37824#TaskStatus)

### 第 1 次发布

发布时间：2019-06-21 19:59:11

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [SentenceRecognition](https://cloud.tencent.com/document/api/1093/35646)




## 应用与服务编排工作流(asw) 版本：2020-07-22

### 第 5 次发布

发布时间：2021-04-02 08:00:26

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [StopExecution](https://cloud.tencent.com/document/api/1272/54300)

修改接口：

* [CreateFlowService](https://cloud.tencent.com/document/api/1272/49737)

	* 新增入参：EnableCLS, Input

* [DescribeFlowServiceDetail](https://cloud.tencent.com/document/api/1272/49736)

	* 新增出参：EnableCLS, CLSUrl, FlowInput

* [ModifyFlowService](https://cloud.tencent.com/document/api/1272/49735)

	* 新增入参：EnableCLS


### 第 4 次发布

发布时间：2021-03-03 08:00:19

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeExecutionHistory](https://cloud.tencent.com/document/api/1272/53356)

新增数据结构：

* [ExecutionEvent](https://cloud.tencent.com/document/api/1272/49976#ExecutionEvent)

### 第 3 次发布

发布时间：2020-11-17 08:00:03

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeFlowServices](https://cloud.tencent.com/document/api/1272/49975)

新增数据结构：

* [Filter](https://cloud.tencent.com/document/api/1272/49976#Filter)
* [StateMachine](https://cloud.tencent.com/document/api/1272/49976#StateMachine)

### 第 2 次发布

发布时间：2020-11-06 08:00:03

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateFlowService](https://cloud.tencent.com/document/api/1272/49737)
* [DescribeFlowServiceDetail](https://cloud.tencent.com/document/api/1272/49736)
* [ModifyFlowService](https://cloud.tencent.com/document/api/1272/49735)
* [StartExecution](https://cloud.tencent.com/document/api/1272/49734)

### 第 1 次发布

发布时间：2020-11-05 15:13:22

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeExecution](https://cloud.tencent.com/document/api/1272/49716)
* [DescribeExecutions](https://cloud.tencent.com/document/api/1272/49715)




## ICP备案(ba) 版本：2020-07-20

### 第 4 次发布

发布时间：2024-02-29 01:08:11

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeGetAuthInfo](https://cloud.tencent.com/document/api/243/59312)

	* 新增出参：Level


### 第 3 次发布

发布时间：2021-07-30 08:01:08

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeGetAuthInfo](https://cloud.tencent.com/document/api/243/59312)

### 第 2 次发布

发布时间：2021-07-20 08:01:59

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [SyncIcpOrderWebInfo](https://cloud.tencent.com/document/api/243/58909)

### 第 1 次发布

发布时间：2020-11-17 14:37:06

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateWeappQRUrl](https://cloud.tencent.com/document/api/243/49995)




## 批量计算(batch) 版本：2017-03-12

### 第 52 次发布

发布时间：2023-12-01 01:07:51

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [DataDisk](https://cloud.tencent.com/document/api/599/15912#DataDisk)

	* 新增成员：BurstPerformance


### 第 51 次发布

发布时间：2023-10-09 01:07:08

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [InstanceTypeQuotaItem](https://cloud.tencent.com/document/api/599/15912#InstanceTypeQuotaItem)

	* 新增成员：StatusCategory


### 第 50 次发布

发布时间：2023-09-15 15:00:54

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [Placement](https://cloud.tencent.com/document/api/599/15912#Placement)

	* <font color="#dd0000">**删除成员**：</font>HostIps


### 第 49 次发布

发布时间：2023-08-25 01:09:47

本次发布包含了以下内容：

改善已有的文档。

新增数据结构：

* [CommandLine](https://cloud.tencent.com/document/api/599/15912#CommandLine)

修改数据结构：

* [Application](https://cloud.tencent.com/document/api/599/15912#Application)

	* 新增成员：Commands


### 第 48 次发布

发布时间：2023-08-17 01:18:33

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [Application](https://cloud.tencent.com/document/api/599/15912#Application)

	* <font color="#dd0000">**修改成员**：</font>Command


### 第 47 次发布

发布时间：2023-07-19 01:07:48

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [StorageBlock](https://cloud.tencent.com/document/api/599/15912#StorageBlock)

	* <font color="#dd0000">**修改成员**：</font>Type, MinSize, MaxSize


### 第 46 次发布

发布时间：2023-07-18 01:08:15

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [ItemPrice](https://cloud.tencent.com/document/api/599/15912#ItemPrice)

	* <font color="#dd0000">**修改成员**：</font>UnitPrice, ChargeUnit, OriginalPrice, DiscountPrice, Discount, UnitPriceDiscount, UnitPriceSecondStep, UnitPriceDiscountSecondStep, UnitPriceThirdStep, UnitPriceDiscountThirdStep, OriginalPriceThreeYear, DiscountPriceThreeYear, DiscountThreeYear, OriginalPriceFiveYear, DiscountPriceFiveYear, DiscountFiveYear, OriginalPriceOneYear, DiscountPriceOneYear, DiscountOneYear


### 第 45 次发布

发布时间：2022-12-09 01:11:02

本次发布包含了以下内容：

改善已有的文档。

新增数据结构：

* [OutputMappingOption](https://cloud.tencent.com/document/api/599/15912#OutputMappingOption)

修改数据结构：

* [OutputMapping](https://cloud.tencent.com/document/api/599/15912#OutputMapping)

	* 新增成员：OutputMappingOption


### 第 44 次发布

发布时间：2022-12-07 06:17:30

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [InstanceTypeQuotaItem](https://cloud.tencent.com/document/api/599/15912#InstanceTypeQuotaItem)

	* 新增成员：GpuCount, Frequency


### 第 43 次发布

发布时间：2022-12-05 06:18:51

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [Docker](https://cloud.tencent.com/document/api/599/15912#Docker)

	* 新增成员：DockerRunOption


### 第 42 次发布

发布时间：2022-08-25 06:10:07

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [Docker](https://cloud.tencent.com/document/api/599/15912#Docker)

	* 新增成员：MaxRetryCount, DelayOnRetry


### 第 41 次发布

发布时间：2022-03-31 06:03:07

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [Job](https://cloud.tencent.com/document/api/599/15912#Job)

	* 新增成员：NotificationTarget

* [NamedComputeEnv](https://cloud.tencent.com/document/api/599/15912#NamedComputeEnv)

	* 新增成员：NotificationTarget

* [NamedCpmComputeEnv](https://cloud.tencent.com/document/api/599/15912#NamedCpmComputeEnv)

	* 新增成员：NotificationTarget


### 第 40 次发布

发布时间：2022-03-29 08:04:27

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [NamedComputeEnv](https://cloud.tencent.com/document/api/599/15912#NamedComputeEnv)

	* <font color="#dd0000">**修改成员**：</font>Notifications


### 第 39 次发布

发布时间：2022-02-18 08:04:38

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [ItemPrice](https://cloud.tencent.com/document/api/599/15912#ItemPrice)

	* <font color="#dd0000">**修改成员**：</font>Discount, UnitPriceDiscount, UnitPriceSecondStep, UnitPriceDiscountSecondStep, UnitPriceThirdStep, UnitPriceDiscountThirdStep, OriginalPriceThreeYear, DiscountPriceThreeYear, DiscountThreeYear, OriginalPriceFiveYear, DiscountPriceFiveYear, DiscountFiveYear, OriginalPriceOneYear, DiscountPriceOneYear, DiscountOneYear


### 第 38 次发布

发布时间：2021-08-25 08:03:12

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [RunAutomationServiceEnabled](https://cloud.tencent.com/document/api/599/15912#RunAutomationServiceEnabled)

	* 新增成员：Enabled


### 第 37 次发布

发布时间：2021-08-18 08:03:13

本次发布包含了以下内容：

改善已有的文档。

新增数据结构：

* [RunAutomationServiceEnabled](https://cloud.tencent.com/document/api/599/15912#RunAutomationServiceEnabled)

修改数据结构：

* [EnhancedService](https://cloud.tencent.com/document/api/599/15912#EnhancedService)

	* 新增成员：AutomationService


### 第 36 次发布

发布时间：2021-02-24 08:01:57

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [DataDisk](https://cloud.tencent.com/document/api/599/15912#DataDisk)

	* 新增成员：CdcId

* [SystemDisk](https://cloud.tencent.com/document/api/599/15912#SystemDisk)

	* 新增成员：CdcId


### 第 35 次发布

发布时间：2021-01-15 08:01:53

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [DataDisk](https://cloud.tencent.com/document/api/599/15912#DataDisk)

	* 新增成员：ThroughputPerformance


### 第 34 次发布

发布时间：2020-10-27 08:02:00

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [ItemPrice](https://cloud.tencent.com/document/api/599/15912#ItemPrice)

	* 新增成员：OriginalPriceThreeYear, DiscountPriceThreeYear, DiscountThreeYear, OriginalPriceFiveYear, DiscountPriceFiveYear, DiscountFiveYear, OriginalPriceOneYear, DiscountPriceOneYear, DiscountOneYear


### 第 33 次发布

发布时间：2020-10-20 08:01:43

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeJob](https://cloud.tencent.com/document/api/599/15904)

	* 新增出参：NextAction

	* <font color="#dd0000">**修改出参**：</font>TaskInstanceMetrics


### 第 32 次发布

发布时间：2020-09-23 08:01:24

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateTaskTemplate](https://cloud.tencent.com/document/api/599/15899)

	* 新增入参：Tags

* [DescribeComputeEnv](https://cloud.tencent.com/document/api/599/15892)

	* 新增出参：Tags

* [DescribeComputeEnvCreateInfo](https://cloud.tencent.com/document/api/599/15897)

	* 新增出参：Tags

* [DescribeJob](https://cloud.tencent.com/document/api/599/15904)

	* 新增出参：Tags

* [DescribeJobSubmitInfo](https://cloud.tencent.com/document/api/599/15910)

	* 新增出参：Tags


新增数据结构：

* [Tag](https://cloud.tencent.com/document/api/599/15912#Tag)

修改数据结构：

* [ComputeEnvCreateInfo](https://cloud.tencent.com/document/api/599/15912#ComputeEnvCreateInfo)

	* 新增成员：Tags

* [ComputeEnvView](https://cloud.tencent.com/document/api/599/15912#ComputeEnvView)

	* 新增成员：Tags

* [Job](https://cloud.tencent.com/document/api/599/15912#Job)

	* 新增成员：Tags

* [JobView](https://cloud.tencent.com/document/api/599/15912#JobView)

	* 新增成员：Tags

* [NamedComputeEnv](https://cloud.tencent.com/document/api/599/15912#NamedComputeEnv)

	* 新增成员：Tags

* [NamedCpmComputeEnv](https://cloud.tencent.com/document/api/599/15912#NamedCpmComputeEnv)

	* 新增成员：Tags

* [TaskTemplateView](https://cloud.tencent.com/document/api/599/15912#TaskTemplateView)

	* 新增成员：Tags


### 第 31 次发布

发布时间：2020-07-07 08:04:05

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [InstanceTypeQuotaItem](https://cloud.tencent.com/document/api/599/15912#InstanceTypeQuotaItem)

	* 新增成员：Gpu, Fpga, Remark


### 第 30 次发布

发布时间：2020-07-03 08:04:08

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [DataDisk](https://cloud.tencent.com/document/api/599/15912#DataDisk)

	* 新增成员：KmsKeyId


### 第 29 次发布

发布时间：2020-06-02 08:04:00

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [InstanceTypeQuotaItem](https://cloud.tencent.com/document/api/599/15912#InstanceTypeQuotaItem)

	* 新增成员：InstanceBandwidth, InstancePps, StorageBlockAmount, CpuType


### 第 28 次发布

发布时间：2020-04-29 08:04:08

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [ItemPrice](https://cloud.tencent.com/document/api/599/15912#ItemPrice)

	* <font color="#dd0000">**修改成员**：</font>Discount


### 第 27 次发布

发布时间：2020-03-16 08:01:47

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [ItemPrice](https://cloud.tencent.com/document/api/599/15912#ItemPrice)

	* 新增成员：Discount, UnitPriceDiscount, UnitPriceSecondStep, UnitPriceDiscountSecondStep, UnitPriceThirdStep, UnitPriceDiscountThirdStep


### 第 26 次发布

发布时间：2020-03-04 17:46:21

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [InstanceTypeQuotaItem](https://cloud.tencent.com/document/api/599/15912#InstanceTypeQuotaItem)

	* 新增成员：SoldOutReason


### 第 25 次发布

发布时间：2020-02-27 19:58:14

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [AttachInstances](https://cloud.tencent.com/document/api/599/41629)
* [DetachInstances](https://cloud.tencent.com/document/api/599/41628)

修改接口：

* [DescribeComputeEnv](https://cloud.tencent.com/document/api/599/15892)

	* 新增出参：AttachedComputeNodeCount


新增数据结构：

* [Instance](https://cloud.tencent.com/document/api/599/15912#Instance)

修改数据结构：

* [ComputeEnvView](https://cloud.tencent.com/document/api/599/15912#ComputeEnvView)

	* 新增成员：AttachedComputeNodeCount

* [ComputeNode](https://cloud.tencent.com/document/api/599/15912#ComputeNode)

	* 新增成员：ResourceOrigin

* [NamedComputeEnv](https://cloud.tencent.com/document/api/599/15912#NamedComputeEnv)

	* 新增成员：ResourceMaxRetryCount

* [NamedCpmComputeEnv](https://cloud.tencent.com/document/api/599/15912#NamedCpmComputeEnv)

	* 新增成员：ResourceMaxRetryCount


### 第 24 次发布

发布时间：2020-01-17 15:09:37

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeComputeEnv](https://cloud.tencent.com/document/api/599/15892)

	* 新增出参：NextAction


修改数据结构：

* [ComputeEnvView](https://cloud.tencent.com/document/api/599/15912#ComputeEnvView)

	* 新增成员：NextAction

* [DataDisk](https://cloud.tencent.com/document/api/599/15912#DataDisk)

	* 新增成员：Encrypt

* [Placement](https://cloud.tencent.com/document/api/599/15912#Placement)

	* 新增成员：HostId


### 第 23 次发布

发布时间：2019-12-23 23:28:59

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeCpmOsInfo](https://cloud.tencent.com/document/api/599/40422)

修改接口：

* [DescribeComputeEnv](https://cloud.tencent.com/document/api/599/15892)

	* 新增出参：ResourceType


新增数据结构：

* [OsInfo](https://cloud.tencent.com/document/api/599/15912#OsInfo)

修改数据结构：

* [ComputeEnvView](https://cloud.tencent.com/document/api/599/15912#ComputeEnvView)

	* 新增成员：ResourceType

* [ComputeNode](https://cloud.tencent.com/document/api/599/15912#ComputeNode)

	* 新增成员：ResourceType

* [VirtualPrivateCloud](https://cloud.tencent.com/document/api/599/15912#VirtualPrivateCloud)

	* 新增成员：Ipv6AddressCount


### 第 22 次发布

发布时间：2019-11-22 11:47:05

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [EnvDataCpm](https://cloud.tencent.com/document/api/599/15912#EnvDataCpm)

	* 新增成员：InstanceTypes, TimeUnit, TimeSpan, RaidId, NeedSecurityAgent, NeedMonitorAgent, AutoRenewFlag, IsZoning, FileSystem, Password, ApplyEip, EipPayMode, EipBandwidth, ImageId, SysRootSpace, SysDataSpace, HyperThreading, LanIps

	* <font color="#dd0000">**删除成员**：</font>ComputeTypes, DeployType, SpotStrategy, Passwd

	* <font color="#dd0000">**修改成员**：</font>OsTypeId

* [LocalDiskType](https://cloud.tencent.com/document/api/599/15912#LocalDiskType)

	* 新增成员：Required


### 第 21 次发布

发布时间：2019-09-20 15:39:29

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [Task](https://cloud.tencent.com/document/api/599/15912#Task)

	* 新增成员：ResourceMaxRetryCount


### 第 20 次发布

发布时间：2019-08-23 11:24:11

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateCpmComputeEnv](https://cloud.tencent.com/document/api/599/37415)

新增数据结构：

* [CpmVirtualPrivateCloud](https://cloud.tencent.com/document/api/599/15912#CpmVirtualPrivateCloud)
* [EnvDataCpm](https://cloud.tencent.com/document/api/599/15912#EnvDataCpm)
* [NamedCpmComputeEnv](https://cloud.tencent.com/document/api/599/15912#NamedCpmComputeEnv)

### 第 19 次发布

发布时间：2019-05-30 20:25:09

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [DataDisk](https://cloud.tencent.com/document/api/599/15912#DataDisk)

	* 新增成员：SnapshotId

* [Placement](https://cloud.tencent.com/document/api/599/15912#Placement)

	* 新增成员：HostIps

* [Task](https://cloud.tencent.com/document/api/599/15912#Task)

	* 新增成员：RestartComputeNode


### 第 18 次发布

发布时间：2019-05-09 19:41:49

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [ComputeNodeMetrics](https://cloud.tencent.com/document/api/599/15912#ComputeNodeMetrics)

	* <font color="#dd0000">**修改成员**：</font>SubmittedCount, CreatingCount, CreationFailedCount, CreatedCount, RunningCount, DeletingCount, AbnormalCount


### 第 17 次发布

发布时间：2019-04-29 17:18:16

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeInstanceCategories](https://cloud.tencent.com/document/api/599/34541)

新增数据结构：

* [InstanceCategoryItem](https://cloud.tencent.com/document/api/599/15912#InstanceCategoryItem)

修改数据结构：

* [EnvData](https://cloud.tencent.com/document/api/599/15912#EnvData)

	* 新增成员：Zones, VirtualPrivateClouds


### 第 16 次发布

发布时间：2019-04-12 11:18:36

本次发布包含了以下内容：

改善已有的文档。

新增数据结构：

* [InstanceTypeOptions](https://cloud.tencent.com/document/api/599/15912#InstanceTypeOptions)

修改数据结构：

* [EnvData](https://cloud.tencent.com/document/api/599/15912#EnvData)

	* 新增成员：InstanceTypeOptions

* [InstanceMarketOptionsRequest](https://cloud.tencent.com/document/api/599/15912#InstanceMarketOptionsRequest)

	* <font color="#dd0000">**修改成员**：</font>SpotOptions

* [InternetAccessible](https://cloud.tencent.com/document/api/599/15912#InternetAccessible)

	* 新增成员：BandwidthPackageId

* [Task](https://cloud.tencent.com/document/api/599/15912#Task)

	* 新增成员：MaxConcurrentNum


### 第 15 次发布

发布时间：2018-12-20 20:36:52

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [RetryJobs](https://cloud.tencent.com/document/api/599/31814)

### 第 14 次发布

发布时间：2018-11-22 19:46:59

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [Activity](https://cloud.tencent.com/document/api/599/15912#Activity)

	* 新增成员：InstanceId


### 第 13 次发布

发布时间：2018-11-08 19:12:59

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeTaskLogs](https://cloud.tencent.com/document/api/599/30318)

新增数据结构：

* [TaskInstanceLog](https://cloud.tencent.com/document/api/599/15912#TaskInstanceLog)

### 第 12 次发布

发布时间：2018-10-26 14:33:56

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [ModifyComputeEnv](https://cloud.tencent.com/document/api/599/15890)

	* 新增入参：EnvName, EnvDescription, EnvData

	* <font color="#dd0000">**修改入参**：</font>DesiredComputeNodeCount


新增数据结构：

* [ComputeEnvData](https://cloud.tencent.com/document/api/599/15912#ComputeEnvData)

### 第 11 次发布

发布时间：2018-10-19 13:22:41

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeTask](https://cloud.tencent.com/document/api/599/15905)

	* 新增入参：Offset, Limit, Filters


### 第 10 次发布

发布时间：2018-10-11 15:27:31

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeCvmZoneInstanceConfigInfos](https://cloud.tencent.com/document/api/599/18565)

	* <font color="#dd0000">**修改入参**：</font>Filters


### 第 9 次发布

发布时间：2018-09-25 14:47:59

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [EnvData](https://cloud.tencent.com/document/api/599/15912#EnvData)

	* 新增成员：InstanceTypes


### 第 8 次发布

发布时间：2018-09-21 11:23:55

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeJobs](https://cloud.tencent.com/document/api/599/15909)

	* <font color="#dd0000">**修改出参**：</font>JobSet


### 第 7 次发布

发布时间：2018-09-20 10:49:02

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [Task](https://cloud.tencent.com/document/api/599/15912#Task)

	* <font color="#dd0000">**修改成员**：</font>EnvVars, Authentications


### 第 6 次发布

发布时间：2018-09-14 14:37:34

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [AnonymousComputeEnv](https://cloud.tencent.com/document/api/599/15912#AnonymousComputeEnv)

	* <font color="#dd0000">**修改成员**：</font>EnvType, EnvData

* [DataDisk](https://cloud.tencent.com/document/api/599/15912#DataDisk)

	* 新增成员：DeleteWithInstance

* [EnvData](https://cloud.tencent.com/document/api/599/15912#EnvData)

	* <font color="#dd0000">**修改成员**：</font>InstanceType, ImageId

* [Job](https://cloud.tencent.com/document/api/599/15912#Job)

	* <font color="#dd0000">**修改成员**：</font>JobName, Priority

* [NamedComputeEnv](https://cloud.tencent.com/document/api/599/15912#NamedComputeEnv)

	* <font color="#dd0000">**修改成员**：</font>EnvType, EnvData

* [Task](https://cloud.tencent.com/document/api/599/15912#Task)

	* <font color="#dd0000">**修改成员**：</font>TaskName, TaskInstanceNum, RedirectInfo, MaxRetryCount, Timeout


### 第 5 次发布

发布时间：2018-08-17 15:26:03

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [InstanceTypeConfig](https://cloud.tencent.com/document/api/599/15912#InstanceTypeConfig)

	* 新增成员：Mem, Cpu

	* <font color="#dd0000">**删除成员**：</font>GPU, CPU, Memory, CbsSupport, InstanceTypeState

	* <font color="#dd0000">**修改成员**：</font>InstanceType, Zone, InstanceFamily


### 第 4 次发布

发布时间：2018-08-02 15:48:13

本次发布包含了以下内容：

改善已有的文档。

### 第 3 次发布

发布时间：2018-07-26 15:15:22

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeCvmZoneInstanceConfigInfos](https://cloud.tencent.com/document/api/599/18565)

新增数据结构：

* [Externals](https://cloud.tencent.com/document/api/599/15912#Externals)
* [InstanceMarketOptionsRequest](https://cloud.tencent.com/document/api/599/15912#InstanceMarketOptionsRequest)
* [InstanceTypeQuotaItem](https://cloud.tencent.com/document/api/599/15912#InstanceTypeQuotaItem)
* [ItemPrice](https://cloud.tencent.com/document/api/599/15912#ItemPrice)
* [LocalDiskType](https://cloud.tencent.com/document/api/599/15912#LocalDiskType)
* [SpotMarketOptions](https://cloud.tencent.com/document/api/599/15912#SpotMarketOptions)
* [StorageBlock](https://cloud.tencent.com/document/api/599/15912#StorageBlock)

修改数据结构：

* [EnvData](https://cloud.tencent.com/document/api/599/15912#EnvData)

	* 新增成员：InstanceChargeType, InstanceMarketOptions


### 第 2 次发布

发布时间：2018-05-24 17:08:50

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [TerminateComputeNodes](https://cloud.tencent.com/document/api/599/17372)

修改接口：

* [DescribeJob](https://cloud.tencent.com/document/api/599/15904)

	* 新增出参：StateReason


修改数据结构：

* [ComputeNode](https://cloud.tencent.com/document/api/599/15912#ComputeNode)

	* 新增成员：PrivateIpAddresses, PublicIpAddresses

* [Job](https://cloud.tencent.com/document/api/599/15912#Job)

	* 新增成员：StateIfCreateCvmFailed

* [NamedComputeEnv](https://cloud.tencent.com/document/api/599/15912#NamedComputeEnv)

	* 新增成员：ActionIfComputeNodeInactive

* [TaskInstanceView](https://cloud.tencent.com/document/api/599/15912#TaskInstanceView)

	* 新增成员：StateDetailedReason


### 第 1 次发布

发布时间：2018-04-24

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateComputeEnv](https://cloud.tencent.com/document/api/599/15891)
* [CreateTaskTemplate](https://cloud.tencent.com/document/api/599/15899)
* [DeleteComputeEnv](https://cloud.tencent.com/document/api/599/15889)
* [DeleteJob](https://cloud.tencent.com/document/api/599/15906)
* [DeleteTaskTemplates](https://cloud.tencent.com/document/api/599/15900)
* [DescribeAvailableCvmInstanceTypes](https://cloud.tencent.com/document/api/599/15887)
* [DescribeComputeEnv](https://cloud.tencent.com/document/api/599/15892)
* [DescribeComputeEnvActivities](https://cloud.tencent.com/document/api/599/15896)
* [DescribeComputeEnvCreateInfo](https://cloud.tencent.com/document/api/599/15897)
* [DescribeComputeEnvCreateInfos](https://cloud.tencent.com/document/api/599/15894)
* [DescribeComputeEnvs](https://cloud.tencent.com/document/api/599/15893)
* [DescribeJob](https://cloud.tencent.com/document/api/599/15904)
* [DescribeJobSubmitInfo](https://cloud.tencent.com/document/api/599/15910)
* [DescribeJobs](https://cloud.tencent.com/document/api/599/15909)
* [DescribeTask](https://cloud.tencent.com/document/api/599/15905)
* [DescribeTaskTemplates](https://cloud.tencent.com/document/api/599/15902)
* [ModifyComputeEnv](https://cloud.tencent.com/document/api/599/15890)
* [ModifyTaskTemplate](https://cloud.tencent.com/document/api/599/15901)
* [SubmitJob](https://cloud.tencent.com/document/api/599/15907)
* [TerminateComputeNode](https://cloud.tencent.com/document/api/599/15895)
* [TerminateJob](https://cloud.tencent.com/document/api/599/20409)
* [TerminateTaskInstance](https://cloud.tencent.com/document/api/599/15908)

新增数据结构：

* [Activity](https://cloud.tencent.com/document/api/599/15912#Activity)
* [AgentRunningMode](https://cloud.tencent.com/document/api/599/15912#AgentRunningMode)
* [AnonymousComputeEnv](https://cloud.tencent.com/document/api/599/15912#AnonymousComputeEnv)
* [Application](https://cloud.tencent.com/document/api/599/15912#Application)
* [Authentication](https://cloud.tencent.com/document/api/599/15912#Authentication)
* [ComputeEnvCreateInfo](https://cloud.tencent.com/document/api/599/15912#ComputeEnvCreateInfo)
* [ComputeEnvView](https://cloud.tencent.com/document/api/599/15912#ComputeEnvView)
* [ComputeNode](https://cloud.tencent.com/document/api/599/15912#ComputeNode)
* [ComputeNodeMetrics](https://cloud.tencent.com/document/api/599/15912#ComputeNodeMetrics)
* [DataDisk](https://cloud.tencent.com/document/api/599/15912#DataDisk)
* [Dependence](https://cloud.tencent.com/document/api/599/15912#Dependence)
* [Docker](https://cloud.tencent.com/document/api/599/15912#Docker)
* [EnhancedService](https://cloud.tencent.com/document/api/599/15912#EnhancedService)
* [EnvData](https://cloud.tencent.com/document/api/599/15912#EnvData)
* [EnvVar](https://cloud.tencent.com/document/api/599/15912#EnvVar)
* [EventConfig](https://cloud.tencent.com/document/api/599/15912#EventConfig)
* [EventVar](https://cloud.tencent.com/document/api/599/15912#EventVar)
* [Filter](https://cloud.tencent.com/document/api/599/15912#Filter)
* [InputMapping](https://cloud.tencent.com/document/api/599/15912#InputMapping)
* [InstanceTypeConfig](https://cloud.tencent.com/document/api/599/15912#InstanceTypeConfig)
* [InternetAccessible](https://cloud.tencent.com/document/api/599/15912#InternetAccessible)
* [Job](https://cloud.tencent.com/document/api/599/15912#Job)
* [JobView](https://cloud.tencent.com/document/api/599/15912#JobView)
* [LoginSettings](https://cloud.tencent.com/document/api/599/15912#LoginSettings)
* [MountDataDisk](https://cloud.tencent.com/document/api/599/15912#MountDataDisk)
* [NamedComputeEnv](https://cloud.tencent.com/document/api/599/15912#NamedComputeEnv)
* [Notification](https://cloud.tencent.com/document/api/599/15912#Notification)
* [OutputMapping](https://cloud.tencent.com/document/api/599/15912#OutputMapping)
* [OutputMappingConfig](https://cloud.tencent.com/document/api/599/15912#OutputMappingConfig)
* [Placement](https://cloud.tencent.com/document/api/599/15912#Placement)
* [RedirectInfo](https://cloud.tencent.com/document/api/599/15912#RedirectInfo)
* [RedirectLocalInfo](https://cloud.tencent.com/document/api/599/15912#RedirectLocalInfo)
* [RunMonitorServiceEnabled](https://cloud.tencent.com/document/api/599/15912#RunMonitorServiceEnabled)
* [RunSecurityServiceEnabled](https://cloud.tencent.com/document/api/599/15912#RunSecurityServiceEnabled)
* [SystemDisk](https://cloud.tencent.com/document/api/599/15912#SystemDisk)
* [Task](https://cloud.tencent.com/document/api/599/15912#Task)
* [TaskInstanceMetrics](https://cloud.tencent.com/document/api/599/15912#TaskInstanceMetrics)
* [TaskInstanceView](https://cloud.tencent.com/document/api/599/15912#TaskInstanceView)
* [TaskMetrics](https://cloud.tencent.com/document/api/599/15912#TaskMetrics)
* [TaskTemplateView](https://cloud.tencent.com/document/api/599/15912#TaskTemplateView)
* [TaskView](https://cloud.tencent.com/document/api/599/15912#TaskView)
* [VirtualPrivateCloud](https://cloud.tencent.com/document/api/599/15912#VirtualPrivateCloud)




## 人体分析(bda) 版本：2020-03-24

### 第 10 次发布

发布时间：2022-12-15 01:09:06

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [SegmentPortraitPic](https://cloud.tencent.com/document/api/1208/42970)

	* 新增入参：Scene


### 第 9 次发布

发布时间：2022-09-06 06:10:38

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [SegmentPortraitPic](https://cloud.tencent.com/document/api/1208/42970)

	* 新增入参：RspImgType

	* 新增出参：HasForeground, ResultImageUrl, ResultMaskUrl


### 第 8 次发布

发布时间：2022-08-04 06:09:29

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DetectBodyJoints](https://cloud.tencent.com/document/api/1208/45846)

	* 新增入参：LocalBodySwitch


修改数据结构：

* [KeyPointInfo](https://cloud.tencent.com/document/api/1208/42985#KeyPointInfo)

	* 新增成员：BodyScore


### 第 7 次发布

发布时间：2021-09-03 08:02:16

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [GetSummaryInfo](https://cloud.tencent.com/document/api/1208/61127)

### 第 6 次发布

发布时间：2021-01-22 08:00:39

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [SegmentCustomizedPortraitPic](https://cloud.tencent.com/document/api/1208/47022)

	* 新增出参：ImageRects


新增数据结构：

* [ImageRect](https://cloud.tencent.com/document/api/1208/42985#ImageRect)

### 第 5 次发布

发布时间：2020-11-27 08:00:29

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateSegmentationTask](https://cloud.tencent.com/document/api/1208/50363)
* [DescribeSegmentationTask](https://cloud.tencent.com/document/api/1208/50362)
* [TerminateSegmentationTask](https://cloud.tencent.com/document/api/1208/50361)

新增数据结构：

* [VideoBasicInformation](https://cloud.tencent.com/document/api/1208/42985#VideoBasicInformation)

### 第 4 次发布

发布时间：2020-07-30 08:01:28

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [SegmentCustomizedPortraitPic](https://cloud.tencent.com/document/api/1208/47022)

新增数据结构：

* [SegmentationOptions](https://cloud.tencent.com/document/api/1208/42985#SegmentationOptions)

### 第 3 次发布

发布时间：2020-06-30 08:01:29

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DetectBodyJoints](https://cloud.tencent.com/document/api/1208/45846)

新增数据结构：

* [BodyJointsResult](https://cloud.tencent.com/document/api/1208/42985#BodyJointsResult)
* [BoundRect](https://cloud.tencent.com/document/api/1208/42985#BoundRect)
* [KeyPointInfo](https://cloud.tencent.com/document/api/1208/42985#KeyPointInfo)

### 第 2 次发布

发布时间：2020-06-19 08:01:05

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DetectBody](https://cloud.tencent.com/document/api/1208/42972)

	* 新增入参：AttributesOptions


新增数据结构：

* [Age](https://cloud.tencent.com/document/api/1208/42985#Age)
* [AttributesOptions](https://cloud.tencent.com/document/api/1208/42985#AttributesOptions)
* [Bag](https://cloud.tencent.com/document/api/1208/42985#Bag)
* [BodyAttributeInfo](https://cloud.tencent.com/document/api/1208/42985#BodyAttributeInfo)
* [Gender](https://cloud.tencent.com/document/api/1208/42985#Gender)
* [LowerBodyCloth](https://cloud.tencent.com/document/api/1208/42985#LowerBodyCloth)
* [LowerBodyClothColor](https://cloud.tencent.com/document/api/1208/42985#LowerBodyClothColor)
* [LowerBodyClothLength](https://cloud.tencent.com/document/api/1208/42985#LowerBodyClothLength)
* [LowerBodyClothType](https://cloud.tencent.com/document/api/1208/42985#LowerBodyClothType)
* [Orientation](https://cloud.tencent.com/document/api/1208/42985#Orientation)
* [UpperBodyCloth](https://cloud.tencent.com/document/api/1208/42985#UpperBodyCloth)
* [UpperBodyClothColor](https://cloud.tencent.com/document/api/1208/42985#UpperBodyClothColor)
* [UpperBodyClothSleeve](https://cloud.tencent.com/document/api/1208/42985#UpperBodyClothSleeve)
* [UpperBodyClothTexture](https://cloud.tencent.com/document/api/1208/42985#UpperBodyClothTexture)

修改数据结构：

* [BodyDetectResult](https://cloud.tencent.com/document/api/1208/42985#BodyDetectResult)

	* 新增成员：BodyAttributeInfo


### 第 1 次发布

发布时间：2020-03-30 08:31:45

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateGroup](https://cloud.tencent.com/document/api/1208/42984)
* [CreatePerson](https://cloud.tencent.com/document/api/1208/42983)
* [CreateTrace](https://cloud.tencent.com/document/api/1208/42982)
* [DeleteGroup](https://cloud.tencent.com/document/api/1208/42981)
* [DeletePerson](https://cloud.tencent.com/document/api/1208/42980)
* [DetectBody](https://cloud.tencent.com/document/api/1208/42972)
* [GetGroupList](https://cloud.tencent.com/document/api/1208/42979)
* [GetPersonList](https://cloud.tencent.com/document/api/1208/42978)
* [ModifyGroup](https://cloud.tencent.com/document/api/1208/42977)
* [ModifyPersonInfo](https://cloud.tencent.com/document/api/1208/42976)
* [SearchTrace](https://cloud.tencent.com/document/api/1208/42974)
* [SegmentPortraitPic](https://cloud.tencent.com/document/api/1208/42970)

新增数据结构：

* [BodyDetectResult](https://cloud.tencent.com/document/api/1208/42985#BodyDetectResult)
* [BodyRect](https://cloud.tencent.com/document/api/1208/42985#BodyRect)
* [Candidate](https://cloud.tencent.com/document/api/1208/42985#Candidate)
* [GroupInfo](https://cloud.tencent.com/document/api/1208/42985#GroupInfo)
* [PersonInfo](https://cloud.tencent.com/document/api/1208/42985#PersonInfo)
* [Trace](https://cloud.tencent.com/document/api/1208/42985#Trace)
* [TraceInfo](https://cloud.tencent.com/document/api/1208/42985#TraceInfo)




## 商业智能分析 BI(bi) 版本：2022-01-05

### 第 12 次发布

发布时间：2024-05-31 01:10:46

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [UserInfo](https://cloud.tencent.com/document/api/590/73726#UserInfo)

	* 新增成员：AppUserId, AppUserName

* [UserRoleListDataUserRoleInfo](https://cloud.tencent.com/document/api/590/73726#UserRoleListDataUserRoleInfo)

	* 新增成员：AppOpenUserId


### 第 11 次发布

发布时间：2024-05-17 01:07:50

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateEmbedToken](https://cloud.tencent.com/document/api/590/73724)

	* 新增入参：GlobalParam


修改数据结构：

* [EmbedTokenInfo](https://cloud.tencent.com/document/api/590/73726#EmbedTokenInfo)

	* 新增成员：GlobalParam


### 第 10 次发布

发布时间：2024-03-29 01:08:41

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateDatasource](https://cloud.tencent.com/document/api/590/98854)

	* 新增入参：OperationAuthLimit

* [CreateProject](https://cloud.tencent.com/document/api/590/98838)

	* 新增入参：ManagePlatform

* [ModifyProject](https://cloud.tencent.com/document/api/590/98834)

	* 新增入参：ManagePlatform


### 第 9 次发布

发布时间：2024-01-31 01:07:03

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [ApplyEmbedInterval](https://cloud.tencent.com/document/api/590/73725)

	* 新增出参：ErrorInfo

* [CreateDatasource](https://cloud.tencent.com/document/api/590/98854)

	* 新增出参：ErrorInfo

* [CreateDatasourceCloud](https://cloud.tencent.com/document/api/590/98853)

	* 新增出参：ErrorInfo

* [CreateEmbedToken](https://cloud.tencent.com/document/api/590/73724)

	* 新增出参：ErrorInfo

* [CreateProject](https://cloud.tencent.com/document/api/590/98838)

	* 新增出参：ErrorInfo

* [CreateUserRole](https://cloud.tencent.com/document/api/590/98848)

	* 新增出参：ErrorInfo

* [CreateUserRoleProject](https://cloud.tencent.com/document/api/590/98847)

	* 新增出参：ErrorInfo

* [DeleteDatasource](https://cloud.tencent.com/document/api/590/98852)

	* 新增出参：ErrorInfo

* [DeleteProject](https://cloud.tencent.com/document/api/590/98837)

	* 新增出参：ErrorInfo

* [DeleteUserRole](https://cloud.tencent.com/document/api/590/98846)

	* 新增出参：ErrorInfo

* [DeleteUserRoleProject](https://cloud.tencent.com/document/api/590/98845)

	* 新增出参：ErrorInfo

* [DescribeDatasourceList](https://cloud.tencent.com/document/api/590/98840)

	* 新增出参：ErrorInfo

* [DescribeProjectInfo](https://cloud.tencent.com/document/api/590/98836)

	* 新增出参：ErrorInfo

* [DescribeProjectList](https://cloud.tencent.com/document/api/590/98835)

	* 新增出参：ErrorInfo

* [DescribeUserProjectList](https://cloud.tencent.com/document/api/590/98844)

	* 新增出参：ErrorInfo

* [DescribeUserRoleList](https://cloud.tencent.com/document/api/590/98843)

	* 新增入参：IsOnlyBindAppUser

	* 新增出参：ErrorInfo

* [DescribeUserRoleProjectList](https://cloud.tencent.com/document/api/590/100532)

	* 新增入参：IsOnlyBindAppUser

	* 新增出参：ErrorInfo

* [ModifyDatasource](https://cloud.tencent.com/document/api/590/98851)

	* 新增出参：ErrorInfo

* [ModifyDatasourceCloud](https://cloud.tencent.com/document/api/590/98850)

	* 新增出参：ErrorInfo

* [ModifyProject](https://cloud.tencent.com/document/api/590/98834)

	* 新增出参：ErrorInfo

* [ModifyUserRole](https://cloud.tencent.com/document/api/590/98878)

	* 新增入参：AppUserId

	* 新增出参：ErrorInfo

* [ModifyUserRoleProject](https://cloud.tencent.com/document/api/590/98842)

	* 新增入参：AppUserId

	* 新增出参：ErrorInfo


新增数据结构：

* [ErrorInfo](https://cloud.tencent.com/document/api/590/73726#ErrorInfo)

修改数据结构：

* [UserIdAndUserName](https://cloud.tencent.com/document/api/590/73726#UserIdAndUserName)

	* 新增成员：AppId, AppUserId, AppUserAliasName, AppUserName, InValidateAppRange

* [UserRoleListDataUserRoleInfo](https://cloud.tencent.com/document/api/590/73726#UserRoleListDataUserRoleInfo)

	* 新增成员：AppUserId, AppUserAliasName, AppUserName, InValidateAppRange

	* <font color="#dd0000">**修改成员**：</font>CorpAdmin


### 第 8 次发布

发布时间：2023-12-22 01:07:03

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [DatasourceInfo](https://cloud.tencent.com/document/api/590/73726#DatasourceInfo)

	* 新增成员：ClusterId


### 第 7 次发布

发布时间：2023-12-06 01:10:35

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateDatasourceCloud](https://cloud.tencent.com/document/api/590/98853)

	* 新增入参：ClusterId

* [CreateEmbedToken](https://cloud.tencent.com/document/api/590/73724)

	* 新增入参：TicketNum

* [ModifyDatasourceCloud](https://cloud.tencent.com/document/api/590/98850)

	* 新增入参：ClusterId


修改数据结构：

* [EmbedTokenInfo](https://cloud.tencent.com/document/api/590/73726#EmbedTokenInfo)

	* 新增成员：TicketNum


### 第 6 次发布

发布时间：2023-10-20 01:06:54

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeUserRoleProjectList](https://cloud.tencent.com/document/api/590/100532)

### 第 5 次发布

发布时间：2023-09-27 01:07:14

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [ModifyUserRole](https://cloud.tencent.com/document/api/590/98878)

### 第 4 次发布

发布时间：2023-09-26 01:06:57

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateDatasource](https://cloud.tencent.com/document/api/590/98854)
* [CreateDatasourceCloud](https://cloud.tencent.com/document/api/590/98853)
* [CreateProject](https://cloud.tencent.com/document/api/590/98838)
* [CreateUserRole](https://cloud.tencent.com/document/api/590/98848)
* [CreateUserRoleProject](https://cloud.tencent.com/document/api/590/98847)
* [DeleteDatasource](https://cloud.tencent.com/document/api/590/98852)
* [DeleteProject](https://cloud.tencent.com/document/api/590/98837)
* [DeleteUserRole](https://cloud.tencent.com/document/api/590/98846)
* [DeleteUserRoleProject](https://cloud.tencent.com/document/api/590/98845)
* [DescribeDatasourceList](https://cloud.tencent.com/document/api/590/98840)
* [DescribeProjectInfo](https://cloud.tencent.com/document/api/590/98836)
* [DescribeProjectList](https://cloud.tencent.com/document/api/590/98835)
* [DescribeUserProjectList](https://cloud.tencent.com/document/api/590/98844)
* [DescribeUserRoleList](https://cloud.tencent.com/document/api/590/98843)
* [ModifyDatasource](https://cloud.tencent.com/document/api/590/98851)
* [ModifyDatasourceCloud](https://cloud.tencent.com/document/api/590/98850)
* [ModifyProject](https://cloud.tencent.com/document/api/590/98834)
* [ModifyUserRoleProject](https://cloud.tencent.com/document/api/590/98842)

新增数据结构：

* [BaseStateAction](https://cloud.tencent.com/document/api/590/73726#BaseStateAction)
* [CorpUserListData](https://cloud.tencent.com/document/api/590/73726#CorpUserListData)
* [Data](https://cloud.tencent.com/document/api/590/73726#Data)
* [DataId](https://cloud.tencent.com/document/api/590/73726#DataId)
* [DatasourceInfo](https://cloud.tencent.com/document/api/590/73726#DatasourceInfo)
* [DatasourceInfoData](https://cloud.tencent.com/document/api/590/73726#DatasourceInfoData)
* [IdDTO](https://cloud.tencent.com/document/api/590/73726#IdDTO)
* [PermissionComponent](https://cloud.tencent.com/document/api/590/73726#PermissionComponent)
* [PermissionGroup](https://cloud.tencent.com/document/api/590/73726#PermissionGroup)
* [Project](https://cloud.tencent.com/document/api/590/73726#Project)
* [ProjectConfigList](https://cloud.tencent.com/document/api/590/73726#ProjectConfigList)
* [ProjectConfigResult](https://cloud.tencent.com/document/api/590/73726#ProjectConfigResult)
* [ProjectListData](https://cloud.tencent.com/document/api/590/73726#ProjectListData)
* [UserIdAndUserName](https://cloud.tencent.com/document/api/590/73726#UserIdAndUserName)
* [UserInfo](https://cloud.tencent.com/document/api/590/73726#UserInfo)
* [UserRoleListData](https://cloud.tencent.com/document/api/590/73726#UserRoleListData)
* [UserRoleListDataRoleInfo](https://cloud.tencent.com/document/api/590/73726#UserRoleListDataRoleInfo)
* [UserRoleListDataUserRoleInfo](https://cloud.tencent.com/document/api/590/73726#UserRoleListDataUserRoleInfo)

### 第 3 次发布

发布时间：2023-09-18 01:10:19

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateEmbedToken](https://cloud.tencent.com/document/api/590/73724)

	* 新增入参：UserCorpId, UserId


修改数据结构：

* [EmbedTokenInfo](https://cloud.tencent.com/document/api/590/73726#EmbedTokenInfo)

	* 新增成员：UserCorpId, UserId


### 第 2 次发布

发布时间：2023-08-10 01:03:11

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [EmbedTokenInfo](https://cloud.tencent.com/document/api/590/73726#EmbedTokenInfo)

	* <font color="#dd0000">**修改成员**：</font>Id, BIToken, ProjectId, CreatedUser, CreatedAt, UpdatedUser, UpdatedAt, PageId, ExtraParam


### 第 1 次发布

发布时间：2022-05-13 18:34:36

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [ApplyEmbedInterval](https://cloud.tencent.com/document/api/590/73725)
* [CreateEmbedToken](https://cloud.tencent.com/document/api/590/73724)

新增数据结构：

* [ApplyEmbedTokenInfo](https://cloud.tencent.com/document/api/590/73726#ApplyEmbedTokenInfo)
* [EmbedTokenInfo](https://cloud.tencent.com/document/api/590/73726#EmbedTokenInfo)




## 费用中心(billing) 版本：2018-07-09

### 第 60 次发布

发布时间：2024-06-21 01:11:19

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [ConsumptionResourceSummaryDataItem](https://cloud.tencent.com/document/api/555/19183#ConsumptionResourceSummaryDataItem)

	* 新增成员：Tags


### 第 59 次发布

发布时间：2024-04-24 01:05:02

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [BillDetail](https://cloud.tencent.com/document/api/555/19183#BillDetail)

	* 新增成员：RegionType, RegionTypeName, ReserveDetail


### 第 58 次发布

发布时间：2024-03-29 01:08:47

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [AllocationDetail](https://cloud.tencent.com/document/api/555/19183#AllocationDetail)

* [AllocationSummaryByItem](https://cloud.tencent.com/document/api/555/19183#AllocationSummaryByItem)

* [AllocationSummaryByResource](https://cloud.tencent.com/document/api/555/19183#AllocationSummaryByResource)

* [ConsumptionBusinessSummaryDataItem](https://cloud.tencent.com/document/api/555/19183#ConsumptionBusinessSummaryDataItem)

	* 新增成员：RegionName

	* <font color="#dd0000">**修改成员**：</font>CashPayAmount, IncentivePayAmount, VoucherPayAmount, TransferPayAmount

* [ConsumptionProjectSummaryDataItem](https://cloud.tencent.com/document/api/555/19183#ConsumptionProjectSummaryDataItem)

	* <font color="#dd0000">**修改成员**：</font>CashPayAmount, IncentivePayAmount, VoucherPayAmount, TransferPayAmount

* [ConsumptionRegionSummaryDataItem](https://cloud.tencent.com/document/api/555/19183#ConsumptionRegionSummaryDataItem)

	* 新增成员：CashPayAmount, VoucherPayAmount, IncentivePayAmount, TransferPayAmount

* [ConsumptionResourceSummaryDataItem](https://cloud.tencent.com/document/api/555/19183#ConsumptionResourceSummaryDataItem)

	* 新增成员：PayerUin, OwnerUin, OperateUin, ProductCode, ProductCodeName, RegionType, RegionTypeName, Extend1, Extend2, Extend3, Extend4, Extend5, InstanceType, InstanceTypeName, PayTime, ZoneName, ComponentConfig

	* <font color="#dd0000">**修改成员**：</font>RealCost, FeeBeginTime, FeeEndTime, DayDiff, DailyTotalCost, OrderId, VoucherPayAmount, IncentivePayAmount, TransferPayAmount

* [GatherResourceSummary](https://cloud.tencent.com/document/api/555/19183#GatherResourceSummary)


### 第 57 次发布

发布时间：2024-03-08 11:57:13

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeAllocateConditions](https://cloud.tencent.com/document/api/555/104186)
* [DescribeAllocationBillConditions](https://cloud.tencent.com/document/api/555/104185)
* [DescribeAllocationBillDetail](https://cloud.tencent.com/document/api/555/104184)
* [DescribeAllocationMonthOverview](https://cloud.tencent.com/document/api/555/104183)
* [DescribeAllocationOverview](https://cloud.tencent.com/document/api/555/104182)
* [DescribeAllocationSummaryByBusiness](https://cloud.tencent.com/document/api/555/104181)
* [DescribeAllocationSummaryByItem](https://cloud.tencent.com/document/api/555/104180)
* [DescribeAllocationSummaryByResource](https://cloud.tencent.com/document/api/555/104179)
* [DescribeAllocationTrendByMonth](https://cloud.tencent.com/document/api/555/104178)
* [DescribeGatherResource](https://cloud.tencent.com/document/api/555/104177)

新增数据结构：

* [AllocationAverageData](https://cloud.tencent.com/document/api/555/19183#AllocationAverageData)
* [AllocationBillTrendDetail](https://cloud.tencent.com/document/api/555/19183#AllocationBillTrendDetail)
* [AllocationDetail](https://cloud.tencent.com/document/api/555/19183#AllocationDetail)
* [AllocationMonthOverviewDetail](https://cloud.tencent.com/document/api/555/19183#AllocationMonthOverviewDetail)
* [AllocationOverviewDetail](https://cloud.tencent.com/document/api/555/19183#AllocationOverviewDetail)
* [AllocationOverviewNode](https://cloud.tencent.com/document/api/555/19183#AllocationOverviewNode)
* [AllocationOverviewTotal](https://cloud.tencent.com/document/api/555/19183#AllocationOverviewTotal)
* [AllocationRule](https://cloud.tencent.com/document/api/555/19183#AllocationRule)
* [AllocationStat](https://cloud.tencent.com/document/api/555/19183#AllocationStat)
* [AllocationSummaryByBusiness](https://cloud.tencent.com/document/api/555/19183#AllocationSummaryByBusiness)
* [AllocationSummaryByItem](https://cloud.tencent.com/document/api/555/19183#AllocationSummaryByItem)
* [AllocationSummaryByResource](https://cloud.tencent.com/document/api/555/19183#AllocationSummaryByResource)
* [AllocationTreeNode](https://cloud.tencent.com/document/api/555/19183#AllocationTreeNode)
* [BillActionType](https://cloud.tencent.com/document/api/555/19183#BillActionType)
* [BillBusiness](https://cloud.tencent.com/document/api/555/19183#BillBusiness)
* [BillBusinessLink](https://cloud.tencent.com/document/api/555/19183#BillBusinessLink)
* [BillComponent](https://cloud.tencent.com/document/api/555/19183#BillComponent)
* [BillDays](https://cloud.tencent.com/document/api/555/19183#BillDays)
* [BillInstanceType](https://cloud.tencent.com/document/api/555/19183#BillInstanceType)
* [BillItem](https://cloud.tencent.com/document/api/555/19183#BillItem)
* [BillOperateUin](https://cloud.tencent.com/document/api/555/19183#BillOperateUin)
* [BillOwnerUin](https://cloud.tencent.com/document/api/555/19183#BillOwnerUin)
* [BillPayMode](https://cloud.tencent.com/document/api/555/19183#BillPayMode)
* [BillProduct](https://cloud.tencent.com/document/api/555/19183#BillProduct)
* [BillProductLink](https://cloud.tencent.com/document/api/555/19183#BillProductLink)
* [BillProject](https://cloud.tencent.com/document/api/555/19183#BillProject)
* [BillRegion](https://cloud.tencent.com/document/api/555/19183#BillRegion)
* [BillTag](https://cloud.tencent.com/document/api/555/19183#BillTag)
* [BillZoneId](https://cloud.tencent.com/document/api/555/19183#BillZoneId)
* [GatherResourceSummary](https://cloud.tencent.com/document/api/555/19183#GatherResourceSummary)

### 第 56 次发布

发布时间：2024-02-28 01:08:46

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeCostExplorerSummary](https://cloud.tencent.com/document/api/555/103991)

新增数据结构：

* [AnalyseActionTypeDetail](https://cloud.tencent.com/document/api/555/19183#AnalyseActionTypeDetail)
* [AnalyseAmountDetail](https://cloud.tencent.com/document/api/555/19183#AnalyseAmountDetail)
* [AnalyseBusinessDetail](https://cloud.tencent.com/document/api/555/19183#AnalyseBusinessDetail)
* [AnalyseConditionDetail](https://cloud.tencent.com/document/api/555/19183#AnalyseConditionDetail)
* [AnalyseConditions](https://cloud.tencent.com/document/api/555/19183#AnalyseConditions)
* [AnalyseDetail](https://cloud.tencent.com/document/api/555/19183#AnalyseDetail)
* [AnalyseHeaderDetail](https://cloud.tencent.com/document/api/555/19183#AnalyseHeaderDetail)
* [AnalyseHeaderTimeDetail](https://cloud.tencent.com/document/api/555/19183#AnalyseHeaderTimeDetail)
* [AnalyseOwnerUinDetail](https://cloud.tencent.com/document/api/555/19183#AnalyseOwnerUinDetail)
* [AnalysePayModeDetail](https://cloud.tencent.com/document/api/555/19183#AnalysePayModeDetail)
* [AnalyseProjectDetail](https://cloud.tencent.com/document/api/555/19183#AnalyseProjectDetail)
* [AnalyseRegionDetail](https://cloud.tencent.com/document/api/555/19183#AnalyseRegionDetail)
* [AnalyseTimeDetail](https://cloud.tencent.com/document/api/555/19183#AnalyseTimeDetail)
* [AnalyseZoneDetail](https://cloud.tencent.com/document/api/555/19183#AnalyseZoneDetail)

### 第 55 次发布

发布时间：2024-01-18 01:09:19

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeSavingPlanResourceInfo](https://cloud.tencent.com/document/api/555/103077)

### 第 54 次发布

发布时间：2024-01-09 01:07:19

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeDosageDetailList](https://cloud.tencent.com/document/api/555/102914)

新增数据结构：

* [DescribeDosageDetail](https://cloud.tencent.com/document/api/555/19183#DescribeDosageDetail)
* [JsonObject](https://cloud.tencent.com/document/api/555/19183#JsonObject)

### 第 53 次发布

发布时间：2023-12-27 01:07:34

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeDosageDetailByDate](https://cloud.tencent.com/document/api/555/33985)

	* 新增入参：PayerUin


修改数据结构：

* [BillDetail](https://cloud.tencent.com/document/api/555/19183#BillDetail)

	* 新增成员：Id


### 第 52 次发布

发布时间：2023-12-01 01:08:07

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [BillDetail](https://cloud.tencent.com/document/api/555/19183#BillDetail)

	* 新增成员：BillDay, BillMonth

* [BillDistributionResourceSummary](https://cloud.tencent.com/document/api/555/19183#BillDistributionResourceSummary)

	* 新增成员：BillMonth

* [BillResourceSummary](https://cloud.tencent.com/document/api/555/19183#BillResourceSummary)

	* 新增成员：BillMonth

	* <font color="#dd0000">**修改成员**：</font>TransferPayAmount, SPDeduction

* [DistributionBillDetail](https://cloud.tencent.com/document/api/555/19183#DistributionBillDetail)

	* 新增成员：BillMonth, BillDay


### 第 51 次发布

发布时间：2023-11-22 16:06:06

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateSavingPlanOrder](https://cloud.tencent.com/document/api/555/100825)

	* 新增入参：ClientToken


### 第 50 次发布

发布时间：2023-11-21 01:07:18

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeBillDetail](https://cloud.tencent.com/document/api/555/19182)

* [DescribeBillDetailForOrganization](https://cloud.tencent.com/document/api/555/98858)

* [DescribeBillResourceSummary](https://cloud.tencent.com/document/api/555/19181)

* [DescribeBillResourceSummaryForOrganization](https://cloud.tencent.com/document/api/555/98857)


### 第 49 次发布

发布时间：2023-10-27 15:51:05

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateSavingPlanOrder](https://cloud.tencent.com/document/api/555/100825)
* [DescribeSavingPlanCoverage](https://cloud.tencent.com/document/api/555/100824)
* [DescribeSavingPlanOverview](https://cloud.tencent.com/document/api/555/100823)
* [DescribeSavingPlanUsage](https://cloud.tencent.com/document/api/555/100822)

新增数据结构：

* [SavingPlanCoverageDetail](https://cloud.tencent.com/document/api/555/19183#SavingPlanCoverageDetail)
* [SavingPlanCoverageRate](https://cloud.tencent.com/document/api/555/19183#SavingPlanCoverageRate)
* [SavingPlanOverviewDetail](https://cloud.tencent.com/document/api/555/19183#SavingPlanOverviewDetail)
* [SavingPlanUsageDetail](https://cloud.tencent.com/document/api/555/19183#SavingPlanUsageDetail)

### 第 48 次发布

发布时间：2023-10-24 01:07:07

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeVoucherInfo](https://cloud.tencent.com/document/api/555/70813)

	* 新增入参：VoucherMainType, VoucherSubType


### 第 47 次发布

发布时间：2023-09-26 01:07:22

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeBillDetailForOrganization](https://cloud.tencent.com/document/api/555/98858)
* [DescribeBillDownloadUrl](https://cloud.tencent.com/document/api/555/98859)
* [DescribeBillResourceSummaryForOrganization](https://cloud.tencent.com/document/api/555/98857)
* [DescribeBillSummaryForOrganization](https://cloud.tencent.com/document/api/555/98856)

新增数据结构：

* [BillDistributionResourceSummary](https://cloud.tencent.com/document/api/555/19183#BillDistributionResourceSummary)
* [DistributionBillDetail](https://cloud.tencent.com/document/api/555/19183#DistributionBillDetail)

### 第 46 次发布

发布时间：2023-08-30 01:07:19

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateAllocationTag](https://cloud.tencent.com/document/api/555/97569)
* [DeleteAllocationTag](https://cloud.tencent.com/document/api/555/97568)
* [DescribeTagList](https://cloud.tencent.com/document/api/555/97567)

修改接口：

* [DescribeBillResourceSummary](https://cloud.tencent.com/document/api/555/19181)

	* 新增入参：TagKey, TagValue


新增数据结构：

* [TagDataInfo](https://cloud.tencent.com/document/api/555/19183#TagDataInfo)

### 第 45 次发布

发布时间：2023-08-22 01:07:10

本次发布包含了以下内容：

改善已有的文档。

新增数据结构：

* [BillDetailAssociatedOrder](https://cloud.tencent.com/document/api/555/19183#BillDetailAssociatedOrder)
* [BillDetailComponentConfig](https://cloud.tencent.com/document/api/555/19183#BillDetailComponentConfig)

修改数据结构：

* [BillDetail](https://cloud.tencent.com/document/api/555/19183#BillDetail)

	* 新增成员：AssociatedOrder, Formula, FormulaUrl

	* <font color="#dd0000">**修改成员**：</font>PriceInfo

* [BillDetailComponent](https://cloud.tencent.com/document/api/555/19183#BillDetailComponent)

	* 新增成员：ComponentConfig


### 第 44 次发布

发布时间：2023-07-03 01:04:02

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [BillDetailComponent](https://cloud.tencent.com/document/api/555/19183#BillDetailComponent)

	* 新增成员：RealTotalMeasure, DeductedMeasure

	* <font color="#dd0000">**修改成员**：</font>SpecifiedPrice, TransferPayAmount, SPDeduction


### 第 43 次发布

发布时间：2023-06-28 01:03:11

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeBillResourceSummary](https://cloud.tencent.com/document/api/555/19181)

	* 新增入参：PayerUin


### 第 42 次发布

发布时间：2023-06-21 01:03:53

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeBillDetail](https://cloud.tencent.com/document/api/555/19182)

	* 新增入参：PayerUin


### 第 41 次发布

发布时间：2023-06-06 01:05:36

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeBillSummary](https://cloud.tencent.com/document/api/555/93162)

新增数据结构：

* [BusinessSummaryInfo](https://cloud.tencent.com/document/api/555/19183#BusinessSummaryInfo)
* [SummaryDetail](https://cloud.tencent.com/document/api/555/19183#SummaryDetail)

修改数据结构：

* [ConsumptionBusinessSummaryDataItem](https://cloud.tencent.com/document/api/555/19183#ConsumptionBusinessSummaryDataItem)

	* 新增成员：CashPayAmount, IncentivePayAmount, VoucherPayAmount, TransferPayAmount

* [ConsumptionProjectSummaryDataItem](https://cloud.tencent.com/document/api/555/19183#ConsumptionProjectSummaryDataItem)

	* 新增成员：CashPayAmount, IncentivePayAmount, VoucherPayAmount, TransferPayAmount

* [ConsumptionResourceSummaryDataItem](https://cloud.tencent.com/document/api/555/19183#ConsumptionResourceSummaryDataItem)

	* 新增成员：RealCost, FeeBeginTime, FeeEndTime, DayDiff, DailyTotalCost, OrderId, VoucherPayAmount, IncentivePayAmount, TransferPayAmount


### 第 40 次发布

发布时间：2023-05-24 01:04:23

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [BillDetailComponent](https://cloud.tencent.com/document/api/555/19183#BillDetailComponent)

	* 新增成员：TransferPayAmount

	* <font color="#dd0000">**修改成员**：</font>SpecifiedPrice, SPDeduction

* [BillResourceSummary](https://cloud.tencent.com/document/api/555/19183#BillResourceSummary)

	* 新增成员：TransferPayAmount

	* <font color="#dd0000">**修改成员**：</font>SPDeduction


### 第 39 次发布

发布时间：2023-05-12 01:04:14

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeBillDetail](https://cloud.tencent.com/document/api/555/19182)

	* 新增入参：Context

	* 新增出参：Context


### 第 38 次发布

发布时间：2023-04-25 01:04:35

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [ActionSummaryOverviewItem](https://cloud.tencent.com/document/api/555/19183#ActionSummaryOverviewItem)

	* 新增成员：TransferPayAmount


### 第 37 次发布

发布时间：2023-04-11 01:03:45

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [BillDetail](https://cloud.tencent.com/document/api/555/19183#BillDetail)

	* 新增成员：PriceInfo


### 第 36 次发布

发布时间：2023-03-27 01:06:31

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeVoucherUsageDetails](https://cloud.tencent.com/document/api/555/70812)

	* <font color="#dd0000">**修改入参**：</font>VoucherId


### 第 35 次发布

发布时间：2022-08-15 06:09:23

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [BusinessSummaryOverviewItem](https://cloud.tencent.com/document/api/555/19183#BusinessSummaryOverviewItem)

	* 新增成员：TransferPayAmount

* [BusinessSummaryTotal](https://cloud.tencent.com/document/api/555/19183#BusinessSummaryTotal)

	* 新增成员：TransferPayAmount

* [PayModeSummaryOverviewItem](https://cloud.tencent.com/document/api/555/19183#PayModeSummaryOverviewItem)

	* 新增成员：TransferPayAmount

* [ProjectSummaryOverviewItem](https://cloud.tencent.com/document/api/555/19183#ProjectSummaryOverviewItem)

	* 新增成员：TransferPayAmount

* [RegionSummaryOverviewItem](https://cloud.tencent.com/document/api/555/19183#RegionSummaryOverviewItem)

	* 新增成员：TransferPayAmount

* [TagSummaryOverviewItem](https://cloud.tencent.com/document/api/555/19183#TagSummaryOverviewItem)

	* 新增成员：CashPayAmount, IncentivePayAmount, VoucherPayAmount, TransferPayAmount


### 第 34 次发布

发布时间：2022-06-08 06:04:08

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [BillDetailComponent](https://cloud.tencent.com/document/api/555/19183#BillDetailComponent)

	* 新增成员：InstanceType, RiTimeSpan, OriginalCostWithRI, SPDeductionRate, SPDeduction, OriginalCostWithSP, BlendedDiscount

* [BillResourceSummary](https://cloud.tencent.com/document/api/555/19183#BillResourceSummary)

	* 新增成员：InstanceType, OriginalCostWithRI, SPDeduction, OriginalCostWithSP


### 第 33 次发布

发布时间：2022-03-30 06:01:46

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeDealsByCond](https://cloud.tencent.com/document/api/555/19179)

	* 新增入参：ResourceId


修改数据结构：

* [Deal](https://cloud.tencent.com/document/api/555/19183#Deal)

	* 新增成员：ResourceId


### 第 32 次发布

发布时间：2022-03-09 08:06:22

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeVoucherInfo](https://cloud.tencent.com/document/api/555/70813)
* [DescribeVoucherUsageDetails](https://cloud.tencent.com/document/api/555/70812)

新增数据结构：

* [ApplicableProducts](https://cloud.tencent.com/document/api/555/19183#ApplicableProducts)
* [ExcludedProducts](https://cloud.tencent.com/document/api/555/19183#ExcludedProducts)
* [UsageDetails](https://cloud.tencent.com/document/api/555/19183#UsageDetails)
* [UsageRecords](https://cloud.tencent.com/document/api/555/19183#UsageRecords)
* [VoucherInfos](https://cloud.tencent.com/document/api/555/19183#VoucherInfos)

### 第 31 次发布

发布时间：2022-03-02 08:05:35

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [Deal](https://cloud.tencent.com/document/api/555/19183#Deal)

	* 新增成员：ProductName, SubProductName


### 第 30 次发布

发布时间：2022-01-11 08:03:32

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [Deal](https://cloud.tencent.com/document/api/555/19183#Deal)

	* 新增成员：Action


### 第 29 次发布

发布时间：2021-11-23 08:03:19

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeBillDetail](https://cloud.tencent.com/document/api/555/19182)

	* 新增入参：BusinessCode

* [DescribeBillResourceSummary](https://cloud.tencent.com/document/api/555/19181)

	* 新增入参：BusinessCode


### 第 28 次发布

发布时间：2021-10-13 08:03:28

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeBillSummaryByProduct](https://cloud.tencent.com/document/api/555/35761)

	* 新增入参：PayType


### 第 27 次发布

发布时间：2021-09-13 08:03:19

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeBillDetail](https://cloud.tencent.com/document/api/555/19182)

	* <font color="#dd0000">**修改入参**：</font>PeriodType

* [DescribeBillResourceSummary](https://cloud.tencent.com/document/api/555/19181)

	* <font color="#dd0000">**修改入参**：</font>PeriodType

* [DescribeBillSummaryByTag](https://cloud.tencent.com/document/api/555/38208)

	* 新增入参：TagValue

	* 新增出参：SummaryTotal


新增数据结构：

* [SummaryTotal](https://cloud.tencent.com/document/api/555/19183#SummaryTotal)

修改数据结构：

* [ActionSummaryOverviewItem](https://cloud.tencent.com/document/api/555/19183#ActionSummaryOverviewItem)

	* 新增成员：TotalCost

* [BusinessSummaryOverviewItem](https://cloud.tencent.com/document/api/555/19183#BusinessSummaryOverviewItem)

	* 新增成员：TotalCost

* [BusinessSummaryTotal](https://cloud.tencent.com/document/api/555/19183#BusinessSummaryTotal)

	* 新增成员：TotalCost

* [PayModeSummaryOverviewItem](https://cloud.tencent.com/document/api/555/19183#PayModeSummaryOverviewItem)

	* 新增成员：TotalCost

* [ProjectSummaryOverviewItem](https://cloud.tencent.com/document/api/555/19183#ProjectSummaryOverviewItem)

	* 新增成员：TotalCost

* [RegionSummaryOverviewItem](https://cloud.tencent.com/document/api/555/19183#RegionSummaryOverviewItem)

	* 新增成员：TotalCost

* [TagSummaryOverviewItem](https://cloud.tencent.com/document/api/555/19183#TagSummaryOverviewItem)

	* 新增成员：TotalCost


### 第 26 次发布

发布时间：2021-06-28 08:03:05

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeBillResourceSummary](https://cloud.tencent.com/document/api/555/19181)

	* 新增入参：ResourceId, PayMode


### 第 25 次发布

发布时间：2021-04-12 08:02:21

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeAccountBalance](https://cloud.tencent.com/document/api/555/20253)

	* 新增出参：Uin, RealBalance, CashAccountBalance, IncomeIntoAccountBalance, PresentAccountBalance, FreezeAmount, OweAmount, IsAllowArrears, IsCreditLimited, CreditAmount, CreditBalance, RealCreditBalance


### 第 24 次发布

发布时间：2020-12-28 08:01:57

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeBillDetail](https://cloud.tencent.com/document/api/555/19182)

	* 新增入参：ProjectId


修改数据结构：

* [BillDetail](https://cloud.tencent.com/document/api/555/19183#BillDetail)

	* 新增成员：ProjectId


### 第 23 次发布

发布时间：2020-11-17 08:02:02

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeBillSummaryByPayMode](https://cloud.tencent.com/document/api/555/35762)

	* <font color="#dd0000">**修改入参**：</font>PayerUin

* [DescribeBillSummaryByProduct](https://cloud.tencent.com/document/api/555/35761)

	* <font color="#dd0000">**修改入参**：</font>PayerUin

* [DescribeBillSummaryByProject](https://cloud.tencent.com/document/api/555/35760)

	* <font color="#dd0000">**修改入参**：</font>PayerUin

* [DescribeBillSummaryByRegion](https://cloud.tencent.com/document/api/555/35759)

	* <font color="#dd0000">**修改入参**：</font>PayerUin

* [DescribeBillSummaryByTag](https://cloud.tencent.com/document/api/555/38208)

	* <font color="#dd0000">**修改入参**：</font>PayerUin

* [DescribeCostSummaryByProduct](https://cloud.tencent.com/document/api/555/41009)

	* <font color="#dd0000">**修改入参**：</font>PayerUin

* [DescribeCostSummaryByProject](https://cloud.tencent.com/document/api/555/41008)

	* <font color="#dd0000">**修改入参**：</font>PayerUin

* [DescribeCostSummaryByRegion](https://cloud.tencent.com/document/api/555/41007)

	* <font color="#dd0000">**修改入参**：</font>PayerUin

* [DescribeCostSummaryByResource](https://cloud.tencent.com/document/api/555/41006)

	* <font color="#dd0000">**修改入参**：</font>PayerUin


### 第 22 次发布

发布时间：2020-11-16 08:01:50

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeDosageCosDetailByDate](https://cloud.tencent.com/document/api/555/49897)

修改接口：

* [DescribeBillList](https://cloud.tencent.com/document/api/555/41874)

	* 新增出参：AgentInAmount, AdvanceRechargeAmount, WithdrawAmount, AgentOutAmount, AdvancePayAmount


新增数据结构：

* [CosDetailSets](https://cloud.tencent.com/document/api/555/19183#CosDetailSets)

### 第 21 次发布

发布时间：2020-08-13 08:04:50

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [Deal](https://cloud.tencent.com/document/api/555/19183#Deal)

	* 新增成员：PayMode


### 第 20 次发布

发布时间：2020-07-30 08:04:30

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [BillTransactionInfo](https://cloud.tencent.com/document/api/555/19183#BillTransactionInfo)

	* 新增成员：PayChannel, DeductMode


### 第 19 次发布

发布时间：2020-07-10 08:04:29

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [Deal](https://cloud.tencent.com/document/api/555/19183#Deal)

	* 新增成员：Formula, RefReturnDeals


### 第 18 次发布

发布时间：2020-06-01 08:05:12

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeDealsByCond](https://cloud.tencent.com/document/api/555/19179)

	* 新增入参：BigDealId

* [PayDeals](https://cloud.tencent.com/document/api/555/19178)

	* 新增入参：BigDealIds

	* <font color="#dd0000">**修改入参**：</font>OrderIds

	* 新增出参：BigDealIds


修改数据结构：

* [Deal](https://cloud.tencent.com/document/api/555/19183#Deal)

	* 新增成员：BigDealId


### 第 17 次发布

发布时间：2020-03-26 08:02:35

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeBillDetail](https://cloud.tencent.com/document/api/555/19182)

	* 新增入参：ActionType

* [DescribeBillResourceSummary](https://cloud.tencent.com/document/api/555/19181)

	* 新增入参：ActionType


### 第 16 次发布

发布时间：2020-03-20 08:02:48

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [BillDetail](https://cloud.tencent.com/document/api/555/19183#BillDetail)

	* <font color="#dd0000">**修改成员**：</font>RegionId


### 第 15 次发布

发布时间：2020-03-19 08:03:21

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [CostDetail](https://cloud.tencent.com/document/api/555/19183#CostDetail)

	* <font color="#dd0000">**修改成员**：</font>ComponentSet


### 第 14 次发布

发布时间：2020-03-16 08:02:00

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [BillDetail](https://cloud.tencent.com/document/api/555/19183#BillDetail)

	* 新增成员：RegionId

* [BillResourceSummary](https://cloud.tencent.com/document/api/555/19183#BillResourceSummary)

	* 新增成员：BusinessCode, ProductCode, RegionId


### 第 13 次发布

发布时间：2020-03-04 17:46:33

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeBillList](https://cloud.tencent.com/document/api/555/41874)

新增数据结构：

* [BillTransactionInfo](https://cloud.tencent.com/document/api/555/19183#BillTransactionInfo)

修改数据结构：

* [ConsumptionResourceSummaryDataItem](https://cloud.tencent.com/document/api/555/19183#ConsumptionResourceSummaryDataItem)

	* 新增成员：ConsumptionTypeName


### 第 12 次发布

发布时间：2020-01-10 15:03:48

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeCostDetail](https://cloud.tencent.com/document/api/555/41010)
* [DescribeCostSummaryByProduct](https://cloud.tencent.com/document/api/555/41009)
* [DescribeCostSummaryByProject](https://cloud.tencent.com/document/api/555/41008)
* [DescribeCostSummaryByRegion](https://cloud.tencent.com/document/api/555/41007)
* [DescribeCostSummaryByResource](https://cloud.tencent.com/document/api/555/41006)

新增数据结构：

* [ConditionBusiness](https://cloud.tencent.com/document/api/555/19183#ConditionBusiness)
* [ConditionPayMode](https://cloud.tencent.com/document/api/555/19183#ConditionPayMode)
* [ConditionProject](https://cloud.tencent.com/document/api/555/19183#ConditionProject)
* [ConditionRegion](https://cloud.tencent.com/document/api/555/19183#ConditionRegion)
* [Conditions](https://cloud.tencent.com/document/api/555/19183#Conditions)
* [ConsumptionBusinessSummaryDataItem](https://cloud.tencent.com/document/api/555/19183#ConsumptionBusinessSummaryDataItem)
* [ConsumptionProjectSummaryDataItem](https://cloud.tencent.com/document/api/555/19183#ConsumptionProjectSummaryDataItem)
* [ConsumptionRegionSummaryDataItem](https://cloud.tencent.com/document/api/555/19183#ConsumptionRegionSummaryDataItem)
* [ConsumptionResourceSummaryConditionValue](https://cloud.tencent.com/document/api/555/19183#ConsumptionResourceSummaryConditionValue)
* [ConsumptionResourceSummaryDataItem](https://cloud.tencent.com/document/api/555/19183#ConsumptionResourceSummaryDataItem)
* [ConsumptionSummaryTotal](https://cloud.tencent.com/document/api/555/19183#ConsumptionSummaryTotal)
* [ConsumptionSummaryTrend](https://cloud.tencent.com/document/api/555/19183#ConsumptionSummaryTrend)
* [CostComponentSet](https://cloud.tencent.com/document/api/555/19183#CostComponentSet)
* [CostDetail](https://cloud.tencent.com/document/api/555/19183#CostDetail)

修改数据结构：

* [BillDetail](https://cloud.tencent.com/document/api/555/19183#BillDetail)

	* 新增成员：BusinessCode, ProductCode, ActionType

* [BillDetailComponent](https://cloud.tencent.com/document/api/555/19183#BillDetailComponent)

	* 新增成员：ItemCode, ComponentCode, ContractPrice

* [Deal](https://cloud.tencent.com/document/api/555/19183#Deal)

	* 新增成员：ProductCode, SubProductCode


### 第 11 次发布

发布时间：2019-11-14 17:42:57

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeBillSummaryByTag](https://cloud.tencent.com/document/api/555/38208)

	* <font color="#dd0000">**修改出参**：</font>SummaryOverview


### 第 10 次发布

发布时间：2019-09-26 20:15:00

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeBillSummaryByTag](https://cloud.tencent.com/document/api/555/38208)

修改接口：

* [DescribeBillDetail](https://cloud.tencent.com/document/api/555/19182)

	* 新增入参：ProductCode, PayMode, ResourceId


新增数据结构：

* [BillTagInfo](https://cloud.tencent.com/document/api/555/19183#BillTagInfo)
* [TagSummaryOverviewItem](https://cloud.tencent.com/document/api/555/19183#TagSummaryOverviewItem)

修改数据结构：

* [ActionSummaryOverviewItem](https://cloud.tencent.com/document/api/555/19183#ActionSummaryOverviewItem)

	* 新增成员：CashPayAmount, IncentivePayAmount, VoucherPayAmount, BillMonth

* [BillDetail](https://cloud.tencent.com/document/api/555/19183#BillDetail)

	* 新增成员：Tags

* [BillResourceSummary](https://cloud.tencent.com/document/api/555/19183#BillResourceSummary)

	* 新增成员：Tags, PayerUin, OwnerUin, OperateUin

* [BusinessSummaryOverviewItem](https://cloud.tencent.com/document/api/555/19183#BusinessSummaryOverviewItem)

	* 新增成员：CashPayAmount, IncentivePayAmount, VoucherPayAmount, BillMonth

* [BusinessSummaryTotal](https://cloud.tencent.com/document/api/555/19183#BusinessSummaryTotal)

	* 新增成员：VoucherPayAmount, IncentivePayAmount, CashPayAmount

* [PayModeSummaryOverviewItem](https://cloud.tencent.com/document/api/555/19183#PayModeSummaryOverviewItem)

	* 新增成员：CashPayAmount, IncentivePayAmount, VoucherPayAmount

* [ProjectSummaryOverviewItem](https://cloud.tencent.com/document/api/555/19183#ProjectSummaryOverviewItem)

	* 新增成员：CashPayAmount, IncentivePayAmount, VoucherPayAmount, BillMonth

* [RegionSummaryOverviewItem](https://cloud.tencent.com/document/api/555/19183#RegionSummaryOverviewItem)

	* 新增成员：CashPayAmount, IncentivePayAmount, VoucherPayAmount, BillMonth


### 第 9 次发布

发布时间：2019-07-04 17:12:16

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeBillDetail](https://cloud.tencent.com/document/api/555/19182)

	* 新增出参：Total


### 第 8 次发布

发布时间：2019-06-27 14:59:09

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeBillSummaryByPayMode](https://cloud.tencent.com/document/api/555/35762)
* [DescribeBillSummaryByProduct](https://cloud.tencent.com/document/api/555/35761)
* [DescribeBillSummaryByProject](https://cloud.tencent.com/document/api/555/35760)
* [DescribeBillSummaryByRegion](https://cloud.tencent.com/document/api/555/35759)

修改接口：

* [DescribeBillDetail](https://cloud.tencent.com/document/api/555/19182)

	* 新增入参：NeedRecordNum


新增数据结构：

* [ActionSummaryOverviewItem](https://cloud.tencent.com/document/api/555/19183#ActionSummaryOverviewItem)
* [BusinessSummaryOverviewItem](https://cloud.tencent.com/document/api/555/19183#BusinessSummaryOverviewItem)
* [BusinessSummaryTotal](https://cloud.tencent.com/document/api/555/19183#BusinessSummaryTotal)
* [PayModeSummaryOverviewItem](https://cloud.tencent.com/document/api/555/19183#PayModeSummaryOverviewItem)
* [ProjectSummaryOverviewItem](https://cloud.tencent.com/document/api/555/19183#ProjectSummaryOverviewItem)
* [RegionSummaryOverviewItem](https://cloud.tencent.com/document/api/555/19183#RegionSummaryOverviewItem)

### 第 7 次发布

发布时间：2019-05-30 20:20:44

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeBillResourceSummary](https://cloud.tencent.com/document/api/555/19181)

	* 新增入参：NeedRecordNum

	* 新增出参：Total


### 第 6 次发布

发布时间：2019-04-12 20:15:32

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [BillResourceSummary](https://cloud.tencent.com/document/api/555/19183#BillResourceSummary)

	* 新增成员：ExtendField3, ExtendField4, ExtendField5


### 第 5 次发布

发布时间：2019-04-04 21:07:27

本次发布包含了以下内容：

改善已有的文档。

### 第 4 次发布

发布时间：2019-03-29 10:56:54

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeDosageDetailByDate](https://cloud.tencent.com/document/api/555/33985)

新增数据结构：

* [DetailPoint](https://cloud.tencent.com/document/api/555/19183#DetailPoint)
* [DetailSet](https://cloud.tencent.com/document/api/555/19183#DetailSet)

### 第 3 次发布

发布时间：2018-11-29 16:46:10

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeBillDetail](https://cloud.tencent.com/document/api/555/19182)

	* 新增入参：BeginTime, EndTime

	* <font color="#dd0000">**修改入参**：</font>Month


新增数据结构：

* [ProductInfo](https://cloud.tencent.com/document/api/555/19183#ProductInfo)

修改数据结构：

* [BillDetail](https://cloud.tencent.com/document/api/555/19183#BillDetail)

	* 新增成员：PayerUin, OwnerUin, OperateUin

* [Deal](https://cloud.tencent.com/document/api/555/19183#Deal)

	* 新增成员：ProductInfo, TimeSpan, TimeUnit, Currency, Policy, Price, TotalCost


### 第 2 次发布

发布时间：2018-09-20 11:04:19

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeAccountBalance](https://cloud.tencent.com/document/api/555/20253)

### 第 1 次发布

发布时间：2018-08-24 17:00:40

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeBillDetail](https://cloud.tencent.com/document/api/555/19182)
* [DescribeBillResourceSummary](https://cloud.tencent.com/document/api/555/19181)
* [DescribeDealsByCond](https://cloud.tencent.com/document/api/555/19179)
* [PayDeals](https://cloud.tencent.com/document/api/555/19178)

新增数据结构：

* [BillDetail](https://cloud.tencent.com/document/api/555/19183#BillDetail)
* [BillDetailComponent](https://cloud.tencent.com/document/api/555/19183#BillDetailComponent)
* [BillResourceSummary](https://cloud.tencent.com/document/api/555/19183#BillResourceSummary)
* [Deal](https://cloud.tencent.com/document/api/555/19183#Deal)




## 小程序 · 云直播(bizlive) 版本：2019-03-13

### 第 2 次发布

发布时间：2020-03-10 01:08:07

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateSession](https://cloud.tencent.com/document/api/1078/42110)
* [DescribeWorkers](https://cloud.tencent.com/document/api/1078/42109)
* [StopGame](https://cloud.tencent.com/document/api/1078/42108)

新增数据结构：

* [WorkerRegionInfo](https://cloud.tencent.com/document/api/1078/35042#WorkerRegionInfo)

### 第 1 次发布

发布时间：2019-05-17 21:06:05

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeStreamPlayInfoList](https://cloud.tencent.com/document/api/1078/35041)
* [ForbidLiveStream](https://cloud.tencent.com/document/api/1078/35037)
* [RegisterIM](https://cloud.tencent.com/document/api/1078/35039)

新增数据结构：

* [DayStreamPlayInfo](https://cloud.tencent.com/document/api/1078/35042#DayStreamPlayInfo)




## 黑石物理服务器CPM(bm) 版本：2018-04-23

### 第 18 次发布

发布时间：2021-08-05 08:03:16

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [RepairTaskControl](https://cloud.tencent.com/document/api/386/32916)

	* 新增入参：OperateRemark


### 第 17 次发布

发布时间：2021-07-22 08:03:11

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeDevices](https://cloud.tencent.com/document/api/386/32904)

	* 新增入参：MaintainStatus


修改数据结构：

* [DeviceInfo](https://cloud.tencent.com/document/api/386/18649#DeviceInfo)

	* 新增成员：MaintainStatus, MaintainMessage


### 第 16 次发布

发布时间：2021-04-01 08:02:25

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateCustomImage](https://cloud.tencent.com/document/api/386/32938)

	* 新增出参：ImageId


### 第 15 次发布

发布时间：2020-08-05 08:05:10

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [DeviceHardwareInfo](https://cloud.tencent.com/document/api/386/18649#DeviceHardwareInfo)

	* 新增成员：DeviceClassCode


### 第 14 次发布

发布时间：2020-04-01 08:07:20

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [OsInfo](https://cloud.tencent.com/document/api/386/18649#OsInfo)

	* 新增成员：OsMinorVersion, OsMinorClass


### 第 13 次发布

发布时间：2020-03-18 08:01:37

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [ReloadDeviceOs](https://cloud.tencent.com/document/api/386/42276)

	* 新增入参：SysDataSpace


### 第 12 次发布

发布时间：2020-03-16 08:02:12

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [ReloadDeviceOs](https://cloud.tencent.com/document/api/386/42276)

修改接口：

* [BuyDevices](https://cloud.tencent.com/document/api/386/32913)

	* 新增入参：SgId, TemplateId

* [DescribeDeviceClass](https://cloud.tencent.com/document/api/386/32911)

	* 新增入参：OnSale, NeedPriceInfo

* [DescribeDeviceClassPartition](https://cloud.tencent.com/document/api/386/32910)

	* 新增入参：CpuId, MemSize, ContainRaidCard, SystemDiskTypeId, SystemDiskCount, DataDiskTypeId, DataDiskCount

* [DescribeDeviceInventory](https://cloud.tencent.com/document/api/386/32909)

	* 新增入参：MemSize, ContainRaidCard, SystemDiskTypeId, SystemDiskCount, DataDiskTypeId, DataDiskCount

	* <font color="#dd0000">**删除入参**：</font>DiskType, DiskSize, DiskNum, Mem, HaveRaidCard


修改数据结构：

* [DeviceClass](https://cloud.tencent.com/document/api/386/18649#DeviceClass)

	* 新增成员：Cpu, Mem

* [DeviceHardwareInfo](https://cloud.tencent.com/document/api/386/18649#DeviceHardwareInfo)

	* 新增成员：Cpu

* [TaskInfo](https://cloud.tencent.com/document/api/386/18649#TaskInfo)

	* 新增成员：TaskTypeName, TaskSubType


### 第 11 次发布

发布时间：2019-11-07 20:07:03

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [AttachCamRole](https://cloud.tencent.com/document/api/386/39042)
* [DetachCamRole](https://cloud.tencent.com/document/api/386/39043)

### 第 10 次发布

发布时间：2019-09-26 21:50:51

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [BuyDevices](https://cloud.tencent.com/document/api/386/32913)

	* 新增入参：BuySession


### 第 9 次发布

发布时间：2019-05-30 19:40:56

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [DevicePartition](https://cloud.tencent.com/document/api/386/18649#DevicePartition)

	* 新增成员：DeviceDiskSizeInfoSet


### 第 8 次发布

发布时间：2019-04-29 16:57:45

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [StartDevices](https://cloud.tencent.com/document/api/386/34540)

修改接口：

* [BuyDevices](https://cloud.tencent.com/document/api/386/32913)

	* 新增入参：FileSystem


修改数据结构：

* [SuccessTaskInfo](https://cloud.tencent.com/document/api/386/18649#SuccessTaskInfo)

	* 新增成员：CmdTaskId


### 第 7 次发布

发布时间：2019-03-08 17:52:05

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeDeviceHardwareInfo](https://cloud.tencent.com/document/api/386/33566)
* [DescribeHardwareSpecification](https://cloud.tencent.com/document/api/386/33565)
* [DescribeHostedDeviceOutBandInfo](https://cloud.tencent.com/document/api/386/33568)
* [DescribeRegions](https://cloud.tencent.com/document/api/386/33564)
* [RecoverDevices](https://cloud.tencent.com/document/api/386/33562)
* [ReturnDevices](https://cloud.tencent.com/document/api/386/33561)

新增数据结构：

* [CpuInfo](https://cloud.tencent.com/document/api/386/18649#CpuInfo)
* [DeviceHardwareInfo](https://cloud.tencent.com/document/api/386/18649#DeviceHardwareInfo)
* [DiskInfo](https://cloud.tencent.com/document/api/386/18649#DiskInfo)
* [HostedDeviceOutBandInfo](https://cloud.tencent.com/document/api/386/18649#HostedDeviceOutBandInfo)
* [RegionInfo](https://cloud.tencent.com/document/api/386/18649#RegionInfo)
* [ZoneInfo](https://cloud.tencent.com/document/api/386/18649#ZoneInfo)

### 第 6 次发布

发布时间：2019-01-25 16:51:10

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [BuyDevices](https://cloud.tencent.com/document/api/386/32913)
* [CreateCustomImage](https://cloud.tencent.com/document/api/386/32938)
* [DeleteCustomImages](https://cloud.tencent.com/document/api/386/32937)
* [DescribeCustomImageProcess](https://cloud.tencent.com/document/api/386/32936)
* [DescribeCustomImages](https://cloud.tencent.com/document/api/386/32935)
* [DescribeDeviceClassPartition](https://cloud.tencent.com/document/api/386/32910)
* [DescribeDevicePartition](https://cloud.tencent.com/document/api/386/32907)
* [DescribeOperationResult](https://cloud.tencent.com/document/api/386/32903)
* [ModifyCustomImageAttribute](https://cloud.tencent.com/document/api/386/32934)
* [ModifyLanIp](https://cloud.tencent.com/document/api/386/32899)
* [ShutdownDevices](https://cloud.tencent.com/document/api/386/32894)

新增数据结构：

* [CustomImage](https://cloud.tencent.com/document/api/386/18649#CustomImage)
* [CustomImageProcess](https://cloud.tencent.com/document/api/386/18649#CustomImageProcess)
* [DeviceClassPartitionInfo](https://cloud.tencent.com/document/api/386/18649#DeviceClassPartitionInfo)
* [DeviceDiskSizeInfo](https://cloud.tencent.com/document/api/386/18649#DeviceDiskSizeInfo)
* [DevicePartition](https://cloud.tencent.com/document/api/386/18649#DevicePartition)
* [PartitionInfo](https://cloud.tencent.com/document/api/386/18649#PartitionInfo)
* [SubtaskStatus](https://cloud.tencent.com/document/api/386/18649#SubtaskStatus)

### 第 5 次发布

发布时间：2018-12-27 20:25:42

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeDeviceClass](https://cloud.tencent.com/document/api/386/32911)
* [DescribeDeviceInventory](https://cloud.tencent.com/document/api/386/32909)
* [DescribeDeviceOperationLog](https://cloud.tencent.com/document/api/386/32908)
* [DescribeDevicePosition](https://cloud.tencent.com/document/api/386/32906)
* [DescribeOsInfo](https://cloud.tencent.com/document/api/386/32902)
* [ModifyDeviceAutoRenewFlag](https://cloud.tencent.com/document/api/386/32900)
* [OfflineDevices](https://cloud.tencent.com/document/api/386/33563)
* [SetOutBandVpnAuthPassword](https://cloud.tencent.com/document/api/386/32895)

新增数据结构：

* [DeviceClass](https://cloud.tencent.com/document/api/386/18649#DeviceClass)
* [DeviceOperationLog](https://cloud.tencent.com/document/api/386/18649#DeviceOperationLog)
* [DevicePositionInfo](https://cloud.tencent.com/document/api/386/18649#DevicePositionInfo)
* [OsInfo](https://cloud.tencent.com/document/api/386/18649#OsInfo)

### 第 4 次发布

发布时间：2018-12-06 19:36:26

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DeleteUserCmds](https://cloud.tencent.com/document/api/386/32931)
* [DescribeDevicePriceInfo](https://cloud.tencent.com/document/api/386/32905)
* [DescribeUserCmdTaskInfo](https://cloud.tencent.com/document/api/386/32930)
* [DescribeUserCmdTasks](https://cloud.tencent.com/document/api/386/32929)
* [DescribeUserCmds](https://cloud.tencent.com/document/api/386/32928)
* [ModifyDeviceAliases](https://cloud.tencent.com/document/api/386/32901)
* [ModifyPayModePre2Post](https://cloud.tencent.com/document/api/386/32898)
* [ModifyUserCmd](https://cloud.tencent.com/document/api/386/32927)
* [RebootDevices](https://cloud.tencent.com/document/api/386/32897)
* [ResetDevicePassword](https://cloud.tencent.com/document/api/386/32896)
* [RunUserCmd](https://cloud.tencent.com/document/api/386/32926)

新增数据结构：

* [DeviceAlias](https://cloud.tencent.com/document/api/386/18649#DeviceAlias)
* [DevicePriceInfo](https://cloud.tencent.com/document/api/386/18649#DevicePriceInfo)
* [FailedTaskInfo](https://cloud.tencent.com/document/api/386/18649#FailedTaskInfo)
* [SuccessTaskInfo](https://cloud.tencent.com/document/api/386/18649#SuccessTaskInfo)
* [UserCmd](https://cloud.tencent.com/document/api/386/18649#UserCmd)
* [UserCmdTask](https://cloud.tencent.com/document/api/386/18649#UserCmdTask)
* [UserCmdTaskInfo](https://cloud.tencent.com/document/api/386/18649#UserCmdTaskInfo)

### 第 3 次发布

发布时间：2018-11-06 10:46:03

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateSpotDevice](https://cloud.tencent.com/document/api/386/32912)
* [CreateUserCmd](https://cloud.tencent.com/document/api/386/32932)
* [DescribeDevices](https://cloud.tencent.com/document/api/386/32904)

新增数据结构：

* [DeviceInfo](https://cloud.tencent.com/document/api/386/18649#DeviceInfo)

### 第 2 次发布

发布时间：2018-10-26 14:29:08

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [BindPsaTag](https://cloud.tencent.com/document/api/386/32924)
* [CreatePsaRegulation](https://cloud.tencent.com/document/api/386/32923)
* [DeletePsaRegulation](https://cloud.tencent.com/document/api/386/32922)
* [DescribePsaRegulations](https://cloud.tencent.com/document/api/386/32921)
* [ModifyPsaRegulation](https://cloud.tencent.com/document/api/386/32917)
* [UnbindPsaTag](https://cloud.tencent.com/document/api/386/32915)

修改接口：

* [DescribeRepairTaskConstant](https://cloud.tencent.com/document/api/386/32920)

	* 新增出参：TaskTypeSet

	* <font color="#dd0000">**删除出参**：</font>TaskTypeList


新增数据结构：

* [PsaRegulation](https://cloud.tencent.com/document/api/386/18649#PsaRegulation)
* [Tag](https://cloud.tencent.com/document/api/386/18649#Tag)

### 第 1 次发布

发布时间：2018-07-30 16:43:10

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeRepairTaskConstant](https://cloud.tencent.com/document/api/386/32920)
* [DescribeTaskInfo](https://cloud.tencent.com/document/api/386/32919)
* [DescribeTaskOperationLog](https://cloud.tencent.com/document/api/386/32918)
* [RepairTaskControl](https://cloud.tencent.com/document/api/386/32916)

新增数据结构：

* [TaskInfo](https://cloud.tencent.com/document/api/386/18649#TaskInfo)
* [TaskOperationLog](https://cloud.tencent.com/document/api/386/18649#TaskOperationLog)
* [TaskType](https://cloud.tencent.com/document/api/386/18649#TaskType)




## 品牌经营管家(bma) 版本：2021-06-24

### 第 17 次发布

发布时间：2023-04-12 01:06:30

本次发布包含了以下内容：

改善已有的文档。

<font color="#dd0000">**删除接口**：</font>

* CreateCRObtain

### 第 16 次发布

发布时间：2023-04-11 01:04:13

本次发布包含了以下内容：

改善已有的文档。

<font color="#dd0000">**预下线接口**：</font>

* CreateCRObtain

### 第 15 次发布

发布时间：2023-01-17 01:09:15

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateCRWork](https://cloud.tencent.com/document/api/1296/78029)

	* 新增入参：IsAutoRenew


修改数据结构：

* [Monitor](https://cloud.tencent.com/document/api/1296/78030#Monitor)

	* 新增成员：MonitorEndTime, AutoRenew


### 第 14 次发布

发布时间：2022-11-04 06:09:26

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeCRMonitorDetail](https://cloud.tencent.com/document/api/1296/78028)

	* 新增出参：ExportURL

* [DescribeCRMonitors](https://cloud.tencent.com/document/api/1296/78027)

	* 新增出参：ExportURL

* [DescribeCRObtainDetail](https://cloud.tencent.com/document/api/1296/81541)

	* 新增出参：DepositPdfCert


修改数据结构：

* [Monitor](https://cloud.tencent.com/document/api/1296/78030#Monitor)

	* 新增成员：WorkCategoryAll, EvidenceStatus, EvidenceNote, TortSiteNum

* [MonitorTort](https://cloud.tencent.com/document/api/1296/78030#MonitorTort)

	* 新增成员：IPLoc


### 第 13 次发布

发布时间：2022-10-19 11:41:42

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateCRDesktopCode](https://cloud.tencent.com/document/api/1296/81572)

### 第 12 次发布

发布时间：2022-10-19 06:10:00

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeCRObtainDetail](https://cloud.tencent.com/document/api/1296/81541)

### 第 11 次发布

发布时间：2022-10-17 06:09:59

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateCRObtain](https://cloud.tencent.com/document/api/1296/81467)

### 第 10 次发布

发布时间：2022-10-12 06:11:10

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateCRUserVerify](https://cloud.tencent.com/document/api/1296/79150)

	* <font color="#dd0000">**修改入参**：</font>VerificationCode


### 第 9 次发布

发布时间：2022-09-28 06:10:28

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateCRBlock](https://cloud.tencent.com/document/api/1296/77824)

	* 新增入参：EvidenceFileUrl, EvidenceValidStartDate, EvidenceValidEndDate

* [CreateCRRight](https://cloud.tencent.com/document/api/1296/77822)

	* 新增入参：EvidenceFileUrl, EvidenceValidStartDate, EvidenceValidEndDate

* [CreateCRWork](https://cloud.tencent.com/document/api/1296/78029)

	* 新增入参：ApplierId, ApplierName


修改数据结构：

* [MonitorTort](https://cloud.tencent.com/document/api/1296/78030#MonitorTort)

	* 新增成员：TortSite, ICP, RightNote, ObtainType, BlockNote, WorkId, WorkName, AuthStatus, CommStatus, EvidenceStatus, IsProducer, IsOverseas


### 第 8 次发布

发布时间：2022-09-14 06:08:57

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeCRWorkInfo](https://cloud.tencent.com/document/api/1296/77821)

	* 新增出参：EvidenceStatus, WorkCategory, IsOriginal, IsRelease, ProducerName, ProduceTime, WhiteLists, WorkDesc, Authorization, AuthorizationStartTime, AuthorizationEndTime, Commission, CommissionStartTime, CommissionEndTime, EvidenceUrl, EvidenceStartTime, EvidenceEndTime


### 第 7 次发布

发布时间：2022-09-07 06:10:17

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateCRWork](https://cloud.tencent.com/document/api/1296/78029)

	* 新增入参：MonitorEndTime


### 第 6 次发布

发布时间：2022-09-05 06:10:17

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateCRRightFile](https://cloud.tencent.com/document/api/1296/80089)
* [CreateCRTort](https://cloud.tencent.com/document/api/1296/80088)
* [ModifyCRWhiteList](https://cloud.tencent.com/document/api/1296/80087)

修改接口：

* [ModifyCRMonitor](https://cloud.tencent.com/document/api/1296/78025)

	* 新增入参：MonitorEnd


新增数据结构：

* [File](https://cloud.tencent.com/document/api/1296/78030#File)

### 第 5 次发布

发布时间：2022-08-17 06:09:30

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateCRUserVerify](https://cloud.tencent.com/document/api/1296/79150)

### 第 4 次发布

发布时间：2022-08-02 06:05:09

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateBPFakeURL](https://cloud.tencent.com/document/api/1296/78237)
* [CreateBPFalseTicket](https://cloud.tencent.com/document/api/1296/78236)
* [CreateBPOfflineAttachment](https://cloud.tencent.com/document/api/1296/78235)
* [CreateBPOfflineTicket](https://cloud.tencent.com/document/api/1296/78234)
* [CreateBPProtectURLs](https://cloud.tencent.com/document/api/1296/78233)
* [DescribeBPCompanyInfo](https://cloud.tencent.com/document/api/1296/78232)
* [DescribeBPFakeURLs](https://cloud.tencent.com/document/api/1296/78231)
* [DescribeBPProtectURLs](https://cloud.tencent.com/document/api/1296/78230)
* [DescribeBPReportFakeURLs](https://cloud.tencent.com/document/api/1296/78229)
* [ModifyBPOfflineAttachment](https://cloud.tencent.com/document/api/1296/78228)

新增数据结构：

* [BrandData](https://cloud.tencent.com/document/api/1296/78030#BrandData)
* [FakeURLInfo](https://cloud.tencent.com/document/api/1296/78030#FakeURLInfo)
* [ProtectURLInfo](https://cloud.tencent.com/document/api/1296/78030#ProtectURLInfo)
* [ReportFakeURLInfo](https://cloud.tencent.com/document/api/1296/78030#ReportFakeURLInfo)

### 第 3 次发布

发布时间：2022-07-29 06:03:11

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateCRWork](https://cloud.tencent.com/document/api/1296/78029)
* [DescribeCRMonitorDetail](https://cloud.tencent.com/document/api/1296/78028)
* [DescribeCRMonitors](https://cloud.tencent.com/document/api/1296/78027)
* [ModifyCRBlockStatus](https://cloud.tencent.com/document/api/1296/78026)
* [ModifyCRMonitor](https://cloud.tencent.com/document/api/1296/78025)
* [ModifyCRObtainStatus](https://cloud.tencent.com/document/api/1296/78024)
* [ModifyCRRightStatus](https://cloud.tencent.com/document/api/1296/78023)
* [UpdateCRWork](https://cloud.tencent.com/document/api/1296/78022)

新增数据结构：

* [Filter](https://cloud.tencent.com/document/api/1296/78030#Filter)
* [Monitor](https://cloud.tencent.com/document/api/1296/78030#Monitor)
* [MonitorTort](https://cloud.tencent.com/document/api/1296/78030#MonitorTort)

### 第 2 次发布

发布时间：2022-07-28 06:06:00

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateCRCompanyVerify](https://cloud.tencent.com/document/api/1296/77823)

	* <font color="#dd0000">**修改入参**：</font>CompanyID, CompanyLegalName, ManagerName, ManagerPhone, VerificationCode


### 第 1 次发布

发布时间：2022-07-26 14:16:47

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateCRBlock](https://cloud.tencent.com/document/api/1296/77824)
* [CreateCRCompanyVerify](https://cloud.tencent.com/document/api/1296/77823)
* [CreateCRRight](https://cloud.tencent.com/document/api/1296/77822)
* [DescribeCRWorkInfo](https://cloud.tencent.com/document/api/1296/77821)



## 品牌经营管家(bma) 版本：2022-11-15

### 第 11 次发布

发布时间：2024-02-02 01:06:13

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [FakeURLData](https://cloud.tencent.com/document/api/1296/86604#FakeURLData)

	* 新增成员：OfflineTime


### 第 10 次发布

发布时间：2023-08-31 01:07:17

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateBPWhiteList](https://cloud.tencent.com/document/api/1296/86602)

	* 新增入参：Remark


修改数据结构：

* [WhiteListData](https://cloud.tencent.com/document/api/1296/86604#WhiteListData)

	* 新增成员：Remark

	* <font color="#dd0000">**修改成员**：</font>WhiteListId, CompanyId, BrandName, AssetsType, WhiteList, InsertTime


### 第 9 次发布

发布时间：2023-07-28 01:09:00

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [FakeURLData](https://cloud.tencent.com/document/api/1296/86604#FakeURLData)

	* 新增成员：AuditStatus

	* <font color="#dd0000">**修改成员**：</font>FakeURLId, BrandName, Origin, FakeURL, FakeDomain, Heat, BlockStatus, BlockNote, OfflineStatus, OfflineNote, IP, IPLocation, WebCompany, WebAttribute, WebName, WebICP, WebCreateTime, WebExpireTime, InsertTime, CertificationStatus, Snapshot, AccountStatus


### 第 8 次发布

发布时间：2023-05-18 01:05:33

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateBPBrand](https://cloud.tencent.com/document/api/1296/86603)

	* 新增入参：APISource


### 第 7 次发布

发布时间：2023-04-28 01:08:34

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateBPBrand](https://cloud.tencent.com/document/api/1296/86603)

	* 新增入参：BrandLogo


修改数据结构：

* [FakeURLData](https://cloud.tencent.com/document/api/1296/86604#FakeURLData)

	* 新增成员：AccountStatus


### 第 6 次发布

发布时间：2023-03-30 01:04:35

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [BrandData](https://cloud.tencent.com/document/api/1296/86604#BrandData)

	* 新增成员：Uin


### 第 5 次发布

发布时间：2023-03-06 01:04:17

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [FakeURLData](https://cloud.tencent.com/document/api/1296/86604#FakeURLData)

	* 新增成员：Snapshot


### 第 4 次发布

发布时间：2023-02-23 14:35:55

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [FakeURLData](https://cloud.tencent.com/document/api/1296/86604#FakeURLData)

	* 新增成员：FakeDomain


### 第 3 次发布

发布时间：2023-02-16 01:09:07

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeBPWhiteLists](https://cloud.tencent.com/document/api/1296/86607)

新增数据结构：

* [WhiteListData](https://cloud.tencent.com/document/api/1296/86604#WhiteListData)

### 第 2 次发布

发布时间：2023-02-15 17:30:37

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateBPBrand](https://cloud.tencent.com/document/api/1296/86603)
* [CreateBPWhiteList](https://cloud.tencent.com/document/api/1296/86602)
* [DeleteBPWhiteList](https://cloud.tencent.com/document/api/1296/86601)
* [DescribeBPBrands](https://cloud.tencent.com/document/api/1296/86600)
* [DescribeBPFakeAPPList](https://cloud.tencent.com/document/api/1296/86599)
* [DescribeBPFakeURLs](https://cloud.tencent.com/document/api/1296/86598)

新增数据结构：

* [BrandData](https://cloud.tencent.com/document/api/1296/86604#BrandData)
* [FakeAPPData](https://cloud.tencent.com/document/api/1296/86604#FakeAPPData)
* [FakeURLData](https://cloud.tencent.com/document/api/1296/86604#FakeURLData)
* [Filter](https://cloud.tencent.com/document/api/1296/86604#Filter)
* [ServiceData](https://cloud.tencent.com/document/api/1296/86604#ServiceData)
* [TrademarkData](https://cloud.tencent.com/document/api/1296/86604#TrademarkData)

### 第 1 次发布

发布时间：2023-02-14 17:30:50

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateBPFakeAPP](https://cloud.tencent.com/document/api/1296/86532)
* [CreateBPFakeAPPList](https://cloud.tencent.com/document/api/1296/86531)
* [CreateBPFakeURL](https://cloud.tencent.com/document/api/1296/86530)
* [CreateBPFakeURLs](https://cloud.tencent.com/document/api/1296/86529)




## 黑石弹性公网IP(bmeip) 版本：2018-06-25

### 第 4 次发布

发布时间：2020-03-10 23:40:57

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeEipAcls](https://cloud.tencent.com/document/api/1028/32856)

	* 新增入参：AclNames


### 第 3 次发布

发布时间：2020-03-04 17:46:44

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [UnbindRsList](https://cloud.tencent.com/document/api/1028/41875)

修改接口：

* [DescribeEipAcls](https://cloud.tencent.com/document/api/1028/32856)

	* 新增入参：EipIds, EipIps, EipNames, OrderField, Order

* [DescribeEips](https://cloud.tencent.com/document/api/1028/32853)

	* 新增出参：TotalCount


新增数据结构：

* [EipRsMap](https://cloud.tencent.com/document/api/1028/32865#EipRsMap)

### 第 2 次发布

发布时间：2019-09-06 10:27:40

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeEips](https://cloud.tencent.com/document/api/1028/32853)

	* <font color="#dd0000">**修改入参**：</font>AclId


### 第 1 次发布

发布时间：2019-01-24 15:02:42

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [BindEipAcls](https://cloud.tencent.com/document/api/1028/32864)
* [BindHosted](https://cloud.tencent.com/document/api/1028/32863)
* [BindRs](https://cloud.tencent.com/document/api/1028/32862)
* [BindVpcIp](https://cloud.tencent.com/document/api/1028/32861)
* [CreateEip](https://cloud.tencent.com/document/api/1028/32860)
* [CreateEipAcl](https://cloud.tencent.com/document/api/1028/32859)
* [DeleteEip](https://cloud.tencent.com/document/api/1028/32858)
* [DeleteEipAcl](https://cloud.tencent.com/document/api/1028/32857)
* [DescribeEipAcls](https://cloud.tencent.com/document/api/1028/32856)
* [DescribeEipQuota](https://cloud.tencent.com/document/api/1028/32855)
* [DescribeEipTask](https://cloud.tencent.com/document/api/1028/32854)
* [DescribeEips](https://cloud.tencent.com/document/api/1028/32853)
* [ModifyEipAcl](https://cloud.tencent.com/document/api/1028/32852)
* [ModifyEipCharge](https://cloud.tencent.com/document/api/1028/32851)
* [ModifyEipName](https://cloud.tencent.com/document/api/1028/32850)
* [UnbindEipAcls](https://cloud.tencent.com/document/api/1028/32849)
* [UnbindHosted](https://cloud.tencent.com/document/api/1028/32848)
* [UnbindRs](https://cloud.tencent.com/document/api/1028/32847)
* [UnbindVpcIp](https://cloud.tencent.com/document/api/1028/32846)

新增数据结构：

* [EipAcl](https://cloud.tencent.com/document/api/1028/32865#EipAcl)
* [EipAclMap](https://cloud.tencent.com/document/api/1028/32865#EipAclMap)
* [EipAclRule](https://cloud.tencent.com/document/api/1028/32865#EipAclRule)
* [EipInfo](https://cloud.tencent.com/document/api/1028/32865#EipInfo)




## 黑石负载均衡(bmlb) 版本：2018-06-25

### 第 4 次发布

发布时间：2020-03-23 08:03:08

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [LoadBalancer](https://cloud.tencent.com/document/api/1027/33287#LoadBalancer)

	* 新增成员：CurVips


### 第 3 次发布

发布时间：2020-03-04 17:47:00

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeL7Backends](https://cloud.tencent.com/document/api/1027/33256)

	* <font color="#dd0000">**修改入参**：</font>DomainId, LocationId

* [DescribeTrafficMirrors](https://cloud.tencent.com/document/api/1027/33238)

	* 新增入参：OrderField, Order, SearchKey

* [ModifyL7Listener](https://cloud.tencent.com/document/api/1027/33249)

	* 新增入参：ForwardProtocol


修改数据结构：

* [CreateL7Listener](https://cloud.tencent.com/document/api/1027/33287#CreateL7Listener)

	* 新增成员：ForwardProtocol

* [L7ListenerInfo](https://cloud.tencent.com/document/api/1027/33287#L7ListenerInfo)

	* 新增成员：ForwardProtocol

* [LoadBalancer](https://cloud.tencent.com/document/api/1027/33287#LoadBalancer)

	* 新增成员：IntVpcId

* [TrafficMirrorReceiver](https://cloud.tencent.com/document/api/1027/33287#TrafficMirrorReceiver)

	* 新增成员：Operates


### 第 2 次发布

发布时间：2019-06-06 20:55:15

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateL4Listeners](https://cloud.tencent.com/document/api/1027/33271)

	* <font color="#dd0000">**修改出参**：</font>TaskId

* [DeleteLoadBalancer](https://cloud.tencent.com/document/api/1027/33284)

	* <font color="#dd0000">**修改出参**：</font>TaskId

* [ModifyL7Listener](https://cloud.tencent.com/document/api/1027/33249)

	* <font color="#dd0000">**修改出参**：</font>TaskId


修改数据结构：

* [L4ListenerInfo](https://cloud.tencent.com/document/api/1027/33287#L4ListenerInfo)

	* 新增成员：CustomHealthSwitch, InputType, LineSeparatorType, HealthRequest, HealthResponse, ToaFlag, BalanceMode

* [LoadBalancer](https://cloud.tencent.com/document/api/1027/33287#LoadBalancer)

	* <font color="#dd0000">**删除成员**：</font>IspId


### 第 1 次发布

发布时间：2019-02-22 19:16:57

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [BindL4Backends](https://cloud.tencent.com/document/api/1027/33272)
* [BindL7Backends](https://cloud.tencent.com/document/api/1027/33261)
* [BindTrafficMirrorListeners](https://cloud.tencent.com/document/api/1027/33245)
* [BindTrafficMirrorReceivers](https://cloud.tencent.com/document/api/1027/33244)
* [CreateL4Listeners](https://cloud.tencent.com/document/api/1027/33271)
* [CreateL7Listeners](https://cloud.tencent.com/document/api/1027/33260)
* [CreateL7Rules](https://cloud.tencent.com/document/api/1027/33259)
* [CreateLoadBalancers](https://cloud.tencent.com/document/api/1027/33286)
* [CreateTrafficMirror](https://cloud.tencent.com/document/api/1027/33243)
* [DeleteL7Domains](https://cloud.tencent.com/document/api/1027/33258)
* [DeleteL7Rules](https://cloud.tencent.com/document/api/1027/33257)
* [DeleteListeners](https://cloud.tencent.com/document/api/1027/33285)
* [DeleteLoadBalancer](https://cloud.tencent.com/document/api/1027/33284)
* [DeleteTrafficMirror](https://cloud.tencent.com/document/api/1027/33242)
* [DescribeCertDetail](https://cloud.tencent.com/document/api/1027/33276)
* [DescribeDevicesBindInfo](https://cloud.tencent.com/document/api/1027/33283)
* [DescribeL4Backends](https://cloud.tencent.com/document/api/1027/33270)
* [DescribeL4ListenerInfo](https://cloud.tencent.com/document/api/1027/33269)
* [DescribeL4Listeners](https://cloud.tencent.com/document/api/1027/33268)
* [DescribeL7Backends](https://cloud.tencent.com/document/api/1027/33256)
* [DescribeL7ListenerInfo](https://cloud.tencent.com/document/api/1027/33255)
* [DescribeL7Listeners](https://cloud.tencent.com/document/api/1027/33254)
* [DescribeL7ListenersEx](https://cloud.tencent.com/document/api/1027/33253)
* [DescribeL7Rules](https://cloud.tencent.com/document/api/1027/33252)
* [DescribeLoadBalancerPortInfo](https://cloud.tencent.com/document/api/1027/33282)
* [DescribeLoadBalancerTaskResult](https://cloud.tencent.com/document/api/1027/33281)
* [DescribeLoadBalancers](https://cloud.tencent.com/document/api/1027/33280)
* [DescribeTrafficMirrorListeners](https://cloud.tencent.com/document/api/1027/33241)
* [DescribeTrafficMirrorReceiverHealthStatus](https://cloud.tencent.com/document/api/1027/33240)
* [DescribeTrafficMirrorReceivers](https://cloud.tencent.com/document/api/1027/33239)
* [DescribeTrafficMirrors](https://cloud.tencent.com/document/api/1027/33238)
* [ModifyL4BackendPort](https://cloud.tencent.com/document/api/1027/33267)
* [ModifyL4BackendProbePort](https://cloud.tencent.com/document/api/1027/33266)
* [ModifyL4BackendWeight](https://cloud.tencent.com/document/api/1027/33265)
* [ModifyL4Listener](https://cloud.tencent.com/document/api/1027/33264)
* [ModifyL7BackendPort](https://cloud.tencent.com/document/api/1027/33251)
* [ModifyL7BackendWeight](https://cloud.tencent.com/document/api/1027/33250)
* [ModifyL7Listener](https://cloud.tencent.com/document/api/1027/33249)
* [ModifyL7Locations](https://cloud.tencent.com/document/api/1027/33248)
* [ModifyLoadBalancer](https://cloud.tencent.com/document/api/1027/33279)
* [ModifyLoadBalancerChargeMode](https://cloud.tencent.com/document/api/1027/33278)
* [ReplaceCert](https://cloud.tencent.com/document/api/1027/33275)
* [SetTrafficMirrorAlias](https://cloud.tencent.com/document/api/1027/33237)
* [SetTrafficMirrorHealthSwitch](https://cloud.tencent.com/document/api/1027/33236)
* [UnbindL4Backends](https://cloud.tencent.com/document/api/1027/33263)
* [UnbindL7Backends](https://cloud.tencent.com/document/api/1027/33247)
* [UnbindTrafficMirrorListeners](https://cloud.tencent.com/document/api/1027/33235)
* [UnbindTrafficMirrorReceivers](https://cloud.tencent.com/document/api/1027/33234)
* [UploadCert](https://cloud.tencent.com/document/api/1027/33274)

新增数据结构：

* [BindL4Backend](https://cloud.tencent.com/document/api/1027/33287#BindL4Backend)
* [BindL7Backend](https://cloud.tencent.com/document/api/1027/33287#BindL7Backend)
* [BindTrafficMirrorReceiver](https://cloud.tencent.com/document/api/1027/33287#BindTrafficMirrorReceiver)
* [CertDetailLoadBalancer](https://cloud.tencent.com/document/api/1027/33287#CertDetailLoadBalancer)
* [CreateL4Listener](https://cloud.tencent.com/document/api/1027/33287#CreateL4Listener)
* [CreateL7Listener](https://cloud.tencent.com/document/api/1027/33287#CreateL7Listener)
* [CreateL7Rule](https://cloud.tencent.com/document/api/1027/33287#CreateL7Rule)
* [CreateLoadBalancerBzConf](https://cloud.tencent.com/document/api/1027/33287#CreateLoadBalancerBzConf)
* [DescribeL4Backend](https://cloud.tencent.com/document/api/1027/33287#DescribeL4Backend)
* [DescribeTrafficMirrorReceiver](https://cloud.tencent.com/document/api/1027/33287#DescribeTrafficMirrorReceiver)
* [DevicesBindInfoBackend](https://cloud.tencent.com/document/api/1027/33287#DevicesBindInfoBackend)
* [DevicesBindInfoL4Listener](https://cloud.tencent.com/document/api/1027/33287#DevicesBindInfoL4Listener)
* [DevicesBindInfoL7Listener](https://cloud.tencent.com/document/api/1027/33287#DevicesBindInfoL7Listener)
* [DevicesBindInfoLoadBalancer](https://cloud.tencent.com/document/api/1027/33287#DevicesBindInfoLoadBalancer)
* [DevicesBindInfoLocation](https://cloud.tencent.com/document/api/1027/33287#DevicesBindInfoLocation)
* [DevicesBindInfoRule](https://cloud.tencent.com/document/api/1027/33287#DevicesBindInfoRule)
* [Filter](https://cloud.tencent.com/document/api/1027/33287#Filter)
* [L4Backend](https://cloud.tencent.com/document/api/1027/33287#L4Backend)
* [L4Listener](https://cloud.tencent.com/document/api/1027/33287#L4Listener)
* [L4ListenerInfo](https://cloud.tencent.com/document/api/1027/33287#L4ListenerInfo)
* [L7Backend](https://cloud.tencent.com/document/api/1027/33287#L7Backend)
* [L7ExListener](https://cloud.tencent.com/document/api/1027/33287#L7ExListener)
* [L7Listener](https://cloud.tencent.com/document/api/1027/33287#L7Listener)
* [L7ListenerInfo](https://cloud.tencent.com/document/api/1027/33287#L7ListenerInfo)
* [L7ListenerInfoBackend](https://cloud.tencent.com/document/api/1027/33287#L7ListenerInfoBackend)
* [L7ListenerInfoLocation](https://cloud.tencent.com/document/api/1027/33287#L7ListenerInfoLocation)
* [L7ListenerInfoRule](https://cloud.tencent.com/document/api/1027/33287#L7ListenerInfoRule)
* [L7Rule](https://cloud.tencent.com/document/api/1027/33287#L7Rule)
* [L7RulesLocation](https://cloud.tencent.com/document/api/1027/33287#L7RulesLocation)
* [LoadBalancer](https://cloud.tencent.com/document/api/1027/33287#LoadBalancer)
* [LoadBalancerPortInfoListener](https://cloud.tencent.com/document/api/1027/33287#LoadBalancerPortInfoListener)
* [ModifyL7LocationRule](https://cloud.tencent.com/document/api/1027/33287#ModifyL7LocationRule)
* [ModifyLoadBalancerChargeModeListener](https://cloud.tencent.com/document/api/1027/33287#ModifyLoadBalancerChargeModeListener)
* [TrafficMirror](https://cloud.tencent.com/document/api/1027/33287#TrafficMirror)
* [TrafficMirrorListener](https://cloud.tencent.com/document/api/1027/33287#TrafficMirrorListener)
* [TrafficMirrorPortStatus](https://cloud.tencent.com/document/api/1027/33287#TrafficMirrorPortStatus)
* [TrafficMirrorReceiver](https://cloud.tencent.com/document/api/1027/33287#TrafficMirrorReceiver)
* [TrafficMirrorReciversStatus](https://cloud.tencent.com/document/api/1027/33287#TrafficMirrorReciversStatus)
* [UnbindL4Backend](https://cloud.tencent.com/document/api/1027/33287#UnbindL4Backend)
* [UnbindL7Backend](https://cloud.tencent.com/document/api/1027/33287#UnbindL7Backend)
* [UnbindTrafficMirrorReceiver](https://cloud.tencent.com/document/api/1027/33287#UnbindTrafficMirrorReceiver)




## 黑石私有网络(bmvpc) 版本：2018-06-25

### 第 5 次发布

发布时间：2020-03-30 08:35:00

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [VpcInfo](https://cloud.tencent.com/document/api/1024/34257#VpcInfo)

	* 新增成员：IntVpcId

* [VpcResource](https://cloud.tencent.com/document/api/1024/34257#VpcResource)

	* 新增成员：IntVpcId


### 第 4 次发布

发布时间：2020-03-19 08:04:09

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [VpnConnection](https://cloud.tencent.com/document/api/1024/34257#VpnConnection)

	* 新增成员：SourceCidr


### 第 3 次发布

发布时间：2020-03-16 08:03:27

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeCustomerGateways](https://cloud.tencent.com/document/api/1024/34253)

	* 新增入参：OrderField, OrderDirection

* [DescribeNatGateways](https://cloud.tencent.com/document/api/1024/34241)

	* 新增入参：Zone, OrderField, OrderDirection

* [DescribeSubnets](https://cloud.tencent.com/document/api/1024/34211)

	* 新增入参：OrderField, OrderDirection

* [DescribeVpcPeerConnections](https://cloud.tencent.com/document/api/1024/36903)

	* 新增入参：VpcId

* [DescribeVpcResource](https://cloud.tencent.com/document/api/1024/34209)

	* 新增入参：OrderField, OrderDirection

* [DescribeVpnConnections](https://cloud.tencent.com/document/api/1024/36905)

	* 新增入参：VpnGatewayId, VpnConnectionName, OrderField, OrderDirection

* [DescribeVpnGateways](https://cloud.tencent.com/document/api/1024/36904)

	* 新增入参：OrderField, OrderDirection


修改数据结构：

* [IPSECOptionsSpecification](https://cloud.tencent.com/document/api/1024/34257#IPSECOptionsSpecification)

	* 新增成员：EncapMode

* [NatGatewayInfo](https://cloud.tencent.com/document/api/1024/34257#NatGatewayInfo)

	* 新增成员：State, IntVpcId, NatResourceId

* [SubnetInfo](https://cloud.tencent.com/document/api/1024/34257#SubnetInfo)

	* 新增成员：Zone, VpcZoneId, VpcZone, BroadcastFlag

* [VpcResource](https://cloud.tencent.com/document/api/1024/34257#VpcResource)

	* 新增成员：CcnServiceNum, VpcPeerLimitToAllRegion, VpcPeerLimitToSameRegion

* [VpnConnection](https://cloud.tencent.com/document/api/1024/34257#VpnConnection)

	* 新增成员：VpnGatewayName, CustomerGatewayName, DestinationCidr


### 第 2 次发布

发布时间：2019-08-08 23:00:28

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateCustomerGateway](https://cloud.tencent.com/document/api/1024/36906)
* [DescribeVpcPeerConnections](https://cloud.tencent.com/document/api/1024/36903)
* [DescribeVpnConnections](https://cloud.tencent.com/document/api/1024/36905)
* [DescribeVpnGateways](https://cloud.tencent.com/document/api/1024/36904)

新增数据结构：

* [VpcPeerConnection](https://cloud.tencent.com/document/api/1024/34257#VpcPeerConnection)
* [VpnConnection](https://cloud.tencent.com/document/api/1024/34257#VpnConnection)
* [VpnGateway](https://cloud.tencent.com/document/api/1024/34257#VpnGateway)

### 第 1 次发布

发布时间：2019-04-11 18:33:51

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [AcceptVpcPeerConnection](https://cloud.tencent.com/document/api/1024/34234)
* [AsyncRegisterIps](https://cloud.tencent.com/document/api/1024/34228)
* [BindEipsToNatGateway](https://cloud.tencent.com/document/api/1024/34246)
* [BindIpsToNatGateway](https://cloud.tencent.com/document/api/1024/34245)
* [BindSubnetsToNatGateway](https://cloud.tencent.com/document/api/1024/34244)
* [CreateDockerSubnetWithVlan](https://cloud.tencent.com/document/api/1024/34227)
* [CreateHostedInterface](https://cloud.tencent.com/document/api/1024/34226)
* [CreateInterfaces](https://cloud.tencent.com/document/api/1024/34225)
* [CreateNatGateway](https://cloud.tencent.com/document/api/1024/34243)
* [CreateRoutePolicies](https://cloud.tencent.com/document/api/1024/34202)
* [CreateSubnet](https://cloud.tencent.com/document/api/1024/34224)
* [CreateVirtualSubnetWithVlan](https://cloud.tencent.com/document/api/1024/34223)
* [CreateVpc](https://cloud.tencent.com/document/api/1024/34222)
* [CreateVpcPeerConnection](https://cloud.tencent.com/document/api/1024/34233)
* [DeleteCustomerGateway](https://cloud.tencent.com/document/api/1024/34256)
* [DeleteHostedInterface](https://cloud.tencent.com/document/api/1024/34221)
* [DeleteHostedInterfaces](https://cloud.tencent.com/document/api/1024/34220)
* [DeleteInterfaces](https://cloud.tencent.com/document/api/1024/34219)
* [DeleteNatGateway](https://cloud.tencent.com/document/api/1024/34242)
* [DeleteRoutePolicy](https://cloud.tencent.com/document/api/1024/34201)
* [DeleteSubnet](https://cloud.tencent.com/document/api/1024/34218)
* [DeleteVirtualIp](https://cloud.tencent.com/document/api/1024/34217)
* [DeleteVpc](https://cloud.tencent.com/document/api/1024/34216)
* [DeleteVpcPeerConnection](https://cloud.tencent.com/document/api/1024/34232)
* [DeleteVpnConnection](https://cloud.tencent.com/document/api/1024/34255)
* [DeleteVpnGateway](https://cloud.tencent.com/document/api/1024/34254)
* [DeregisterIps](https://cloud.tencent.com/document/api/1024/34215)
* [DescribeCustomerGateways](https://cloud.tencent.com/document/api/1024/34253)
* [DescribeNatGateways](https://cloud.tencent.com/document/api/1024/34241)
* [DescribeNatSubnets](https://cloud.tencent.com/document/api/1024/34240)
* [DescribeRoutePolicies](https://cloud.tencent.com/document/api/1024/34200)
* [DescribeRouteTables](https://cloud.tencent.com/document/api/1024/34199)
* [DescribeSubnetAvailableIps](https://cloud.tencent.com/document/api/1024/34214)
* [DescribeSubnetByDevice](https://cloud.tencent.com/document/api/1024/34213)
* [DescribeSubnetByHostedDevice](https://cloud.tencent.com/document/api/1024/34212)
* [DescribeSubnets](https://cloud.tencent.com/document/api/1024/34211)
* [DescribeTaskStatus](https://cloud.tencent.com/document/api/1024/34195)
* [DescribeVpcQuota](https://cloud.tencent.com/document/api/1024/34210)
* [DescribeVpcResource](https://cloud.tencent.com/document/api/1024/34209)
* [DescribeVpcView](https://cloud.tencent.com/document/api/1024/34208)
* [DescribeVpcs](https://cloud.tencent.com/document/api/1024/34207)
* [DownloadCustomerGatewayConfiguration](https://cloud.tencent.com/document/api/1024/34252)
* [ModifyCustomerGatewayAttribute](https://cloud.tencent.com/document/api/1024/34251)
* [ModifyRoutePolicy](https://cloud.tencent.com/document/api/1024/34198)
* [ModifyRouteTable](https://cloud.tencent.com/document/api/1024/34197)
* [ModifySubnetAttribute](https://cloud.tencent.com/document/api/1024/34206)
* [ModifySubnetDHCPRelay](https://cloud.tencent.com/document/api/1024/34205)
* [ModifyVpcAttribute](https://cloud.tencent.com/document/api/1024/34204)
* [ModifyVpcPeerConnection](https://cloud.tencent.com/document/api/1024/34231)
* [ModifyVpnConnectionAttribute](https://cloud.tencent.com/document/api/1024/34250)
* [ModifyVpnGatewayAttribute](https://cloud.tencent.com/document/api/1024/34249)
* [RejectVpcPeerConnection](https://cloud.tencent.com/document/api/1024/34230)
* [ResetVpnConnection](https://cloud.tencent.com/document/api/1024/34248)
* [UnbindEipsFromNatGateway](https://cloud.tencent.com/document/api/1024/34239)
* [UnbindIpsFromNatGateway](https://cloud.tencent.com/document/api/1024/34238)
* [UnbindSubnetsFromNatGateway](https://cloud.tencent.com/document/api/1024/34237)
* [UpgradeNatGateway](https://cloud.tencent.com/document/api/1024/34236)

新增数据结构：

* [CustomerGateway](https://cloud.tencent.com/document/api/1024/34257#CustomerGateway)
* [Filter](https://cloud.tencent.com/document/api/1024/34257#Filter)
* [IKEOptionsSpecification](https://cloud.tencent.com/document/api/1024/34257#IKEOptionsSpecification)
* [IPSECOptionsSpecification](https://cloud.tencent.com/document/api/1024/34257#IPSECOptionsSpecification)
* [IpInfo](https://cloud.tencent.com/document/api/1024/34257#IpInfo)
* [NatGatewayInfo](https://cloud.tencent.com/document/api/1024/34257#NatGatewayInfo)
* [NatSubnetInfo](https://cloud.tencent.com/document/api/1024/34257#NatSubnetInfo)
* [RoutePolicy](https://cloud.tencent.com/document/api/1024/34257#RoutePolicy)
* [RouteTable](https://cloud.tencent.com/document/api/1024/34257#RouteTable)
* [SecurityPolicyDatabase](https://cloud.tencent.com/document/api/1024/34257#SecurityPolicyDatabase)
* [SubnetCreateInputInfo](https://cloud.tencent.com/document/api/1024/34257#SubnetCreateInputInfo)
* [SubnetInfo](https://cloud.tencent.com/document/api/1024/34257#SubnetInfo)
* [VpcInfo](https://cloud.tencent.com/document/api/1024/34257#VpcInfo)
* [VpcQuota](https://cloud.tencent.com/document/api/1024/34257#VpcQuota)
* [VpcResource](https://cloud.tencent.com/document/api/1024/34257#VpcResource)
* [VpcSubnetCreateInfo](https://cloud.tencent.com/document/api/1024/34257#VpcSubnetCreateInfo)
* [VpcSubnetViewInfo](https://cloud.tencent.com/document/api/1024/34257#VpcSubnetViewInfo)
* [VpcViewInfo](https://cloud.tencent.com/document/api/1024/34257#VpcViewInfo)




## 商业流程服务(bpaas) 版本：2018-12-17

### 第 6 次发布

发布时间：2024-07-05 01:04:07

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [ApproveUser](https://cloud.tencent.com/document/api/1083/80917#ApproveUser)

	* 新增成员：ApproveStatus, ApproveMsg, ApproveTime, ApproveGroup


### 第 5 次发布

发布时间：2023-06-14 01:09:11

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [GetBpaasApproveDetail](https://cloud.tencent.com/document/api/1083/80916)

	* 新增出参：ModifyTime


修改数据结构：

* [StatusNode](https://cloud.tencent.com/document/api/1083/80917#StatusNode)

	* 新增成员：RejectedCloudFunctionMsg, PrevNode


### 第 4 次发布

发布时间：2023-03-08 01:04:59

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [StatusNode](https://cloud.tencent.com/document/api/1083/80917#StatusNode)

	* 新增成员：ParallelNodes


### 第 3 次发布

发布时间：2022-12-15 01:10:28

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [StatusNode](https://cloud.tencent.com/document/api/1083/80917#StatusNode)

	* 新增成员：DataHubId, TaskName, CKafkaRegion, ExternalUrl


### 第 2 次发布

发布时间：2022-09-30 06:12:23

本次发布包含了以下内容：

改善已有的文档。

新增数据结构：

* [Scf](https://cloud.tencent.com/document/api/1083/80917#Scf)
* [ScfParam](https://cloud.tencent.com/document/api/1083/80917#ScfParam)

修改数据结构：

* [ApproveUser](https://cloud.tencent.com/document/api/1083/80917#ApproveUser)

	* 新增成员：Scf


### 第 1 次发布

发布时间：2022-09-22 11:16:45

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [GetBpaasApproveDetail](https://cloud.tencent.com/document/api/1083/80916)
* [OutApproveBpaasApplication](https://cloud.tencent.com/document/api/1083/80915)

新增数据结构：

* [ApplyParam](https://cloud.tencent.com/document/api/1083/80917#ApplyParam)
* [ApproveOpinion](https://cloud.tencent.com/document/api/1083/80917#ApproveOpinion)
* [ApproveUser](https://cloud.tencent.com/document/api/1083/80917#ApproveUser)
* [StatusNode](https://cloud.tencent.com/document/api/1083/80917#StatusNode)




## 业务风险情报(bri) 版本：2019-03-28

### 第 5 次发布

发布时间：2024-04-09 01:08:44

本次发布包含了以下内容：

改善已有的文档。

<font color="#dd0000">**预下线接口**：</font>

* DescribeBRI

### 第 4 次发布

发布时间：2023-08-03 12:20:37

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [BRIRequest](https://cloud.tencent.com/document/api/1064/35632#BRIRequest)

	* 新增成员：SubAppid


### 第 3 次发布

发布时间：2020-10-19 08:01:54

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeBRI](https://cloud.tencent.com/document/api/#/#)

	* <font color="#dd0000">**修改入参**：</font>RequestData, ResourceId


### 第 2 次发布

发布时间：2020-07-03 08:05:30

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [BRIRequest](https://cloud.tencent.com/document/api/1064/35632#BRIRequest)

	* 新增成员：QQ, QQTag, Scene, Wechat, WechatTag


### 第 1 次发布

发布时间：2019-06-21 19:18:04

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeBRI](https://cloud.tencent.com/document/api/#/#)

新增数据结构：

* [BRIRequest](https://cloud.tencent.com/document/api/1064/35632#BRIRequest)
* [BRIResponse](https://cloud.tencent.com/document/api/1064/35632#BRIResponse)




## 二进制软件成分分析(bsca) 版本：2021-08-11

### 第 6 次发布

发布时间：2024-04-16 01:05:23

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeKBComponentVulnerability](https://cloud.tencent.com/document/api/1483/72072)

	* 新增入参：Language

* [DescribeKBVulnerability](https://cloud.tencent.com/document/api/1483/72070)

	* 新增入参：Language


### 第 5 次发布

发布时间：2023-10-24 01:07:40

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeKBVulnerability](https://cloud.tencent.com/document/api/1483/72070)

	* 新增入参：CNVDID, CNNVDID


新增数据结构：

* [AffectedComponent](https://cloud.tencent.com/document/api/1483/72074#AffectedComponent)

修改数据结构：

* [VulnerabilityDetail](https://cloud.tencent.com/document/api/1483/72074#VulnerabilityDetail)

	* 新增成员：AffectedComponentList


### 第 4 次发布

发布时间：2023-10-17 01:08:28

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeKBComponentVersionList](https://cloud.tencent.com/document/api/1483/100319)
* [SearchKBComponent](https://cloud.tencent.com/document/api/1483/100318)

新增数据结构：

* [ComponentVersion](https://cloud.tencent.com/document/api/1483/72074#ComponentVersion)

### 第 3 次发布

发布时间：2022-09-29 06:12:03

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [MatchKBPURLList](https://cloud.tencent.com/document/api/1483/75192)

	* 新增出参：Hit


### 第 2 次发布

发布时间：2022-06-09 06:06:39

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [MatchKBPURLList](https://cloud.tencent.com/document/api/1483/75192)

### 第 1 次发布

发布时间：2022-04-02 17:37:22

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeKBComponent](https://cloud.tencent.com/document/api/1483/72073)
* [DescribeKBComponentVulnerability](https://cloud.tencent.com/document/api/1483/72072)
* [DescribeKBLicense](https://cloud.tencent.com/document/api/1483/72071)
* [DescribeKBVulnerability](https://cloud.tencent.com/document/api/1483/72070)

新增数据结构：

* [CVSSV2Info](https://cloud.tencent.com/document/api/1483/72074#CVSSV2Info)
* [CVSSV3Info](https://cloud.tencent.com/document/api/1483/72074#CVSSV3Info)
* [Component](https://cloud.tencent.com/document/api/1483/72074#Component)
* [ComponentVulnerabilitySummary](https://cloud.tencent.com/document/api/1483/72074#ComponentVulnerabilitySummary)
* [ComponentVulnerabilityUnion](https://cloud.tencent.com/document/api/1483/72074#ComponentVulnerabilityUnion)
* [LicenseDetail](https://cloud.tencent.com/document/api/1483/72074#LicenseDetail)
* [LicenseRestriction](https://cloud.tencent.com/document/api/1483/72074#LicenseRestriction)
* [LicenseSummary](https://cloud.tencent.com/document/api/1483/72074#LicenseSummary)
* [LicenseUnion](https://cloud.tencent.com/document/api/1483/72074#LicenseUnion)
* [PURL](https://cloud.tencent.com/document/api/1483/72074#PURL)
* [Qualifier](https://cloud.tencent.com/document/api/1483/72074#Qualifier)
* [VulnerabilityDetail](https://cloud.tencent.com/document/api/1483/72074#VulnerabilityDetail)
* [VulnerabilitySummary](https://cloud.tencent.com/document/api/1483/72074#VulnerabilitySummary)
* [VulnerabilityUnion](https://cloud.tencent.com/document/api/1483/72074#VulnerabilityUnion)




## 区块链可信取证(btoe) 版本：2021-03-03

### 第 1 次发布

发布时间：2021-04-21 17:20:24

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateAudioDeposit](https://cloud.tencent.com/document/api/1259/54919)
* [CreateDataDeposit](https://cloud.tencent.com/document/api/1259/54918)
* [CreateDocDeposit](https://cloud.tencent.com/document/api/1259/54917)
* [CreateHashDeposit](https://cloud.tencent.com/document/api/1259/54916)
* [CreateHashDepositNoCert](https://cloud.tencent.com/document/api/1259/54915)
* [CreateHashDepositNoSeal](https://cloud.tencent.com/document/api/1259/54914)
* [CreateImageDeposit](https://cloud.tencent.com/document/api/1259/54931)
* [CreateVideoDeposit](https://cloud.tencent.com/document/api/1259/54930)
* [CreateWebpageDeposit](https://cloud.tencent.com/document/api/1259/54913)
* [GetDepositCert](https://cloud.tencent.com/document/api/1259/54912)
* [GetDepositFile](https://cloud.tencent.com/document/api/1259/54911)
* [GetDepositInfo](https://cloud.tencent.com/document/api/1259/54910)



## 区块链可信取证(btoe) 版本：2021-05-14

### 第 1 次发布

发布时间：2021-06-02 08:00:26

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateAudioDeposit](https://cloud.tencent.com/document/api/1259/56574)
* [CreateDataDeposit](https://cloud.tencent.com/document/api/1259/56573)
* [CreateDocDeposit](https://cloud.tencent.com/document/api/1259/56572)
* [CreateHashDeposit](https://cloud.tencent.com/document/api/1259/56571)
* [CreateHashDepositNoCert](https://cloud.tencent.com/document/api/1259/56570)
* [CreateHashDepositNoSeal](https://cloud.tencent.com/document/api/1259/56569)
* [CreateImageDeposit](https://cloud.tencent.com/document/api/1259/56568)
* [CreateVideoDeposit](https://cloud.tencent.com/document/api/1259/56567)
* [GetDepositCert](https://cloud.tencent.com/document/api/1259/56566)
* [GetDepositFile](https://cloud.tencent.com/document/api/1259/56565)
* [GetDepositInfo](https://cloud.tencent.com/document/api/1259/56564)
* [VerifyEvidenceBlockChainTxHash](https://cloud.tencent.com/document/api/1259/56563)
* [VerifyEvidenceHash](https://cloud.tencent.com/document/api/1259/56562)




## 访问管理(cam) 版本：2019-01-16

### 第 60 次发布

发布时间：2024-07-24 01:13:41

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [RoleInfo](https://cloud.tencent.com/document/api/598/33167#RoleInfo)

	* 新增成员：RoleArn


### 第 59 次发布

发布时间：2024-06-21 01:14:07

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateAccessKey](https://cloud.tencent.com/document/api/598/82370)

	* 新增入参：Description


修改数据结构：

* [AccessKey](https://cloud.tencent.com/document/api/598/33167#AccessKey)

	* 新增成员：Description

* [AccessKeyDetail](https://cloud.tencent.com/document/api/598/33167#AccessKeyDetail)

	* 新增成员：Description


### 第 58 次发布

发布时间：2024-06-11 11:13:54

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [BuildDataFlowAuthToken](https://cloud.tencent.com/document/api/598/107089)

新增数据结构：

* [AuthToken](https://cloud.tencent.com/document/api/598/33167#AuthToken)

### 第 57 次发布

发布时间：2024-03-12 19:49:56

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [LoginActionFlag](https://cloud.tencent.com/document/api/598/33167#LoginActionFlag)

	* 新增成员：U2FToken

* [LoginActionFlagIntl](https://cloud.tencent.com/document/api/598/33167#LoginActionFlagIntl)

	* 新增成员：U2FToken


### 第 56 次发布

发布时间：2023-12-11 00:09:38

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [LoginActionFlag](https://cloud.tencent.com/document/api/598/33167#LoginActionFlag)

	* 新增成员：Mail


### 第 55 次发布

发布时间：2023-08-11 01:04:42

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateMessageReceiver](https://cloud.tencent.com/document/api/598/96136)

### 第 54 次发布

发布时间：2023-07-19 01:09:39

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [GetAccountSummary](https://cloud.tencent.com/document/api/598/58534)

	* 新增出参：IdentityProviders


### 第 53 次发布

发布时间：2023-05-17 01:07:15

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateUserSAMLConfig](https://cloud.tencent.com/document/api/598/62664)

	* 新增入参：AuxiliaryDomain

* [DescribeUserSAMLConfig](https://cloud.tencent.com/document/api/598/62663)

	* 新增出参：AuxiliaryDomain

* [UpdateUserSAMLConfig](https://cloud.tencent.com/document/api/598/62662)

	* 新增入参：AuxiliaryDomain


### 第 52 次发布

发布时间：2023-05-10 01:06:45

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeSafeAuthFlagColl](https://cloud.tencent.com/document/api/598/48602)

	* 新增出参：PromptTrust


### 第 51 次发布

发布时间：2023-03-01 01:04:59

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [GetUser](https://cloud.tencent.com/document/api/598/34590)

	* 新增出参：RecentlyLoginIP, RecentlyLoginTime


### 第 50 次发布

发布时间：2022-12-23 01:11:34

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [SecretIdLastUsed](https://cloud.tencent.com/document/api/598/33167#SecretIdLastUsed)

	* 新增成员：LastSecretUsedDate


### 第 49 次发布

发布时间：2022-11-04 06:10:29

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateAccessKey](https://cloud.tencent.com/document/api/598/82370)
* [DeleteAccessKey](https://cloud.tencent.com/document/api/598/82369)
* [UpdateAccessKey](https://cloud.tencent.com/document/api/598/82368)

新增数据结构：

* [AccessKeyDetail](https://cloud.tencent.com/document/api/598/33167#AccessKeyDetail)

### 第 48 次发布

发布时间：2022-05-25 06:03:56

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [TagRole](https://cloud.tencent.com/document/api/598/74379)
* [UntagRole](https://cloud.tencent.com/document/api/598/74378)

### 第 47 次发布

发布时间：2022-05-19 06:07:36

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateRole](https://cloud.tencent.com/document/api/598/36225)

	* 新增入参：Tags

* [CreateServiceLinkedRole](https://cloud.tencent.com/document/api/598/43711)

	* 新增入参：Tags

* [DescribeRoleList](https://cloud.tencent.com/document/api/598/36223)

	* 新增入参：Tags


新增数据结构：

* [RoleTags](https://cloud.tencent.com/document/api/598/33167#RoleTags)

修改数据结构：

* [RoleInfo](https://cloud.tencent.com/document/api/598/33167#RoleInfo)

	* 新增成员：Tags


### 第 46 次发布

发布时间：2022-05-09 06:03:17

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateOIDCConfig](https://cloud.tencent.com/document/api/598/73473)
* [DeleteOIDCConfig](https://cloud.tencent.com/document/api/598/73472)
* [DescribeOIDCConfig](https://cloud.tencent.com/document/api/598/73471)
* [UpdateOIDCConfig](https://cloud.tencent.com/document/api/598/73470)

### 第 45 次发布

发布时间：2022-04-04 06:10:24

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateUserOIDCConfig](https://cloud.tencent.com/document/api/598/72091)
* [DescribeUserOIDCConfig](https://cloud.tencent.com/document/api/598/72090)
* [DisableUserSSO](https://cloud.tencent.com/document/api/598/72089)
* [UpdateUserOIDCConfig](https://cloud.tencent.com/document/api/598/72088)

### 第 44 次发布

发布时间：2022-03-28 08:03:45

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeSafeAuthFlag](https://cloud.tencent.com/document/api/598/48426)

	* 新增出参：PromptTrust


### 第 43 次发布

发布时间：2022-03-01 08:01:53

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [GetUserAppId](https://cloud.tencent.com/document/api/598/70416)

### 第 42 次发布

发布时间：2022-01-27 08:10:42

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [SubAccountInfo](https://cloud.tencent.com/document/api/598/33167#SubAccountInfo)

	* 新增成员：NickName


### 第 41 次发布

发布时间：2022-01-07 08:04:06

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [ListAttachedUserAllPolicies](https://cloud.tencent.com/document/api/598/67728)

新增数据结构：

* [AttachedUserPolicy](https://cloud.tencent.com/document/api/598/33167#AttachedUserPolicy)
* [AttachedUserPolicyGroupInfo](https://cloud.tencent.com/document/api/598/33167#AttachedUserPolicyGroupInfo)

### 第 40 次发布

发布时间：2021-12-23 08:06:14

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [GetRolePermissionBoundary](https://cloud.tencent.com/document/api/598/66679)
* [GetUserPermissionBoundary](https://cloud.tencent.com/document/api/598/66680)

### 第 39 次发布

发布时间：2021-11-08 08:02:23

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [GroupIdOfUidInfo](https://cloud.tencent.com/document/api/598/33167#GroupIdOfUidInfo)

	* 新增成员：Uin

	* <font color="#dd0000">**修改成员**：</font>Uid


### 第 38 次发布

发布时间：2021-10-14 08:05:24

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateUserSAMLConfig](https://cloud.tencent.com/document/api/598/62664)
* [DescribeUserSAMLConfig](https://cloud.tencent.com/document/api/598/62663)
* [UpdateUserSAMLConfig](https://cloud.tencent.com/document/api/598/62662)

### 第 37 次发布

发布时间：2021-08-24 08:04:06

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [ListAttachedGroupPolicies](https://cloud.tencent.com/document/api/598/34573)

	* 新增入参：Keyword

* [ListAttachedRolePolicies](https://cloud.tencent.com/document/api/598/36220)

	* 新增入参：Keyword


### 第 36 次发布

发布时间：2021-07-27 08:04:10

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [StrategyInfo](https://cloud.tencent.com/document/api/598/33167#StrategyInfo)

	* 新增成员：AttachEntityCount, AttachEntityBoundaryCount, UpdateTime


### 第 35 次发布

发布时间：2021-07-13 08:05:10

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeSafeAuthFlagIntl](https://cloud.tencent.com/document/api/598/58533)
* [GetAccountSummary](https://cloud.tencent.com/document/api/598/58534)

新增数据结构：

* [LoginActionFlagIntl](https://cloud.tencent.com/document/api/598/33167#LoginActionFlagIntl)

### 第 34 次发布

发布时间：2021-07-07 17:29:00

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [SecretIdLastUsed](https://cloud.tencent.com/document/api/598/33167#SecretIdLastUsed)

	* 新增成员：SecretId, LastUsedDate


### 第 33 次发布

发布时间：2021-07-07 15:44:01

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [GetSecurityLastUsed](https://cloud.tencent.com/document/api/598/58230)

	* 新增入参：SecretIdList

	* 新增出参：SecretIdLastUsedRows


新增数据结构：

* [SecretIdLastUsed](https://cloud.tencent.com/document/api/598/33167#SecretIdLastUsed)

### 第 32 次发布

发布时间：2021-07-07 09:58:11

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [GetSecurityLastUsed](https://cloud.tencent.com/document/api/598/58230)

### 第 31 次发布

发布时间：2021-07-06 08:03:53

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [ListPoliciesGrantingServiceAccess](https://cloud.tencent.com/document/api/598/58191)

新增数据结构：

* [ListGrantServiceAccessActionNode](https://cloud.tencent.com/document/api/598/33167#ListGrantServiceAccessActionNode)
* [ListGrantServiceAccessNode](https://cloud.tencent.com/document/api/598/33167#ListGrantServiceAccessNode)
* [ListGrantServiceAccessPolicy](https://cloud.tencent.com/document/api/598/33167#ListGrantServiceAccessPolicy)
* [ListGrantServiceAccessService](https://cloud.tencent.com/document/api/598/33167#ListGrantServiceAccessService)

### 第 30 次发布

发布时间：2021-03-17 08:03:11

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [SubAccountUser](https://cloud.tencent.com/document/api/598/33167#SubAccountUser)

	* 新增成员：LastLoginIp, LastLoginTime


### 第 29 次发布

发布时间：2021-03-10 08:03:36

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeSubAccounts](https://cloud.tencent.com/document/api/598/53486)

新增数据结构：

* [SubAccountUser](https://cloud.tencent.com/document/api/598/33167#SubAccountUser)

### 第 28 次发布

发布时间：2021-01-06 21:25:23

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [ListWeChatWorkSubAccounts](https://cloud.tencent.com/document/api/598/51774)

新增数据结构：

* [WeChatWorkSubAccount](https://cloud.tencent.com/document/api/598/33167#WeChatWorkSubAccount)

修改数据结构：

* [SubAccountInfo](https://cloud.tencent.com/document/api/598/33167#SubAccountInfo)

	* 新增成员：CreateTime


### 第 27 次发布

发布时间：2020-09-23 08:01:59

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeSafeAuthFlagColl](https://cloud.tencent.com/document/api/598/48602)

### 第 26 次发布

发布时间：2020-09-22 08:02:07

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [AttachEntityOfPolicy](https://cloud.tencent.com/document/api/598/33167#AttachEntityOfPolicy)

	* 新增成员：AttachmentTime


### 第 25 次发布

发布时间：2020-09-16 08:01:43

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeSafeAuthFlag](https://cloud.tencent.com/document/api/598/48426)

新增数据结构：

* [LoginActionFlag](https://cloud.tencent.com/document/api/598/33167#LoginActionFlag)
* [OffsiteFlag](https://cloud.tencent.com/document/api/598/33167#OffsiteFlag)

### 第 24 次发布

发布时间：2020-07-22 08:05:59

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DeleteRolePermissionsBoundary](https://cloud.tencent.com/document/api/598/46593)
* [DeleteUserPermissionsBoundary](https://cloud.tencent.com/document/api/598/46595)
* [PutRolePermissionsBoundary](https://cloud.tencent.com/document/api/598/46592)
* [PutUserPermissionsBoundary](https://cloud.tencent.com/document/api/598/46594)

### 第 23 次发布

发布时间：2020-06-03 08:05:26

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [ListAccessKeys](https://cloud.tencent.com/document/api/598/45156)

新增数据结构：

* [AccessKey](https://cloud.tencent.com/document/api/598/33167#AccessKey)

### 第 22 次发布

发布时间：2020-05-14 08:06:40

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [SetMfaFlag](https://cloud.tencent.com/document/api/598/36227)

新增数据结构：

* [LoginActionMfaFlag](https://cloud.tencent.com/document/api/598/33167#LoginActionMfaFlag)

### 第 21 次发布

发布时间：2020-04-29 08:05:36

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [UpdatePolicy](https://cloud.tencent.com/document/api/598/34569)

### 第 20 次发布

发布时间：2020-04-27 08:04:39

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreatePolicyVersion](https://cloud.tencent.com/document/api/598/43842)
* [DeletePolicyVersion](https://cloud.tencent.com/document/api/598/43841)
* [GetPolicyVersion](https://cloud.tencent.com/document/api/598/43840)
* [ListPolicyVersions](https://cloud.tencent.com/document/api/598/43839)
* [SetDefaultPolicyVersion](https://cloud.tencent.com/document/api/598/43838)

新增数据结构：

* [PolicyVersionDetail](https://cloud.tencent.com/document/api/598/33167#PolicyVersionDetail)
* [PolicyVersionItem](https://cloud.tencent.com/document/api/598/33167#PolicyVersionItem)

### 第 19 次发布

发布时间：2020-04-23 08:04:56

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateServiceLinkedRole](https://cloud.tencent.com/document/api/598/43711)
* [DeleteServiceLinkedRole](https://cloud.tencent.com/document/api/598/43710)
* [GetServiceLinkedRoleDeletionStatus](https://cloud.tencent.com/document/api/598/43709)

<font color="#dd0000">**删除接口**：</font>

* CheckNewMfaCode
* SetFlag

<font color="#dd0000">**删除数据结构**：</font>

* LoginActionFlag
* OffsiteFlag

### 第 18 次发布

发布时间：2020-04-22 08:04:48

本次发布包含了以下内容：

改善已有的文档。

<font color="#dd0000">**删除接口**：</font>

* Check
* DescribeMFADeviceColl
* DescribeMfaCodeStatus
* DetectAuth
* DetectMaskAuth
* DetectState

### 第 17 次发布

发布时间：2020-04-17 08:04:31

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeMFADeviceColl](https://cloud.tencent.com/document/api/598/43496)

### 第 16 次发布

发布时间：2020-04-16 08:04:28

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [ListCollaborators](https://cloud.tencent.com/document/api/598/43470)
* [UpdateRoleConsoleLogin](https://cloud.tencent.com/document/api/598/43469)

修改接口：

* [GetPolicy](https://cloud.tencent.com/document/api/598/34574)

	* 新增出参：PresetAlias, IsServiceLinkedRolePolicy


### 第 15 次发布

发布时间：2020-04-15 08:05:30

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [Check](https://cloud.tencent.com/document/api/598/43431)
* [CheckNewMfaCode](https://cloud.tencent.com/document/api/598/43430)
* [DescribeMfaCodeStatus](https://cloud.tencent.com/document/api/598/43429)
* [DetectAuth](https://cloud.tencent.com/document/api/598/43428)
* [DetectMaskAuth](https://cloud.tencent.com/document/api/598/43427)
* [DetectState](https://cloud.tencent.com/document/api/598/43426)

### 第 14 次发布

发布时间：2020-04-14 08:04:46

本次发布包含了以下内容：

改善已有的文档。

<font color="#dd0000">**删除接口**：</font>

* UpdatePolicy

### 第 13 次发布

发布时间：2020-04-09 16:33:09

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [AttachRolePolicy](https://cloud.tencent.com/document/api/598/36226)

	* 新增入参：PolicyName

	* <font color="#dd0000">**修改入参**：</font>PolicyId

* [DetachRolePolicy](https://cloud.tencent.com/document/api/598/36222)

	* 新增入参：PolicyName

	* <font color="#dd0000">**修改入参**：</font>PolicyId


### 第 12 次发布

发布时间：2020-03-31 08:03:45

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [ListGroupsForUser](https://cloud.tencent.com/document/api/598/34588)

	* 新增入参：SubUin

	* <font color="#dd0000">**修改入参**：</font>Uid


### 第 11 次发布

发布时间：2020-03-26 08:03:40

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [RoleInfo](https://cloud.tencent.com/document/api/598/33167#RoleInfo)

	* 新增成员：DeletionTaskId


### 第 10 次发布

发布时间：2020-03-25 08:03:57

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [StrategyInfo](https://cloud.tencent.com/document/api/598/33167#StrategyInfo)

	* 新增成员：IsServiceLinkedPolicy


### 第 9 次发布

发布时间：2020-03-19 08:04:26

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [AttachedPolicyOfRole](https://cloud.tencent.com/document/api/598/33167#AttachedPolicyOfRole)

	* 新增成员：Description


### 第 8 次发布

发布时间：2020-03-13 20:52:37

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateRole](https://cloud.tencent.com/document/api/598/36225)

	* 新增入参：SessionDuration

* [DeleteUser](https://cloud.tencent.com/document/api/598/34592)

	* 新增入参：Force


修改数据结构：

* [AttachPolicyInfo](https://cloud.tencent.com/document/api/598/33167#AttachPolicyInfo)

	* 新增成员：DeactivedDetail

* [AttachedPolicyOfRole](https://cloud.tencent.com/document/api/598/33167#AttachedPolicyOfRole)

	* 新增成员：DeactivedDetail

* [RoleInfo](https://cloud.tencent.com/document/api/598/33167#RoleInfo)

	* 新增成员：SessionDuration

* [StrategyInfo](https://cloud.tencent.com/document/api/598/33167#StrategyInfo)

	* 新增成员：DeactivedDetail


### 第 7 次发布

发布时间：2020-01-16 16:44:57

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [AttachPolicyInfo](https://cloud.tencent.com/document/api/598/33167#AttachPolicyInfo)

	* 新增成员：Deactived

* [AttachedPolicyOfRole](https://cloud.tencent.com/document/api/598/33167#AttachedPolicyOfRole)

	* 新增成员：Deactived

* [OffsiteFlag](https://cloud.tencent.com/document/api/598/33167#OffsiteFlag)

	* 新增成员：Tips

* [RoleInfo](https://cloud.tencent.com/document/api/598/33167#RoleInfo)

	* 新增成员：RoleType

* [StrategyInfo](https://cloud.tencent.com/document/api/598/33167#StrategyInfo)

	* 新增成员：Deactived


### 第 6 次发布

发布时间：2019-11-15 16:48:59

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [AttachPolicyInfo](https://cloud.tencent.com/document/api/598/33167#AttachPolicyInfo)

	* <font color="#dd0000">**修改成员**：</font>OperateOwnerUin, OperateUin

* [StrategyInfo](https://cloud.tencent.com/document/api/598/33167#StrategyInfo)

	* 新增成员：IsAttached


### 第 5 次发布

发布时间：2019-10-17 22:55:56

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [AttachPolicyInfo](https://cloud.tencent.com/document/api/598/33167#AttachPolicyInfo)

	* 新增成员：Remark, OperateOwnerUin, OperateUin, OperateUinType


### 第 4 次发布

发布时间：2019-07-16 19:20:26

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [AttachRolePolicy](https://cloud.tencent.com/document/api/598/36226)
* [ConsumeCustomMFAToken](https://cloud.tencent.com/document/api/598/36229)
* [CreateRole](https://cloud.tencent.com/document/api/598/36225)
* [DeleteRole](https://cloud.tencent.com/document/api/598/36224)
* [DescribeRoleList](https://cloud.tencent.com/document/api/598/36223)
* [DetachRolePolicy](https://cloud.tencent.com/document/api/598/36222)
* [GetCustomMFATokenInfo](https://cloud.tencent.com/document/api/598/36228)
* [GetRole](https://cloud.tencent.com/document/api/598/36221)
* [ListAttachedRolePolicies](https://cloud.tencent.com/document/api/598/36220)
* [SetFlag](https://cloud.tencent.com/document/api/598/36227)
* [UpdateAssumeRolePolicy](https://cloud.tencent.com/document/api/598/36219)
* [UpdateRoleDescription](https://cloud.tencent.com/document/api/598/36218)

修改接口：

* [AttachGroupPolicy](https://cloud.tencent.com/document/api/598/34580)

	* <font color="#dd0000">**修改入参**：</font>PolicyId, AttachGroupId

* [AttachUserPolicy](https://cloud.tencent.com/document/api/598/34579)

	* <font color="#dd0000">**修改入参**：</font>PolicyId, AttachUin

* [CreatePolicy](https://cloud.tencent.com/document/api/598/34578)

	* <font color="#dd0000">**修改出参**：</font>PolicyId

* [DetachGroupPolicy](https://cloud.tencent.com/document/api/598/34576)

	* <font color="#dd0000">**修改入参**：</font>PolicyId, DetachGroupId

* [DetachUserPolicy](https://cloud.tencent.com/document/api/598/34575)

	* <font color="#dd0000">**修改入参**：</font>DetachUin

* [UpdatePolicy](https://cloud.tencent.com/document/api/598/34569)

	* <font color="#dd0000">**修改入参**：</font>PolicyId


新增数据结构：

* [AttachedPolicyOfRole](https://cloud.tencent.com/document/api/598/33167#AttachedPolicyOfRole)
* [LoginActionFlag](https://cloud.tencent.com/document/api/598/33167#LoginActionFlag)
* [OffsiteFlag](https://cloud.tencent.com/document/api/598/33167#OffsiteFlag)
* [RoleInfo](https://cloud.tencent.com/document/api/598/33167#RoleInfo)

### 第 3 次发布

发布时间：2019-05-16 16:13:14

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [AddUser](https://cloud.tencent.com/document/api/598/34595)

	* 新增出参：Uid


### 第 2 次发布

发布时间：2019-04-30 17:32:43

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [AddUser](https://cloud.tencent.com/document/api/598/34595)
* [AddUserToGroup](https://cloud.tencent.com/document/api/598/34594)
* [DeleteGroup](https://cloud.tencent.com/document/api/598/34593)
* [DeleteUser](https://cloud.tencent.com/document/api/598/34592)
* [GetGroup](https://cloud.tencent.com/document/api/598/34591)
* [GetUser](https://cloud.tencent.com/document/api/598/34590)
* [ListGroups](https://cloud.tencent.com/document/api/598/34589)
* [ListGroupsForUser](https://cloud.tencent.com/document/api/598/34588)
* [ListUsers](https://cloud.tencent.com/document/api/598/34587)
* [ListUsersForGroup](https://cloud.tencent.com/document/api/598/34586)
* [RemoveUserFromGroup](https://cloud.tencent.com/document/api/598/34585)
* [UpdateGroup](https://cloud.tencent.com/document/api/598/34584)
* [UpdateUser](https://cloud.tencent.com/document/api/598/34583)

新增数据结构：

* [GroupIdOfUidInfo](https://cloud.tencent.com/document/api/598/33167#GroupIdOfUidInfo)
* [GroupInfo](https://cloud.tencent.com/document/api/598/33167#GroupInfo)
* [GroupMemberInfo](https://cloud.tencent.com/document/api/598/33167#GroupMemberInfo)
* [SubAccountInfo](https://cloud.tencent.com/document/api/598/33167#SubAccountInfo)

### 第 1 次发布

发布时间：2019-04-30 15:00:41

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [AttachGroupPolicy](https://cloud.tencent.com/document/api/598/34580)
* [AttachUserPolicy](https://cloud.tencent.com/document/api/598/34579)
* [CreateGroup](https://cloud.tencent.com/document/api/598/34582)
* [CreatePolicy](https://cloud.tencent.com/document/api/598/34578)
* [CreateSAMLProvider](https://cloud.tencent.com/document/api/598/34567)
* [DeletePolicy](https://cloud.tencent.com/document/api/598/34577)
* [DeleteSAMLProvider](https://cloud.tencent.com/document/api/598/34566)
* [DetachGroupPolicy](https://cloud.tencent.com/document/api/598/34576)
* [DetachUserPolicy](https://cloud.tencent.com/document/api/598/34575)
* [GetPolicy](https://cloud.tencent.com/document/api/598/34574)
* [GetSAMLProvider](https://cloud.tencent.com/document/api/598/34565)
* [ListAttachedGroupPolicies](https://cloud.tencent.com/document/api/598/34573)
* [ListAttachedUserPolicies](https://cloud.tencent.com/document/api/598/34572)
* [ListEntitiesForPolicy](https://cloud.tencent.com/document/api/598/34571)
* [ListPolicies](https://cloud.tencent.com/document/api/598/34570)
* [ListSAMLProviders](https://cloud.tencent.com/document/api/598/34564)
* [UpdatePolicy](https://cloud.tencent.com/document/api/598/34569)
* [UpdateSAMLProvider](https://cloud.tencent.com/document/api/598/34563)

新增数据结构：

* [AttachEntityOfPolicy](https://cloud.tencent.com/document/api/598/33167#AttachEntityOfPolicy)
* [AttachPolicyInfo](https://cloud.tencent.com/document/api/598/33167#AttachPolicyInfo)
* [SAMLProviderInfo](https://cloud.tencent.com/document/api/598/33167#SAMLProviderInfo)
* [StrategyInfo](https://cloud.tencent.com/document/api/598/33167#StrategyInfo)




## 验证码(captcha) 版本：2019-07-22

### 第 17 次发布

发布时间：2023-12-01 01:09:01

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeCaptchaRceResult](https://cloud.tencent.com/document/api/1110/102104)

新增数据结构：

* [RceResult](https://cloud.tencent.com/document/api/1110/40481#RceResult)

### 第 16 次发布

发布时间：2023-04-06 20:55:55

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeCaptchaResult](https://cloud.tencent.com/document/api/1110/36926)

	* 新增出参：EvilBitmap, SubmitCaptchaTime


### 第 15 次发布

发布时间：2023-02-17 11:41:16

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [GetRequestStatistics](https://cloud.tencent.com/document/api/1110/86633)

	* 新增入参：CaptchaAppId, StartTimeStr, EndTimeStr, Dimension

	* 新增出参：Data, CaptchaCode, CaptchaMsg

* [GetTotalRequestStatistics](https://cloud.tencent.com/document/api/1110/86632)

	* 新增入参：StartTimeStr, EndTimeStr, Dimension

	* 新增出参：Data, CaptchaCode, CaptchaMsg


### 第 14 次发布

发布时间：2023-02-17 01:29:11

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [GetRequestStatistics](https://cloud.tencent.com/document/api/1110/86633)
* [GetTotalRequestStatistics](https://cloud.tencent.com/document/api/1110/86632)

### 第 13 次发布

发布时间：2022-11-02 06:08:36

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [GetTicketStatistics](https://cloud.tencent.com/document/api/1110/82276)

### 第 12 次发布

发布时间：2022-10-19 06:11:45

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [GetTotalTicketStatistics](https://cloud.tencent.com/document/api/1110/81517)

	* 新增入参：StartTimeStr, EndTimeStr, Dimension

	* 新增出参：Data, CaptchaCode, CaptchaMsg


新增数据结构：

* [CaptchaStatisticObj](https://cloud.tencent.com/document/api/1110/40481#CaptchaStatisticObj)
* [InterceptPerTrendObj](https://cloud.tencent.com/document/api/1110/40481#InterceptPerTrendObj)
* [RequestTrendObj](https://cloud.tencent.com/document/api/1110/40481#RequestTrendObj)
* [TicketCheckTrendObj](https://cloud.tencent.com/document/api/1110/40481#TicketCheckTrendObj)

### 第 11 次发布

发布时间：2022-10-18 06:13:00

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [GetTotalTicketStatistics](https://cloud.tencent.com/document/api/1110/81517)

### 第 10 次发布

发布时间：2022-10-10 06:11:02

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeCaptchaDataSum](https://cloud.tencent.com/document/api/1110/40478)

	* 新增出参：TicketThroughputSum, TicketInterceptSum


### 第 9 次发布

发布时间：2022-03-16 08:04:45

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeCaptchaMiniOperData](https://cloud.tencent.com/document/api/1110/48470)

	* 新增入参：End

* [DescribeCaptchaOperData](https://cloud.tencent.com/document/api/1110/40477)

	* 新增入参：End

* [DescribeCaptchaTicketData](https://cloud.tencent.com/document/api/1110/47983)

	* 新增入参：End


### 第 8 次发布

发布时间：2020-12-07 08:02:17

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeCaptchaMiniRiskResult](https://cloud.tencent.com/document/api/1110/50711)

新增数据结构：

* [OutputManageMarketingRiskValue](https://cloud.tencent.com/document/api/1110/40481#OutputManageMarketingRiskValue)

### 第 7 次发布

发布时间：2020-09-18 08:01:58

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeCaptchaMiniResult](https://cloud.tencent.com/document/api/1110/48499)

### 第 6 次发布

发布时间：2020-09-17 08:02:16

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeCaptchaMiniData](https://cloud.tencent.com/document/api/1110/48472)
* [DescribeCaptchaMiniDataSum](https://cloud.tencent.com/document/api/1110/48471)
* [DescribeCaptchaMiniOperData](https://cloud.tencent.com/document/api/1110/48470)

### 第 5 次发布

发布时间：2020-09-16 08:01:53

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [CaptchaUserAllAppId](https://cloud.tencent.com/document/api/1110/40481#CaptchaUserAllAppId)

	* 新增成员：ChannelInfo


### 第 4 次发布

发布时间：2020-09-01 08:01:58

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeCaptchaTicketData](https://cloud.tencent.com/document/api/1110/47983)

新增数据结构：

* [CaptchaTicketDataRes](https://cloud.tencent.com/document/api/1110/40481#CaptchaTicketDataRes)
* [TicketAmountUnit](https://cloud.tencent.com/document/api/1110/40481#TicketAmountUnit)
* [TicketInterceptUnit](https://cloud.tencent.com/document/api/1110/40481#TicketInterceptUnit)
* [TicketThroughUnit](https://cloud.tencent.com/document/api/1110/40481#TicketThroughUnit)

### 第 3 次发布

发布时间：2020-03-10 00:49:50

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeCaptchaResult](https://cloud.tencent.com/document/api/1110/36926)

	* 新增入参：NeedGetCaptchaTime

	* 新增出参：GetCaptchaTime


### 第 2 次发布

发布时间：2019-12-26 16:13:49

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeCaptchaAppIdInfo](https://cloud.tencent.com/document/api/1110/40480)
* [DescribeCaptchaData](https://cloud.tencent.com/document/api/1110/40479)
* [DescribeCaptchaDataSum](https://cloud.tencent.com/document/api/1110/40478)
* [DescribeCaptchaOperData](https://cloud.tencent.com/document/api/1110/40477)
* [DescribeCaptchaUserAllAppId](https://cloud.tencent.com/document/api/1110/40476)
* [UpdateCaptchaAppIdInfo](https://cloud.tencent.com/document/api/1110/40475)

新增数据结构：

* [CaptchaOperDataInterceptUnit](https://cloud.tencent.com/document/api/1110/40481#CaptchaOperDataInterceptUnit)
* [CaptchaOperDataLoadTimeUnit](https://cloud.tencent.com/document/api/1110/40481#CaptchaOperDataLoadTimeUnit)
* [CaptchaOperDataRes](https://cloud.tencent.com/document/api/1110/40481#CaptchaOperDataRes)
* [CaptchaOperDataTryTimesDistributeUnit](https://cloud.tencent.com/document/api/1110/40481#CaptchaOperDataTryTimesDistributeUnit)
* [CaptchaOperDataTryTimesUnit](https://cloud.tencent.com/document/api/1110/40481#CaptchaOperDataTryTimesUnit)
* [CaptchaQueryData](https://cloud.tencent.com/document/api/1110/40481#CaptchaQueryData)
* [CaptchaUserAllAppId](https://cloud.tencent.com/document/api/1110/40481#CaptchaUserAllAppId)

### 第 1 次发布

发布时间：2019-08-09 13:07:13

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeCaptchaResult](https://cloud.tencent.com/document/api/1110/36926)




## 应用云渲染(car) 版本：2022-01-10

### 第 9 次发布

发布时间：2023-09-21 01:28:16

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [StartPublishStreamWithURL](https://cloud.tencent.com/document/api/1547/98726)

### 第 8 次发布

发布时间：2023-08-23 01:10:00

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [StartPublishStream](https://cloud.tencent.com/document/api/1547/89669)

	* 新增入参：PublishStreamArgs


### 第 7 次发布

发布时间：2023-05-31 01:09:58

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateSession](https://cloud.tencent.com/document/api/1547/72826)

	* 新增入参：ApplicationParameters


### 第 6 次发布

发布时间：2023-05-08 01:10:15

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateSession](https://cloud.tencent.com/document/api/1547/72826)

	* 新增入参：HostUserId, Role

	* <font color="#dd0000">**修改入参**：</font>ClientSession


### 第 5 次发布

发布时间：2023-03-30 17:11:05

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [StartPublishStream](https://cloud.tencent.com/document/api/1547/89669)
* [StopPublishStream](https://cloud.tencent.com/document/api/1547/89668)

### 第 4 次发布

发布时间：2023-01-09 01:07:04

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [ApplyConcurrent](https://cloud.tencent.com/document/api/1547/72827)

	* 新增入参：ApplicationId


### 第 3 次发布

发布时间：2022-08-03 06:08:12

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateSession](https://cloud.tencent.com/document/api/1547/72826)

	* 新增入参：RunMode


### 第 2 次发布

发布时间：2022-04-21 06:07:22

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [ApplyConcurrent](https://cloud.tencent.com/document/api/1547/72827)
* [CreateSession](https://cloud.tencent.com/document/api/1547/72826)

### 第 1 次发布

发布时间：2022-04-20 16:44:47

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DestroySession](https://cloud.tencent.com/document/api/1547/72812)




## 云拨测(cat) 版本：2018-04-09

### 第 18 次发布

发布时间：2024-07-26 01:15:04

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateProbeTasks](https://cloud.tencent.com/document/api/280/66213)

	* 新增入参：SubSyncFlag


### 第 17 次发布

发布时间：2024-06-12 01:16:37

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [ProbeTask](https://cloud.tencent.com/document/api/280/40931#ProbeTask)

	* 新增成员：SubSyncFlag


### 第 16 次发布

发布时间：2023-12-26 01:07:57

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeDetailedSingleProbeData](https://cloud.tencent.com/document/api/280/66205)

	* 新增入参：QueryFlag


### 第 15 次发布

发布时间：2023-11-24 01:07:54

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeInstantTasks](https://cloud.tencent.com/document/api/280/101869)

修改接口：

* [CreateProbeTasks](https://cloud.tencent.com/document/api/280/66213)

	* 新增入参：NodeIpType

* [UpdateProbeTaskConfigurationList](https://cloud.tencent.com/document/api/280/66201)

	* 新增入参：NodeIpType


新增数据结构：

* [SingleInstantTask](https://cloud.tencent.com/document/api/280/40931#SingleInstantTask)

修改数据结构：

* [ProbeTask](https://cloud.tencent.com/document/api/280/40931#ProbeTask)

	* 新增成员：NodeIpType


### 第 14 次发布

发布时间：2023-10-25 01:08:41

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeDetailedSingleProbeData](https://cloud.tencent.com/document/api/280/66205)

	* 新增入参：ScrollID

	* 新增出参：ScrollID


### 第 13 次发布

发布时间：2022-11-09 06:14:16

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [UpdateProbeTaskAttributes](https://cloud.tencent.com/document/api/280/82588)

### 第 12 次发布

发布时间：2022-08-26 06:12:22

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [UpdateProbeTaskConfigurationList](https://cloud.tencent.com/document/api/280/66201)

	* 新增入参：ResourceIDs


### 第 11 次发布

发布时间：2022-08-02 06:06:56

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeNodes](https://cloud.tencent.com/document/api/280/78238)

新增数据结构：

* [NodeDefineExt](https://cloud.tencent.com/document/api/280/40931#NodeDefineExt)

### 第 10 次发布

发布时间：2022-06-15 06:04:25

本次发布包含了以下内容：

改善已有的文档。

<font color="#dd0000">**删除接口**：</font>

* BindAlarmPolicy
* CreateAgentGroup
* CreateTaskEx
* DeleteAgentGroup
* DeleteTasks
* DescribeAgentGroups
* DescribeAgents
* DescribeAlarmTopic
* DescribeAlarms
* DescribeAlarmsByTask
* DescribeCatLogs
* DescribeTaskDetail
* DescribeTasksByType
* DescribeUserLimit
* GetAvailRatioHistory
* GetDailyAvailRatio
* GetRealAvailRatio
* GetRespTimeTrendEx
* GetResultSummary
* GetReturnCodeHistory
* GetReturnCodeInfo
* GetTaskTotalNumber
* ModifyAgentGroup
* ModifyTaskEx
* PauseTask
* RunTask
* VerifyResult

<font color="#dd0000">**删除数据结构**：</font>

* AgentGroup
* AlarmInfo
* AlarmTopic
* CatAgent
* CatLog
* CatReturnDetail
* CatReturnSummary
* CatTaskDetail
* DataPoint
* DataPointMetric
* DimensionsDetail
* IspDetail
* ProvinceDetail
* ResultSummary
* TaskAlarm

### 第 9 次发布

发布时间：2022-05-23 06:03:34

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateProbeTasks](https://cloud.tencent.com/document/api/280/66213)

	* 新增入参：ClientNum

	* 新增出参：TaskIDs


修改数据结构：

* [NodeDefine](https://cloud.tencent.com/document/api/280/40931#NodeDefine)

	* 新增成员：CodeType, NodeDefineStatus


### 第 8 次发布

发布时间：2022-04-28 06:07:39

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateProbeTasks](https://cloud.tencent.com/document/api/280/66213)

	* 新增入参：ProbeType, PluginSource


### 第 7 次发布

发布时间：2022-03-31 06:03:51

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeProbeMetricData](https://cloud.tencent.com/document/api/280/71856)

### 第 6 次发布

发布时间：2022-01-18 08:04:56

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeDetailedSingleProbeData](https://cloud.tencent.com/document/api/280/66205)

	* 新增入参：City


### 第 5 次发布

发布时间：2021-12-22 08:07:25

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateProbeTasks](https://cloud.tencent.com/document/api/280/66213)

	* 新增入参：Tag

* [DescribeProbeTasks](https://cloud.tencent.com/document/api/280/66212)

	* 新增入参：TagFilters


新增数据结构：

* [KeyValuePair](https://cloud.tencent.com/document/api/280/40931#KeyValuePair)
* [Tag](https://cloud.tencent.com/document/api/280/40931#Tag)

修改数据结构：

* [ProbeTask](https://cloud.tencent.com/document/api/280/40931#ProbeTask)

	* 新增成员：TagInfoList


### 第 4 次发布

发布时间：2021-12-16 17:16:49

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateProbeTasks](https://cloud.tencent.com/document/api/280/66213)
* [DescribeProbeTasks](https://cloud.tencent.com/document/api/280/66212)

新增数据结构：

* [ProbeTask](https://cloud.tencent.com/document/api/280/40931#ProbeTask)
* [ProbeTaskBasicConfiguration](https://cloud.tencent.com/document/api/280/40931#ProbeTaskBasicConfiguration)

### 第 3 次发布

发布时间：2021-12-16 16:46:02

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DeleteProbeTask](https://cloud.tencent.com/document/api/280/66206)
* [DescribeDetailedSingleProbeData](https://cloud.tencent.com/document/api/280/66205)
* [DescribeProbeNodes](https://cloud.tencent.com/document/api/280/66204)
* [ResumeProbeTask](https://cloud.tencent.com/document/api/280/66203)
* [SuspendProbeTask](https://cloud.tencent.com/document/api/280/66202)
* [UpdateProbeTaskConfigurationList](https://cloud.tencent.com/document/api/280/66201)

新增数据结构：

* [DetailedSingleDataDefine](https://cloud.tencent.com/document/api/280/40931#DetailedSingleDataDefine)
* [Field](https://cloud.tencent.com/document/api/280/40931#Field)
* [Label](https://cloud.tencent.com/document/api/280/40931#Label)
* [NodeDefine](https://cloud.tencent.com/document/api/280/40931#NodeDefine)
* [TaskResult](https://cloud.tencent.com/document/api/280/40931#TaskResult)

### 第 2 次发布

发布时间：2020-01-10 14:24:52

本次发布包含了以下内容：

改善已有的文档。

<font color="#dd0000">**删除接口**：</font>

* CreateAlarmPloicy
* CreateTask
* DescribeAgentGroup
* DescribeAlarmGroups
* DescribeTask
* DescribeTasks
* GetRespTimeTrend
* ModifyAlarmPloicy
* ModifyTask

<font color="#dd0000">**删除数据结构**：</font>

* AlarmGroupInfo
* CatTask

### 第 1 次发布

发布时间：2020-01-08 19:00:35

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [BindAlarmPolicy](https://cloud.tencent.com/document/api/280/40906)
* [CreateAgentGroup](https://cloud.tencent.com/document/api/280/40911)
* [CreateAlarmPloicy](https://cloud.tencent.com/document/api/280/40930)
* [CreateTask](https://cloud.tencent.com/document/api/280/40929)
* [CreateTaskEx](https://cloud.tencent.com/document/api/280/40920)
* [DeleteAgentGroup](https://cloud.tencent.com/document/api/280/40910)
* [DeleteTasks](https://cloud.tencent.com/document/api/280/40919)
* [DescribeAgentGroup](https://cloud.tencent.com/document/api/280/40928)
* [DescribeAgentGroups](https://cloud.tencent.com/document/api/280/40909)
* [DescribeAgents](https://cloud.tencent.com/document/api/280/40892)
* [DescribeAlarmGroups](https://cloud.tencent.com/document/api/280/40927)
* [DescribeAlarmTopic](https://cloud.tencent.com/document/api/280/40891)
* [DescribeAlarms](https://cloud.tencent.com/document/api/280/40905)
* [DescribeAlarmsByTask](https://cloud.tencent.com/document/api/280/40904)
* [DescribeCatLogs](https://cloud.tencent.com/document/api/280/40902)
* [DescribeTask](https://cloud.tencent.com/document/api/280/40926)
* [DescribeTaskDetail](https://cloud.tencent.com/document/api/280/40918)
* [DescribeTasks](https://cloud.tencent.com/document/api/280/40925)
* [DescribeTasksByType](https://cloud.tencent.com/document/api/280/40917)
* [DescribeUserLimit](https://cloud.tencent.com/document/api/280/40890)
* [GetAvailRatioHistory](https://cloud.tencent.com/document/api/280/40901)
* [GetDailyAvailRatio](https://cloud.tencent.com/document/api/280/40900)
* [GetRealAvailRatio](https://cloud.tencent.com/document/api/280/40899)
* [GetRespTimeTrend](https://cloud.tencent.com/document/api/280/40924)
* [GetRespTimeTrendEx](https://cloud.tencent.com/document/api/280/40898)
* [GetResultSummary](https://cloud.tencent.com/document/api/280/40897)
* [GetReturnCodeHistory](https://cloud.tencent.com/document/api/280/40896)
* [GetReturnCodeInfo](https://cloud.tencent.com/document/api/280/40895)
* [GetTaskTotalNumber](https://cloud.tencent.com/document/api/280/40916)
* [ModifyAgentGroup](https://cloud.tencent.com/document/api/280/40908)
* [ModifyAlarmPloicy](https://cloud.tencent.com/document/api/280/40923)
* [ModifyTask](https://cloud.tencent.com/document/api/280/40922)
* [ModifyTaskEx](https://cloud.tencent.com/document/api/280/40915)
* [PauseTask](https://cloud.tencent.com/document/api/280/40914)
* [RunTask](https://cloud.tencent.com/document/api/280/40913)
* [VerifyResult](https://cloud.tencent.com/document/api/280/40894)

新增数据结构：

* [AgentGroup](https://cloud.tencent.com/document/api/280/40931#AgentGroup)
* [AlarmGroupInfo](https://cloud.tencent.com/document/api/280/40931#AlarmGroupInfo)
* [AlarmInfo](https://cloud.tencent.com/document/api/280/40931#AlarmInfo)
* [AlarmTopic](https://cloud.tencent.com/document/api/280/40931#AlarmTopic)
* [CatAgent](https://cloud.tencent.com/document/api/280/40931#CatAgent)
* [CatLog](https://cloud.tencent.com/document/api/280/40931#CatLog)
* [CatReturnDetail](https://cloud.tencent.com/document/api/280/40931#CatReturnDetail)
* [CatReturnSummary](https://cloud.tencent.com/document/api/280/40931#CatReturnSummary)
* [CatTask](https://cloud.tencent.com/document/api/280/40931#CatTask)
* [CatTaskDetail](https://cloud.tencent.com/document/api/280/40931#CatTaskDetail)
* [DataPoint](https://cloud.tencent.com/document/api/280/40931#DataPoint)
* [DataPointMetric](https://cloud.tencent.com/document/api/280/40931#DataPointMetric)
* [DimensionsDetail](https://cloud.tencent.com/document/api/280/40931#DimensionsDetail)
* [IspDetail](https://cloud.tencent.com/document/api/280/40931#IspDetail)
* [ProvinceDetail](https://cloud.tencent.com/document/api/280/40931#ProvinceDetail)
* [ResultSummary](https://cloud.tencent.com/document/api/280/40931#ResultSummary)
* [TaskAlarm](https://cloud.tencent.com/document/api/280/40931#TaskAlarm)




## 云硬盘(cbs) 版本：2017-03-12

### 第 57 次发布

发布时间：2024-07-16 01:09:24

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeSnapshotOverview](https://cloud.tencent.com/document/api/362/108737)

### 第 56 次发布

发布时间：2024-07-15 01:04:45

本次发布包含了以下内容：

改善已有的文档。

<font color="#dd0000">**预下线接口**：</font>

* GetSnapOverview

### 第 55 次发布

发布时间：2024-06-28 01:05:34

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [AutoMountConfiguration](https://cloud.tencent.com/document/api/362/15669#AutoMountConfiguration)

	* <font color="#dd0000">**修改成员**：</font>MountPoint, FileSystemType


### 第 54 次发布

发布时间：2024-03-21 01:09:20

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [ModifyDisksRenewFlag](https://cloud.tencent.com/document/api/362/15668)

	* 新增入参：AutoRenewPeriod


### 第 53 次发布

发布时间：2023-11-01 01:07:57

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeDiskConfigQuota](https://cloud.tencent.com/document/api/362/16318)

	* 新增入参：DedicatedClusterId


### 第 52 次发布

发布时间：2023-09-20 01:08:08

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [CdcSize](https://cloud.tencent.com/document/api/362/15669#CdcSize)

	* 新增成员：DiskAvailable

	* <font color="#dd0000">**删除成员**：</font>DiskAavilable


### 第 51 次发布

发布时间：2023-07-24 01:12:51

本次发布包含了以下内容：

改善已有的文档。

<font color="#dd0000">**删除接口**：</font>

* DescribeDiskOperationLogs
* DescribeSnapshotOperationLogs

<font color="#dd0000">**删除数据结构**：</font>

* DiskOperationLog
* SnapshotOperationLog

### 第 50 次发布

发布时间：2023-05-23 01:06:09

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateDisks](https://cloud.tencent.com/document/api/362/16312)

	* 新增入参：BurstPerformance

* [ModifyDiskAttributes](https://cloud.tencent.com/document/api/362/15659)

	* 新增入参：BurstPerformanceOperation


### 第 49 次发布

发布时间：2023-04-26 01:07:08

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [Disk](https://cloud.tencent.com/document/api/362/15669#Disk)

	* 新增成员：BurstPerformance


### 第 48 次发布

发布时间：2023-02-27 01:09:26

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeDiskStoragePool](https://cloud.tencent.com/document/api/362/62143)

	* 新增出参：CdcSet


新增数据结构：

* [DetailPrice](https://cloud.tencent.com/document/api/362/15669#DetailPrice)

修改数据结构：

* [AutoSnapshotPolicy](https://cloud.tencent.com/document/api/362/15669#AutoSnapshotPolicy)

	* 新增成员：CopyFromAccountUin, Tags

* [Cdc](https://cloud.tencent.com/document/api/362/15669#Cdc)

	* 新增成员：CreatedTime, DiskNumber

* [Disk](https://cloud.tencent.com/document/api/362/15669#Disk)

	* 新增成员：LastAttachInsId, ErrorPrompt

* [DiskConfig](https://cloud.tencent.com/document/api/362/15669#DiskConfig)

	* 新增成员：Price

* [Placement](https://cloud.tencent.com/document/api/362/15669#Placement)

	* 新增成员：ProjectName

* [PrepayPrice](https://cloud.tencent.com/document/api/362/15669#PrepayPrice)

	* 新增成员：DetailPrices

* [Snapshot](https://cloud.tencent.com/document/api/362/15669#Snapshot)

	* <font color="#dd0000">**修改成员**：</font>Tags


### 第 47 次发布

发布时间：2023-02-22 01:08:38

本次发布包含了以下内容：

改善已有的文档。

新增数据结构：

* [AdvancedRetentionPolicy](https://cloud.tencent.com/document/api/362/15669#AdvancedRetentionPolicy)

修改数据结构：

* [AutoSnapshotPolicy](https://cloud.tencent.com/document/api/362/15669#AutoSnapshotPolicy)

	* 新增成员：RetentionMonths, RetentionAmount, AdvancedRetentionPolicy

* [Policy](https://cloud.tencent.com/document/api/362/15669#Policy)

	* 新增成员：DayOfMonth, IntervalDays


### 第 46 次发布

发布时间：2023-02-09 01:08:40

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [Disk](https://cloud.tencent.com/document/api/362/15669#Disk)

	* 新增成员：DiskBackupQuota


### 第 45 次发布

发布时间：2022-12-28 01:04:48

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateDiskBackup](https://cloud.tencent.com/document/api/362/84591)

### 第 44 次发布

发布时间：2022-09-08 06:11:23

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [ApplyDiskBackup](https://cloud.tencent.com/document/api/362/80280)
* [DeleteDiskBackups](https://cloud.tencent.com/document/api/362/80279)
* [DescribeDiskBackups](https://cloud.tencent.com/document/api/362/80278)
* [InquirePriceModifyDiskBackupQuota](https://cloud.tencent.com/document/api/362/80277)
* [ModifyDiskBackupQuota](https://cloud.tencent.com/document/api/362/80276)

新增数据结构：

* [DiskBackup](https://cloud.tencent.com/document/api/362/15669#DiskBackup)

### 第 43 次发布

发布时间：2022-08-04 06:12:23

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [DiskConfig](https://cloud.tencent.com/document/api/362/15669#DiskConfig)

	* 新增成员：StepSize, ExtraPerformanceRange


### 第 42 次发布

发布时间：2022-07-06 06:07:59

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [Policy](https://cloud.tencent.com/document/api/362/15669#Policy)

	* <font color="#dd0000">**修改成员**：</font>DayOfWeek


### 第 41 次发布

发布时间：2022-05-31 06:05:45

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [BindAutoSnapshotPolicy](https://cloud.tencent.com/document/api/362/33559)

	* <font color="#dd0000">**修改入参**：</font>DiskIds

* [CreateSnapshot](https://cloud.tencent.com/document/api/362/15648)

	* 新增入参：Tags

* [UnbindAutoSnapshotPolicy](https://cloud.tencent.com/document/api/362/33554)

	* <font color="#dd0000">**修改入参**：</font>DiskIds


修改数据结构：

* [AutoSnapshotPolicy](https://cloud.tencent.com/document/api/362/15669#AutoSnapshotPolicy)

	* 新增成员：IsCopyToRemote, CopyToAccountUin, InstanceIdSet

* [Snapshot](https://cloud.tencent.com/document/api/362/15669#Snapshot)

	* 新增成员：Tags


### 第 40 次发布

发布时间：2022-04-13 06:12:00

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateDisks](https://cloud.tencent.com/document/api/362/16312)

	* 新增入参：DiskBackupQuota

* [CreateSnapshot](https://cloud.tencent.com/document/api/362/15648)

	* 新增入参：DiskBackupId

* [InquiryPriceCreateDisks](https://cloud.tencent.com/document/api/362/16314)

	* 新增入参：DiskBackupQuota


修改数据结构：

* [Disk](https://cloud.tencent.com/document/api/362/15669#Disk)

	* 新增成员：DiskBackupCount, InstanceType


### 第 39 次发布

发布时间：2022-01-26 08:03:48

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CopySnapshotCrossRegions](https://cloud.tencent.com/document/api/362/68848)

新增数据结构：

* [SnapshotCopyResult](https://cloud.tencent.com/document/api/362/15669#SnapshotCopyResult)

### 第 38 次发布

发布时间：2022-01-13 08:11:09

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [InitializeDisks](https://cloud.tencent.com/document/api/362/68110)

### 第 37 次发布

发布时间：2022-01-12 08:06:01

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [Disk](https://cloud.tencent.com/document/api/362/15669#Disk)

	* 新增成员：DeleteSnapshot


### 第 36 次发布

发布时间：2022-01-11 08:04:11

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [TerminateDisks](https://cloud.tencent.com/document/api/362/16321)

	* 新增入参：DeleteSnapshot


### 第 35 次发布

发布时间：2021-12-21 08:01:42

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [ApplySnapshot](https://cloud.tencent.com/document/api/362/15643)

	* 新增入参：AutoStopInstance, AutoStartInstance


### 第 34 次发布

发布时间：2021-12-17 08:07:31

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateDisks](https://cloud.tencent.com/document/api/362/16312)

	* 新增入参：AutoMountConfiguration


新增数据结构：

* [AutoMountConfiguration](https://cloud.tencent.com/document/api/362/15669#AutoMountConfiguration)

### 第 33 次发布

发布时间：2021-10-27 08:03:51

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [Snapshot](https://cloud.tencent.com/document/api/362/15669#Snapshot)

	* <font color="#dd0000">**修改成员**：</font>SnapshotId


### 第 32 次发布

发布时间：2021-09-30 08:01:36

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeDiskStoragePool](https://cloud.tencent.com/document/api/362/62143)

新增数据结构：

* [Cdc](https://cloud.tencent.com/document/api/362/15669#Cdc)
* [CdcSize](https://cloud.tencent.com/document/api/362/15669#CdcSize)

### 第 31 次发布

发布时间：2021-07-15 08:03:44

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateDisks](https://cloud.tencent.com/document/api/362/16312)

	* 新增入参：DeleteSnapshot


### 第 30 次发布

发布时间：2021-07-09 08:03:51

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DeleteSnapshots](https://cloud.tencent.com/document/api/362/15645)

	* 新增入参：DeleteBindImages


### 第 29 次发布

发布时间：2021-06-09 08:03:29

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [Disk](https://cloud.tencent.com/document/api/362/15669#Disk)

	* 新增成员：AttachMode

* [Placement](https://cloud.tencent.com/document/api/362/15669#Placement)

	* 新增成员：DedicatedClusterId


### 第 28 次发布

发布时间：2021-06-04 08:03:35

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [ModifyDisksChargeType](https://cloud.tencent.com/document/api/362/38075)

	* 新增入参：DiskChargePostpaid

	* <font color="#dd0000">**修改入参**：</font>DiskChargePrepaid


### 第 27 次发布

发布时间：2021-05-21 08:03:17

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [AttachDisks](https://cloud.tencent.com/document/api/362/16313)

	* 新增入参：AttachMode


### 第 26 次发布

发布时间：2021-01-28 08:02:42

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [PrepayPrice](https://cloud.tencent.com/document/api/362/15669#PrepayPrice)

	* <font color="#dd0000">**修改成员**：</font>UnitPrice, UnitPriceDiscount


### 第 25 次发布

发布时间：2021-01-18 08:02:47

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [Disk](https://cloud.tencent.com/document/api/362/15669#Disk)

	* 新增成员：ThroughputPerformance


### 第 24 次发布

发布时间：2021-01-14 08:02:56

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [Snapshot](https://cloud.tencent.com/document/api/362/15669#Snapshot)

	* 新增成员：TimeStartShare


### 第 23 次发布

发布时间：2020-12-29 08:02:44

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [PrepayPrice](https://cloud.tencent.com/document/api/362/15669#PrepayPrice)

	* 新增成员：OriginalPriceHigh, DiscountPriceHigh, UnitPrice, ChargeUnit, UnitPriceDiscount, UnitPriceHigh, UnitPriceDiscountHigh


### 第 22 次发布

发布时间：2020-12-25 08:02:47

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [InquirePriceModifyDiskExtraPerformance](https://cloud.tencent.com/document/api/362/51484)
* [ModifyDiskExtraPerformance](https://cloud.tencent.com/document/api/362/51483)

修改接口：

* [CreateDisks](https://cloud.tencent.com/document/api/362/16312)

	* 新增入参：ThroughputPerformance


### 第 21 次发布

发布时间：2020-12-24 08:02:42

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [InquiryPriceCreateDisks](https://cloud.tencent.com/document/api/362/16314)

	* 新增入参：ThroughputPerformance


修改数据结构：

* [Price](https://cloud.tencent.com/document/api/362/15669#Price)

	* 新增成员：OriginalPriceHigh, DiscountPriceHigh, UnitPriceHigh, UnitPriceDiscountHigh


### 第 20 次发布

发布时间：2020-09-28 08:02:56

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateSnapshot](https://cloud.tencent.com/document/api/362/15648)

	* 新增入参：Deadline

* [ModifySnapshotAttribute](https://cloud.tencent.com/document/api/362/15650)

	* 新增入参：Deadline


### 第 19 次发布

发布时间：2020-03-20 08:04:16

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [GetSnapOverview](https://cloud.tencent.com/document/api/362/42706)

### 第 18 次发布

发布时间：2020-03-16 08:04:23

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [Disk](https://cloud.tencent.com/document/api/362/15669#Disk)

	* 新增成员：BackupDisk


### 第 17 次发布

发布时间：2019-12-06 10:20:56

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeDiskOperationLogs](https://cloud.tencent.com/document/api/362/30162)

	* 新增入参：BeginTime, EndTime

* [DescribeSnapshotOperationLogs](https://cloud.tencent.com/document/api/362/32490)

	* 新增入参：BeginTime, EndTime


### 第 16 次发布

发布时间：2019-09-19 20:13:44

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeSnapshotSharePermission](https://cloud.tencent.com/document/api/362/38074)
* [ModifyDisksChargeType](https://cloud.tencent.com/document/api/362/38075)
* [ModifySnapshotsSharePermission](https://cloud.tencent.com/document/api/362/38073)

新增数据结构：

* [SharePermission](https://cloud.tencent.com/document/api/362/15669#SharePermission)

修改数据结构：

* [Disk](https://cloud.tencent.com/document/api/362/15669#Disk)

	* 新增成员：SnapshotCount, SnapshotSize

	* <font color="#dd0000">**删除成员**：</font>AttachDeviceId, AttachDeviceType

* [Snapshot](https://cloud.tencent.com/document/api/362/15669#Snapshot)

	* 新增成员：ShareReference


### 第 15 次发布

发布时间：2019-08-01 14:31:23

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [Disk](https://cloud.tencent.com/document/api/362/15669#Disk)

	* 新增成员：AttachDeviceId, AttachDeviceType

* [Snapshot](https://cloud.tencent.com/document/api/362/15669#Snapshot)

	* 新增成员：SnapshotType


### 第 14 次发布

发布时间：2019-06-14 08:52:05

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [ModifyAutoSnapshotPolicyAttribute](https://cloud.tencent.com/document/api/362/35482)

### 第 13 次发布

发布时间：2019-05-30 21:22:47

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateDisks](https://cloud.tencent.com/document/api/362/16312)

	* <font color="#dd0000">**删除入参**：</font>DeleteWithInstance

* [DetachDisks](https://cloud.tencent.com/document/api/362/16316)

	* 新增入参：InstanceId


### 第 12 次发布

发布时间：2019-05-09 17:16:40

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateDisks](https://cloud.tencent.com/document/api/362/16312)

	* 新增入参：Shareable


### 第 11 次发布

发布时间：2019-04-12 11:13:22

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [Disk](https://cloud.tencent.com/document/api/362/15669#Disk)

	* 新增成员：Shareable, InstanceIdList


### 第 10 次发布

发布时间：2019-03-08 17:29:54

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [BindAutoSnapshotPolicy](https://cloud.tencent.com/document/api/362/33559)
* [CreateAutoSnapshotPolicy](https://cloud.tencent.com/document/api/362/33558)
* [DeleteAutoSnapshotPolicies](https://cloud.tencent.com/document/api/362/33557)
* [DescribeAutoSnapshotPolicies](https://cloud.tencent.com/document/api/362/33556)
* [DescribeDiskAssociatedAutoSnapshotPolicy](https://cloud.tencent.com/document/api/362/33555)
* [UnbindAutoSnapshotPolicy](https://cloud.tencent.com/document/api/362/33554)

新增数据结构：

* [AutoSnapshotPolicy](https://cloud.tencent.com/document/api/362/15669#AutoSnapshotPolicy)
* [Policy](https://cloud.tencent.com/document/api/362/15669#Policy)

### 第 9 次发布

发布时间：2019-02-22 14:29:13

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [ModifyDiskAttributes](https://cloud.tencent.com/document/api/362/15659)

	* 新增入参：DiskType


新增数据结构：

* [Image](https://cloud.tencent.com/document/api/362/15669#Image)

修改数据结构：

* [Placement](https://cloud.tencent.com/document/api/362/15669#Placement)

	* 新增成员：CdcId, CageId, CdcName

* [Snapshot](https://cloud.tencent.com/document/api/362/15669#Snapshot)

	* 新增成员：Images, ImageCount

	* <font color="#dd0000">**删除成员**：</font>ImageIds


### 第 8 次发布

发布时间：2019-01-10 20:01:16

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeSnapshotOperationLogs](https://cloud.tencent.com/document/api/362/32490)

新增数据结构：

* [SnapshotOperationLog](https://cloud.tencent.com/document/api/362/15669#SnapshotOperationLog)

修改数据结构：

* [Disk](https://cloud.tencent.com/document/api/362/15669#Disk)

	* 新增成员：Migrating, MigratePercent

* [Price](https://cloud.tencent.com/document/api/362/15669#Price)

	* 新增成员：UnitPriceDiscount

* [Snapshot](https://cloud.tencent.com/document/api/362/15669#Snapshot)

	* 新增成员：ImageIds


### 第 7 次发布

发布时间：2018-10-26 14:34:03

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeDiskOperationLogs](https://cloud.tencent.com/document/api/362/30162)

修改接口：

* [CreateDisks](https://cloud.tencent.com/document/api/362/16312)

	* 新增入参：DeleteWithInstance

* [DescribeInstancesDiskNum](https://cloud.tencent.com/document/api/362/16311)

	* 新增出参：AttachDetail

	* <font color="#dd0000">**删除出参**：</font>AttachedDiskCount, MaxAttachCount

* [InquiryPriceRenewDisks](https://cloud.tencent.com/document/api/362/16317)

	* <font color="#dd0000">**修改出参**：</font>DiskPrice

* [InquiryPriceResizeDisk](https://cloud.tencent.com/document/api/362/16320)

	* <font color="#dd0000">**修改出参**：</font>DiskPrice


新增数据结构：

* [AttachDetail](https://cloud.tencent.com/document/api/362/15669#AttachDetail)
* [DiskOperationLog](https://cloud.tencent.com/document/api/362/15669#DiskOperationLog)
* [PrepayPrice](https://cloud.tencent.com/document/api/362/15669#PrepayPrice)

修改数据结构：

* [Disk](https://cloud.tencent.com/document/api/362/15669#Disk)

	* 新增成员：DifferDaysOfDeadline

	* <font color="#dd0000">**修改成员**：</font>ReturnFailCode


### 第 6 次发布

发布时间：2018-07-26 12:20:04

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [ModifyDiskAttributes](https://cloud.tencent.com/document/api/362/15659)

	* 新增入参：DeleteWithInstance


修改数据结构：

* [Disk](https://cloud.tencent.com/document/api/362/15669#Disk)

	* 新增成员：DeleteWithInstance


### 第 5 次发布

发布时间：2018-06-28 15:15:08

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [AttachDisks](https://cloud.tencent.com/document/api/362/16313)

	* 新增入参：DeleteWithInstance


修改数据结构：

* [Price](https://cloud.tencent.com/document/api/362/15669#Price)

	* 新增成员：UnitPrice, ChargeUnit


### 第 4 次发布

发布时间：2018-06-21 14:34:22

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateDisks](https://cloud.tencent.com/document/api/362/16312)

	* 新增入参：Tags


### 第 3 次发布

发布时间：2018-05-31 14:45:35

本次发布包含了以下内容：

改善已有的文档。

新增数据结构：

* [Tag](https://cloud.tencent.com/document/api/362/15669#Tag)

修改数据结构：

* [Disk](https://cloud.tencent.com/document/api/362/15669#Disk)

	* 新增成员：Tags


### 第 2 次发布

发布时间：2018-05-24 17:08:50

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeDiskConfigQuota](https://cloud.tencent.com/document/api/362/16318)

	* 新增入参：DiskTypes

	* <font color="#dd0000">**删除入参**：</font>DiskType


修改数据结构：

* [Snapshot](https://cloud.tencent.com/document/api/362/15669#Snapshot)

	* 新增成员：CopyingToRegions, CopyFromRemote


### 第 1 次发布

发布时间：2018-04-24

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [ApplySnapshot](https://cloud.tencent.com/document/api/362/15643)
* [AttachDisks](https://cloud.tencent.com/document/api/362/16313)
* [CreateDisks](https://cloud.tencent.com/document/api/362/16312)
* [CreateSnapshot](https://cloud.tencent.com/document/api/362/15648)
* [DeleteSnapshots](https://cloud.tencent.com/document/api/362/15645)
* [DescribeDiskConfigQuota](https://cloud.tencent.com/document/api/362/16318)
* [DescribeDisks](https://cloud.tencent.com/document/api/362/16315)
* [DescribeInstancesDiskNum](https://cloud.tencent.com/document/api/362/16311)
* [DescribeSnapshots](https://cloud.tencent.com/document/api/362/15647)
* [DetachDisks](https://cloud.tencent.com/document/api/362/16316)
* [InquiryPriceCreateDisks](https://cloud.tencent.com/document/api/362/16314)
* [InquiryPriceRenewDisks](https://cloud.tencent.com/document/api/362/16317)
* [InquiryPriceResizeDisk](https://cloud.tencent.com/document/api/362/16320)
* [ModifyDiskAttributes](https://cloud.tencent.com/document/api/362/15659)
* [ModifyDisksRenewFlag](https://cloud.tencent.com/document/api/362/15668)
* [ModifySnapshotAttribute](https://cloud.tencent.com/document/api/362/15650)
* [RenewDisk](https://cloud.tencent.com/document/api/362/16319)
* [ResizeDisk](https://cloud.tencent.com/document/api/362/16310)
* [TerminateDisks](https://cloud.tencent.com/document/api/362/16321)

新增数据结构：

* [Disk](https://cloud.tencent.com/document/api/362/15669#Disk)
* [DiskChargePrepaid](https://cloud.tencent.com/document/api/362/15669#DiskChargePrepaid)
* [DiskConfig](https://cloud.tencent.com/document/api/362/15669#DiskConfig)
* [Filter](https://cloud.tencent.com/document/api/362/15669#Filter)
* [Placement](https://cloud.tencent.com/document/api/362/15669#Placement)
* [Price](https://cloud.tencent.com/document/api/362/15669#Price)
* [Snapshot](https://cloud.tencent.com/document/api/362/15669#Snapshot)




## 云联络中心(ccc) 版本：2020-02-10

### 第 70 次发布

发布时间：2024-07-23 01:10:10

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [SkillGroupInfoItem](https://cloud.tencent.com/document/api/679/47715#SkillGroupInfoItem)

	* 新增成员：Alias


### 第 69 次发布

发布时间：2024-06-06 01:17:16

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateIVRSession](https://cloud.tencent.com/document/api/679/106913)

### 第 68 次发布

发布时间：2024-05-20 01:15:04

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [CompanyApplyInfo](https://cloud.tencent.com/document/api/679/47715#CompanyApplyInfo)

	* 新增成员：IsEqualTencentCloud, CorporationMobile, CorporationMobilePicUrl, UseDescribeFileUrl, CompanyAuthLetterPicUrl, OperatorMobile, OperatorEmail, OperatorMobilePicUrl

	* <font color="#dd0000">**删除成员**：</font>BusinessScope

* [CompanyStateInfo](https://cloud.tencent.com/document/api/679/47715#CompanyStateInfo)

	* 新增成员：ModifyTime


### 第 67 次发布

发布时间：2024-04-24 01:06:08

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeChatMessages](https://cloud.tencent.com/document/api/679/49676)


### 第 66 次发布

发布时间：2024-04-23 01:09:39

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [ModifyStaffPassword](https://cloud.tencent.com/document/api/679/105562)

### 第 65 次发布

发布时间：2024-04-10 01:09:30

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [UploadIvrAudio](https://cloud.tencent.com/document/api/679/104894)

	* 新增出参：SuccessFileList


### 第 64 次发布

发布时间：2024-04-08 01:09:16

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeIvrAudioList](https://cloud.tencent.com/document/api/679/104895)
* [UploadIvrAudio](https://cloud.tencent.com/document/api/679/104894)

新增数据结构：

* [AudioFileInfo](https://cloud.tencent.com/document/api/679/47715#AudioFileInfo)
* [UploadAudioInfo](https://cloud.tencent.com/document/api/679/47715#UploadAudioInfo)
* [UploadIvrAudioFailedInfo](https://cloud.tencent.com/document/api/679/47715#UploadIvrAudioFailedInfo)

### 第 63 次发布

发布时间：2024-03-28 01:09:50

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateCompanyApply](https://cloud.tencent.com/document/api/679/104629)
* [DescribeCompanyList](https://cloud.tencent.com/document/api/679/104628)
* [ModifyCompanyApply](https://cloud.tencent.com/document/api/679/104627)

新增数据结构：

* [CompanyApplyInfo](https://cloud.tencent.com/document/api/679/47715#CompanyApplyInfo)
* [CompanyStateInfo](https://cloud.tencent.com/document/api/679/47715#CompanyStateInfo)

### 第 62 次发布

发布时间：2024-03-13 01:09:37

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [SdkAppIdBuyInfo](https://cloud.tencent.com/document/api/679/47715#SdkAppIdBuyInfo)

	* <font color="#dd0000">**修改成员**：</font>SipBuyNum

* [ServeParticipant](https://cloud.tencent.com/document/api/679/47715#ServeParticipant)

	* <font color="#dd0000">**修改成员**：</font>TransferFromType

* [SkillGroupInfoItem](https://cloud.tencent.com/document/api/679/47715#SkillGroupInfoItem)

	* <font color="#dd0000">**修改成员**：</font>SkillGroupId, SkillGroupName, Type, RoutePolicy, UsingLastSeat, MaxConcurrency, LastModifyTimestamp, SkillGroupType

* [StaffBuyInfo](https://cloud.tencent.com/document/api/679/47715#StaffBuyInfo)

	* <font color="#dd0000">**修改成员**：</font>SipNum

* [StaffStatusMetrics](https://cloud.tencent.com/document/api/679/47715#StaffStatusMetrics)

	* <font color="#dd0000">**修改成员**：</font>LastOnlineTimestamp, LastStatusTimestamp


### 第 61 次发布

发布时间：2024-03-07 01:09:17

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [StaffInfo](https://cloud.tencent.com/document/api/679/47715#StaffInfo)

	* 新增成员：RoleId


### 第 60 次发布

发布时间：2024-03-05 01:09:20

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [UpdateCCCSkillGroup](https://cloud.tencent.com/document/api/679/104097)

### 第 59 次发布

发布时间：2024-03-01 01:09:52

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [AbortPredictiveDialingCampaign](https://cloud.tencent.com/document/api/679/104035)
* [CreatePredictiveDialingCampaign](https://cloud.tencent.com/document/api/679/104034)
* [DeletePredictiveDialingCampaign](https://cloud.tencent.com/document/api/679/104033)
* [DescribePredictiveDialingCampaign](https://cloud.tencent.com/document/api/679/104032)
* [DescribePredictiveDialingCampaigns](https://cloud.tencent.com/document/api/679/104031)
* [DescribePredictiveDialingSessions](https://cloud.tencent.com/document/api/679/104030)
* [PausePredictiveDialingCampaign](https://cloud.tencent.com/document/api/679/104029)
* [ResumePredictiveDialingCampaign](https://cloud.tencent.com/document/api/679/104028)
* [UpdatePredictiveDialingCampaign](https://cloud.tencent.com/document/api/679/104027)

新增数据结构：

* [DescribePredictiveDialingCampaignsElement](https://cloud.tencent.com/document/api/679/47715#DescribePredictiveDialingCampaignsElement)

### 第 58 次发布

发布时间：2023-11-03 01:08:07

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [SeatUserInfo](https://cloud.tencent.com/document/api/679/47715#SeatUserInfo)

	* 新增成员：Role

* [TelCdrInfo](https://cloud.tencent.com/document/api/679/47715#TelCdrInfo)

	* 新增成员：RecordId


### 第 57 次发布

发布时间：2023-10-13 01:09:06

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeIMCdrList](https://cloud.tencent.com/document/api/679/89012)

修改接口：

* [DescribeChatMessages](https://cloud.tencent.com/document/api/679/49676)

* [DescribeIMCdrs](https://cloud.tencent.com/document/api/679/49675)

	* 新增出参：IMCdrList


### 第 56 次发布

发布时间：2023-10-12 01:16:25

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateCallOutSession](https://cloud.tencent.com/document/api/679/68726)

	* 新增入参：UUI

* [DescribeProtectedTelCdr](https://cloud.tencent.com/document/api/679/72597)

	* 新增出参：TelCdrList

* [DescribeTelCallInfo](https://cloud.tencent.com/document/api/679/50168)

	* 新增出参：VOIPCallInCount

* [DescribeTelCdr](https://cloud.tencent.com/document/api/679/47714)

	* 新增出参：TelCdrList


修改数据结构：

* [NumberInfo](https://cloud.tencent.com/document/api/679/47715#NumberInfo)

	* 新增成员：State

	* <font color="#dd0000">**修改成员**：</font>Number, CallOutSkillGroupIds

* [TelCdrInfo](https://cloud.tencent.com/document/api/679/47715#TelCdrInfo)

	* 新增成员：UUI


### 第 55 次发布

发布时间：2023-09-07 01:15:54

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [BindStaffSkillGroupList](https://cloud.tencent.com/document/api/679/58190)

	* 新增入参：StaffSkillGroupList

	* <font color="#dd0000">**修改入参**：</font>SkillGroupList


新增数据结构：

* [StaffSkillGroupList](https://cloud.tencent.com/document/api/679/47715#StaffSkillGroupList)

### 第 54 次发布

发布时间：2023-08-23 01:10:26

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateSDKLoginToken](https://cloud.tencent.com/document/api/679/49227)

	* 新增入参：OnlyOnce


### 第 53 次发布

发布时间：2023-08-08 01:09:59

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateAdminURL](https://cloud.tencent.com/document/api/679/96062)

### 第 52 次发布

发布时间：2023-07-28 01:10:59

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [SdkAppIdBuyInfo](https://cloud.tencent.com/document/api/679/47715#SdkAppIdBuyInfo)

	* 新增成员：SipBuyNum

* [StaffBuyInfo](https://cloud.tencent.com/document/api/679/47715#StaffBuyInfo)

	* 新增成员：SipNum


### 第 51 次发布

发布时间：2023-06-30 01:11:07

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateExtension](https://cloud.tencent.com/document/api/679/82130)

	* 新增入参：SkillGroupIds, Relation


修改数据结构：

* [TelCdrInfo](https://cloud.tencent.com/document/api/679/47715#TelCdrInfo)

	* 新增成员：VoicemailAsrURL

	* <font color="#dd0000">**修改成员**：</font>Caller, Callee, Time, Direction, Duration, RecordURL, SeatUser, EndStatus, SkillGroup, CallerLocation, IVRDuration, RingTimestamp, AcceptTimestamp, EndedTimestamp, IVRKeyPressed, HungUpSide, ServeParticipants, SkillGroupId, EndStatusString, StartTimestamp, QueuedTimestamp, PostIVRKeyPressed, QueuedSkillGroupId, SessionId, ProtectedCaller, ProtectedCallee, Uui, IVRKeyPressedEx, AsrUrl, CustomRecordURL, Remark, QueuedSkillGroupName, VoicemailRecordURL


### 第 50 次发布

发布时间：2023-06-08 01:08:30

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateCallOutSession](https://cloud.tencent.com/document/api/679/68726)

	* 新增入参：Callers


### 第 49 次发布

发布时间：2023-05-17 01:08:49

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateAutoCalloutTask](https://cloud.tencent.com/document/api/679/69194)

	* 新增入参：UUI, CalleeAttributes


新增数据结构：

* [CalleeAttribute](https://cloud.tencent.com/document/api/679/47715#CalleeAttribute)

### 第 48 次发布

发布时间：2023-05-08 01:11:11

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [ServeParticipant](https://cloud.tencent.com/document/api/679/47715#ServeParticipant)

	* 新增成员：TransferFromType


### 第 47 次发布

发布时间：2023-04-24 01:06:05

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeCallInMetrics](https://cloud.tencent.com/document/api/679/60006)

	* 新增入参：GroupIdList

* [DescribeStaffStatusMetrics](https://cloud.tencent.com/document/api/679/60007)

	* 新增入参：GroupIdList, StatusList


### 第 46 次发布

发布时间：2023-03-28 01:09:13

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeTelCallInfo](https://cloud.tencent.com/document/api/679/50168)

	* 新增出参：AsrOfflineCount, AsrRealtimeCount


### 第 45 次发布

发布时间：2023-03-24 01:13:32

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [SeatUserInfo](https://cloud.tencent.com/document/api/679/47715#SeatUserInfo)

	* <font color="#dd0000">**修改成员**：</font>Name, Mail, StaffNumber


### 第 44 次发布

发布时间：2023-03-23 01:14:04

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [StaffStatusMetrics](https://cloud.tencent.com/document/api/679/47715#StaffStatusMetrics)

	* 新增成员：LastOnlineTimestamp, LastStatusTimestamp


### 第 43 次发布

发布时间：2023-03-08 01:06:07

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DisableCCCPhoneNumber](https://cloud.tencent.com/document/api/679/80901)

	* <font color="#dd0000">**修改入参**：</font>SdkAppId


### 第 42 次发布

发布时间：2023-03-07 01:06:27

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeTelCallInfo](https://cloud.tencent.com/document/api/679/50168)

	* 新增出参：VoipCallInCount


### 第 41 次发布

发布时间：2023-02-09 01:09:05

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [BindNumberCallOutSkillGroup](https://cloud.tencent.com/document/api/679/86305)
* [DescribeNumbers](https://cloud.tencent.com/document/api/679/86304)
* [UnbindNumberCallOutSkillGroup](https://cloud.tencent.com/document/api/679/86303)

新增数据结构：

* [NumberInfo](https://cloud.tencent.com/document/api/679/47715#NumberInfo)

修改数据结构：

* [TelCdrInfo](https://cloud.tencent.com/document/api/679/47715#TelCdrInfo)

	* 新增成员：VoicemailRecordURL


### 第 40 次发布

发布时间：2023-01-09 01:07:34

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [TelCdrInfo](https://cloud.tencent.com/document/api/679/47715#TelCdrInfo)

	* 新增成员：QueuedSkillGroupName


### 第 39 次发布

发布时间：2022-12-16 01:10:35

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [HangUpCall](https://cloud.tencent.com/document/api/679/84273)

### 第 38 次发布

发布时间：2022-12-08 01:17:22

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [TelCdrInfo](https://cloud.tencent.com/document/api/679/47715#TelCdrInfo)

	* 新增成员：Remark

	* <font color="#dd0000">**修改成员**：</font>Caller, Callee, Time, Direction, Duration, RecordURL, SeatUser, EndStatus, SkillGroup, CallerLocation, IVRDuration, RingTimestamp, AcceptTimestamp, EndedTimestamp, IVRKeyPressed, HungUpSide, ServeParticipants, SkillGroupId, EndStatusString, StartTimestamp, QueuedTimestamp, PostIVRKeyPressed, QueuedSkillGroupId, SessionId, ProtectedCaller, ProtectedCallee, Uui, IVRKeyPressedEx, AsrUrl, CustomRecordURL


### 第 37 次发布

发布时间：2022-12-07 06:21:07

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [SkillGroupInfoItem](https://cloud.tencent.com/document/api/679/47715#SkillGroupInfoItem)

	* 新增成员：SkillGroupType

	* <font color="#dd0000">**修改成员**：</font>SkillGroupId, SkillGroupName, Type, RoutePolicy, UsingLastSeat, MaxConcurrency, LastModifyTimestamp


### 第 36 次发布

发布时间：2022-11-21 06:12:39

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateCarrierPrivilegeNumberApplicant](https://cloud.tencent.com/document/api/679/83127)
* [DescribeActiveCarrierPrivilegeNumber](https://cloud.tencent.com/document/api/679/83126)
* [DescribeCarrierPrivilegeNumberApplicants](https://cloud.tencent.com/document/api/679/83125)

新增数据结构：

* [ActiveCarrierPrivilegeNumber](https://cloud.tencent.com/document/api/679/47715#ActiveCarrierPrivilegeNumber)
* [CarrierPrivilegeNumberApplicant](https://cloud.tencent.com/document/api/679/47715#CarrierPrivilegeNumberApplicant)
* [Filter](https://cloud.tencent.com/document/api/679/47715#Filter)

### 第 35 次发布

发布时间：2022-11-16 06:11:21

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateStaff](https://cloud.tencent.com/document/api/679/49677)

	* 新增入参：SendPassword


### 第 34 次发布

发布时间：2022-11-08 06:12:05

本次发布包含了以下内容：

改善已有的文档。

新增数据结构：

* [IMSatisfaction](https://cloud.tencent.com/document/api/679/47715#IMSatisfaction)

修改数据结构：

* [IMCdrInfo](https://cloud.tencent.com/document/api/679/47715#IMCdrInfo)

	* 新增成员：Satisfaction


### 第 33 次发布

发布时间：2022-10-31 06:13:20

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateExtension](https://cloud.tencent.com/document/api/679/82130)
* [DeleteExtension](https://cloud.tencent.com/document/api/679/82129)
* [DescribeExtension](https://cloud.tencent.com/document/api/679/82128)
* [DescribeExtensions](https://cloud.tencent.com/document/api/679/82127)
* [ModifyExtension](https://cloud.tencent.com/document/api/679/82126)
* [ResetExtensionPassword](https://cloud.tencent.com/document/api/679/82125)

新增数据结构：

* [ExtensionInfo](https://cloud.tencent.com/document/api/679/47715#ExtensionInfo)

### 第 32 次发布

发布时间：2022-10-26 06:15:12

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateAutoCalloutTask](https://cloud.tencent.com/document/api/679/69194)

	* 新增入参：Variables


新增数据结构：

* [Variable](https://cloud.tencent.com/document/api/679/47715#Variable)

### 第 31 次发布

发布时间：2022-09-22 06:12:48

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DisableCCCPhoneNumber](https://cloud.tencent.com/document/api/679/80901)

### 第 30 次发布

发布时间：2022-09-06 06:13:56

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [AutoCalloutTaskCalleeInfo](https://cloud.tencent.com/document/api/679/47715#AutoCalloutTaskCalleeInfo)

	* 新增成员：Sessions


### 第 29 次发布

发布时间：2022-08-17 06:11:23

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeStaffInfoList](https://cloud.tencent.com/document/api/679/53309)

	* 新增入参：SkillGroupId


### 第 28 次发布

发布时间：2022-08-11 06:14:26

本次发布包含了以下内容：

改善已有的文档。

<font color="#dd0000">**删除接口**：</font>

* DescribeSeatUserList

修改接口：

* [DescribeSkillGroupInfoList](https://cloud.tencent.com/document/api/679/53310)

	* 新增入参：SkillGroupName

* [ModifyStaff](https://cloud.tencent.com/document/api/679/76322)

	* 新增入参：UseMobileCallOut, UseMobileAccept


修改数据结构：

* [StaffStatusMetrics](https://cloud.tencent.com/document/api/679/47715#StaffStatusMetrics)

	* 新增成员：UseMobileAccept, UseMobileCallOut


### 第 27 次发布

发布时间：2022-07-01 06:06:59

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [ModifyStaff](https://cloud.tencent.com/document/api/679/76322)

### 第 26 次发布

发布时间：2022-06-20 06:03:42

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateCCCSkillGroup](https://cloud.tencent.com/document/api/679/75751)

### 第 25 次发布

发布时间：2022-05-24 06:07:44

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [AutoCalloutTaskInfo](https://cloud.tencent.com/document/api/679/47715#AutoCalloutTaskInfo)

	* 新增成员：TaskId


### 第 24 次发布

发布时间：2022-04-15 06:03:13

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeProtectedTelCdr](https://cloud.tencent.com/document/api/679/72597)

### 第 23 次发布

发布时间：2022-04-13 06:12:26

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeTelCdr](https://cloud.tencent.com/document/api/679/47714)

	* <font color="#dd0000">**修改入参**：</font>Limit, Offset


### 第 22 次发布

发布时间：2022-03-04 08:05:02

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [ServeParticipant](https://cloud.tencent.com/document/api/679/47715#ServeParticipant)

	* 新增成员：CustomRecordURL

* [TelCdrInfo](https://cloud.tencent.com/document/api/679/47715#TelCdrInfo)

	* 新增成员：CustomRecordURL


### 第 21 次发布

发布时间：2022-02-14 08:06:57

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateAutoCalloutTask](https://cloud.tencent.com/document/api/679/69194)
* [DescribeAutoCalloutTask](https://cloud.tencent.com/document/api/679/69193)
* [StopAutoCalloutTask](https://cloud.tencent.com/document/api/679/69192)

新增数据结构：

* [AutoCalloutTaskCalleeInfo](https://cloud.tencent.com/document/api/679/47715#AutoCalloutTaskCalleeInfo)

修改数据结构：

* [TelCdrInfo](https://cloud.tencent.com/document/api/679/47715#TelCdrInfo)

	* 新增成员：AsrUrl


### 第 20 次发布

发布时间：2022-01-24 08:05:51

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateCallOutSession](https://cloud.tencent.com/document/api/679/68726)
* [DescribeAutoCalloutTasks](https://cloud.tencent.com/document/api/679/68725)

新增数据结构：

* [AutoCalloutTaskInfo](https://cloud.tencent.com/document/api/679/47715#AutoCalloutTaskInfo)

修改数据结构：

* [IMCdrInfo](https://cloud.tencent.com/document/api/679/47715#IMCdrInfo)

	* 新增成员：SessionId, SkillGroupId, SkillGroupName


### 第 19 次发布

发布时间：2021-12-10 08:02:29

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [TelCdrInfo](https://cloud.tencent.com/document/api/679/47715#TelCdrInfo)

	* 新增成员：IVRKeyPressedEx


### 第 18 次发布

发布时间：2021-12-06 08:02:18

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeCCCBuyInfoList](https://cloud.tencent.com/document/api/679/65435)

新增数据结构：

* [PackageBuyInfo](https://cloud.tencent.com/document/api/679/47715#PackageBuyInfo)
* [PhoneNumBuyInfo](https://cloud.tencent.com/document/api/679/47715#PhoneNumBuyInfo)
* [SdkAppIdBuyInfo](https://cloud.tencent.com/document/api/679/47715#SdkAppIdBuyInfo)
* [StaffBuyInfo](https://cloud.tencent.com/document/api/679/47715#StaffBuyInfo)

### 第 17 次发布

发布时间：2021-11-16 08:06:45

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [TelCdrInfo](https://cloud.tencent.com/document/api/679/47715#TelCdrInfo)

	* 新增成员：Uui


### 第 16 次发布

发布时间：2021-11-01 08:06:08

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeChatMessages](https://cloud.tencent.com/document/api/679/49676)

	* 新增入参：SessionId

	* <font color="#dd0000">**修改入参**：</font>CdrId

* [DescribeTelCdr](https://cloud.tencent.com/document/api/679/47714)

	* 新增入参：SessionIds


修改数据结构：

* [PSTNSession](https://cloud.tencent.com/document/api/679/47715#PSTNSession)

	* 新增成员：ProtectedCaller, ProtectedCallee

* [PSTNSessionInfo](https://cloud.tencent.com/document/api/679/47715#PSTNSessionInfo)

	* 新增成员：ProtectedCaller, ProtectedCallee

* [TelCdrInfo](https://cloud.tencent.com/document/api/679/47715#TelCdrInfo)

	* 新增成员：ProtectedCaller, ProtectedCallee


### 第 15 次发布

发布时间：2021-08-10 08:01:44

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeCallInMetrics](https://cloud.tencent.com/document/api/679/60006)
* [DescribeStaffStatusMetrics](https://cloud.tencent.com/document/api/679/60007)

新增数据结构：

* [CallInMetrics](https://cloud.tencent.com/document/api/679/47715#CallInMetrics)
* [CallInNumberMetrics](https://cloud.tencent.com/document/api/679/47715#CallInNumberMetrics)
* [CallInSkillGroupMetrics](https://cloud.tencent.com/document/api/679/47715#CallInSkillGroupMetrics)
* [StaffStatusExtra](https://cloud.tencent.com/document/api/679/47715#StaffStatusExtra)
* [StaffStatusMetrics](https://cloud.tencent.com/document/api/679/47715#StaffStatusMetrics)

### 第 14 次发布

发布时间：2021-07-08 08:01:24

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateUserSig](https://cloud.tencent.com/document/api/679/58260)

### 第 13 次发布

发布时间：2021-07-07 09:55:44

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeTelCdr](https://cloud.tencent.com/document/api/679/47714)

	* 新增入参：Phones


### 第 12 次发布

发布时间：2021-07-06 08:01:37

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [BindStaffSkillGroupList](https://cloud.tencent.com/document/api/679/58190)
* [DeleteStaff](https://cloud.tencent.com/document/api/679/58189)
* [UnbindStaffSkillGroupList](https://cloud.tencent.com/document/api/679/58188)

修改接口：

* [CreateStaff](https://cloud.tencent.com/document/api/679/49677)

	* 新增出参：ErrorStaffList


新增数据结构：

* [ErrStaffItem](https://cloud.tencent.com/document/api/679/47715#ErrStaffItem)

### 第 11 次发布

发布时间：2021-04-07 08:00:41

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeTelSession](https://cloud.tencent.com/document/api/679/54343)

新增数据结构：

* [PSTNSession](https://cloud.tencent.com/document/api/679/47715#PSTNSession)

### 第 10 次发布

发布时间：2021-03-16 08:00:43

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [TelCdrInfo](https://cloud.tencent.com/document/api/679/47715#TelCdrInfo)

	* 新增成员：SessionId


### 第 9 次发布

发布时间：2021-03-02 08:00:36

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeSkillGroupInfoList](https://cloud.tencent.com/document/api/679/53310)
* [DescribeStaffInfoList](https://cloud.tencent.com/document/api/679/53309)

新增数据结构：

* [SkillGroupInfoItem](https://cloud.tencent.com/document/api/679/47715#SkillGroupInfoItem)
* [SkillGroupItem](https://cloud.tencent.com/document/api/679/47715#SkillGroupItem)
* [StaffInfo](https://cloud.tencent.com/document/api/679/47715#StaffInfo)

### 第 8 次发布

发布时间：2021-01-28 08:00:34

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeSeatUserList](https://cloud.tencent.com/document/api/679/52561)

修改接口：

* [DescribeTelCdr](https://cloud.tencent.com/document/api/679/47714)

	* 新增入参：PageSize, PageNumber


新增数据结构：

* [IVRKeyPressedElement](https://cloud.tencent.com/document/api/679/47715#IVRKeyPressedElement)
* [ServeParticipant](https://cloud.tencent.com/document/api/679/47715#ServeParticipant)

修改数据结构：

* [TelCdrInfo](https://cloud.tencent.com/document/api/679/47715#TelCdrInfo)

	* 新增成员：IVRDuration, RingTimestamp, AcceptTimestamp, EndedTimestamp, IVRKeyPressed, HungUpSide, ServeParticipants, SkillGroupId, EndStatusString, StartTimestamp, QueuedTimestamp, PostIVRKeyPressed, QueuedSkillGroupId


### 第 7 次发布

发布时间：2020-12-17 08:00:22

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribePSTNActiveSessionList](https://cloud.tencent.com/document/api/679/51091)

新增数据结构：

* [PSTNSessionInfo](https://cloud.tencent.com/document/api/679/47715#PSTNSessionInfo)

### 第 6 次发布

发布时间：2020-11-23 08:00:28

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeTelCallInfo](https://cloud.tencent.com/document/api/679/50168)

### 第 5 次发布

发布时间：2020-11-16 08:00:24

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateSDKLoginToken](https://cloud.tencent.com/document/api/679/49227)

	* 新增出参：SdkURL


### 第 4 次发布

发布时间：2020-11-05 08:00:21

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateStaff](https://cloud.tencent.com/document/api/679/49677)
* [DescribeChatMessages](https://cloud.tencent.com/document/api/679/49676)
* [DescribeIMCdrs](https://cloud.tencent.com/document/api/679/49675)

修改接口：

* [DescribeTelCdr](https://cloud.tencent.com/document/api/679/47714)

	* 新增入参：SdkAppId

	* <font color="#dd0000">**修改入参**：</font>InstanceId


新增数据结构：

* [IMCdrInfo](https://cloud.tencent.com/document/api/679/47715#IMCdrInfo)
* [Message](https://cloud.tencent.com/document/api/679/47715#Message)
* [MessageBody](https://cloud.tencent.com/document/api/679/47715#MessageBody)

### 第 3 次发布

发布时间：2020-10-23 08:00:22

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [SeatUserInfo](https://cloud.tencent.com/document/api/679/47715#SeatUserInfo)

	* 新增成员：StaffNumber

	* <font color="#dd0000">**修改成员**：</font>Phone


### 第 2 次发布

发布时间：2020-10-20 08:00:12

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateSDKLoginToken](https://cloud.tencent.com/document/api/679/49227)

### 第 1 次发布

发布时间：2020-08-21 17:50:27

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeTelCdr](https://cloud.tencent.com/document/api/679/47714)

新增数据结构：

* [SeatUserInfo](https://cloud.tencent.com/document/api/679/47715#SeatUserInfo)
* [TelCdrInfo](https://cloud.tencent.com/document/api/679/47715#TelCdrInfo)




## 云数据库 MySQL(cdb) 版本：2017-03-20

### 第 163 次发布

发布时间：2024-08-02 01:11:12

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateDBInstance](https://cloud.tencent.com/document/api/236/15871)

	* 新增入参：DataProtectVolume, DiskType

* [CreateDBInstanceHour](https://cloud.tencent.com/document/api/236/15865)

	* 新增入参：DataProtectVolume, DiskType


### 第 162 次发布

发布时间：2024-07-26 01:16:06

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateCloneInstance](https://cloud.tencent.com/document/api/236/50424)

	* 新增入参：ClusterTopology

* [CreateDBInstance](https://cloud.tencent.com/document/api/236/15871)

	* 新增入参：ClusterTopology

* [CreateDBInstanceHour](https://cloud.tencent.com/document/api/236/15865)

	* 新增入参：ClusterTopology


### 第 161 次发布

发布时间：2024-07-23 01:10:42

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [UpgradeDBInstanceEngineVersion](https://cloud.tencent.com/document/api/236/15870)

	* 新增入参：ParamList


新增数据结构：

* [UpgradeEngineVersionParams](https://cloud.tencent.com/document/api/236/15878#UpgradeEngineVersionParams)

### 第 160 次发布

发布时间：2024-07-08 01:09:08

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateRotationPassword](https://cloud.tencent.com/document/api/236/108310)
* [DeleteRotationPassword](https://cloud.tencent.com/document/api/236/108309)
* [ResetPassword](https://cloud.tencent.com/document/api/236/108308)

### 第 159 次发布

发布时间：2024-06-24 01:09:17

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeInstanceUpgradeType](https://cloud.tencent.com/document/api/236/107630)

新增数据结构：

* [ClusterTopology](https://cloud.tencent.com/document/api/236/15878#ClusterTopology)
* [NodeDistribution](https://cloud.tencent.com/document/api/236/15878#NodeDistribution)
* [ReadWriteNode](https://cloud.tencent.com/document/api/236/15878#ReadWriteNode)
* [ReadonlyNode](https://cloud.tencent.com/document/api/236/15878#ReadonlyNode)

### 第 158 次发布

发布时间：2024-06-04 01:16:12

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [AdjustCdbProxyAddress](https://cloud.tencent.com/document/api/236/90589)

	* 新增入参：AutoLoadBalance, AccessMode

* [CreateCdbProxyAddress](https://cloud.tencent.com/document/api/236/90586)

	* 新增入参：AutoLoadBalance, AccessMode

* [DescribeProxySupportParam](https://cloud.tencent.com/document/api/236/90584)

	* 新增出参：SupportAutoLoadBalance, SupportAccessMode


修改数据结构：

* [ProxyAddress](https://cloud.tencent.com/document/api/236/15878#ProxyAddress)

	* 新增成员：AccessMode, AutoLoadBalance

* [ProxyInst](https://cloud.tencent.com/document/api/236/15878#ProxyInst)

	* 新增成员：InstNodeId, InstNodeRole


### 第 157 次发布

发布时间：2024-05-07 01:10:17

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CloseSSL](https://cloud.tencent.com/document/api/236/105850)
* [DescribeSSLStatus](https://cloud.tencent.com/document/api/236/105849)
* [OpenSSL](https://cloud.tencent.com/document/api/236/105848)

### 第 156 次发布

发布时间：2024-04-23 01:09:48

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateCdbProxy](https://cloud.tencent.com/document/api/236/90587)

	* 新增入参：ProxyVersion


### 第 155 次发布

发布时间：2024-04-12 01:09:15

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CheckMigrateCluster](https://cloud.tencent.com/document/api/236/105117)
* [DescribeClusterInfo](https://cloud.tencent.com/document/api/236/105116)

新增数据结构：

* [AddressInfo](https://cloud.tencent.com/document/api/236/15878#AddressInfo)
* [ClusterNodeInfo](https://cloud.tencent.com/document/api/236/15878#ClusterNodeInfo)

### 第 154 次发布

发布时间：2024-03-26 01:09:47

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateCloneInstance](https://cloud.tencent.com/document/api/236/50424)

	* 新增入参：PayType, Period


新增数据结构：

* [TaskAttachInfo](https://cloud.tencent.com/document/api/236/15878#TaskAttachInfo)

修改数据结构：

* [TaskDetail](https://cloud.tencent.com/document/api/236/15878#TaskDetail)

	* 新增成员：TaskAttachInfo


### 第 153 次发布

发布时间：2024-02-28 01:09:55

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeDBSecurityGroups](https://cloud.tencent.com/document/api/236/15854)

	* 新增入参：OpResourceId


### 第 152 次发布

发布时间：2024-01-30 01:08:20

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeInstanceAlarmEvents](https://cloud.tencent.com/document/api/236/103572)

### 第 151 次发布

发布时间：2024-01-24 01:22:49

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeDBInstanceLogToCLS](https://cloud.tencent.com/document/api/236/100576)

	* 新增入参：ClsRegion

* [ModifyDBInstanceLogToCLS](https://cloud.tencent.com/document/api/236/100575)

	* 新增入参：ClsRegion


修改数据结构：

* [LogToCLSConfig](https://cloud.tencent.com/document/api/236/15878#LogToCLSConfig)

	* 新增成员：ClsRegion


### 第 150 次发布

发布时间：2023-12-22 01:08:53

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeBinlogs](https://cloud.tencent.com/document/api/236/15843)

	* 新增入参：ContainsMinStartTime


修改数据结构：

* [BackupInfo](https://cloud.tencent.com/document/api/236/15878#BackupInfo)

	* 新增成员：ExecutedGTIDSet


### 第 149 次发布

发布时间：2023-12-13 01:17:04

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeBackupDecryptionKey](https://cloud.tencent.com/document/api/236/91083)

	* 新增入参：BackupType


### 第 148 次发布

发布时间：2023-11-22 01:30:13

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CloseAuditService](https://cloud.tencent.com/document/api/236/101816)
* [CreateAuditRuleTemplate](https://cloud.tencent.com/document/api/236/101815)
* [DeleteAuditRuleTemplates](https://cloud.tencent.com/document/api/236/101814)
* [DeleteDatabase](https://cloud.tencent.com/document/api/236/101808)
* [DescribeAuditInstanceList](https://cloud.tencent.com/document/api/236/101813)
* [DescribeAuditRuleTemplateModifyHistory](https://cloud.tencent.com/document/api/236/101812)
* [DescribeAuditRuleTemplates](https://cloud.tencent.com/document/api/236/101811)
* [ModifyAuditRuleTemplates](https://cloud.tencent.com/document/api/236/101810)
* [ModifyAuditService](https://cloud.tencent.com/document/api/236/101809)

新增数据结构：

* [AuditInstanceFilters](https://cloud.tencent.com/document/api/236/15878#AuditInstanceFilters)
* [AuditInstanceInfo](https://cloud.tencent.com/document/api/236/15878#AuditInstanceInfo)
* [AuditRuleTemplateInfo](https://cloud.tencent.com/document/api/236/15878#AuditRuleTemplateInfo)
* [InstanceDbAuditStatus](https://cloud.tencent.com/document/api/236/15878#InstanceDbAuditStatus)
* [RuleTemplateInfo](https://cloud.tencent.com/document/api/236/15878#RuleTemplateInfo)
* [RuleTemplateRecordInfo](https://cloud.tencent.com/document/api/236/15878#RuleTemplateRecordInfo)

修改数据结构：

* [InstanceInfo](https://cloud.tencent.com/document/api/236/15878#InstanceInfo)

	* 新增成员：ExpandCpu

	* <font color="#dd0000">**修改成员**：</font>MasterInfo


### 第 147 次发布

发布时间：2023-11-21 01:08:38

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [RenewDBInstance](https://cloud.tencent.com/document/api/236/30160)

	* 新增入参：AutoRenew


### 第 146 次发布

发布时间：2023-10-23 00:03:18

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeDBInstanceLogToCLS](https://cloud.tencent.com/document/api/236/100576)
* [ModifyDBInstanceLogToCLS](https://cloud.tencent.com/document/api/236/100575)

新增数据结构：

* [LogToCLSConfig](https://cloud.tencent.com/document/api/236/15878#LogToCLSConfig)

### 第 145 次发布

发布时间：2023-10-18 01:20:48

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [StartCpuExpand](https://cloud.tencent.com/document/api/236/96017)

	* 新增入参：InstanceId, Type, ExpandCpu, AutoStrategy


新增数据结构：

* [AutoStrategy](https://cloud.tencent.com/document/api/236/15878#AutoStrategy)

### 第 144 次发布

发布时间：2023-09-21 01:31:18

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [ParamRecord](https://cloud.tencent.com/document/api/236/15878#ParamRecord)

	* 新增成员：IsSuccess


### 第 143 次发布

发布时间：2023-09-14 01:15:30

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [OpenAuditService](https://cloud.tencent.com/document/api/236/76408)

	* 新增入参：AuditAll


新增数据结构：

* [LogRuleTemplateInfo](https://cloud.tencent.com/document/api/236/15878#LogRuleTemplateInfo)

修改数据结构：

* [AuditLog](https://cloud.tencent.com/document/api/236/15878#AuditLog)

	* 新增成员：TemplateInfo


### 第 142 次发布

发布时间：2023-08-18 01:07:18

本次发布包含了以下内容：

改善已有的文档。

<font color="#dd0000">**删除接口**：</font>

* DescribeBackupDatabases

<font color="#dd0000">**删除数据结构**：</font>

* DatabaseName

### 第 141 次发布

发布时间：2023-08-07 01:07:06

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeCpuExpandStrategy](https://cloud.tencent.com/document/api/236/96018)
* [StartCpuExpand](https://cloud.tencent.com/document/api/236/96017)
* [StopCpuExpand](https://cloud.tencent.com/document/api/236/96016)

### 第 140 次发布

发布时间：2023-07-31 01:10:35

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [RoInstanceInfo](https://cloud.tencent.com/document/api/236/15878#RoInstanceInfo)

	* <font color="#dd0000">**修改成员**：</font>MasterInstanceId, RoStatus, OfflineTime, Weight, Region, Zone, InstanceId, Status, InstanceType, InstanceName, HourFeeStatus, TaskStatus, Memory, Volume, Qps, Vip, Vport, VpcId, SubnetId, DeviceType, EngineVersion, DeadlineTime, PayType


### 第 139 次发布

发布时间：2023-07-24 01:13:25

本次发布包含了以下内容：

改善已有的文档。

<font color="#dd0000">**删除接口**：</font>

* DescribeCDBProxy
* DescribeProxyConnectionPoolConf
* ModifyCDBProxyConnectionPool
* ModifyCDBProxyVipVPort
* QueryCDBProxy

<font color="#dd0000">**删除数据结构**：</font>

* Address
* BaseGroupInfo
* ConnectionPoolInfo
* PoolConf
* ProxyGroup
* ProxyGroups
* ProxyNodeInfo
* RWInfo
* RWInfos
* RWInstanceInfo

### 第 138 次发布

发布时间：2023-07-20 01:13:27

本次发布包含了以下内容：

改善已有的文档。

<font color="#dd0000">**删除接口**：</font>

* ModifyCDBProxyDesc

### 第 137 次发布

发布时间：2023-07-14 01:06:10

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeAuditLogs](https://cloud.tencent.com/document/api/236/95032)

新增数据结构：

* [AuditLog](https://cloud.tencent.com/document/api/236/15878#AuditLog)

### 第 136 次发布

发布时间：2023-07-13 01:06:06

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [AnalyzeAuditLogs](https://cloud.tencent.com/document/api/236/89112)

	* 新增入参：LogFilter

* [CreateAuditLogFile](https://cloud.tencent.com/document/api/236/45461)

	* 新增入参：LogFilter


新增数据结构：

* [InstanceAuditLogFilters](https://cloud.tencent.com/document/api/236/15878#InstanceAuditLogFilters)

### 第 135 次发布

发布时间：2023-06-29 01:07:08

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [RemoteBackupInfo](https://cloud.tencent.com/document/api/236/15878#RemoteBackupInfo)

	* <font color="#dd0000">**修改成员**：</font>SubBackupId


### 第 134 次发布

发布时间：2023-06-27 01:06:53

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [ProxyInst](https://cloud.tencent.com/document/api/236/15878#ProxyInst)

	* <font color="#dd0000">**修改成员**：</font>InstanceType


### 第 133 次发布

发布时间：2023-06-22 01:12:14

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateDatabase](https://cloud.tencent.com/document/api/236/94238)

### 第 132 次发布

发布时间：2023-06-15 01:05:53

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateCdbProxyAddress](https://cloud.tencent.com/document/api/236/90586)

	* 新增入参：ConnectionPoolType


### 第 131 次发布

发布时间：2023-06-08 01:08:54

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeDefaultParams](https://cloud.tencent.com/document/api/236/32662)

	* <font color="#dd0000">**修改入参**：</font>EngineVersion


### 第 130 次发布

发布时间：2023-06-07 01:07:38

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [Inbound](https://cloud.tencent.com/document/api/236/15878#Inbound)

	* 新增成员：AddressModule

* [Outbound](https://cloud.tencent.com/document/api/236/15878#Outbound)

	* 新增成员：AddressModule


### 第 129 次发布

发布时间：2023-06-01 09:45:06

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeBinlogs](https://cloud.tencent.com/document/api/236/15843)

	* 新增入参：MinStartTime, MaxStartTime


### 第 128 次发布

发布时间：2023-05-22 01:07:39

本次发布包含了以下内容：

改善已有的文档。

<font color="#dd0000">**删除接口**：</font>

* DescribeBackupTables

<font color="#dd0000">**删除数据结构**：</font>

* TableName

### 第 127 次发布

发布时间：2023-05-19 01:19:11

本次发布包含了以下内容：

改善已有的文档。

<font color="#dd0000">**预下线接口**：</font>

* DescribeBackupDatabases
* DescribeBackupTables

### 第 126 次发布

发布时间：2023-05-18 01:08:29

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeParamTemplateInfo](https://cloud.tencent.com/document/api/236/32660)

	* 新增出参：EngineType


### 第 125 次发布

发布时间：2023-05-17 01:09:16

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeBackupDecryptionKey](https://cloud.tencent.com/document/api/236/91083)

修改数据结构：

* [ParamTemplateInfo](https://cloud.tencent.com/document/api/236/15878#ParamTemplateInfo)

	* 新增成员：EngineType


### 第 124 次发布

发布时间：2023-05-15 01:12:13

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeRollbackRangeTime](https://cloud.tencent.com/document/api/236/18726)

	* 新增入参：IsRemoteZone, BackupRegion


### 第 123 次发布

发布时间：2023-05-08 01:11:27

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [ParameterDetail](https://cloud.tencent.com/document/api/236/15878#ParameterDetail)

	* 新增成员：IsNotSupportEdit


### 第 122 次发布

发布时间：2023-04-25 01:08:05

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [AdjustCdbProxy](https://cloud.tencent.com/document/api/236/90590)
* [AdjustCdbProxyAddress](https://cloud.tencent.com/document/api/236/90589)
* [CloseCdbProxyAddress](https://cloud.tencent.com/document/api/236/90588)
* [CreateCdbProxy](https://cloud.tencent.com/document/api/236/90587)
* [CreateCdbProxyAddress](https://cloud.tencent.com/document/api/236/90586)
* [DescribeCdbProxyInfo](https://cloud.tencent.com/document/api/236/90585)
* [DescribeProxySupportParam](https://cloud.tencent.com/document/api/236/90584)
* [ModifyCdbProxyAddressDesc](https://cloud.tencent.com/document/api/236/90583)
* [ModifyCdbProxyAddressVipAndVPort](https://cloud.tencent.com/document/api/236/90582)
* [ModifyCdbProxyParam](https://cloud.tencent.com/document/api/236/90581)

新增数据结构：

* [ProxyAddress](https://cloud.tencent.com/document/api/236/15878#ProxyAddress)
* [ProxyAllocation](https://cloud.tencent.com/document/api/236/15878#ProxyAllocation)
* [ProxyGroupInfo](https://cloud.tencent.com/document/api/236/15878#ProxyGroupInfo)
* [ProxyInst](https://cloud.tencent.com/document/api/236/15878#ProxyInst)
* [ProxyNode](https://cloud.tencent.com/document/api/236/15878#ProxyNode)
* [ProxyNodeCustom](https://cloud.tencent.com/document/api/236/15878#ProxyNodeCustom)

### 第 121 次发布

发布时间：2023-04-24 01:06:23

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [OpenAuditService](https://cloud.tencent.com/document/api/236/76408)

	* 新增入参：AuditRuleFilters, RuleTemplateIds


新增数据结构：

* [AuditRuleFilters](https://cloud.tencent.com/document/api/236/15878#AuditRuleFilters)
* [RuleFilters](https://cloud.tencent.com/document/api/236/15878#RuleFilters)

修改数据结构：

* [AuditLogFilter](https://cloud.tencent.com/document/api/236/15878#AuditLogFilter)

	* 新增成员：ThreadId, SentRows, ErrCode


### 第 120 次发布

发布时间：2023-04-19 01:10:00

本次发布包含了以下内容：

改善已有的文档。

<font color="#dd0000">**预下线接口**：</font>

* DescribeCDBProxy
* DescribeProxyConnectionPoolConf
* ModifyCDBProxyConnectionPool
* ModifyCDBProxyDesc
* ModifyCDBProxyVipVPort
* QueryCDBProxy

### 第 119 次发布

发布时间：2023-04-11 01:06:22

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [UpgradeDBInstance](https://cloud.tencent.com/document/api/236/15876)

	* 新增入参：RoTransType


### 第 118 次发布

发布时间：2023-03-28 01:09:40

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeDBInstances](https://cloud.tencent.com/document/api/236/15872)

	* 新增入参：EngineTypes


修改数据结构：

* [InstanceInfo](https://cloud.tencent.com/document/api/236/15878#InstanceInfo)

	* 新增成员：DiskType


### 第 117 次发布

发布时间：2023-03-27 01:12:07

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeDefaultParams](https://cloud.tencent.com/document/api/236/32662)

	* 新增入参：EngineType


### 第 116 次发布

发布时间：2023-03-22 01:11:38

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [AnalyzeAuditLogs](https://cloud.tencent.com/document/api/236/89112)

<font color="#dd0000">**预下线接口**：</font>

* InitDBInstances

新增数据结构：

* [AggregationCondition](https://cloud.tencent.com/document/api/236/15878#AggregationCondition)
* [AuditLogAggregationResult](https://cloud.tencent.com/document/api/236/15878#AuditLogAggregationResult)
* [Bucket](https://cloud.tencent.com/document/api/236/15878#Bucket)

修改数据结构：

* [AuditLogFilter](https://cloud.tencent.com/document/api/236/15878#AuditLogFilter)

	* 新增成员：AffectRowsSection, SentRowsSection, ExecTimeSection, LockWaitTimeSection, IoWaitTimeSection, TransactionLivingTimeSection


### 第 115 次发布

发布时间：2023-03-10 01:06:15

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [CloneItem](https://cloud.tencent.com/document/api/236/15878#CloneItem)

	* 新增成员：NewRegionId, SrcRegionId


### 第 114 次发布

发布时间：2023-02-17 01:33:04

本次发布包含了以下内容：

改善已有的文档。

<font color="#dd0000">**删除接口**：</font>

* UpgradeCDBProxy

### 第 113 次发布

发布时间：2023-02-16 01:11:25

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [OpenDBInstanceEncryption](https://cloud.tencent.com/document/api/236/86608)

### 第 112 次发布

发布时间：2023-02-14 01:08:31

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeBackupEncryptionStatus](https://cloud.tencent.com/document/api/236/86508)
* [ModifyBackupEncryptionStatus](https://cloud.tencent.com/document/api/236/86507)

<font color="#dd0000">**预下线接口**：</font>

* UpgradeCDBProxy

### 第 111 次发布

发布时间：2023-01-30 01:08:01

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeDBFeatures](https://cloud.tencent.com/document/api/236/85925)

### 第 110 次发布

发布时间：2023-01-16 01:12:59

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [CommonTimeWindow](https://cloud.tencent.com/document/api/236/15878#CommonTimeWindow)

	* 新增成员：BackupPeriodStrategy, Days, BackupPeriodTime


### 第 109 次发布

发布时间：2023-01-13 01:08:41

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeDBInstances](https://cloud.tencent.com/document/api/236/15872)

	* 新增入参：ProxyVips, ProxyIds


### 第 108 次发布

发布时间：2022-12-21 01:20:25

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeRemoteBackupConfig](https://cloud.tencent.com/document/api/236/84375)
* [ModifyRemoteBackupConfig](https://cloud.tencent.com/document/api/236/84374)

修改接口：

* [DescribeBackupConfig](https://cloud.tencent.com/document/api/236/15837)

	* 新增出参：EnableBackupStandby, BackupStandbyDays, EnableBinlogStandby, BinlogStandbyDays

* [DescribeBackupOverview](https://cloud.tencent.com/document/api/236/41229)

	* 新增出参：BackupStandbyVolume

* [DescribeBinlogBackupOverview](https://cloud.tencent.com/document/api/236/41227)

	* 新增出参：BinlogStandbyVolume, BinlogStandbyCount

* [DescribeDataBackupOverview](https://cloud.tencent.com/document/api/236/41226)

	* 新增出参：DataBackupStandbyVolume, DataBackupStandbyCount

* [ModifyBackupConfig](https://cloud.tencent.com/document/api/236/15839)

	* 新增入参：EnableBackupStandby, BackupStandbyDays, EnableBinlogStandby, BinlogStandbyDays


### 第 107 次发布

发布时间：2022-12-07 06:21:29

本次发布包含了以下内容：

改善已有的文档。

<font color="#dd0000">**删除接口**：</font>

* ApplyCDBProxy

### 第 106 次发布

发布时间：2022-12-05 06:24:01

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [BackupInfo](https://cloud.tencent.com/document/api/236/15878#BackupInfo)

	* 新增成员：EncryptionFlag


### 第 105 次发布

发布时间：2022-11-29 06:19:07

本次发布包含了以下内容：

改善已有的文档。

<font color="#dd0000">**删除接口**：</font>

* ModifyCDBProxy

<font color="#dd0000">**删除数据结构**：</font>

* RoWeight

### 第 104 次发布

发布时间：2022-11-16 06:11:36

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CloseCDBProxy](https://cloud.tencent.com/document/api/236/68171)

	* <font color="#dd0000">**修改入参**：</font>ProxyGroupId

* [ReloadBalanceProxyNode](https://cloud.tencent.com/document/api/236/68163)

	* 新增入参：ProxyAddressId


### 第 103 次发布

发布时间：2022-10-11 06:14:09

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeBackupConfig](https://cloud.tencent.com/document/api/236/15837)

	* 新增出参：EnableBackupArchive, BackupArchiveDays, EnableBinlogArchive, BinlogArchiveDays

* [DescribeBackupOverview](https://cloud.tencent.com/document/api/236/41229)

	* 新增出参：RemoteBackupVolume, BackupArchiveVolume

* [DescribeBinlogBackupOverview](https://cloud.tencent.com/document/api/236/41227)

	* 新增出参：BinlogArchiveVolume, BinlogArchiveCount

* [DescribeDataBackupOverview](https://cloud.tencent.com/document/api/236/41226)

	* 新增出参：DataBackupArchiveVolume, DataBackupArchiveCount

* [ModifyBackupConfig](https://cloud.tencent.com/document/api/236/15839)

	* 新增入参：EnableBackupArchive, BackupArchiveDays, BinlogArchiveDays, EnableBinlogArchive


新增数据结构：

* [RemoteBackupInfo](https://cloud.tencent.com/document/api/236/15878#RemoteBackupInfo)

修改数据结构：

* [BackupInfo](https://cloud.tencent.com/document/api/236/15878#BackupInfo)

	* 新增成员：Region, RemoteInfo, CosStorageType, InstanceId

* [BinlogInfo](https://cloud.tencent.com/document/api/236/15878#BinlogInfo)

	* 新增成员：Region, Status, RemoteInfo, CosStorageType, InstanceId


### 第 102 次发布

发布时间：2022-09-29 06:13:46

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [ModifyInstanceParam](https://cloud.tencent.com/document/api/236/15860)

	* 新增入参：NotSyncRo, NotSyncDr


### 第 101 次发布

发布时间：2022-09-21 06:12:53

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateParamTemplate](https://cloud.tencent.com/document/api/236/32663)

	* 新增入参：EngineType


### 第 100 次发布

发布时间：2022-09-14 06:11:05

本次发布包含了以下内容：

改善已有的文档。

<font color="#dd0000">**删除接口**：</font>

* DescribeDBZoneConfig

修改接口：

* [DescribeBinlogBackupOverview](https://cloud.tencent.com/document/api/236/41227)

	* 新增出参：RemoteBinlogVolume, RemoteBinlogCount

* [DescribeDataBackupOverview](https://cloud.tencent.com/document/api/236/41226)

	* 新增出参：RemoteBackupVolume, RemoteBackupCount


<font color="#dd0000">**删除数据结构**：</font>

* RegionSellConf
* SellConfig
* SellType
* ZoneSellConf

### 第 99 次发布

发布时间：2022-09-08 06:12:00

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeCdbZoneConfig](https://cloud.tencent.com/document/api/236/80281)

新增数据结构：

* [CdbRegionSellConf](https://cloud.tencent.com/document/api/236/15878#CdbRegionSellConf)
* [CdbSellConfig](https://cloud.tencent.com/document/api/236/15878#CdbSellConfig)
* [CdbSellType](https://cloud.tencent.com/document/api/236/15878#CdbSellType)
* [CdbZoneDataResult](https://cloud.tencent.com/document/api/236/15878#CdbZoneDataResult)
* [CdbZoneSellConf](https://cloud.tencent.com/document/api/236/15878#CdbZoneSellConf)

### 第 98 次发布

发布时间：2022-09-07 06:13:01

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeDBPrice](https://cloud.tencent.com/document/api/236/18566)

	* 新增入参：Ladder

	* 新增出参：Currency


修改数据结构：

* [InstanceInfo](https://cloud.tencent.com/document/api/236/15878#InstanceInfo)

	* 新增成员：EngineType, MaxDelayTime


### 第 97 次发布

发布时间：2022-08-30 06:13:27

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeParamTemplates](https://cloud.tencent.com/document/api/236/32659)

	* 新增入参：EngineTypes, TemplateNames, TemplateIds


### 第 96 次发布

发布时间：2022-08-01 11:27:47

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [ModifyInstancePasswordComplexity](https://cloud.tencent.com/document/api/236/78162)

### 第 95 次发布

发布时间：2022-07-05 06:08:02

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [OpenAuditService](https://cloud.tencent.com/document/api/236/76408)

修改接口：

* [ModifyAuditConfig](https://cloud.tencent.com/document/api/236/45451)

	* 新增入参：HighLogExpireDay


### 第 94 次发布

发布时间：2022-06-08 06:05:02

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [SellConfig](https://cloud.tencent.com/document/api/236/15878#SellConfig)

	* 新增成员：EngineType


### 第 93 次发布

发布时间：2022-06-02 06:03:38

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeDBInstances](https://cloud.tencent.com/document/api/236/15872)

	* 新增入参：Tags


新增数据结构：

* [Tag](https://cloud.tencent.com/document/api/236/15878#Tag)

### 第 92 次发布

发布时间：2022-05-09 06:03:50

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateDBInstance](https://cloud.tencent.com/document/api/236/15871)

	* 新增入参：EngineType

* [CreateDBInstanceHour](https://cloud.tencent.com/document/api/236/15865)

	* 新增入参：EngineType


### 第 91 次发布

发布时间：2022-04-18 06:07:35

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeBackupConfig](https://cloud.tencent.com/document/api/236/15837)

	* 新增出参：EnableBackupPeriodSave, BackupPeriodSaveDays, BackupPeriodSaveInterval, BackupPeriodSaveCount, StartBackupPeriodSaveDate

* [ModifyBackupConfig](https://cloud.tencent.com/document/api/236/15839)

	* 新增入参：EnableBackupPeriodSave, EnableBackupPeriodLongTermSave, BackupPeriodSaveDays, BackupPeriodSaveInterval, BackupPeriodSaveCount, StartBackupPeriodSaveDate


修改数据结构：

* [BackupInfo](https://cloud.tencent.com/document/api/236/15878#BackupInfo)

	* 新增成员：SaveMode


### 第 90 次发布

发布时间：2022-04-14 06:07:55

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [ResetRootAccount](https://cloud.tencent.com/document/api/236/72551)

修改接口：

* [AddTimeWindow](https://cloud.tencent.com/document/api/236/33891)

	* 新增入参：MaxDelayTime

* [CreateDBInstance](https://cloud.tencent.com/document/api/236/15871)

	* 新增入参：Vips

* [CreateDBInstanceHour](https://cloud.tencent.com/document/api/236/15865)

	* 新增入参：Vips

* [DescribeTimeWindow](https://cloud.tencent.com/document/api/236/33889)

	* 新增出参：MaxDelayTime

* [ModifyTimeWindow](https://cloud.tencent.com/document/api/236/33888)

	* 新增入参：MaxDelayTime


### 第 89 次发布

发布时间：2022-04-07 06:13:17

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeDBInstances](https://cloud.tencent.com/document/api/236/15872)

	* 新增入参：TagValues, UniqueVpcIds, UniqSubnetIds


### 第 88 次发布

发布时间：2022-04-04 06:12:51

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateCloneInstance](https://cloud.tencent.com/document/api/236/50424)

	* 新增入参：ProjectId


### 第 87 次发布

发布时间：2022-03-30 06:02:35

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeAuditPolicies](https://cloud.tencent.com/document/api/236/45453)

	* 新增入参：InstanceName


### 第 86 次发布

发布时间：2022-03-03 08:02:04

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [AuditPolicy](https://cloud.tencent.com/document/api/236/15878#AuditPolicy)

	* 新增成员：InstanceName


### 第 85 次发布

发布时间：2022-02-16 08:02:33

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [ZoneSellConf](https://cloud.tencent.com/document/api/236/15878#ZoneSellConf)

	* 新增成员：ExClusterStatus, ExClusterRemoteRoZone, ExClusterZoneConf


### 第 84 次发布

发布时间：2022-02-14 08:07:04

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeDefaultParams](https://cloud.tencent.com/document/api/236/32662)

	* 新增入参：TemplateType


### 第 83 次发布

发布时间：2022-02-11 08:03:05

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateDBImportJob](https://cloud.tencent.com/document/api/236/15858)

	* 新增入参：CosUrl

	* <font color="#dd0000">**修改入参**：</font>FileName


### 第 82 次发布

发布时间：2022-01-20 08:05:53

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [QueryCDBProxy](https://cloud.tencent.com/document/api/236/68461)

新增数据结构：

* [ProxyGroups](https://cloud.tencent.com/document/api/236/15878#ProxyGroups)
* [RWInfos](https://cloud.tencent.com/document/api/236/15878#RWInfos)

### 第 81 次发布

发布时间：2022-01-17 08:04:00

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeCDBProxy](https://cloud.tencent.com/document/api/236/68170)

	* 新增出参：Count, ProxyGroup


新增数据结构：

* [ProxyGroup](https://cloud.tencent.com/document/api/236/15878#ProxyGroup)

### 第 80 次发布

发布时间：2022-01-14 08:06:35

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [ApplyCDBProxy](https://cloud.tencent.com/document/api/236/68172)
* [CloseCDBProxy](https://cloud.tencent.com/document/api/236/68171)
* [DescribeCDBProxy](https://cloud.tencent.com/document/api/236/68170)
* [DescribeLocalBinlogConfig](https://cloud.tencent.com/document/api/236/68174)
* [DescribeProxyConnectionPoolConf](https://cloud.tencent.com/document/api/236/68169)
* [DescribeProxyCustomConf](https://cloud.tencent.com/document/api/236/68168)
* [ModifyCDBProxy](https://cloud.tencent.com/document/api/236/68167)
* [ModifyCDBProxyConnectionPool](https://cloud.tencent.com/document/api/236/68166)
* [ModifyCDBProxyDesc](https://cloud.tencent.com/document/api/236/68165)
* [ModifyCDBProxyVipVPort](https://cloud.tencent.com/document/api/236/68164)
* [ModifyLocalBinlogConfig](https://cloud.tencent.com/document/api/236/68173)
* [ReloadBalanceProxyNode](https://cloud.tencent.com/document/api/236/68163)
* [SwitchCDBProxy](https://cloud.tencent.com/document/api/236/68162)
* [UpgradeCDBProxy](https://cloud.tencent.com/document/api/236/68161)
* [UpgradeCDBProxyVersion](https://cloud.tencent.com/document/api/236/68160)

新增数据结构：

* [Address](https://cloud.tencent.com/document/api/236/15878#Address)
* [BaseGroupInfo](https://cloud.tencent.com/document/api/236/15878#BaseGroupInfo)
* [ConnectionPoolInfo](https://cloud.tencent.com/document/api/236/15878#ConnectionPoolInfo)
* [CustomConfig](https://cloud.tencent.com/document/api/236/15878#CustomConfig)
* [LocalBinlogConfig](https://cloud.tencent.com/document/api/236/15878#LocalBinlogConfig)
* [LocalBinlogConfigDefault](https://cloud.tencent.com/document/api/236/15878#LocalBinlogConfigDefault)
* [PoolConf](https://cloud.tencent.com/document/api/236/15878#PoolConf)
* [ProxyNodeInfo](https://cloud.tencent.com/document/api/236/15878#ProxyNodeInfo)
* [RWInfo](https://cloud.tencent.com/document/api/236/15878#RWInfo)
* [RWInstanceInfo](https://cloud.tencent.com/document/api/236/15878#RWInstanceInfo)
* [RoWeight](https://cloud.tencent.com/document/api/236/15878#RoWeight)
* [Rule](https://cloud.tencent.com/document/api/236/15878#Rule)

### 第 79 次发布

发布时间：2022-01-13 08:11:45

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateParamTemplate](https://cloud.tencent.com/document/api/236/32663)

	* 新增入参：TemplateType

* [DescribeParamTemplateInfo](https://cloud.tencent.com/document/api/236/32660)

	* 新增出参：TemplateType

* [DescribeParamTemplates](https://cloud.tencent.com/document/api/236/32659)

	* 新增入参：EngineVersions


修改数据结构：

* [ParamTemplateInfo](https://cloud.tencent.com/document/api/236/15878#ParamTemplateInfo)

	* 新增成员：TemplateType

* [ParameterDetail](https://cloud.tencent.com/document/api/236/15878#ParameterDetail)

	* 新增成员：MaxFunc, MinFunc


### 第 78 次发布

发布时间：2022-01-10 08:06:53

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateDBInstanceHour](https://cloud.tencent.com/document/api/236/15865)

	* 新增入参：ParamTemplateType


### 第 77 次发布

发布时间：2022-01-06 08:05:45

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateCloneInstance](https://cloud.tencent.com/document/api/236/50424)

	* 新增入参：CageId


### 第 76 次发布

发布时间：2022-01-05 08:04:53

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateDBInstance](https://cloud.tencent.com/document/api/236/15871)

	* 新增入参：ParamTemplateType


### 第 75 次发布

发布时间：2021-12-24 08:06:02

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [StartReplication](https://cloud.tencent.com/document/api/236/66849)
* [StopReplication](https://cloud.tencent.com/document/api/236/66848)

### 第 74 次发布

发布时间：2021-12-22 08:07:40

本次发布包含了以下内容：

改善已有的文档。

<font color="#dd0000">**删除接口**：</font>

* ModifyRoReplicationDelay
* StartDelayReplication
* StopDelayReplication

修改接口：

* [ModifyRoGroupInfo](https://cloud.tencent.com/document/api/236/40938)

	* 新增入参：ReplicationDelayTime

	* 新增出参：AsyncRequestId

* [UpgradeDBInstance](https://cloud.tencent.com/document/api/236/15876)

	* 新增入参：CrossCluster, ZoneId


修改数据结构：

* [RoGroup](https://cloud.tencent.com/document/api/236/15878#RoGroup)

	* 新增成员：DelayReplicationTime

* [RoGroupAttr](https://cloud.tencent.com/document/api/236/15878#RoGroupAttr)

	* 新增成员：ReplicationDelayTime


### 第 73 次发布

发布时间：2021-12-02 08:03:37

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [UpgradeDBInstance](https://cloud.tencent.com/document/api/236/15876)

	* 新增入参：MaxDelayTime

* [UpgradeDBInstanceEngineVersion](https://cloud.tencent.com/document/api/236/15870)

	* 新增入参：MaxDelayTime


### 第 72 次发布

发布时间：2021-11-11 10:57:53

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeBackupDownloadRestriction](https://cloud.tencent.com/document/api/236/63891)
* [ModifyBackupDownloadRestriction](https://cloud.tencent.com/document/api/236/63890)

新增数据结构：

* [BackupLimitVpcItem](https://cloud.tencent.com/document/api/236/15878#BackupLimitVpcItem)

### 第 71 次发布

发布时间：2021-11-01 08:06:13

本次发布包含了以下内容：

改善已有的文档。

<font color="#dd0000">**删除接口**：</font>

* ModifyRoType

### 第 70 次发布

发布时间：2021-10-29 08:01:53

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateBackup](https://cloud.tencent.com/document/api/236/15844)

	* 新增入参：ManualBackupName

* [CreateCloneInstance](https://cloud.tencent.com/document/api/236/50424)

	* 新增入参：DryRun

* [CreateDBInstance](https://cloud.tencent.com/document/api/236/15871)

	* 新增入参：AlarmPolicyIdList, DryRun

* [CreateDBInstanceHour](https://cloud.tencent.com/document/api/236/15865)

	* 新增入参：AlarmPolicyIdList, DryRun


修改数据结构：

* [BackupInfo](https://cloud.tencent.com/document/api/236/15878#BackupInfo)

	* 新增成员：ManualBackupName


### 第 69 次发布

发布时间：2021-10-21 11:16:58

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateCloneInstance](https://cloud.tencent.com/document/api/236/50424)

	* 新增入参：DeployGroupId


### 第 68 次发布

发布时间：2021-09-26 15:02:28

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateDBInstance](https://cloud.tencent.com/document/api/236/15871)

	* 新增入参：CageId

* [CreateDBInstanceHour](https://cloud.tencent.com/document/api/236/15865)

	* 新增入参：CageId

* [DescribeDBInstances](https://cloud.tencent.com/document/api/236/15872)

	* 新增入参：CageIds


### 第 67 次发布

发布时间：2021-08-25 08:03:59

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [AuditLogFilter](https://cloud.tencent.com/document/api/236/15878#AuditLogFilter)

	* 新增成员：SqlTypes, Sqls


### 第 66 次发布

发布时间：2021-08-24 08:04:24

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [ModifyAccountHost](https://cloud.tencent.com/document/api/236/60617)

### 第 65 次发布

发布时间：2021-08-20 08:04:01

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeAuditConfig](https://cloud.tencent.com/document/api/236/45455)

	* 新增出参：CreateTime


### 第 64 次发布

发布时间：2021-08-11 08:04:02

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [UpgradeDBInstance](https://cloud.tencent.com/document/api/236/15876)

	* 新增入参：FastUpgrade


### 第 63 次发布

发布时间：2021-06-08 08:03:57

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [UpgradeDBInstance](https://cloud.tencent.com/document/api/236/15876)

	* 新增入参：DeviceType, Cpu


### 第 62 次发布

发布时间：2021-05-25 08:03:54

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeDBInstances](https://cloud.tencent.com/document/api/236/15872)

	* 新增入参：TagKeysForSearch

* [DescribeDBPrice](https://cloud.tencent.com/document/api/236/18566)

	* 新增入参：InstanceId

	* <font color="#dd0000">**修改入参**：</font>Zone, GoodsNum, Memory, Volume, PayType


### 第 61 次发布

发布时间：2021-05-24 08:03:21

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [ModifyAccountMaxUserConnections](https://cloud.tencent.com/document/api/236/56200)

修改接口：

* [CreateAccounts](https://cloud.tencent.com/document/api/236/17502)

	* 新增入参：MaxUserConnections

* [DescribeAccounts](https://cloud.tencent.com/document/api/236/17499)

	* 新增出参：MaxUserConnections

* [ModifyAccountPrivileges](https://cloud.tencent.com/document/api/236/17496)

	* 新增入参：ModifyAction


新增数据结构：

* [TagInfoItem](https://cloud.tencent.com/document/api/236/15878#TagInfoItem)

修改数据结构：

* [AccountInfo](https://cloud.tencent.com/document/api/236/15878#AccountInfo)

	* 新增成员：MaxUserConnections

* [InstanceInfo](https://cloud.tencent.com/document/api/236/15878#InstanceInfo)

	* 新增成员：TagList


### 第 60 次发布

发布时间：2021-03-30 08:03:14

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeAuditConfig](https://cloud.tencent.com/document/api/236/45455)

	* 新增出参：IsClosing

* [DescribeDBInstanceConfig](https://cloud.tencent.com/document/api/236/17491)

	* 新增出参：Switched

* [DescribeDatabases](https://cloud.tencent.com/document/api/236/17493)

	* 新增出参：DatabaseList

* [DescribeParamTemplateInfo](https://cloud.tencent.com/document/api/236/32660)

	* 新增出参：Description

* [DescribeProjectSecurityGroups](https://cloud.tencent.com/document/api/236/15850)

	* 新增出参：TotalCount


新增数据结构：

* [DatabasesWithCharacterLists](https://cloud.tencent.com/document/api/236/15878#DatabasesWithCharacterLists)

### 第 59 次发布

发布时间：2021-03-24 08:03:08

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [SellConfig](https://cloud.tencent.com/document/api/236/15878#SellConfig)

	* 新增成员：DeviceType, DeviceTypeName


### 第 58 次发布

发布时间：2021-03-02 08:03:14

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [AssociateSecurityGroups](https://cloud.tencent.com/document/api/236/15852)

	* 新增入参：ForReadonlyInstance

* [CreateDBInstance](https://cloud.tencent.com/document/api/236/15871)

	* 新增入参：AutoSyncFlag

* [CreateDBInstanceHour](https://cloud.tencent.com/document/api/236/15865)

	* 新增入参：AutoSyncFlag

* [DescribeDBSecurityGroups](https://cloud.tencent.com/document/api/236/15854)

	* 新增入参：ForReadonlyInstance

* [DisassociateSecurityGroups](https://cloud.tencent.com/document/api/236/15851)

	* 新增入参：ForReadonlyInstance

* [ModifyDBInstanceSecurityGroups](https://cloud.tencent.com/document/api/236/15853)

	* 新增入参：ForReadonlyInstance


修改数据结构：

* [Inbound](https://cloud.tencent.com/document/api/236/15878#Inbound)

	* 新增成员：Desc

* [Outbound](https://cloud.tencent.com/document/api/236/15878#Outbound)

	* 新增成员：Desc


### 第 57 次发布

发布时间：2021-03-01 08:02:55

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [InstanceInfo](https://cloud.tencent.com/document/api/236/15878#InstanceInfo)

	* 新增成员：InstanceNodes


### 第 56 次发布

发布时间：2021-02-26 08:02:40

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateCloneInstance](https://cloud.tencent.com/document/api/236/50424)

	* 新增入参：InstanceNodes

* [CreateDBInstance](https://cloud.tencent.com/document/api/236/15871)

	* 新增入参：InstanceNodes, Cpu

* [CreateDBInstanceHour](https://cloud.tencent.com/document/api/236/15865)

	* 新增入参：InstanceNodes, Cpu

* [DescribeDBPrice](https://cloud.tencent.com/document/api/236/18566)

	* 新增入参：InstanceNodes, Cpu

* [InquiryPriceUpgradeInstances](https://cloud.tencent.com/document/api/236/32665)

	* 新增入参：InstanceNodes


### 第 55 次发布

发布时间：2021-01-28 08:02:49

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [SwitchDrInstanceToMaster](https://cloud.tencent.com/document/api/236/52562)

### 第 54 次发布

发布时间：2021-01-19 08:03:10

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [SwitchDBInstanceMasterSlave](https://cloud.tencent.com/document/api/236/52171)

### 第 53 次发布

发布时间：2021-01-14 08:03:04

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeErrorLogData](https://cloud.tencent.com/document/api/236/43041)

	* 新增入参：InstType

* [DescribeSlowLogData](https://cloud.tencent.com/document/api/236/43060)

	* 新增入参：InstType


### 第 52 次发布

发布时间：2020-12-03 08:02:41

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [ModifyRoReplicationDelay](https://cloud.tencent.com/document/api/236/50619)
* [ModifyRoType](https://cloud.tencent.com/document/api/236/50618)
* [StartDelayReplication](https://cloud.tencent.com/document/api/236/50617)
* [StopDelayReplication](https://cloud.tencent.com/document/api/236/50616)

### 第 51 次发布

发布时间：2020-11-30 08:09:51

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateCloneInstance](https://cloud.tencent.com/document/api/236/50424)
* [DescribeCloneList](https://cloud.tencent.com/document/api/236/50423)
* [StopRollback](https://cloud.tencent.com/document/api/236/50422)

新增数据结构：

* [CloneItem](https://cloud.tencent.com/document/api/236/15878#CloneItem)

### 第 50 次发布

发布时间：2020-11-26 08:02:19

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [Parameter](https://cloud.tencent.com/document/api/236/15878#Parameter)

	* <font color="#dd0000">**修改成员**：</font>Name, CurrentValue


### 第 49 次发布

发布时间：2020-11-03 08:02:46

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeDBPrice](https://cloud.tencent.com/document/api/236/18566)

	* 新增入参：DeviceType

* [InquiryPriceUpgradeInstances](https://cloud.tencent.com/document/api/236/32665)

	* 新增入参：DeviceType


### 第 48 次发布

发布时间：2020-11-02 08:02:23

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateDBInstance](https://cloud.tencent.com/document/api/236/15871)

	* 新增入参：ParamTemplateId, AlarmPolicyList

* [CreateDBInstanceHour](https://cloud.tencent.com/document/api/236/15865)

	* 新增入参：ParamTemplateId, AlarmPolicyList

* [DescribeProjectSecurityGroups](https://cloud.tencent.com/document/api/236/15850)

	* <font color="#dd0000">**修改入参**：</font>ProjectId


### 第 47 次发布

发布时间：2020-10-23 08:03:07

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeDBInstanceInfo](https://cloud.tencent.com/document/api/236/44160)

	* 新增出参：DefaultKmsRegion


### 第 46 次发布

发布时间：2020-09-28 08:03:03

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [DeviceDiskInfo](https://cloud.tencent.com/document/api/236/15878#DeviceDiskInfo)

	* 新增成员：CapacityRatio


### 第 45 次发布

发布时间：2020-07-22 08:06:46

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateRoInstanceIp](https://cloud.tencent.com/document/api/236/46596)

修改接口：

* [DeleteAuditPolicy](https://cloud.tencent.com/document/api/236/45457)

	* 新增入参：InstanceId


### 第 44 次发布

发布时间：2020-07-08 08:06:07

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [ModifyInstanceParam](https://cloud.tencent.com/document/api/236/15860)

	* 新增入参：TemplateId, WaitSwitch

	* <font color="#dd0000">**修改入参**：</font>ParamList


### 第 43 次发布

发布时间：2020-07-07 08:06:09

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeRoMinScale](https://cloud.tencent.com/document/api/236/46009)

### 第 42 次发布

发布时间：2020-06-12 08:07:33

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [UpgradeDBInstanceEngineVersion](https://cloud.tencent.com/document/api/236/15870)

	* 新增入参：UpgradeSubversion


### 第 41 次发布

发布时间：2020-06-10 08:06:06

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateAuditLogFile](https://cloud.tencent.com/document/api/236/45461)
* [CreateAuditPolicy](https://cloud.tencent.com/document/api/236/45460)
* [CreateAuditRule](https://cloud.tencent.com/document/api/236/45459)
* [DeleteAuditLogFile](https://cloud.tencent.com/document/api/236/45458)
* [DeleteAuditPolicy](https://cloud.tencent.com/document/api/236/45457)
* [DeleteAuditRule](https://cloud.tencent.com/document/api/236/45456)
* [DescribeAuditConfig](https://cloud.tencent.com/document/api/236/45455)
* [DescribeAuditLogFiles](https://cloud.tencent.com/document/api/236/45454)
* [DescribeAuditPolicies](https://cloud.tencent.com/document/api/236/45453)
* [DescribeAuditRules](https://cloud.tencent.com/document/api/236/45452)
* [ModifyAuditConfig](https://cloud.tencent.com/document/api/236/45451)
* [ModifyAuditRule](https://cloud.tencent.com/document/api/236/45450)

新增数据结构：

* [AuditFilter](https://cloud.tencent.com/document/api/236/15878#AuditFilter)
* [AuditLogFile](https://cloud.tencent.com/document/api/236/15878#AuditLogFile)
* [AuditLogFilter](https://cloud.tencent.com/document/api/236/15878#AuditLogFilter)
* [AuditPolicy](https://cloud.tencent.com/document/api/236/15878#AuditPolicy)
* [AuditRule](https://cloud.tencent.com/document/api/236/15878#AuditRule)

### 第 40 次发布

发布时间：2020-04-30 08:05:56

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeDBInstanceInfo](https://cloud.tencent.com/document/api/236/44160)

### 第 39 次发布

发布时间：2020-04-29 08:06:13

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeRollbackTaskDetail](https://cloud.tencent.com/document/api/236/44047)

新增数据结构：

* [RollbackTask](https://cloud.tencent.com/document/api/236/15878#RollbackTask)

### 第 38 次发布

发布时间：2020-04-17 08:05:09

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [RenewDBInstance](https://cloud.tencent.com/document/api/236/30160)

	* 新增入参：ModifyPayType


### 第 37 次发布

发布时间：2020-04-15 08:06:12

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateDBInstance](https://cloud.tencent.com/document/api/236/15871)

	* 新增入参：DeviceType

* [CreateDBInstanceHour](https://cloud.tencent.com/document/api/236/15865)

	* 新增入参：DeviceType


### 第 36 次发布

发布时间：2020-04-13 08:05:16

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeAccounts](https://cloud.tencent.com/document/api/236/17499)

	* 新增入参：AccountRegexp

* [ModifyDBInstanceVipVport](https://cloud.tencent.com/document/api/236/15867)

	* 新增入参：ReleaseDuration


### 第 35 次发布

发布时间：2020-04-02 08:04:57

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeSLowLogData](https://cloud.tencent.com/document/api/236/43060)

修改接口：

* [CreateDeployGroup](https://cloud.tencent.com/document/api/236/38681)

	* 新增入参：DevClass


新增数据结构：

* [SlowLogItem](https://cloud.tencent.com/document/api/236/15878#SlowLogItem)

### 第 34 次发布

发布时间：2020-04-01 08:10:41

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeErrorLogData](https://cloud.tencent.com/document/api/236/43041)

新增数据结构：

* [ErrlogItem](https://cloud.tencent.com/document/api/236/15878#ErrlogItem)

### 第 33 次发布

发布时间：2020-03-23 08:04:09

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [SellConfig](https://cloud.tencent.com/document/api/236/15878#SellConfig)

	* 新增成员：Tag

* [ZoneSellConf](https://cloud.tencent.com/document/api/236/15878#ZoneSellConf)

	* 新增成员：IsSupportRemoteRo, RemoteRoZone


### 第 32 次发布

发布时间：2020-03-16 08:04:58

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [InstanceInfo](https://cloud.tencent.com/document/api/236/15878#InstanceInfo)

	* 新增成员：ZoneId


### 第 31 次发布

发布时间：2020-02-19 17:23:26

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [BinlogInfo](https://cloud.tencent.com/document/api/236/15878#BinlogInfo)

	* 新增成员：BinlogStartTime, BinlogFinishTime


### 第 30 次发布

发布时间：2020-02-12 22:03:42

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeBackupOverview](https://cloud.tencent.com/document/api/236/41229)
* [DescribeBackupSummaries](https://cloud.tencent.com/document/api/236/41228)
* [DescribeBinlogBackupOverview](https://cloud.tencent.com/document/api/236/41227)
* [DescribeDataBackupOverview](https://cloud.tencent.com/document/api/236/41226)

新增数据结构：

* [BackupSummaryItem](https://cloud.tencent.com/document/api/236/15878#BackupSummaryItem)

修改数据结构：

* [BackupInfo](https://cloud.tencent.com/document/api/236/15878#BackupInfo)

	* 新增成员：StartTime, Method, Way


### 第 29 次发布

发布时间：2020-01-16 18:25:02

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [DeployGroupInfo](https://cloud.tencent.com/document/api/236/15878#DeployGroupInfo)

	* 新增成员：DevClass


### 第 28 次发布

发布时间：2020-01-09 10:24:44

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [BalanceRoGroupLoad](https://cloud.tencent.com/document/api/236/40940)
* [DescribeRoGroups](https://cloud.tencent.com/document/api/236/40939)
* [ModifyRoGroupInfo](https://cloud.tencent.com/document/api/236/40938)
* [ReleaseIsolatedDBInstances](https://cloud.tencent.com/document/api/236/40937)

修改接口：

* [DescribeBackupConfig](https://cloud.tencent.com/document/api/236/15837)

	* 新增出参：BackupTimeWindow


新增数据结构：

* [ReleaseResult](https://cloud.tencent.com/document/api/236/15878#ReleaseResult)
* [RoGroupAttr](https://cloud.tencent.com/document/api/236/15878#RoGroupAttr)
* [RoWeightValue](https://cloud.tencent.com/document/api/236/15878#RoWeightValue)

修改数据结构：

* [RoGroup](https://cloud.tencent.com/document/api/236/15878#RoGroup)

	* 新增成员：UniqVpcId, UniqSubnetId, RoGroupRegion, RoGroupZone


### 第 27 次发布

发布时间：2019-12-27 19:47:36

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateDeployGroup](https://cloud.tencent.com/document/api/236/38681)

	* 新增入参：Affinity, LimitNum

* [DescribeDBInstances](https://cloud.tencent.com/document/api/236/15872)

	* 新增入参：DeployGroupIds


修改数据结构：

* [DeployGroupInfo](https://cloud.tencent.com/document/api/236/15878#DeployGroupInfo)

	* 新增成员：Affinity, LimitNum

* [InstanceInfo](https://cloud.tencent.com/document/api/236/15878#InstanceInfo)

	* 新增成员：DeployGroupId


### 第 26 次发布

发布时间：2019-11-21 21:56:43

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateDBInstance](https://cloud.tencent.com/document/api/236/15871)

	* 新增入参：ClientToken

* [CreateDBInstanceHour](https://cloud.tencent.com/document/api/236/15865)

	* 新增入参：ClientToken

* [DescribeTasks](https://cloud.tencent.com/document/api/236/15848)

	* <font color="#dd0000">**修改出参**：</font>Items


新增数据结构：

* [TaskDetail](https://cloud.tencent.com/document/api/236/15878#TaskDetail)

修改数据结构：

* [SlowLogInfo](https://cloud.tencent.com/document/api/236/15878#SlowLogInfo)

	* <font color="#dd0000">**修改成员**：</font>Date


### 第 25 次发布

发布时间：2019-10-24 19:10:38

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateDeployGroup](https://cloud.tencent.com/document/api/236/38681)
* [DeleteDeployGroups](https://cloud.tencent.com/document/api/236/38680)
* [DescribeDeployGroupList](https://cloud.tencent.com/document/api/236/38679)
* [ModifyNameOrDescByDpId](https://cloud.tencent.com/document/api/236/38678)

修改接口：

* [ModifyBackupConfig](https://cloud.tencent.com/document/api/236/15839)

	* 新增入参：BackupTimeWindow


新增数据结构：

* [CommonTimeWindow](https://cloud.tencent.com/document/api/236/15878#CommonTimeWindow)
* [DeployGroupInfo](https://cloud.tencent.com/document/api/236/15878#DeployGroupInfo)

### 第 24 次发布

发布时间：2019-10-11 21:21:52

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateDBInstance](https://cloud.tencent.com/document/api/236/15871)

	* 新增入参：DeployGroupId

* [CreateDBInstanceHour](https://cloud.tencent.com/document/api/236/15865)

	* 新增入参：DeployGroupId


### 第 23 次发布

发布时间：2019-07-26 10:22:32

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [ModifyBackupConfig](https://cloud.tencent.com/document/api/236/15839)

	* 新增入参：BinlogExpireDays


### 第 22 次发布

发布时间：2019-07-13 00:41:37

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [OfflineIsolatedInstances](https://cloud.tencent.com/document/api/236/36197)

### 第 21 次发布

发布时间：2019-06-20 15:37:57

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [InstanceInfo](https://cloud.tencent.com/document/api/236/15878#InstanceInfo)

	* 新增成员：DeviceClass


### 第 20 次发布

发布时间：2019-04-12 11:06:07

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateBackup](https://cloud.tencent.com/document/api/236/15844)

	* 新增入参：BackupDBTableList


新增数据结构：

* [BackupItem](https://cloud.tencent.com/document/api/236/15878#BackupItem)

修改数据结构：

* [BackupConfig](https://cloud.tencent.com/document/api/236/15878#BackupConfig)

	* <font color="#dd0000">**修改成员**：</font>Vport


### 第 19 次发布

发布时间：2019-03-22 14:45:10

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [AddTimeWindow](https://cloud.tencent.com/document/api/236/33891)
* [DeleteTimeWindow](https://cloud.tencent.com/document/api/236/33890)
* [DescribeTimeWindow](https://cloud.tencent.com/document/api/236/33889)
* [ModifyTimeWindow](https://cloud.tencent.com/document/api/236/33888)

### 第 18 次发布

发布时间：2019-02-28 20:09:20

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [ZoneSellConf](https://cloud.tencent.com/document/api/236/15878#ZoneSellConf)

	* 新增成员：DrZone


### 第 17 次发布

发布时间：2019-02-22 14:26:42

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [InstanceInfo](https://cloud.tencent.com/document/api/236/15878#InstanceInfo)

	* 新增成员：Qps, ZoneName


### 第 16 次发布

发布时间：2019-01-24 14:45:31

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DeleteParamTemplate](https://cloud.tencent.com/document/api/236/32824)
* [DescribeSupportedPrivileges](https://cloud.tencent.com/document/api/236/32825)

### 第 15 次发布

发布时间：2019-01-18 20:33:05

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateParamTemplate](https://cloud.tencent.com/document/api/236/32663)
* [DescribeDefaultParams](https://cloud.tencent.com/document/api/236/32662)
* [DescribeDeviceMonitorInfo](https://cloud.tencent.com/document/api/236/32668)
* [DescribeInstanceParamRecords](https://cloud.tencent.com/document/api/236/32661)
* [DescribeParamTemplateInfo](https://cloud.tencent.com/document/api/236/32660)
* [DescribeParamTemplates](https://cloud.tencent.com/document/api/236/32659)
* [DescribeTagsOfInstanceIds](https://cloud.tencent.com/document/api/236/32666)
* [InquiryPriceUpgradeInstances](https://cloud.tencent.com/document/api/236/32665)
* [ModifyInstanceTag](https://cloud.tencent.com/document/api/236/32664)
* [ModifyParamTemplate](https://cloud.tencent.com/document/api/236/32658)

新增数据结构：

* [DeviceCpuInfo](https://cloud.tencent.com/document/api/236/15878#DeviceCpuInfo)
* [DeviceCpuRateInfo](https://cloud.tencent.com/document/api/236/15878#DeviceCpuRateInfo)
* [DeviceDiskInfo](https://cloud.tencent.com/document/api/236/15878#DeviceDiskInfo)
* [DeviceMemInfo](https://cloud.tencent.com/document/api/236/15878#DeviceMemInfo)
* [DeviceNetInfo](https://cloud.tencent.com/document/api/236/15878#DeviceNetInfo)
* [ParamRecord](https://cloud.tencent.com/document/api/236/15878#ParamRecord)
* [ParamTemplateInfo](https://cloud.tencent.com/document/api/236/15878#ParamTemplateInfo)
* [TagInfoUnit](https://cloud.tencent.com/document/api/236/15878#TagInfoUnit)
* [TagsInfoOfInstance](https://cloud.tencent.com/document/api/236/15878#TagsInfoOfInstance)

### 第 14 次发布

发布时间：2018-12-20 20:32:55

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateDBInstance](https://cloud.tencent.com/document/api/236/15871)

	* 新增入参：ResourceTags

* [CreateDBInstanceHour](https://cloud.tencent.com/document/api/236/15865)

	* 新增入参：ResourceTags


新增数据结构：

* [TagInfo](https://cloud.tencent.com/document/api/236/15878#TagInfo)

修改数据结构：

* [InstanceInfo](https://cloud.tencent.com/document/api/236/15878#InstanceInfo)

	* 新增成员：Cpu


### 第 13 次发布

发布时间：2018-11-22 19:48:07

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [InstanceInfo](https://cloud.tencent.com/document/api/236/15878#InstanceInfo)

	* 新增成员：PhysicalId


### 第 12 次发布

发布时间：2018-10-26 14:33:40

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeUploadedFiles](https://cloud.tencent.com/document/api/236/30161)
* [RenewDBInstance](https://cloud.tencent.com/document/api/236/30160)

新增数据结构：

* [SlaveInstanceInfo](https://cloud.tencent.com/document/api/236/15878#SlaveInstanceInfo)
* [SqlFileInfo](https://cloud.tencent.com/document/api/236/15878#SqlFileInfo)
* [UploadInfo](https://cloud.tencent.com/document/api/236/15878#UploadInfo)

<font color="#dd0000">**删除数据结构**：</font>

* First

修改数据结构：

* [SlaveInfo](https://cloud.tencent.com/document/api/236/15878#SlaveInfo)

	* <font color="#dd0000">**修改成员**：</font>First, Second


### 第 11 次发布

发布时间：2018-10-11 15:32:18

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeAsyncRequestInfo](https://cloud.tencent.com/document/api/236/20410)
* [DescribeInstanceParams](https://cloud.tencent.com/document/api/236/20411)

新增数据结构：

* [ParameterDetail](https://cloud.tencent.com/document/api/236/15878#ParameterDetail)

### 第 10 次发布

发布时间：2018-09-07 11:31:31

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [ModifyAutoRenewFlag](https://cloud.tencent.com/document/api/236/19652)

### 第 9 次发布

发布时间：2018-08-02 15:48:57

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeRollbackRangeTime](https://cloud.tencent.com/document/api/236/18726)
* [DescribeTables](https://cloud.tencent.com/document/api/236/18727)
* [StartBatchRollback](https://cloud.tencent.com/document/api/236/18725)

新增数据结构：

* [InstanceRollbackRangeTime](https://cloud.tencent.com/document/api/236/15878#InstanceRollbackRangeTime)
* [RollbackDBName](https://cloud.tencent.com/document/api/236/15878#RollbackDBName)
* [RollbackInstancesInfo](https://cloud.tencent.com/document/api/236/15878#RollbackInstancesInfo)
* [RollbackTableName](https://cloud.tencent.com/document/api/236/15878#RollbackTableName)
* [RollbackTables](https://cloud.tencent.com/document/api/236/15878#RollbackTables)
* [RollbackTimeRange](https://cloud.tencent.com/document/api/236/15878#RollbackTimeRange)

### 第 8 次发布

发布时间：2018-07-26 12:22:36

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeDBPrice](https://cloud.tencent.com/document/api/236/18566)

### 第 7 次发布

发布时间：2018-07-12 16:12:26

本次发布包含了以下内容：

改善已有的文档。

<font color="#dd0000">**删除接口**：</font>

* DescribeBackupDownloadDbTableCode

<font color="#dd0000">**删除数据结构**：</font>

* DatabaseTableList

### 第 6 次发布

发布时间：2018-07-05 14:15:06

本次发布包含了以下内容：

改善已有的文档。

新增数据结构：

* [RoInstanceInfo](https://cloud.tencent.com/document/api/236/15878#RoInstanceInfo)

修改数据结构：

* [InstanceInfo](https://cloud.tencent.com/document/api/236/15878#InstanceInfo)

	* <font color="#dd0000">**修改成员**：</font>RoVipInfo

* [RoGroup](https://cloud.tencent.com/document/api/236/15878#RoGroup)

	* 新增成员：RoInstances, Vip, Vport


### 第 5 次发布

发布时间：2018-06-14 12:15:42

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateBackup](https://cloud.tencent.com/document/api/236/15844)

	* 新增出参：BackupId

* [CreateDBInstance](https://cloud.tencent.com/document/api/236/15871)

	* <font color="#dd0000">**修改出参**：</font>DealIds

* [CreateDBInstanceHour](https://cloud.tencent.com/document/api/236/15865)

	* <font color="#dd0000">**修改出参**：</font>DealIds

* [DescribeBackupTables](https://cloud.tencent.com/document/api/236/15846)

	* <font color="#dd0000">**修改入参**：</font>SearchTable

* [UpgradeDBInstance](https://cloud.tencent.com/document/api/236/15876)

	* <font color="#dd0000">**删除出参**：</font>DealNames


修改数据结构：

* [RoGroup](https://cloud.tencent.com/document/api/236/15878#RoGroup)

	* <font color="#dd0000">**修改成员**：</font>RoGroupMode


### 第 4 次发布

发布时间：2018-05-31 14:45:35

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateAccounts](https://cloud.tencent.com/document/api/236/17502)
* [DeleteAccounts](https://cloud.tencent.com/document/api/236/17501)
* [DescribeAccountPrivileges](https://cloud.tencent.com/document/api/236/17500)
* [DescribeAccounts](https://cloud.tencent.com/document/api/236/17499)
* [DescribeDBInstanceConfig](https://cloud.tencent.com/document/api/236/17491)
* [DescribeDBSwitchRecords](https://cloud.tencent.com/document/api/236/17490)
* [DescribeDatabases](https://cloud.tencent.com/document/api/236/17493)
* [ModifyAccountDescription](https://cloud.tencent.com/document/api/236/17498)
* [ModifyAccountPassword](https://cloud.tencent.com/document/api/236/17497)
* [ModifyAccountPrivileges](https://cloud.tencent.com/document/api/236/17496)
* [OpenDBInstanceGTID](https://cloud.tencent.com/document/api/236/17489)
* [RestartDBInstances](https://cloud.tencent.com/document/api/236/17488)
* [VerifyRootAccount](https://cloud.tencent.com/document/api/236/17495)

新增数据结构：

* [Account](https://cloud.tencent.com/document/api/236/15878#Account)
* [AccountInfo](https://cloud.tencent.com/document/api/236/15878#AccountInfo)
* [BackupConfig](https://cloud.tencent.com/document/api/236/15878#BackupConfig)
* [ColumnPrivilege](https://cloud.tencent.com/document/api/236/15878#ColumnPrivilege)
* [DBSwitchInfo](https://cloud.tencent.com/document/api/236/15878#DBSwitchInfo)
* [DatabasePrivilege](https://cloud.tencent.com/document/api/236/15878#DatabasePrivilege)
* [SlaveConfig](https://cloud.tencent.com/document/api/236/15878#SlaveConfig)
* [TablePrivilege](https://cloud.tencent.com/document/api/236/15878#TablePrivilege)

### 第 3 次发布

发布时间：2018-05-17 15:58:40

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeDBZoneConfig](https://cloud.tencent.com/document/api/236/17229)

新增数据结构：

* [RegionSellConf](https://cloud.tencent.com/document/api/236/15878#RegionSellConf)
* [SellConfig](https://cloud.tencent.com/document/api/236/15878#SellConfig)
* [SellType](https://cloud.tencent.com/document/api/236/15878#SellType)
* [ZoneConf](https://cloud.tencent.com/document/api/236/15878#ZoneConf)
* [ZoneSellConf](https://cloud.tencent.com/document/api/236/15878#ZoneSellConf)

修改数据结构：

* [InstanceInfo](https://cloud.tencent.com/document/api/236/15878#InstanceInfo)

	* 新增成员：UniqVpcId, UniqSubnetId


### 第 2 次发布

发布时间：2018-05-11 10:47:37

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [InstanceInfo](https://cloud.tencent.com/document/api/236/15878#InstanceInfo)

	* <font color="#dd0000">**修改成员**：</font>RoVipInfo


### 第 1 次发布

发布时间：2018-04-24

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [AssociateSecurityGroups](https://cloud.tencent.com/document/api/236/15852)
* [CloseWanService](https://cloud.tencent.com/document/api/236/15863)
* [CreateBackup](https://cloud.tencent.com/document/api/236/15844)
* [CreateDBImportJob](https://cloud.tencent.com/document/api/236/15858)
* [CreateDBInstance](https://cloud.tencent.com/document/api/236/15871)
* [CreateDBInstanceHour](https://cloud.tencent.com/document/api/236/15865)
* [DeleteBackup](https://cloud.tencent.com/document/api/236/15841)
* [DescribeBackupConfig](https://cloud.tencent.com/document/api/236/15837)
* [DescribeBackupDatabases](https://cloud.tencent.com/document/api/236/15840)
* [DescribeBackupDownloadDbTableCode](https://cloud.tencent.com/document/api/#/#)
* [DescribeBackupTables](https://cloud.tencent.com/document/api/236/15846)
* [DescribeBackups](https://cloud.tencent.com/document/api/236/15842)
* [DescribeBinlogs](https://cloud.tencent.com/document/api/236/15843)
* [DescribeDBImportRecords](https://cloud.tencent.com/document/api/236/15856)
* [DescribeDBInstanceCharset](https://cloud.tencent.com/document/api/236/15866)
* [DescribeDBInstanceGTID](https://cloud.tencent.com/document/api/236/15862)
* [DescribeDBInstanceRebootTime](https://cloud.tencent.com/document/api/236/15874)
* [DescribeDBInstances](https://cloud.tencent.com/document/api/236/15872)
* [DescribeDBSecurityGroups](https://cloud.tencent.com/document/api/236/15854)
* [DescribeProjectSecurityGroups](https://cloud.tencent.com/document/api/236/15850)
* [DescribeSlowLogs](https://cloud.tencent.com/document/api/236/15845)
* [DescribeTasks](https://cloud.tencent.com/document/api/236/15848)
* [DisassociateSecurityGroups](https://cloud.tencent.com/document/api/236/15851)
* [InitDBInstances](https://cloud.tencent.com/document/api/236/15873)
* [IsolateDBInstance](https://cloud.tencent.com/document/api/236/15869)
* [ModifyBackupConfig](https://cloud.tencent.com/document/api/236/15839)
* [ModifyDBInstanceName](https://cloud.tencent.com/document/api/236/15877)
* [ModifyDBInstanceProject](https://cloud.tencent.com/document/api/236/15868)
* [ModifyDBInstanceSecurityGroups](https://cloud.tencent.com/document/api/236/15853)
* [ModifyDBInstanceVipVport](https://cloud.tencent.com/document/api/236/15867)
* [ModifyInstanceParam](https://cloud.tencent.com/document/api/236/15860)
* [OpenWanService](https://cloud.tencent.com/document/api/236/15875)
* [StopDBImportJob](https://cloud.tencent.com/document/api/236/15857)
* [SwitchForUpgrade](https://cloud.tencent.com/document/api/236/15864)
* [UpgradeDBInstance](https://cloud.tencent.com/document/api/236/15876)
* [UpgradeDBInstanceEngineVersion](https://cloud.tencent.com/document/api/236/15870)

新增数据结构：

* [BackupInfo](https://cloud.tencent.com/document/api/236/15878#BackupInfo)
* [BinlogInfo](https://cloud.tencent.com/document/api/236/15878#BinlogInfo)
* [DatabaseName](https://cloud.tencent.com/document/api/236/15878#DatabaseName)
* [DatabaseTableList](https://cloud.tencent.com/document/api/236/15878#DatabaseTableList)
* [DrInfo](https://cloud.tencent.com/document/api/236/15878#DrInfo)
* [First](https://cloud.tencent.com/document/api/236/15878#First)
* [ImportRecord](https://cloud.tencent.com/document/api/236/15878#ImportRecord)
* [Inbound](https://cloud.tencent.com/document/api/236/15878#Inbound)
* [InstanceInfo](https://cloud.tencent.com/document/api/236/15878#InstanceInfo)
* [InstanceRebootTime](https://cloud.tencent.com/document/api/236/15878#InstanceRebootTime)
* [MasterInfo](https://cloud.tencent.com/document/api/236/15878#MasterInfo)
* [Outbound](https://cloud.tencent.com/document/api/236/15878#Outbound)
* [ParamInfo](https://cloud.tencent.com/document/api/236/15878#ParamInfo)
* [Parameter](https://cloud.tencent.com/document/api/236/15878#Parameter)
* [RoGroup](https://cloud.tencent.com/document/api/236/15878#RoGroup)
* [RoVipInfo](https://cloud.tencent.com/document/api/236/15878#RoVipInfo)
* [SecurityGroup](https://cloud.tencent.com/document/api/236/15878#SecurityGroup)
* [SlaveInfo](https://cloud.tencent.com/document/api/236/15878#SlaveInfo)
* [SlowLogInfo](https://cloud.tencent.com/document/api/236/15878#SlowLogInfo)
* [TableName](https://cloud.tencent.com/document/api/236/15878#TableName)




## 本地专用集群(cdc) 版本：2020-12-14

### 第 10 次发布

发布时间：2024-07-17 01:09:51

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeDedicatedClusterOrders](https://cloud.tencent.com/document/api/1346/73761)

	* 新增入参：OrderTypes


修改数据结构：

* [DedicatedClusterOrder](https://cloud.tencent.com/document/api/1346/73770#DedicatedClusterOrder)

	* 新增成员：CheckStatus, DeliverExpectTime, DeliverFinishTime, CheckExpectTime, CheckFinishTime, OrderSLA, OrderPayPlan


### 第 9 次发布

发布时间：2024-03-12 01:14:14

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeDedicatedClusterCbsStatistics](https://cloud.tencent.com/document/api/1346/104267)

新增数据结构：

* [SetInfo](https://cloud.tencent.com/document/api/1346/73770#SetInfo)

### 第 8 次发布

发布时间：2024-01-03 01:08:25

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeDedicatedClusterOverview](https://cloud.tencent.com/document/api/1346/73760)

	* 新增出参：HostDetailInfo, HostStandbyCount, HostNormalCount


新增数据结构：

* [HostDetailInfo](https://cloud.tencent.com/document/api/1346/73770#HostDetailInfo)

### 第 7 次发布

发布时间：2023-09-12 01:18:51

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeDedicatedClusterHostStatistics](https://cloud.tencent.com/document/api/1346/73764)

	* 新增入参：HostId, StartTime, EndTime, Period


新增数据结构：

* [DetailData](https://cloud.tencent.com/document/api/1346/73770#DetailData)

修改数据结构：

* [HostStatistic](https://cloud.tencent.com/document/api/1346/73770#HostStatistic)

	* 新增成员：CpuAverage, MemAverage, NetAverage, CpuDetailData, MemDetailData, NetRateDetailData, NetPacketDetailData


### 第 6 次发布

发布时间：2023-02-24 01:07:16

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeDedicatedClusterOverview](https://cloud.tencent.com/document/api/1346/73760)

	* 新增出参：VpnConnectionState, VpngwBandwidthData, LocalNetInfo, VpnConnectionBandwidthData


新增数据结构：

* [InBandwidth](https://cloud.tencent.com/document/api/1346/73770#InBandwidth)
* [LocalNetInfo](https://cloud.tencent.com/document/api/1346/73770#LocalNetInfo)
* [OutBandwidth](https://cloud.tencent.com/document/api/1346/73770#OutBandwidth)
* [VpngwBandwidthData](https://cloud.tencent.com/document/api/1346/73770#VpngwBandwidthData)

### 第 5 次发布

发布时间：2023-02-22 01:10:12

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [HostInfo](https://cloud.tencent.com/document/api/1346/73770#HostInfo)

	* 新增成员：HostId


### 第 4 次发布

发布时间：2022-12-15 01:12:58

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [DedicatedClusterOrder](https://cloud.tencent.com/document/api/1346/73770#DedicatedClusterOrder)

	* 新增成员：OrderType


### 第 3 次发布

发布时间：2022-07-30 15:07:54

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [DedicatedClusterOrder](https://cloud.tencent.com/document/api/1346/73770#DedicatedClusterOrder)

	* 新增成员：PayType, TimeUnit, TimeSpan

* [DedicatedClusterOrderItem](https://cloud.tencent.com/document/api/1346/73770#DedicatedClusterOrderItem)

	* 新增成员：TypeFamily, SubOrderPayStatus


### 第 2 次发布

发布时间：2022-05-16 17:18:07

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateDedicatedClusterOrder](https://cloud.tencent.com/document/api/1346/73769)
* [CreateSite](https://cloud.tencent.com/document/api/1346/73768)
* [DeleteDedicatedClusters](https://cloud.tencent.com/document/api/1346/73767)
* [DeleteSites](https://cloud.tencent.com/document/api/1346/73766)
* [DescribeDedicatedClusterCosCapacity](https://cloud.tencent.com/document/api/1346/73765)
* [DescribeDedicatedClusterHostStatistics](https://cloud.tencent.com/document/api/1346/73764)
* [DescribeDedicatedClusterHosts](https://cloud.tencent.com/document/api/1346/73763)
* [DescribeDedicatedClusterInstanceTypes](https://cloud.tencent.com/document/api/1346/73762)
* [DescribeDedicatedClusterOrders](https://cloud.tencent.com/document/api/1346/73761)
* [DescribeDedicatedClusterOverview](https://cloud.tencent.com/document/api/1346/73760)
* [DescribeDedicatedClusterTypes](https://cloud.tencent.com/document/api/1346/73759)
* [DescribeDedicatedClusters](https://cloud.tencent.com/document/api/1346/73758)
* [DescribeDedicatedSupportedZones](https://cloud.tencent.com/document/api/1346/73757)
* [DescribeSites](https://cloud.tencent.com/document/api/1346/73756)
* [DescribeSitesDetail](https://cloud.tencent.com/document/api/1346/73755)
* [ModifyDedicatedClusterInfo](https://cloud.tencent.com/document/api/1346/73754)
* [ModifyOrderStatus](https://cloud.tencent.com/document/api/1346/73753)
* [ModifySiteDeviceInfo](https://cloud.tencent.com/document/api/1346/73752)
* [ModifySiteInfo](https://cloud.tencent.com/document/api/1346/73751)

新增数据结构：

* [CbsInfo](https://cloud.tencent.com/document/api/1346/73770#CbsInfo)
* [CosCapacity](https://cloud.tencent.com/document/api/1346/73770#CosCapacity)
* [CosInfo](https://cloud.tencent.com/document/api/1346/73770#CosInfo)
* [DedicatedCluster](https://cloud.tencent.com/document/api/1346/73770#DedicatedCluster)
* [DedicatedClusterInstanceType](https://cloud.tencent.com/document/api/1346/73770#DedicatedClusterInstanceType)
* [DedicatedClusterOrder](https://cloud.tencent.com/document/api/1346/73770#DedicatedClusterOrder)
* [DedicatedClusterOrderItem](https://cloud.tencent.com/document/api/1346/73770#DedicatedClusterOrderItem)
* [DedicatedClusterType](https://cloud.tencent.com/document/api/1346/73770#DedicatedClusterType)
* [DedicatedClusterTypeInfo](https://cloud.tencent.com/document/api/1346/73770#DedicatedClusterTypeInfo)
* [HostInfo](https://cloud.tencent.com/document/api/1346/73770#HostInfo)
* [HostStatistic](https://cloud.tencent.com/document/api/1346/73770#HostStatistic)
* [RegionZoneInfo](https://cloud.tencent.com/document/api/1346/73770#RegionZoneInfo)
* [Site](https://cloud.tencent.com/document/api/1346/73770#Site)
* [SiteDetail](https://cloud.tencent.com/document/api/1346/73770#SiteDetail)
* [ZoneInfo](https://cloud.tencent.com/document/api/1346/73770#ZoneInfo)

### 第 1 次发布

发布时间：2022-05-16 14:37:22

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateDedicatedCluster](https://cloud.tencent.com/document/api/1346/73710)




## 内容分发网络 CDN(cdn) 版本：2018-06-06

### 第 128 次发布

发布时间：2024-07-26 01:17:46

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [UpdateDomainConfig](https://cloud.tencent.com/document/api/228/41116)

	* 新增入参：ParamFilter


新增数据结构：

* [ParamFilter](https://cloud.tencent.com/document/api/228/30987#ParamFilter)
* [ParamFilterRule](https://cloud.tencent.com/document/api/228/30987#ParamFilterRule)

修改数据结构：

* [DetailDomain](https://cloud.tencent.com/document/api/228/30987#DetailDomain)

	* 新增成员：ParamFilter


### 第 127 次发布

发布时间：2024-05-21 01:17:01

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [AvifAdapter](https://cloud.tencent.com/document/api/228/30987#AvifAdapter)

	* 新增成员：FallbackFormats


### 第 126 次发布

发布时间：2023-07-12 01:11:36

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [HttpsPackage](https://cloud.tencent.com/document/api/228/30987#HttpsPackage)

	* <font color="#dd0000">**修改成员**：</font>AutoExtension


### 第 125 次发布

发布时间：2023-06-28 01:06:57

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [DetailDomain](https://cloud.tencent.com/document/api/228/30987#DetailDomain)

	* <font color="#dd0000">**修改成员**：</font>OthersPrivateAccess


### 第 124 次发布

发布时间：2023-06-26 01:13:28

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [ModifyDomainConfig](https://cloud.tencent.com/document/api/228/94258)

### 第 123 次发布

发布时间：2023-06-09 01:07:13

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [Authentication](https://cloud.tencent.com/document/api/228/30987#Authentication)

	* 新增成员：AuthAlgorithm


### 第 122 次发布

发布时间：2023-06-05 01:12:49

本次发布包含了以下内容：

改善已有的文档。

新增数据结构：

* [OriginSni](https://cloud.tencent.com/document/api/228/30987#OriginSni)

修改数据结构：

* [Origin](https://cloud.tencent.com/document/api/228/30987#Origin)

	* 新增成员：Sni


### 第 121 次发布

发布时间：2023-05-08 01:12:20

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [HttpsPackage](https://cloud.tencent.com/document/api/228/30987#HttpsPackage)

	* 新增成员：AutoExtension


### 第 120 次发布

发布时间：2023-04-28 01:11:33

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribePayType](https://cloud.tencent.com/document/api/228/31295)

	* 新增入参：Type


### 第 119 次发布

发布时间：2023-04-19 01:11:05

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [DomainLog](https://cloud.tencent.com/document/api/228/30987#DomainLog)

	* 新增成员：FileSize


### 第 118 次发布

发布时间：2023-03-31 01:08:16

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [AddCdnDomain](https://cloud.tencent.com/document/api/228/41123)

	* 新增入参：OthersPrivateAccess

* [UpdateDomainConfig](https://cloud.tencent.com/document/api/228/41116)

	* 新增入参：OthersPrivateAccess


新增数据结构：

* [OthersPrivateAccess](https://cloud.tencent.com/document/api/228/30987#OthersPrivateAccess)

修改数据结构：

* [DetailDomain](https://cloud.tencent.com/document/api/228/30987#DetailDomain)

	* 新增成员：OthersPrivateAccess


### 第 117 次发布

发布时间：2023-02-28 01:07:06

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeHttpsPackages](https://cloud.tencent.com/document/api/228/86968)

新增数据结构：

* [HttpsPackage](https://cloud.tencent.com/document/api/228/30987#HttpsPackage)

### 第 116 次发布

发布时间：2023-01-17 01:12:53

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeEdgePackTaskStatus](https://cloud.tencent.com/document/api/228/85848)

新增数据结构：

* [EdgePackTaskFilter](https://cloud.tencent.com/document/api/228/30987#EdgePackTaskFilter)
* [EdgePackTaskStatus](https://cloud.tencent.com/document/api/228/30987#EdgePackTaskStatus)

### 第 115 次发布

发布时间：2023-01-05 01:08:26

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [AddCdnDomain](https://cloud.tencent.com/document/api/228/41123)

	* 新增入参：HttpsBilling

* [UpdateDomainConfig](https://cloud.tencent.com/document/api/228/41116)

	* 新增入参：HttpsBilling


### 第 114 次发布

发布时间：2023-01-04 01:08:35

本次发布包含了以下内容：

改善已有的文档。

新增数据结构：

* [HttpsBilling](https://cloud.tencent.com/document/api/228/30987#HttpsBilling)

修改数据结构：

* [DetailDomain](https://cloud.tencent.com/document/api/228/30987#DetailDomain)

	* 新增成员：HttpsBilling


### 第 113 次发布

发布时间：2022-11-29 06:20:53

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeIpStatus](https://cloud.tencent.com/document/api/228/41954)

	* 新增入参：AbbreviationIpv6


### 第 112 次发布

发布时间：2022-10-25 06:16:59

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeImageConfig](https://cloud.tencent.com/document/api/228/43844)

	* 新增出参：AvifAdapter

* [UpdateImageConfig](https://cloud.tencent.com/document/api/228/43843)

	* 新增入参：AvifAdapter


新增数据结构：

* [AvifAdapter](https://cloud.tencent.com/document/api/228/30987#AvifAdapter)
* [MaxAgeCodeRule](https://cloud.tencent.com/document/api/228/30987#MaxAgeCodeRule)

修改数据结构：

* [ImageOptimization](https://cloud.tencent.com/document/api/228/30987#ImageOptimization)

	* 新增成员：AvifAdapter

* [MaxAge](https://cloud.tencent.com/document/api/228/30987#MaxAge)

	* 新增成员：MaxAgeCodeRule


### 第 111 次发布

发布时间：2022-09-19 06:14:28

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [PushUrlsCache](https://cloud.tencent.com/document/api/228/37869)

	* 新增入参：Headers


新增数据结构：

* [HTTPHeader](https://cloud.tencent.com/document/api/228/30987#HTTPHeader)

### 第 110 次发布

发布时间：2022-08-04 06:14:18

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [AdvancedCCRules](https://cloud.tencent.com/document/api/228/30987#AdvancedCCRules)

	* 新增成员：Switch

* [ScdnConfig](https://cloud.tencent.com/document/api/228/30987#ScdnConfig)

	* 新增成员：GlobalAdvancedRules


### 第 109 次发布

发布时间：2022-07-29 06:04:29

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [PushUrlsCache](https://cloud.tencent.com/document/api/228/37869)

	* 新增入参：UrlEncode


### 第 108 次发布

发布时间：2022-07-25 06:03:43

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeIpStatus](https://cloud.tencent.com/document/api/228/41954)

	* 新增入参：ShowIpv6


修改数据结构：

* [IpStatus](https://cloud.tencent.com/document/api/228/30987#IpStatus)

	* 新增成员：Ipv6


### 第 107 次发布

发布时间：2022-07-11 06:07:38

本次发布包含了以下内容：

改善已有的文档。

新增数据结构：

* [RedirectConfig](https://cloud.tencent.com/document/api/228/30987#RedirectConfig)

修改数据结构：

* [FollowRedirect](https://cloud.tencent.com/document/api/228/30987#FollowRedirect)

	* 新增成员：RedirectConfig


### 第 106 次发布

发布时间：2022-06-30 06:02:27

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [PurgePathCache](https://cloud.tencent.com/document/api/228/37871)

	* 新增入参：Area


### 第 105 次发布

发布时间：2022-06-23 06:08:11

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateVerifyRecord](https://cloud.tencent.com/document/api/228/48118)

	* 新增出参：FileVerifyDomains, FileVerifyName


### 第 104 次发布

发布时间：2022-06-13 06:07:47

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [TrafficPackage](https://cloud.tencent.com/document/api/228/30987#TrafficPackage)

	* 新增成员：TrueEnableTime, TrueExpireTime


### 第 103 次发布

发布时间：2022-06-07 06:02:40

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [AddCLSTopicDomains](https://cloud.tencent.com/document/api/228/74961)

### 第 102 次发布

发布时间：2022-04-25 06:02:44

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateVerifyRecord](https://cloud.tencent.com/document/api/228/48118)

	* 新增出参：FileVerifyUrl

* [VerifyDomainRecord](https://cloud.tencent.com/document/api/228/48117)

	* 新增入参：VerifyType


### 第 101 次发布

发布时间：2022-04-22 06:05:51

本次发布包含了以下内容：

改善已有的文档。

新增数据结构：

* [StatisticItem](https://cloud.tencent.com/document/api/228/30987#StatisticItem)

修改数据结构：

* [BandwidthAlert](https://cloud.tencent.com/document/api/228/30987#BandwidthAlert)

	* 新增成员：StatisticItems


### 第 100 次发布

发布时间：2022-04-21 06:07:58

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeBillingData](https://cloud.tencent.com/document/api/228/41237)

	* 新增入参：TimeZone

* [DescribeCdnData](https://cloud.tencent.com/document/api/228/30986)

	* 新增入参：TimeZone

* [DescribeOriginData](https://cloud.tencent.com/document/api/228/30984)

	* 新增入参：TimeZone

* [UpdateDomainConfig](https://cloud.tencent.com/document/api/228/41116)

	* 新增入参：PostMaxSize


新增数据结构：

* [CacheConfig](https://cloud.tencent.com/document/api/228/30987#CacheConfig)
* [HeuristicCache](https://cloud.tencent.com/document/api/228/30987#HeuristicCache)

修改数据结构：

* [CacheConfigFollowOrigin](https://cloud.tencent.com/document/api/228/30987#CacheConfigFollowOrigin)

	* 新增成员：HeuristicCache


### 第 99 次发布

发布时间：2022-04-18 06:07:58

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [OverseaConfig](https://cloud.tencent.com/document/api/228/30987#OverseaConfig)

	* 新增成员：HwPrivateAccess, QnPrivateAccess


### 第 98 次发布

发布时间：2022-04-14 06:08:21

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [AddCdnDomain](https://cloud.tencent.com/document/api/228/41123)

	* 新增入参：HwPrivateAccess, QnPrivateAccess

* [UpdateDomainConfig](https://cloud.tencent.com/document/api/228/41116)

	* 新增入参：HwPrivateAccess, QnPrivateAccess


新增数据结构：

* [HwPrivateAccess](https://cloud.tencent.com/document/api/228/30987#HwPrivateAccess)
* [QnPrivateAccess](https://cloud.tencent.com/document/api/228/30987#QnPrivateAccess)

修改数据结构：

* [AwsPrivateAccess](https://cloud.tencent.com/document/api/228/30987#AwsPrivateAccess)

	* 新增成员：Region, Bucket

* [DetailDomain](https://cloud.tencent.com/document/api/228/30987#DetailDomain)

	* 新增成员：HwPrivateAccess, QnPrivateAccess

* [MainlandConfig](https://cloud.tencent.com/document/api/228/30987#MainlandConfig)

	* 新增成员：HwPrivateAccess, QnPrivateAccess

* [Origin](https://cloud.tencent.com/document/api/228/30987#Origin)

	* 新增成员：OriginCompany

* [OssPrivateAccess](https://cloud.tencent.com/document/api/228/30987#OssPrivateAccess)

	* 新增成员：Region, Bucket


### 第 97 次发布

发布时间：2022-04-11 06:08:14

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [PushUrlsCache](https://cloud.tencent.com/document/api/228/37869)

	* 新增入参：DisableRange


### 第 96 次发布

发布时间：2022-04-07 06:15:45

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeTrafficPackages](https://cloud.tencent.com/document/api/228/39230)

	* 新增入参：SortBy

	* 新增出参：PaidCount


### 第 95 次发布

发布时间：2022-04-04 06:15:19

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeDiagnoseReport](https://cloud.tencent.com/document/api/228/49325)

	* 新增出参：PurgeInfo


### 第 94 次发布

发布时间：2022-03-28 08:04:33

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [BriefDomain](https://cloud.tencent.com/document/api/228/30987#BriefDomain)

	* 新增成员：ParentHost

* [DetailDomain](https://cloud.tencent.com/document/api/228/30987#DetailDomain)

	* 新增成员：ParentHost


### 第 93 次发布

发布时间：2022-02-17 08:07:01

本次发布包含了以下内容：

改善已有的文档。

新增数据结构：

* [RuleEngine](https://cloud.tencent.com/document/api/228/30987#RuleEngine)

修改数据结构：

* [DetailDomain](https://cloud.tencent.com/document/api/228/30987#DetailDomain)

	* 新增成员：RuleEngine

* [ServerCert](https://cloud.tencent.com/document/api/228/30987#ServerCert)

	* 新增成员：From


### 第 92 次发布

发布时间：2022-01-05 08:05:09

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [MainlandConfig](https://cloud.tencent.com/document/api/228/30987#MainlandConfig)

	* 新增成员：AwsPrivateAccess, OssPrivateAccess

* [OverseaConfig](https://cloud.tencent.com/document/api/228/30987#OverseaConfig)

	* 新增成员：AwsPrivateAccess, OssPrivateAccess


### 第 91 次发布

发布时间：2021-12-17 08:07:56

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeScdnBotRecords](https://cloud.tencent.com/document/api/228/63468)

	* 新增入参：Domains


修改数据结构：

* [BotRecord](https://cloud.tencent.com/document/api/228/30987#BotRecord)

	* 新增成员：Domain


### 第 90 次发布

发布时间：2021-12-10 08:02:48

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [TrafficPackage](https://cloud.tencent.com/document/api/228/30987#TrafficPackage)

	* 新增成员：ExtensionMode


### 第 89 次发布

发布时间：2021-12-09 08:02:35

本次发布包含了以下内容：

改善已有的文档。

新增数据结构：

* [AdvanceHttps](https://cloud.tencent.com/document/api/228/30987#AdvanceHttps)

修改数据结构：

* [Origin](https://cloud.tencent.com/document/api/228/30987#Origin)

	* 新增成员：AdvanceHttps


### 第 88 次发布

发布时间：2021-12-06 08:02:38

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [ListClsLogTopics](https://cloud.tencent.com/document/api/228/42194)

	* 新增出参：ExtraLogset


新增数据结构：

* [ExtraLogset](https://cloud.tencent.com/document/api/228/30987#ExtraLogset)

修改数据结构：

* [LogSetInfo](https://cloud.tencent.com/document/api/228/30987#LogSetInfo)

	* 新增成员：Deleted, RegionEn

* [TopicInfo](https://cloud.tencent.com/document/api/228/30987#TopicInfo)

	* 新增成员：Deleted


### 第 87 次发布

发布时间：2021-11-19 08:07:05

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [UpdateDomainConfig](https://cloud.tencent.com/document/api/228/41116)

	* 新增入参：ShareCname


新增数据结构：

* [ShareCname](https://cloud.tencent.com/document/api/228/30987#ShareCname)

修改数据结构：

* [AuthenticationTypeA](https://cloud.tencent.com/document/api/228/30987#AuthenticationTypeA)

	* 新增成员：BackupSecretKey

* [AuthenticationTypeB](https://cloud.tencent.com/document/api/228/30987#AuthenticationTypeB)

	* 新增成员：BackupSecretKey

* [AuthenticationTypeC](https://cloud.tencent.com/document/api/228/30987#AuthenticationTypeC)

	* 新增成员：BackupSecretKey

* [AuthenticationTypeD](https://cloud.tencent.com/document/api/228/30987#AuthenticationTypeD)

	* 新增成员：BackupSecretKey

* [DetailDomain](https://cloud.tencent.com/document/api/228/30987#DetailDomain)

	* 新增成员：ShareCname


### 第 86 次发布

发布时间：2021-11-09 08:07:45

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeScdnBotData](https://cloud.tencent.com/document/api/228/63777)

新增数据结构：

* [BotStats](https://cloud.tencent.com/document/api/228/30987#BotStats)
* [BotStatsDetailData](https://cloud.tencent.com/document/api/228/30987#BotStatsDetailData)

修改数据结构：

* [TrafficPackage](https://cloud.tencent.com/document/api/228/30987#TrafficPackage)

	* 新增成员：ConfigId


### 第 85 次发布

发布时间：2021-11-02 08:03:38

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [UrlRedirectRule](https://cloud.tencent.com/document/api/228/30987#UrlRedirectRule)

	* 新增成员：FullMatch


### 第 84 次发布

发布时间：2021-10-28 15:10:03

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeScdnBotRecords](https://cloud.tencent.com/document/api/228/63468)
* [DescribeTopData](https://cloud.tencent.com/document/api/228/63466)
* [ListScdnTopBotData](https://cloud.tencent.com/document/api/228/63467)

修改接口：

* [ListTopData](https://cloud.tencent.com/document/api/228/30983)

	* 新增入参：Limit

* [UpdateDomainConfig](https://cloud.tencent.com/document/api/228/41116)

	* 新增入参：RemoteAuthentication


新增数据结构：

* [BotRecord](https://cloud.tencent.com/document/api/228/30987#BotRecord)
* [BotSortBy](https://cloud.tencent.com/document/api/228/30987#BotSortBy)
* [BotStatisticsCount](https://cloud.tencent.com/document/api/228/30987#BotStatisticsCount)
* [RemoteAuthentication](https://cloud.tencent.com/document/api/228/30987#RemoteAuthentication)
* [RemoteAuthenticationRule](https://cloud.tencent.com/document/api/228/30987#RemoteAuthenticationRule)
* [TopDataMore](https://cloud.tencent.com/document/api/228/30987#TopDataMore)
* [TopDetailDataMore](https://cloud.tencent.com/document/api/228/30987#TopDetailDataMore)

修改数据结构：

* [DetailDomain](https://cloud.tencent.com/document/api/228/30987#DetailDomain)

	* 新增成员：RemoteAuthentication

* [TrafficPackage](https://cloud.tencent.com/document/api/228/30987#TrafficPackage)

	* 新增成员：Region


### 第 83 次发布

发布时间：2021-10-21 11:18:54

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeCcData](https://cloud.tencent.com/document/api/228/63166)
* [DescribeDDoSData](https://cloud.tencent.com/document/api/228/63165)
* [DescribeEventLogData](https://cloud.tencent.com/document/api/228/63164)
* [DescribeWafData](https://cloud.tencent.com/document/api/228/63163)
* [ListTopClsLogData](https://cloud.tencent.com/document/api/228/63162)

修改接口：

* [ListTopDDoSData](https://cloud.tencent.com/document/api/228/60686)

	* 新增入参：Metric

	* 新增出参：IPData


新增数据结构：

* [ClsLogIpData](https://cloud.tencent.com/document/api/228/30987#ClsLogIpData)
* [DDoSAttackBandwidthData](https://cloud.tencent.com/document/api/228/30987#DDoSAttackBandwidthData)
* [DDoSAttackIPTopData](https://cloud.tencent.com/document/api/228/30987#DDoSAttackIPTopData)
* [DDoSStatsData](https://cloud.tencent.com/document/api/228/30987#DDoSStatsData)
* [EventLogStatsData](https://cloud.tencent.com/document/api/228/30987#EventLogStatsData)

### 第 82 次发布

发布时间：2021-10-15 08:07:48

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateDiagnoseUrl](https://cloud.tencent.com/document/api/228/49326)

	* 新增入参：Origin

* [ListDiagnoseReport](https://cloud.tencent.com/document/api/228/49324)

	* 新增入参：Origin


### 第 81 次发布

发布时间：2021-10-14 08:06:02

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeScdnIpStrategy](https://cloud.tencent.com/document/api/228/62665)

新增数据结构：

* [ScdnIpStrategy](https://cloud.tencent.com/document/api/228/30987#ScdnIpStrategy)
* [ScdnIpStrategyFilter](https://cloud.tencent.com/document/api/228/30987#ScdnIpStrategyFilter)

修改数据结构：

* [IpFilter](https://cloud.tencent.com/document/api/228/30987#IpFilter)

	* 新增成员：ReturnCode


### 第 80 次发布

发布时间：2021-10-12 08:03:17

本次发布包含了以下内容：

改善已有的文档。

新增数据结构：

* [AdvancedScdnAclGroup](https://cloud.tencent.com/document/api/228/30987#AdvancedScdnAclGroup)
* [AdvancedScdnAclRule](https://cloud.tencent.com/document/api/228/30987#AdvancedScdnAclRule)
* [RangeOriginPullRule](https://cloud.tencent.com/document/api/228/30987#RangeOriginPullRule)

修改数据结构：

* [CompressionRule](https://cloud.tencent.com/document/api/228/30987#CompressionRule)

	* 新增成员：RuleType, RulePaths

	* <font color="#dd0000">**修改成员**：</font>FileExtensions

* [RangeOriginPull](https://cloud.tencent.com/document/api/228/30987#RangeOriginPull)

	* 新增成员：RangeRules

* [ScdnAclConfig](https://cloud.tencent.com/document/api/228/30987#ScdnAclConfig)

	* 新增成员：AdvancedScriptData


### 第 79 次发布

发布时间：2021-09-27 08:07:49

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [EnableCaches](https://cloud.tencent.com/document/api/228/33540)

	* 新增出参：TaskId


新增数据结构：

* [AdvancedCCRules](https://cloud.tencent.com/document/api/228/30987#AdvancedCCRules)
* [ScdnSevenLayerRules](https://cloud.tencent.com/document/api/228/30987#ScdnSevenLayerRules)

修改数据结构：

* [ScdnConfig](https://cloud.tencent.com/document/api/228/30987#ScdnConfig)

	* 新增成员：AdvancedRules


### 第 78 次发布

发布时间：2021-09-23 08:05:21

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [ScdnDomain](https://cloud.tencent.com/document/api/228/30987#ScdnDomain)

	* 新增成员：WafLevel


### 第 77 次发布

发布时间：2021-09-15 08:04:54

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [BandwidthAlert](https://cloud.tencent.com/document/api/228/30987#BandwidthAlert)

	* 新增成员：Metric


### 第 76 次发布

发布时间：2021-09-02 08:03:38

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [BandwidthAlert](https://cloud.tencent.com/document/api/228/30987#BandwidthAlert)

	* 新增成员：AlertSwitch, AlertPercentage, LastTriggerTimeOverseas


### 第 75 次发布

发布时间：2021-08-25 08:04:15

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [ListTopBotData](https://cloud.tencent.com/document/api/228/60688)
* [ListTopCcData](https://cloud.tencent.com/document/api/228/60687)
* [ListTopDDoSData](https://cloud.tencent.com/document/api/228/60686)
* [ListTopWafData](https://cloud.tencent.com/document/api/228/60685)

新增数据结构：

* [CcTopData](https://cloud.tencent.com/document/api/228/30987#CcTopData)
* [DDoSTopData](https://cloud.tencent.com/document/api/228/30987#DDoSTopData)
* [DomainBotCount](https://cloud.tencent.com/document/api/228/30987#DomainBotCount)
* [ScdnTopDomainData](https://cloud.tencent.com/document/api/228/30987#ScdnTopDomainData)

### 第 74 次发布

发布时间：2021-08-13 08:04:13

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [PathRule](https://cloud.tencent.com/document/api/228/30987#PathRule)

	* 新增成员：FullMatch


### 第 73 次发布

发布时间：2021-07-28 08:04:27

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateScdnDomain](https://cloud.tencent.com/document/api/228/59239)

### 第 72 次发布

发布时间：2021-07-23 08:04:13

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeBillingData](https://cloud.tencent.com/document/api/228/41237)

	* 新增入参：Product

* [DescribeCdnData](https://cloud.tencent.com/document/api/228/30986)

	* 新增入参：Product

* [DescribeCertDomains](https://cloud.tencent.com/document/api/228/42491)

	* 新增入参：CertId, Product

	* <font color="#dd0000">**修改入参**：</font>Cert

* [DescribePayType](https://cloud.tencent.com/document/api/228/31295)

	* 新增入参：Product

* [ListTopData](https://cloud.tencent.com/document/api/228/30983)

	* 新增入参：Product

* [UpdateDomainConfig](https://cloud.tencent.com/document/api/228/41116)

	* 新增入参：WebSocket


新增数据结构：

* [WebSocket](https://cloud.tencent.com/document/api/228/30987#WebSocket)

修改数据结构：

* [BriefDomain](https://cloud.tencent.com/document/api/228/30987#BriefDomain)

	* 新增成员：Product

* [DetailDomain](https://cloud.tencent.com/document/api/228/30987#DetailDomain)

	* 新增成员：WebSocket

* [TopicInfo](https://cloud.tencent.com/document/api/228/30987#TopicInfo)

	* 新增成员：Channel


### 第 71 次发布

发布时间：2021-07-21 08:04:29

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DisableCaches](https://cloud.tencent.com/document/api/228/33541)

	* 新增出参：TaskId

* [GetDisableRecords](https://cloud.tencent.com/document/api/228/33539)

	* 新增入参：TaskId

	* <font color="#dd0000">**修改入参**：</font>StartTime, EndTime


### 第 70 次发布

发布时间：2021-07-16 08:04:26

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [AddCdnDomain](https://cloud.tencent.com/document/api/228/41123)

	* 新增入参：AwsPrivateAccess, OssPrivateAccess

* [UpdateDomainConfig](https://cloud.tencent.com/document/api/228/41116)

	* 新增入参：OssPrivateAccess


新增数据结构：

* [OssPrivateAccess](https://cloud.tencent.com/document/api/228/30987#OssPrivateAccess)

修改数据结构：

* [DetailDomain](https://cloud.tencent.com/document/api/228/30987#DetailDomain)

	* 新增成员：OssPrivateAccess


### 第 69 次发布

发布时间：2021-07-14 08:04:04

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [ScdnAclGroup](https://cloud.tencent.com/document/api/228/30987#ScdnAclGroup)

	* 新增成员：ErrorPage


### 第 68 次发布

发布时间：2021-06-23 11:31:26

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeIpStatus](https://cloud.tencent.com/document/api/228/41954)

	* 新增入参：Segment

* [EnableCaches](https://cloud.tencent.com/document/api/228/33540)

	* 新增入参：Date


### 第 67 次发布

发布时间：2021-06-09 08:03:50

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [ModifyPurgeFetchTaskStatus](https://cloud.tencent.com/document/api/228/56898)

### 第 66 次发布

发布时间：2021-04-28 08:04:49

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeDistrictIspData](https://cloud.tencent.com/document/api/228/47395)

	* 新增入参：Interval


### 第 65 次发布

发布时间：2021-04-20 08:03:37

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateEdgePackTask](https://cloud.tencent.com/document/api/228/49977)

	* <font color="#dd0000">**修改入参**：</font>CosUriTo


### 第 64 次发布

发布时间：2021-03-10 08:04:14

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateScdnFailedLogTask](https://cloud.tencent.com/document/api/228/53487)

修改接口：

* [CreateScdnLogTask](https://cloud.tencent.com/document/api/228/47941)

	* 新增入参：Source, Area

* [ListScdnLogTasks](https://cloud.tencent.com/document/api/228/49012)

	* 新增入参：Source, Area


新增数据结构：

* [WafSubRuleStatus](https://cloud.tencent.com/document/api/228/30987#WafSubRuleStatus)

修改数据结构：

* [ScdnDomain](https://cloud.tencent.com/document/api/228/30987#ScdnDomain)

	* 新增成员：Area

* [ScdnLogTaskDetail](https://cloud.tencent.com/document/api/228/30987#ScdnLogTaskDetail)

	* 新增成员：Area

* [ScdnWafConfig](https://cloud.tencent.com/document/api/228/30987#ScdnWafConfig)

	* 新增成员：Level, SubRuleSwitch


### 第 63 次发布

发布时间：2021-03-03 08:03:10

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [AddCdnDomain](https://cloud.tencent.com/document/api/228/41123)

	* 新增入参：Quic

* [UpdateDomainConfig](https://cloud.tencent.com/document/api/228/41116)

	* 新增入参：Quic


新增数据结构：

* [PostSize](https://cloud.tencent.com/document/api/228/30987#PostSize)
* [Quic](https://cloud.tencent.com/document/api/228/30987#Quic)

修改数据结构：

* [DetailDomain](https://cloud.tencent.com/document/api/228/30987#DetailDomain)

	* 新增成员：PostMaxSize, Quic


### 第 62 次发布

发布时间：2021-01-14 08:03:23

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [TrafficPackage](https://cloud.tencent.com/document/api/228/30987#TrafficPackage)

	* 新增成员：Area, LifeTimeMonth, ExtensionAvailable, RefundAvailable


### 第 61 次发布

发布时间：2021-01-07 08:03:12

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [AddCdnDomain](https://cloud.tencent.com/document/api/228/41123)

	* 新增入参：OfflineCache

* [UpdateDomainConfig](https://cloud.tencent.com/document/api/228/41116)

	* 新增入参：OfflineCache, OriginCombine


新增数据结构：

* [OfflineCache](https://cloud.tencent.com/document/api/228/30987#OfflineCache)
* [OriginCombine](https://cloud.tencent.com/document/api/228/30987#OriginCombine)

修改数据结构：

* [DetailDomain](https://cloud.tencent.com/document/api/228/30987#DetailDomain)

	* 新增成员：OfflineCache, OriginCombine


### 第 60 次发布

发布时间：2020-12-30 08:02:56

本次发布包含了以下内容：

改善已有的文档。

新增数据结构：

* [PathBasedOriginRule](https://cloud.tencent.com/document/api/228/30987#PathBasedOriginRule)

修改数据结构：

* [Origin](https://cloud.tencent.com/document/api/228/30987#Origin)

	* 新增成员：PathBasedOrigin


### 第 59 次发布

发布时间：2020-12-28 08:02:49

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeScdnConfig](https://cloud.tencent.com/document/api/228/51326)

	* 新增出参：Status

* [ListScdnDomains](https://cloud.tencent.com/document/api/228/51325)

	* 新增入参：Domain


### 第 58 次发布

发布时间：2020-12-24 08:03:03

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [PushUrlsCache](https://cloud.tencent.com/document/api/228/37869)

	* 新增入参：ParseM3U8


### 第 57 次发布

发布时间：2020-12-23 08:02:40

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeScdnConfig](https://cloud.tencent.com/document/api/228/51326)
* [ListScdnDomains](https://cloud.tencent.com/document/api/228/51325)
* [StartScdnDomain](https://cloud.tencent.com/document/api/228/51324)
* [StopScdnDomain](https://cloud.tencent.com/document/api/228/51323)

新增数据结构：

* [ScdnDomain](https://cloud.tencent.com/document/api/228/30987#ScdnDomain)

### 第 56 次发布

发布时间：2020-12-22 08:03:32

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [ForceRedirect](https://cloud.tencent.com/document/api/228/30987#ForceRedirect)

	* 新增成员：CarryHeaders


### 第 55 次发布

发布时间：2020-12-21 08:03:14

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateScdnLogTask](https://cloud.tencent.com/document/api/228/47941)

	* 新增入参：AttackTypes, Conditions


新增数据结构：

* [AdvanceConfig](https://cloud.tencent.com/document/api/228/30987#AdvanceConfig)
* [ScdnEventLogConditions](https://cloud.tencent.com/document/api/228/30987#ScdnEventLogConditions)

修改数据结构：

* [DetailDomain](https://cloud.tencent.com/document/api/228/30987#DetailDomain)

	* 新增成员：AdvanceSet

* [ScdnLogTaskDetail](https://cloud.tencent.com/document/api/228/30987#ScdnLogTaskDetail)

	* 新增成员：Conditions


### 第 54 次发布

发布时间：2020-12-17 08:02:55

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [ScdnTopUrlData](https://cloud.tencent.com/document/api/228/30987#ScdnTopUrlData)

	* 新增成员：Domain


### 第 53 次发布

发布时间：2020-12-15 08:04:38

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [AddCdnDomain](https://cloud.tencent.com/document/api/228/41123)

	* 新增入参：Ipv6Access

* [UpdateDomainConfig](https://cloud.tencent.com/document/api/228/41116)

	* 新增入参：Ipv6Access


新增数据结构：

* [Ipv6Access](https://cloud.tencent.com/document/api/228/30987#Ipv6Access)

修改数据结构：

* [DetailDomain](https://cloud.tencent.com/document/api/228/30987#DetailDomain)

	* 新增成员：Ipv6Access


### 第 52 次发布

发布时间：2020-12-07 08:02:41

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [UpdateScdnDomain](https://cloud.tencent.com/document/api/228/50712)

新增数据结构：

* [BotCookie](https://cloud.tencent.com/document/api/228/30987#BotCookie)
* [BotJavaScript](https://cloud.tencent.com/document/api/228/30987#BotJavaScript)
* [ScdnAclConfig](https://cloud.tencent.com/document/api/228/30987#ScdnAclConfig)
* [ScdnAclGroup](https://cloud.tencent.com/document/api/228/30987#ScdnAclGroup)
* [ScdnAclRule](https://cloud.tencent.com/document/api/228/30987#ScdnAclRule)
* [ScdnBotConfig](https://cloud.tencent.com/document/api/228/30987#ScdnBotConfig)
* [ScdnCCRules](https://cloud.tencent.com/document/api/228/30987#ScdnCCRules)
* [ScdnConfig](https://cloud.tencent.com/document/api/228/30987#ScdnConfig)
* [ScdnDdosConfig](https://cloud.tencent.com/document/api/228/30987#ScdnDdosConfig)
* [ScdnErrorPage](https://cloud.tencent.com/document/api/228/30987#ScdnErrorPage)
* [ScdnWafConfig](https://cloud.tencent.com/document/api/228/30987#ScdnWafConfig)
* [ScdnWafRule](https://cloud.tencent.com/document/api/228/30987#ScdnWafRule)

修改数据结构：

* [Https](https://cloud.tencent.com/document/api/228/30987#Https)

	* 新增成员：TlsVersion

* [MaxAgeRule](https://cloud.tencent.com/document/api/228/30987#MaxAgeRule)

	* 新增成员：FollowOrigin

* [PathRule](https://cloud.tencent.com/document/api/228/30987#PathRule)

	* <font color="#dd0000">**修改成员**：</font>Origin, ServerName, OriginArea

* [UrlRedirectRule](https://cloud.tencent.com/document/api/228/30987#UrlRedirectRule)

	* 新增成员：RedirectHost


### 第 51 次发布

发布时间：2020-12-03 08:03:02

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [DiagnoseInfo](https://cloud.tencent.com/document/api/228/30987#DiagnoseInfo)

	* 新增成员：Area


### 第 50 次发布

发布时间：2020-12-02 08:02:23

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeCdnOriginIp](https://cloud.tencent.com/document/api/228/50513)

新增数据结构：

* [OriginIp](https://cloud.tencent.com/document/api/228/30987#OriginIp)

### 第 49 次发布

发布时间：2020-12-01 08:02:29

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [UpdateDomainConfig](https://cloud.tencent.com/document/api/228/41116)

	* 新增入参：AdvancedAuthentication, OriginAuthentication


新增数据结构：

* [AdvancedAuthentication](https://cloud.tencent.com/document/api/228/30987#AdvancedAuthentication)
* [AdvancedAuthenticationTypeA](https://cloud.tencent.com/document/api/228/30987#AdvancedAuthenticationTypeA)
* [AdvancedAuthenticationTypeB](https://cloud.tencent.com/document/api/228/30987#AdvancedAuthenticationTypeB)
* [AdvancedAuthenticationTypeC](https://cloud.tencent.com/document/api/228/30987#AdvancedAuthenticationTypeC)
* [AdvancedAuthenticationTypeD](https://cloud.tencent.com/document/api/228/30987#AdvancedAuthenticationTypeD)
* [AdvancedAuthenticationTypeE](https://cloud.tencent.com/document/api/228/30987#AdvancedAuthenticationTypeE)
* [AdvancedAuthenticationTypeF](https://cloud.tencent.com/document/api/228/30987#AdvancedAuthenticationTypeF)
* [OriginAuthentication](https://cloud.tencent.com/document/api/228/30987#OriginAuthentication)
* [OriginAuthenticationTypeA](https://cloud.tencent.com/document/api/228/30987#OriginAuthenticationTypeA)

修改数据结构：

* [DetailDomain](https://cloud.tencent.com/document/api/228/30987#DetailDomain)

	* 新增成员：AdvancedAuthentication, OriginAuthentication


### 第 48 次发布

发布时间：2020-11-19 08:02:35

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [PurgePathCache](https://cloud.tencent.com/document/api/228/37871)

	* 新增入参：UrlEncode


### 第 47 次发布

发布时间：2020-11-17 08:03:08

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateEdgePackTask](https://cloud.tencent.com/document/api/228/49977)

### 第 46 次发布

发布时间：2020-11-16 08:02:49

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [PurgeUrlsCache](https://cloud.tencent.com/document/api/228/37870)

	* 新增入参：UrlEncode


### 第 45 次发布

发布时间：2020-11-05 08:02:34

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [ListClsLogTopics](https://cloud.tencent.com/document/api/228/42194)

	* 新增出参：Logset, Topics

* [ListClsTopicDomains](https://cloud.tencent.com/document/api/228/42193)

	* 新增出参：AppId, Channel, LogsetId, TopicId, DomainAreaConfigs, TopicName, UpdateTime

* [SearchClsLog](https://cloud.tencent.com/document/api/228/42191)

	* 新增出参：Logs


新增数据结构：

* [ClsLogObject](https://cloud.tencent.com/document/api/228/30987#ClsLogObject)
* [ClsSearchLogs](https://cloud.tencent.com/document/api/228/30987#ClsSearchLogs)
* [LogSetInfo](https://cloud.tencent.com/document/api/228/30987#LogSetInfo)
* [TopicInfo](https://cloud.tencent.com/document/api/228/30987#TopicInfo)

### 第 44 次发布

发布时间：2020-11-04 08:02:33

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [ListDiagnoseReport](https://cloud.tencent.com/document/api/228/49324)

	* 新增入参：DiagnoseLink


### 第 43 次发布

发布时间：2020-11-02 08:02:41

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DuplicateDomainConfig](https://cloud.tencent.com/document/api/228/49592)

### 第 42 次发布

发布时间：2020-10-29 08:02:27

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [ListClsLogTopics](https://cloud.tencent.com/document/api/228/42194)

	* <font color="#dd0000">**删除出参**：</font>Logset, Topics

* [ListClsTopicDomains](https://cloud.tencent.com/document/api/228/42193)

	* <font color="#dd0000">**删除出参**：</font>AppId, Channel, LogsetId, TopicId, DomainAreaConfigs, TopicName, UpdateTime

* [SearchClsLog](https://cloud.tencent.com/document/api/228/42191)

	* <font color="#dd0000">**删除出参**：</font>Logs


<font color="#dd0000">**删除数据结构**：</font>

* ClsLogObject
* ClsSearchLogs
* LogSetInfo
* TopicInfo

### 第 41 次发布

发布时间：2020-10-23 08:03:22

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateDiagnoseUrl](https://cloud.tencent.com/document/api/228/49326)
* [DescribeDiagnoseReport](https://cloud.tencent.com/document/api/228/49325)
* [ListDiagnoseReport](https://cloud.tencent.com/document/api/228/49324)

新增数据结构：

* [ClientInfo](https://cloud.tencent.com/document/api/228/30987#ClientInfo)
* [DiagnoseData](https://cloud.tencent.com/document/api/228/30987#DiagnoseData)
* [DiagnoseInfo](https://cloud.tencent.com/document/api/228/30987#DiagnoseInfo)
* [DiagnoseList](https://cloud.tencent.com/document/api/228/30987#DiagnoseList)
* [DiagnoseUnit](https://cloud.tencent.com/document/api/228/30987#DiagnoseUnit)

### 第 40 次发布

发布时间：2020-10-16 08:02:55

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [CdnIp](https://cloud.tencent.com/document/api/228/30987#CdnIp)

	* 新增成员：City


### 第 39 次发布

发布时间：2020-10-15 08:02:21

本次发布包含了以下内容：

改善已有的文档。

新增数据结构：

* [HttpHeaderRule](https://cloud.tencent.com/document/api/228/30987#HttpHeaderRule)
* [PathRule](https://cloud.tencent.com/document/api/228/30987#PathRule)

修改数据结构：

* [Origin](https://cloud.tencent.com/document/api/228/30987#Origin)

	* 新增成员：PathRules


### 第 38 次发布

发布时间：2020-10-12 08:02:20

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DeleteScdnDomain](https://cloud.tencent.com/document/api/228/49013)
* [ListScdnLogTasks](https://cloud.tencent.com/document/api/228/49012)

新增数据结构：

* [ScdnLogTaskDetail](https://cloud.tencent.com/document/api/228/30987#ScdnLogTaskDetail)

### 第 37 次发布

发布时间：2020-09-30 08:02:23

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeIpStatus](https://cloud.tencent.com/document/api/228/41954)

	* 新增入参：Area


新增数据结构：

* [IpFilterPathRule](https://cloud.tencent.com/document/api/228/30987#IpFilterPathRule)

修改数据结构：

* [IpFilter](https://cloud.tencent.com/document/api/228/30987#IpFilter)

	* 新增成员：FilterRules


### 第 36 次发布

发布时间：2020-09-28 08:03:19

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [AuthenticationTypeC](https://cloud.tencent.com/document/api/228/30987#AuthenticationTypeC)

	* 新增成员：TimeFormat


### 第 35 次发布

发布时间：2020-09-14 08:01:57

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [AddCdnDomain](https://cloud.tencent.com/document/api/228/41123)

	* 新增入参：Tag


新增数据结构：

* [Tag](https://cloud.tencent.com/document/api/228/30987#Tag)

修改数据结构：

* [DetailDomain](https://cloud.tencent.com/document/api/228/30987#DetailDomain)

	* 新增成员：Tag


### 第 34 次发布

发布时间：2020-09-04 08:02:36

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateVerifyRecord](https://cloud.tencent.com/document/api/228/48118)
* [VerifyDomainRecord](https://cloud.tencent.com/document/api/228/48117)

### 第 33 次发布

发布时间：2020-09-01 08:02:19

本次发布包含了以下内容：

改善已有的文档。

新增数据结构：

* [CacheConfigCache](https://cloud.tencent.com/document/api/228/30987#CacheConfigCache)
* [CacheConfigFollowOrigin](https://cloud.tencent.com/document/api/228/30987#CacheConfigFollowOrigin)
* [CacheConfigNoCache](https://cloud.tencent.com/document/api/228/30987#CacheConfigNoCache)
* [KeyRule](https://cloud.tencent.com/document/api/228/30987#KeyRule)
* [RuleCache](https://cloud.tencent.com/document/api/228/30987#RuleCache)
* [RuleCacheConfig](https://cloud.tencent.com/document/api/228/30987#RuleCacheConfig)
* [RuleQueryString](https://cloud.tencent.com/document/api/228/30987#RuleQueryString)

修改数据结构：

* [Cache](https://cloud.tencent.com/document/api/228/30987#Cache)

	* 新增成员：RuleCache

* [CacheKey](https://cloud.tencent.com/document/api/228/30987#CacheKey)

	* 新增成员：KeyRules


### 第 32 次发布

发布时间：2020-08-31 08:02:28

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateScdnLogTask](https://cloud.tencent.com/document/api/228/47941)
* [DescribeScdnTopData](https://cloud.tencent.com/document/api/228/47940)

新增数据结构：

* [ScdnTopData](https://cloud.tencent.com/document/api/228/30987#ScdnTopData)
* [ScdnTopUrlData](https://cloud.tencent.com/document/api/228/30987#ScdnTopUrlData)
* [ScdnTypeData](https://cloud.tencent.com/document/api/228/30987#ScdnTypeData)

### 第 31 次发布

发布时间：2020-08-14 08:07:25

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [UpdateDomainConfig](https://cloud.tencent.com/document/api/228/41116)

	* 新增入参：AccessControl, UrlRedirect, AccessPort


新增数据结构：

* [UrlRedirect](https://cloud.tencent.com/document/api/228/30987#UrlRedirect)
* [UrlRedirectRule](https://cloud.tencent.com/document/api/228/30987#UrlRedirectRule)

修改数据结构：

* [DetailDomain](https://cloud.tencent.com/document/api/228/30987#DetailDomain)

	* 新增成员：Advance, UrlRedirect, AccessPort


### 第 30 次发布

发布时间：2020-08-13 08:07:16

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeDistrictIspData](https://cloud.tencent.com/document/api/228/47395)

新增数据结构：

* [DistrictIspInfo](https://cloud.tencent.com/document/api/228/30987#DistrictIspInfo)

### 第 29 次发布

发布时间：2020-08-11 08:08:54

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [PushUrlsCache](https://cloud.tencent.com/document/api/228/37869)

	* 新增入参：Layer


### 第 28 次发布

发布时间：2020-07-17 08:06:38

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [PurgeUrlsCache](https://cloud.tencent.com/document/api/228/37870)

	* 新增入参：Area


### 第 27 次发布

发布时间：2020-07-06 08:06:38

本次发布包含了以下内容：

改善已有的文档。

新增数据结构：

* [AccessControl](https://cloud.tencent.com/document/api/228/30987#AccessControl)
* [AccessControlRule](https://cloud.tencent.com/document/api/228/30987#AccessControlRule)
* [CacheTagKey](https://cloud.tencent.com/document/api/228/30987#CacheTagKey)
* [CookieKey](https://cloud.tencent.com/document/api/228/30987#CookieKey)
* [HeaderKey](https://cloud.tencent.com/document/api/228/30987#HeaderKey)
* [QueryStringKey](https://cloud.tencent.com/document/api/228/30987#QueryStringKey)
* [Revalidate](https://cloud.tencent.com/document/api/228/30987#Revalidate)
* [SchemeKey](https://cloud.tencent.com/document/api/228/30987#SchemeKey)

修改数据结构：

* [CacheKey](https://cloud.tencent.com/document/api/228/30987#CacheKey)

	* 新增成员：QueryString, Cookie, Header, CacheTag, Scheme

* [DetailDomain](https://cloud.tencent.com/document/api/228/30987#DetailDomain)

	* 新增成员：AccessControl

* [SimpleCache](https://cloud.tencent.com/document/api/228/30987#SimpleCache)

	* 新增成员：Revalidate


### 第 26 次发布

发布时间：2020-07-02 08:06:45

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [Origin](https://cloud.tencent.com/document/api/228/30987#Origin)

	* 新增成员：BasePath


### 第 25 次发布

发布时间：2020-06-30 08:07:58

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [UpdateDomainConfig](https://cloud.tencent.com/document/api/228/41116)

	* 新增入参：UserAgentFilter


新增数据结构：

* [Hsts](https://cloud.tencent.com/document/api/228/30987#Hsts)

<font color="#dd0000">**删除数据结构**：</font>

* CacheTagKey
* CookieKey
* HeaderKey
* QueryStringKey
* SchemeKey

修改数据结构：

* [CacheKey](https://cloud.tencent.com/document/api/228/30987#CacheKey)

	* 新增成员：IgnoreCase

	* <font color="#dd0000">**删除成员**：</font>QueryString, Header, Cookie, Scheme, CacheTag

* [Https](https://cloud.tencent.com/document/api/228/30987#Https)

	* 新增成员：Hsts


### 第 24 次发布

发布时间：2020-06-10 08:06:47

本次发布包含了以下内容：

改善已有的文档。

<font color="#dd0000">**删除数据结构**：</font>

* Hsts

修改数据结构：

* [CacheKey](https://cloud.tencent.com/document/api/228/30987#CacheKey)

	* <font color="#dd0000">**删除成员**：</font>CaseSensitive

* [Https](https://cloud.tencent.com/document/api/228/30987#Https)

	* <font color="#dd0000">**删除成员**：</font>TlsVersion, Hsts


### 第 23 次发布

发布时间：2020-06-08 08:06:18

本次发布包含了以下内容：

改善已有的文档。

新增数据结构：

* [CacheTagKey](https://cloud.tencent.com/document/api/228/30987#CacheTagKey)
* [CookieKey](https://cloud.tencent.com/document/api/228/30987#CookieKey)
* [HeaderKey](https://cloud.tencent.com/document/api/228/30987#HeaderKey)
* [QueryStringKey](https://cloud.tencent.com/document/api/228/30987#QueryStringKey)
* [SchemeKey](https://cloud.tencent.com/document/api/228/30987#SchemeKey)

修改数据结构：

* [CacheKey](https://cloud.tencent.com/document/api/228/30987#CacheKey)

	* 新增成员：QueryString, Header, Cookie, Scheme, CacheTag


### 第 22 次发布

发布时间：2020-05-21 08:06:19

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [Sort](https://cloud.tencent.com/document/api/228/30987#Sort)

	* <font color="#dd0000">**修改成员**：</font>Key


### 第 21 次发布

发布时间：2020-05-15 08:06:22

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateClsLogTopic](https://cloud.tencent.com/document/api/228/42198)

	* 新增出参：TopicId


### 第 20 次发布

发布时间：2020-05-14 08:07:44

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeCdnDomainLogs](https://cloud.tencent.com/document/api/228/39232)

	* 新增入参：LogType


### 第 19 次发布

发布时间：2020-04-30 08:06:25

本次发布包含了以下内容：

改善已有的文档。

新增数据结构：

* [Hsts](https://cloud.tencent.com/document/api/228/30987#Hsts)
* [UserAgentFilter](https://cloud.tencent.com/document/api/228/30987#UserAgentFilter)
* [UserAgentFilterRule](https://cloud.tencent.com/document/api/228/30987#UserAgentFilterRule)

修改数据结构：

* [CacheKey](https://cloud.tencent.com/document/api/228/30987#CacheKey)

	* 新增成员：CaseSensitive

* [DetailDomain](https://cloud.tencent.com/document/api/228/30987#DetailDomain)

	* 新增成员：UserAgentFilter

* [Https](https://cloud.tencent.com/document/api/228/30987#Https)

	* 新增成员：TlsVersion, Hsts


### 第 18 次发布

发布时间：2020-04-27 08:05:45

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeImageConfig](https://cloud.tencent.com/document/api/228/43844)
* [UpdateImageConfig](https://cloud.tencent.com/document/api/228/43843)

### 第 17 次发布

发布时间：2020-04-24 08:05:45

本次发布包含了以下内容：

改善已有的文档。

新增数据结构：

* [GuetzliAdapter](https://cloud.tencent.com/document/api/228/30987#GuetzliAdapter)
* [ImageOptimization](https://cloud.tencent.com/document/api/228/30987#ImageOptimization)
* [TpgAdapter](https://cloud.tencent.com/document/api/228/30987#TpgAdapter)
* [WebpAdapter](https://cloud.tencent.com/document/api/228/30987#WebpAdapter)

修改数据结构：

* [DetailDomain](https://cloud.tencent.com/document/api/228/30987#DetailDomain)

	* 新增成员：ImageOptimization


### 第 16 次发布

发布时间：2020-04-21 08:06:30

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [DetailDomain](https://cloud.tencent.com/document/api/228/30987#DetailDomain)

	* <font color="#dd0000">**修改成员**：</font>SecurityConfig


### 第 15 次发布

发布时间：2020-04-14 08:05:44

本次发布包含了以下内容：

改善已有的文档。

新增数据结构：

* [SecurityConfig](https://cloud.tencent.com/document/api/228/30987#SecurityConfig)

修改数据结构：

* [DetailDomain](https://cloud.tencent.com/document/api/228/30987#DetailDomain)

	* 新增成员：SecurityConfig


### 第 14 次发布

发布时间：2020-04-13 08:05:44

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeReportData](https://cloud.tencent.com/document/api/228/43367)

新增数据结构：

* [ReportData](https://cloud.tencent.com/document/api/228/30987#ReportData)

### 第 13 次发布

发布时间：2020-03-18 08:04:17

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeCertDomains](https://cloud.tencent.com/document/api/228/42491)

### 第 12 次发布

发布时间：2020-03-13 08:00:09

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateClsLogTopic](https://cloud.tencent.com/document/api/228/42198)
* [DeleteClsLogTopic](https://cloud.tencent.com/document/api/228/42197)
* [DisableClsLogTopic](https://cloud.tencent.com/document/api/228/42196)
* [EnableClsLogTopic](https://cloud.tencent.com/document/api/228/42195)
* [ListClsLogTopics](https://cloud.tencent.com/document/api/228/42194)
* [ListClsTopicDomains](https://cloud.tencent.com/document/api/228/42193)
* [ManageClsTopicDomains](https://cloud.tencent.com/document/api/228/42192)
* [SearchClsLog](https://cloud.tencent.com/document/api/228/42191)

新增数据结构：

* [ClsLogObject](https://cloud.tencent.com/document/api/228/30987#ClsLogObject)
* [ClsSearchLogs](https://cloud.tencent.com/document/api/228/30987#ClsSearchLogs)
* [DomainAreaConfig](https://cloud.tencent.com/document/api/228/30987#DomainAreaConfig)
* [LogSetInfo](https://cloud.tencent.com/document/api/228/30987#LogSetInfo)
* [TopicInfo](https://cloud.tencent.com/document/api/228/30987#TopicInfo)

### 第 11 次发布

发布时间：2020-03-06 23:46:17

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [UpdateDomainConfig](https://cloud.tencent.com/document/api/228/41116)

	* 新增入参：AwsPrivateAccess


新增数据结构：

* [AwsPrivateAccess](https://cloud.tencent.com/document/api/228/30987#AwsPrivateAccess)

修改数据结构：

* [DetailDomain](https://cloud.tencent.com/document/api/228/30987#DetailDomain)

	* 新增成员：AwsPrivateAccess


### 第 10 次发布

发布时间：2020-03-05 22:50:00

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeIpStatus](https://cloud.tencent.com/document/api/228/41954)
* [DescribePurgeQuota](https://cloud.tencent.com/document/api/228/41956)
* [DescribePushQuota](https://cloud.tencent.com/document/api/228/41955)

新增数据结构：

* [IpStatus](https://cloud.tencent.com/document/api/228/30987#IpStatus)
* [Quota](https://cloud.tencent.com/document/api/228/30987#Quota)

### 第 9 次发布

发布时间：2020-03-04 17:47:30

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [AddCdnDomain](https://cloud.tencent.com/document/api/228/41123)

	* 新增入参：OriginPullTimeout

* [UpdateDomainConfig](https://cloud.tencent.com/document/api/228/41116)

	* 新增入参：OriginPullTimeout


### 第 8 次发布

发布时间：2020-02-13 10:15:36

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeBillingData](https://cloud.tencent.com/document/api/228/41237)

新增数据结构：

* [ResourceBillingData](https://cloud.tencent.com/document/api/228/30987#ResourceBillingData)

### 第 7 次发布

发布时间：2020-01-16 09:53:27

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [AddCdnDomain](https://cloud.tencent.com/document/api/228/41123)
* [DeleteCdnDomain](https://cloud.tencent.com/document/api/228/41122)
* [DescribeDomains](https://cloud.tencent.com/document/api/228/41118)
* [DescribeDomainsConfig](https://cloud.tencent.com/document/api/228/41117)
* [DescribeUrlViolations](https://cloud.tencent.com/document/api/228/41131)
* [StartCdnDomain](https://cloud.tencent.com/document/api/228/41121)
* [StopCdnDomain](https://cloud.tencent.com/document/api/228/41120)
* [UpdateDomainConfig](https://cloud.tencent.com/document/api/228/41116)
* [UpdatePayType](https://cloud.tencent.com/document/api/228/41135)

新增数据结构：

* [AdvanceCacheRule](https://cloud.tencent.com/document/api/228/30987#AdvanceCacheRule)
* [AdvancedCache](https://cloud.tencent.com/document/api/228/30987#AdvancedCache)
* [Authentication](https://cloud.tencent.com/document/api/228/30987#Authentication)
* [AuthenticationTypeA](https://cloud.tencent.com/document/api/228/30987#AuthenticationTypeA)
* [AuthenticationTypeB](https://cloud.tencent.com/document/api/228/30987#AuthenticationTypeB)
* [AuthenticationTypeC](https://cloud.tencent.com/document/api/228/30987#AuthenticationTypeC)
* [AuthenticationTypeD](https://cloud.tencent.com/document/api/228/30987#AuthenticationTypeD)
* [BandwidthAlert](https://cloud.tencent.com/document/api/228/30987#BandwidthAlert)
* [BriefDomain](https://cloud.tencent.com/document/api/228/30987#BriefDomain)
* [Cache](https://cloud.tencent.com/document/api/228/30987#Cache)
* [CacheKey](https://cloud.tencent.com/document/api/228/30987#CacheKey)
* [CappingRule](https://cloud.tencent.com/document/api/228/30987#CappingRule)
* [ClientCert](https://cloud.tencent.com/document/api/228/30987#ClientCert)
* [Compatibility](https://cloud.tencent.com/document/api/228/30987#Compatibility)
* [Compression](https://cloud.tencent.com/document/api/228/30987#Compression)
* [CompressionRule](https://cloud.tencent.com/document/api/228/30987#CompressionRule)
* [DetailDomain](https://cloud.tencent.com/document/api/228/30987#DetailDomain)
* [DomainFilter](https://cloud.tencent.com/document/api/228/30987#DomainFilter)
* [DownstreamCapping](https://cloud.tencent.com/document/api/228/30987#DownstreamCapping)
* [ErrorPage](https://cloud.tencent.com/document/api/228/30987#ErrorPage)
* [ErrorPageRule](https://cloud.tencent.com/document/api/228/30987#ErrorPageRule)
* [FollowRedirect](https://cloud.tencent.com/document/api/228/30987#FollowRedirect)
* [ForceRedirect](https://cloud.tencent.com/document/api/228/30987#ForceRedirect)
* [HttpHeaderPathRule](https://cloud.tencent.com/document/api/228/30987#HttpHeaderPathRule)
* [Https](https://cloud.tencent.com/document/api/228/30987#Https)
* [IpFilter](https://cloud.tencent.com/document/api/228/30987#IpFilter)
* [IpFreqLimit](https://cloud.tencent.com/document/api/228/30987#IpFreqLimit)
* [Ipv6](https://cloud.tencent.com/document/api/228/30987#Ipv6)
* [MainlandConfig](https://cloud.tencent.com/document/api/228/30987#MainlandConfig)
* [MaxAge](https://cloud.tencent.com/document/api/228/30987#MaxAge)
* [MaxAgeRule](https://cloud.tencent.com/document/api/228/30987#MaxAgeRule)
* [Origin](https://cloud.tencent.com/document/api/228/30987#Origin)
* [OriginPullOptimization](https://cloud.tencent.com/document/api/228/30987#OriginPullOptimization)
* [OriginPullTimeout](https://cloud.tencent.com/document/api/228/30987#OriginPullTimeout)
* [OverseaConfig](https://cloud.tencent.com/document/api/228/30987#OverseaConfig)
* [RangeOriginPull](https://cloud.tencent.com/document/api/228/30987#RangeOriginPull)
* [Referer](https://cloud.tencent.com/document/api/228/30987#Referer)
* [RefererRule](https://cloud.tencent.com/document/api/228/30987#RefererRule)
* [RequestHeader](https://cloud.tencent.com/document/api/228/30987#RequestHeader)
* [ResponseHeader](https://cloud.tencent.com/document/api/228/30987#ResponseHeader)
* [ResponseHeaderCache](https://cloud.tencent.com/document/api/228/30987#ResponseHeaderCache)
* [Seo](https://cloud.tencent.com/document/api/228/30987#Seo)
* [ServerCert](https://cloud.tencent.com/document/api/228/30987#ServerCert)
* [SimpleCache](https://cloud.tencent.com/document/api/228/30987#SimpleCache)
* [SimpleCacheRule](https://cloud.tencent.com/document/api/228/30987#SimpleCacheRule)
* [Sort](https://cloud.tencent.com/document/api/228/30987#Sort)
* [SpecificConfig](https://cloud.tencent.com/document/api/228/30987#SpecificConfig)
* [StatusCodeCache](https://cloud.tencent.com/document/api/228/30987#StatusCodeCache)
* [StatusCodeCacheRule](https://cloud.tencent.com/document/api/228/30987#StatusCodeCacheRule)
* [VideoSeek](https://cloud.tencent.com/document/api/228/30987#VideoSeek)
* [ViolationUrl](https://cloud.tencent.com/document/api/228/30987#ViolationUrl)

修改数据结构：

* [PushTask](https://cloud.tencent.com/document/api/228/30987#PushTask)

	* 新增成员：UpdateTime


### 第 6 次发布

发布时间：2019-11-14 20:53:26

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeCdnDomainLogs](https://cloud.tencent.com/document/api/228/39232)
* [DescribeTrafficPackages](https://cloud.tencent.com/document/api/228/39230)

修改接口：

* [DescribePurgeTasks](https://cloud.tencent.com/document/api/228/37873)

	* 新增入参：Area

* [PushUrlsCache](https://cloud.tencent.com/document/api/228/37869)

	* 新增入参：Area


新增数据结构：

* [DomainLog](https://cloud.tencent.com/document/api/228/30987#DomainLog)
* [TrafficPackage](https://cloud.tencent.com/document/api/228/30987#TrafficPackage)

### 第 5 次发布

发布时间：2019-11-01 10:02:29

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeCdnData](https://cloud.tencent.com/document/api/228/30986)

	* 新增入参：Area, AreaType

* [DescribeMapInfo](https://cloud.tencent.com/document/api/228/31296)

	* 新增出参：ServerRegionRelation, ClientRegionRelation

* [DescribeOriginData](https://cloud.tencent.com/document/api/228/30984)

	* 新增入参：Area

* [DescribePayType](https://cloud.tencent.com/document/api/228/31295)

	* 新增入参：Area

	* 新增出参：RegionType, CurrentPayType

* [GetDisableRecords](https://cloud.tencent.com/document/api/228/33539)

	* 新增入参：Offset, Limit

	* 新增出参：TotalCount

* [ListTopData](https://cloud.tencent.com/document/api/228/30983)

	* 新增入参：Area, AreaType


新增数据结构：

* [RegionMapRelation](https://cloud.tencent.com/document/api/228/30987#RegionMapRelation)

修改数据结构：

* [PushTask](https://cloud.tencent.com/document/api/228/30987#PushTask)

	* 新增成员：Area


### 第 4 次发布

发布时间：2019-09-06 18:54:49

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeCdnIp](https://cloud.tencent.com/document/api/228/37868)
* [DescribePurgeTasks](https://cloud.tencent.com/document/api/228/37873)
* [DescribePushTasks](https://cloud.tencent.com/document/api/228/37872)
* [PurgePathCache](https://cloud.tencent.com/document/api/228/37871)
* [PurgeUrlsCache](https://cloud.tencent.com/document/api/228/37870)
* [PushUrlsCache](https://cloud.tencent.com/document/api/228/37869)

新增数据结构：

* [CdnIp](https://cloud.tencent.com/document/api/228/30987#CdnIp)
* [CdnIpHistory](https://cloud.tencent.com/document/api/228/30987#CdnIpHistory)
* [PurgeTask](https://cloud.tencent.com/document/api/228/30987#PurgeTask)
* [PushTask](https://cloud.tencent.com/document/api/228/30987#PushTask)

### 第 3 次发布

发布时间：2019-03-08 11:50:32

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DisableCaches](https://cloud.tencent.com/document/api/228/33541)
* [EnableCaches](https://cloud.tencent.com/document/api/228/33540)
* [GetDisableRecords](https://cloud.tencent.com/document/api/228/33539)

修改接口：

* [DescribeCdnData](https://cloud.tencent.com/document/api/228/30986)

	* 新增入参：IpProtocol


新增数据结构：

* [CacheOptResult](https://cloud.tencent.com/document/api/228/30987#CacheOptResult)
* [UrlRecord](https://cloud.tencent.com/document/api/228/30987#UrlRecord)

### 第 2 次发布

发布时间：2018-12-06 21:01:55

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeMapInfo](https://cloud.tencent.com/document/api/228/31296)
* [DescribePayType](https://cloud.tencent.com/document/api/228/31295)

新增数据结构：

* [MapInfo](https://cloud.tencent.com/document/api/228/30987#MapInfo)

### 第 1 次发布

发布时间：2018-11-29 17:36:37

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeCdnData](https://cloud.tencent.com/document/api/228/30986)
* [DescribeIpVisit](https://cloud.tencent.com/document/api/228/30985)
* [DescribeOriginData](https://cloud.tencent.com/document/api/228/30984)
* [ListTopData](https://cloud.tencent.com/document/api/228/30983)

新增数据结构：

* [CdnData](https://cloud.tencent.com/document/api/228/30987#CdnData)
* [ResourceData](https://cloud.tencent.com/document/api/228/30987#ResourceData)
* [ResourceOriginData](https://cloud.tencent.com/document/api/228/30987#ResourceOriginData)
* [SummarizedData](https://cloud.tencent.com/document/api/228/30987#SummarizedData)
* [TimestampData](https://cloud.tencent.com/document/api/228/30987#TimestampData)
* [TopData](https://cloud.tencent.com/document/api/228/30987#TopData)
* [TopDetailData](https://cloud.tencent.com/document/api/228/30987#TopDetailData)




## T-Sec-数据安全审计（DSA）(cds) 版本：2018-04-20

### 第 4 次发布

发布时间：2024-06-18 01:18:51

本次发布包含了以下内容：

改善已有的文档。

<font color="#dd0000">**删除接口**：</font>

* DescribeDasbImageIds

### 第 3 次发布

发布时间：2024-06-12 01:21:04

本次发布包含了以下内容：

改善已有的文档。

<font color="#dd0000">**预下线接口**：</font>

* DescribeDasbImageIds

### 第 2 次发布

发布时间：2020-03-16 08:05:41

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeDasbImageIds](https://cloud.tencent.com/document/api/856/42278)

修改数据结构：

* [CdsAuditInstance](https://cloud.tencent.com/document/api/856/33913#CdsAuditInstance)

	* 新增成员：InstanceName, PublicIp, PrivateIp, InstanceType, Pdomain


### 第 1 次发布

发布时间：2019-03-22 16:19:27

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeDbauditInstanceType](https://cloud.tencent.com/document/api/856/33912)
* [DescribeDbauditInstances](https://cloud.tencent.com/document/api/856/33911)
* [DescribeDbauditUsedRegions](https://cloud.tencent.com/document/api/856/33910)
* [InquiryPriceDbauditInstance](https://cloud.tencent.com/document/api/856/33909)
* [ModifyDbauditInstancesRenewFlag](https://cloud.tencent.com/document/api/856/33908)

新增数据结构：

* [CdsAuditInstance](https://cloud.tencent.com/document/api/856/33913#CdsAuditInstance)
* [DbauditTypesInfo](https://cloud.tencent.com/document/api/856/33913#DbauditTypesInfo)
* [RegionInfo](https://cloud.tencent.com/document/api/856/33913#RegionInfo)




## 腾讯云数据仓库TCHouse-C(cdwch) 版本：2020-09-15

### 第 22 次发布

发布时间：2024-07-24 01:18:03

本次发布包含了以下内容：

改善已有的文档。

新增数据结构：

* [InstanceDetail](https://cloud.tencent.com/document/api/1299/83429#InstanceDetail)

修改数据结构：

* [InstanceInfo](https://cloud.tencent.com/document/api/1299/83429#InstanceInfo)

	* 新增成员：Details


### 第 21 次发布

发布时间：2024-06-18 01:18:55

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [InstanceInfo](https://cloud.tencent.com/document/api/1299/83429#InstanceInfo)

	* 新增成员：IsSecondaryZone, SecondaryZoneInfo, ClickHouseKeeper


### 第 20 次发布

发布时间：2024-04-02 01:09:49

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateInstanceNew](https://cloud.tencent.com/document/api/1299/84353)

	* 新增入参：TagItems


### 第 19 次发布

发布时间：2024-01-04 01:08:58

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeInstanceNodes](https://cloud.tencent.com/document/api/1299/102819)

新增数据结构：

* [GroupInfo](https://cloud.tencent.com/document/api/1299/83429#GroupInfo)
* [InstanceNode](https://cloud.tencent.com/document/api/1299/83429#InstanceNode)

### 第 18 次发布

发布时间：2024-01-03 01:08:49

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeSpec](https://cloud.tencent.com/document/api/1299/83510)

	* 新增入参：CaseType


### 第 17 次发布

发布时间：2023-09-08 01:20:53

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeBackUpTables](https://cloud.tencent.com/document/api/1299/97836)

### 第 16 次发布

发布时间：2023-09-05 02:01:53

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [ModifyUserNewPrivilege](https://cloud.tencent.com/document/api/1299/83422)

	* 新增入参：InstanceId, Cluster, UserName, AllDatabase, GlobalPrivileges, DatabasePrivilegeList


新增数据结构：

* [DatabasePrivilegeInfo](https://cloud.tencent.com/document/api/1299/83429#DatabasePrivilegeInfo)
* [TablePrivilegeInfo](https://cloud.tencent.com/document/api/1299/83429#TablePrivilegeInfo)

### 第 15 次发布

发布时间：2023-08-31 01:09:05

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DeleteBackUpData](https://cloud.tencent.com/document/api/1299/97603)
* [DescribeBackUpJob](https://cloud.tencent.com/document/api/1299/97605)
* [DescribeBackUpJobDetail](https://cloud.tencent.com/document/api/1299/97604)
* [RecoverBackUpJob](https://cloud.tencent.com/document/api/1299/97602)

修改接口：

* [DescribeCkSqlApis](https://cloud.tencent.com/document/api/1299/83428)

	* 新增入参：UserType


新增数据结构：

* [BackUpJobDisplay](https://cloud.tencent.com/document/api/1299/83429#BackUpJobDisplay)

### 第 14 次发布

发布时间：2023-08-30 01:09:10

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateBackUpSchedule](https://cloud.tencent.com/document/api/1299/83424)

	* 新增入参：InstanceId, ScheduleType, OperationType, RetainDays

	* 新增出参：ErrorMsg


### 第 13 次发布

发布时间：2023-07-20 01:14:55

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [InstanceInfo](https://cloud.tencent.com/document/api/1299/83429#InstanceInfo)

	* 新增成员：EsIndexId, EsIndexUsername, EsIndexPassword, HasEsIndex

	* <font color="#dd0000">**修改成员**：</font>MountDiskType, CHProxyVip, CosBucketName, CanAttachCbs, CanAttachCbsLvm, CanAttachCos, Components, UpgradeVersions

* [InstanceStateInfo](https://cloud.tencent.com/document/api/1299/83429#InstanceStateInfo)

	* 新增成员：ProcessSubName

	* <font color="#dd0000">**修改成员**：</font>RequestId


### 第 12 次发布

发布时间：2023-06-30 01:12:59

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeBackUpSchedule](https://cloud.tencent.com/document/api/1299/86155)

	* 新增出参：ErrorMsg

* [DescribeInstancesNew](https://cloud.tencent.com/document/api/1299/93328)

	* 新增入参：IsSimple


修改数据结构：

* [BackupTableContent](https://cloud.tencent.com/document/api/1299/83429#BackupTableContent)

	* 新增成员：ZooPath, Rip

* [ScheduleStrategy](https://cloud.tencent.com/document/api/1299/83429#ScheduleStrategy)

	* 新增成员：NextBackupTime


### 第 11 次发布

发布时间：2023-06-09 01:07:54

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeInstancesNew](https://cloud.tencent.com/document/api/1299/93328)

新增数据结构：

* [SearchTags](https://cloud.tencent.com/document/api/1299/83429#SearchTags)

### 第 10 次发布

发布时间：2023-04-03 01:07:25

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeInstance](https://cloud.tencent.com/document/api/1299/84354)

	* 新增入参：IsOpenApi


### 第 9 次发布

发布时间：2023-03-31 01:09:05

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeInstanceState](https://cloud.tencent.com/document/api/1299/89676)

### 第 8 次发布

发布时间：2023-03-16 01:15:13

本次发布包含了以下内容：

改善已有的文档。

新增数据结构：

* [AttachCBSSpec](https://cloud.tencent.com/document/api/1299/83429#AttachCBSSpec)
* [InstanceStateInfo](https://cloud.tencent.com/document/api/1299/83429#InstanceStateInfo)
* [ServiceInfo](https://cloud.tencent.com/document/api/1299/83429#ServiceInfo)

修改数据结构：

* [InstanceInfo](https://cloud.tencent.com/document/api/1299/83429#InstanceInfo)

	* 新增成员：Kind, IsElastic, InstanceStateInfo, HAZk, MountDiskType, CHProxyVip, CosBucketName, CanAttachCbs, CanAttachCbsLvm, CanAttachCos, Components, UpgradeVersions

* [NodesSummary](https://cloud.tencent.com/document/api/1299/83429#NodesSummary)

	* 新增成员：AttachCBSSpec, SubProductType, SpecCore, SpecMemory, DiskCount, MaxDiskSize, Encrypt


### 第 7 次发布

发布时间：2023-03-15 01:11:52

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeInstanceClusters](https://cloud.tencent.com/document/api/1299/88646)

新增数据结构：

* [ClusterInfo](https://cloud.tencent.com/document/api/1299/83429#ClusterInfo)

### 第 6 次发布

发布时间：2023-02-08 01:18:00

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DestroyInstance](https://cloud.tencent.com/document/api/1299/86254)

修改接口：

* [ScaleOutInstance](https://cloud.tencent.com/document/api/1299/86157)

	* 新增入参：ReduceShardInfo


### 第 5 次发布

发布时间：2023-02-07 01:12:30

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeClusterConfigs](https://cloud.tencent.com/document/api/1299/86161)
* [DescribeInstanceKeyValConfigs](https://cloud.tencent.com/document/api/1299/86160)
* [ModifyInstanceKeyValConfigs](https://cloud.tencent.com/document/api/1299/86159)
* [ResizeDisk](https://cloud.tencent.com/document/api/1299/86158)
* [ScaleOutInstance](https://cloud.tencent.com/document/api/1299/86157)
* [ScaleUpInstance](https://cloud.tencent.com/document/api/1299/86156)

新增数据结构：

* [ClusterConfigsInfoFromEMR](https://cloud.tencent.com/document/api/1299/83429#ClusterConfigsInfoFromEMR)
* [InstanceConfigInfo](https://cloud.tencent.com/document/api/1299/83429#InstanceConfigInfo)
* [InstanceConfigItem](https://cloud.tencent.com/document/api/1299/83429#InstanceConfigItem)
* [MapConfigItem](https://cloud.tencent.com/document/api/1299/83429#MapConfigItem)

### 第 4 次发布

发布时间：2023-02-06 19:10:59

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeBackUpSchedule](https://cloud.tencent.com/document/api/1299/86155)

新增数据结构：

* [ScheduleStrategy](https://cloud.tencent.com/document/api/1299/83429#ScheduleStrategy)

### 第 3 次发布

发布时间：2022-12-20 14:06:27

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateInstanceNew](https://cloud.tencent.com/document/api/1299/84353)
* [DescribeInstance](https://cloud.tencent.com/document/api/1299/84354)

新增数据结构：

* [Charge](https://cloud.tencent.com/document/api/1299/83429#Charge)
* [InstanceInfo](https://cloud.tencent.com/document/api/1299/83429#InstanceInfo)
* [NodeSpec](https://cloud.tencent.com/document/api/1299/83429#NodeSpec)
* [NodesSummary](https://cloud.tencent.com/document/api/1299/83429#NodesSummary)
* [Tag](https://cloud.tencent.com/document/api/1299/83429#Tag)

### 第 2 次发布

发布时间：2022-11-30 06:17:14

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeSpec](https://cloud.tencent.com/document/api/1299/83510)

新增数据结构：

* [DiskSpec](https://cloud.tencent.com/document/api/1299/83429#DiskSpec)
* [ResourceSpec](https://cloud.tencent.com/document/api/1299/83429#ResourceSpec)

### 第 1 次发布

发布时间：2022-11-25 17:33:17

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [ActionAlterCkUser](https://cloud.tencent.com/document/api/1299/83425)
* [CreateBackUpSchedule](https://cloud.tencent.com/document/api/1299/83424)
* [DescribeCkSqlApis](https://cloud.tencent.com/document/api/1299/83428)
* [DescribeInstanceShards](https://cloud.tencent.com/document/api/1299/83427)
* [ModifyClusterConfigs](https://cloud.tencent.com/document/api/1299/83423)
* [ModifyUserNewPrivilege](https://cloud.tencent.com/document/api/1299/83422)
* [OpenBackUp](https://cloud.tencent.com/document/api/1299/83421)

新增数据结构：

* [BackupTableContent](https://cloud.tencent.com/document/api/1299/83429#BackupTableContent)
* [CkUserAlterInfo](https://cloud.tencent.com/document/api/1299/83429#CkUserAlterInfo)
* [ConfigSubmitContext](https://cloud.tencent.com/document/api/1299/83429#ConfigSubmitContext)




## 腾讯云数据仓库 TCHouse-D(cdwdoris) 版本：2021-12-28

### 第 16 次发布

发布时间：2024-08-01 01:19:02

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CancelBackupJob](https://cloud.tencent.com/document/api/1387/109544)
* [CreateBackUpSchedule](https://cloud.tencent.com/document/api/1387/109543)
* [DeleteBackUpData](https://cloud.tencent.com/document/api/1387/109542)
* [DescribeAreaRegion](https://cloud.tencent.com/document/api/1387/109559)
* [DescribeBackUpJob](https://cloud.tencent.com/document/api/1387/109558)
* [DescribeBackUpJobDetail](https://cloud.tencent.com/document/api/1387/109557)
* [DescribeBackUpSchedules](https://cloud.tencent.com/document/api/1387/109556)
* [DescribeBackUpTables](https://cloud.tencent.com/document/api/1387/109555)
* [DescribeBackUpTaskDetail](https://cloud.tencent.com/document/api/1387/109554)
* [DescribeClusterConfigsHistory](https://cloud.tencent.com/document/api/1387/109553)
* [DescribeDatabaseAuditResource](https://cloud.tencent.com/document/api/1387/109552)
* [DescribeDmsSqlHistory](https://cloud.tencent.com/document/api/1387/109551)
* [DescribeDorisMetricFiles](https://cloud.tencent.com/document/api/1387/109550)
* [DescribeFrontEnd](https://cloud.tencent.com/document/api/1387/109549)
* [DescribeInstanceNodesRole](https://cloud.tencent.com/document/api/1387/109548)
* [DescribeInstanceOperations](https://cloud.tencent.com/document/api/1387/109547)
* [DescribeInstancesHealthState](https://cloud.tencent.com/document/api/1387/109546)
* [DescribeSpec](https://cloud.tencent.com/document/api/1387/109545)
* [ModifyNodeStatus](https://cloud.tencent.com/document/api/1387/109541)
* [OpenBackUp](https://cloud.tencent.com/document/api/1387/109540)
* [RecoverBackUpJob](https://cloud.tencent.com/document/api/1387/109539)
* [RestartClusterForConfigs](https://cloud.tencent.com/document/api/1387/109538)

新增数据结构：

* [BackUpJobDisplay](https://cloud.tencent.com/document/api/1387/102385#BackUpJobDisplay)
* [BackupCosInfo](https://cloud.tencent.com/document/api/1387/102385#BackupCosInfo)
* [BackupStatus](https://cloud.tencent.com/document/api/1387/102385#BackupStatus)
* [BackupTableContent](https://cloud.tencent.com/document/api/1387/102385#BackupTableContent)
* [ClusterConfigsHistory](https://cloud.tencent.com/document/api/1387/102385#ClusterConfigsHistory)
* [CosSourceInfo](https://cloud.tencent.com/document/api/1387/102385#CosSourceInfo)
* [DescribeMetricsFileReq](https://cloud.tencent.com/document/api/1387/102385#DescribeMetricsFileReq)
* [DiskSpec](https://cloud.tencent.com/document/api/1387/102385#DiskSpec)
* [DorisSourceInfo](https://cloud.tencent.com/document/api/1387/102385#DorisSourceInfo)
* [FrontEndRule](https://cloud.tencent.com/document/api/1387/102385#FrontEndRule)
* [InstanceOperation](https://cloud.tencent.com/document/api/1387/102385#InstanceOperation)
* [ModifyMetricFileStruct](https://cloud.tencent.com/document/api/1387/102385#ModifyMetricFileStruct)
* [ModifyMetricFileStructNew](https://cloud.tencent.com/document/api/1387/102385#ModifyMetricFileStructNew)
* [NodeInfos](https://cloud.tencent.com/document/api/1387/102385#NodeInfos)
* [ResourceSpec](https://cloud.tencent.com/document/api/1387/102385#ResourceSpec)

### 第 15 次发布

发布时间：2024-07-31 01:13:58

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateWorkloadGroup](https://cloud.tencent.com/document/api/1387/109440)
* [DeleteWorkloadGroup](https://cloud.tencent.com/document/api/1387/109439)
* [DescribeFederationToken](https://cloud.tencent.com/document/api/1387/109447)
* [DescribeGoodsDetail](https://cloud.tencent.com/document/api/1387/109446)
* [DescribeInstanceUsedSubnets](https://cloud.tencent.com/document/api/1387/109445)
* [DescribeRegionZone](https://cloud.tencent.com/document/api/1387/109444)
* [DescribeReplicaVersion](https://cloud.tencent.com/document/api/1387/109443)
* [DescribeRestoreTaskDetail](https://cloud.tencent.com/document/api/1387/109442)
* [DescribeSqlApis](https://cloud.tencent.com/document/api/1387/109441)
* [DescribeUserBindWorkloadGroup](https://cloud.tencent.com/document/api/1387/109438)
* [DescribeWorkloadGroup](https://cloud.tencent.com/document/api/1387/109437)
* [FitClsLog](https://cloud.tencent.com/document/api/1387/109436)
* [ModifyInstanceKeyValConfigs](https://cloud.tencent.com/document/api/1387/109435)
* [ModifySecurityGroups](https://cloud.tencent.com/document/api/1387/109434)
* [ModifyUserBindWorkloadGroup](https://cloud.tencent.com/document/api/1387/109433)
* [ModifyUserPrivilegesV3](https://cloud.tencent.com/document/api/1387/109432)
* [ModifyWorkloadGroup](https://cloud.tencent.com/document/api/1387/109431)
* [ModifyWorkloadGroupStatus](https://cloud.tencent.com/document/api/1387/109430)
* [ReduceInstance](https://cloud.tencent.com/document/api/1387/109429)

新增数据结构：

* [BindUser](https://cloud.tencent.com/document/api/1387/102385#BindUser)
* [InstanceConfigItem](https://cloud.tencent.com/document/api/1387/102385#InstanceConfigItem)
* [RegionAreaInfo](https://cloud.tencent.com/document/api/1387/102385#RegionAreaInfo)
* [RegionInfo](https://cloud.tencent.com/document/api/1387/102385#RegionInfo)
* [ResourceNodeDiskSpec](https://cloud.tencent.com/document/api/1387/102385#ResourceNodeDiskSpec)
* [ResourceNodeSpec](https://cloud.tencent.com/document/api/1387/102385#ResourceNodeSpec)
* [RestoreStatus](https://cloud.tencent.com/document/api/1387/102385#RestoreStatus)
* [SpecExtra](https://cloud.tencent.com/document/api/1387/102385#SpecExtra)
* [UpdateUserPrivileges](https://cloud.tencent.com/document/api/1387/102385#UpdateUserPrivileges)
* [UserWorkloadGroup](https://cloud.tencent.com/document/api/1387/102385#UserWorkloadGroup)
* [VersionReplicaItem](https://cloud.tencent.com/document/api/1387/102385#VersionReplicaItem)
* [WorkloadGroupConfig](https://cloud.tencent.com/document/api/1387/102385#WorkloadGroupConfig)
* [ZoneInfo](https://cloud.tencent.com/document/api/1387/102385#ZoneInfo)

### 第 14 次发布

发布时间：2024-07-24 01:18:18

本次发布包含了以下内容：

改善已有的文档。

新增数据结构：

* [InstanceDetail](https://cloud.tencent.com/document/api/1387/102385#InstanceDetail)

修改数据结构：

* [InstanceInfo](https://cloud.tencent.com/document/api/1387/102385#InstanceInfo)

	* 新增成员：Details


### 第 13 次发布

发布时间：2024-06-20 01:19:00

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeSlowQueryRecordsDownload](https://cloud.tencent.com/document/api/1387/102613)

	* 新增入参：DbName, CatalogName


### 第 12 次发布

发布时间：2024-06-14 01:22:52

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [InstanceInfo](https://cloud.tencent.com/document/api/1387/102385#InstanceInfo)

	* 新增成员：EnableCoolDown, CoolDownBucket


### 第 11 次发布

发布时间：2024-05-27 01:18:10

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeSlowQueryRecordsDownload](https://cloud.tencent.com/document/api/1387/102613)

	* 新增入参：IsQuery


### 第 10 次发布

发布时间：2024-05-15 01:12:20

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeSlowQueryRecords](https://cloud.tencent.com/document/api/1387/102614)

	* 新增入参：Sql, ReadRows, ResultBytes, MemoryUsage

* [DescribeSlowQueryRecordsDownload](https://cloud.tencent.com/document/api/1387/102613)

	* 新增入参：Sql, ReadRows, ResultBytes, MemoryUsage


### 第 9 次发布

发布时间：2024-04-02 01:09:54

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateInstanceNew](https://cloud.tencent.com/document/api/1387/102611)

	* 新增入参：EnableMultiZones, UserMultiZoneInfos


新增数据结构：

* [NetworkInfo](https://cloud.tencent.com/document/api/1387/102385#NetworkInfo)

修改数据结构：

* [InstanceInfo](https://cloud.tencent.com/document/api/1387/102385#InstanceInfo)

	* 新增成员：EnableMultiZones, UserNetworkInfos

* [NodeInfo](https://cloud.tencent.com/document/api/1387/102385#NodeInfo)

	* 新增成员：NodeName, ComponentName, NodeRole, LastRestartTime, Zone


### 第 8 次发布

发布时间：2024-03-08 01:10:20

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [InstanceInfo](https://cloud.tencent.com/document/api/1387/102385#InstanceInfo)

	* 新增成员：IsWhiteSGs, BindSGs


### 第 7 次发布

发布时间：2024-01-24 01:23:33

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [SlowQueryRecord](https://cloud.tencent.com/document/api/1387/102385#SlowQueryRecord)

	* 新增成员：ResultBytesMB, MemoryUsageMB, DurationSec


### 第 6 次发布

发布时间：2023-12-26 01:09:04

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateInstanceNew](https://cloud.tencent.com/document/api/1387/102611)
* [DescribeClusterConfigs](https://cloud.tencent.com/document/api/1387/102619)
* [DescribeDatabaseAuditDownload](https://cloud.tencent.com/document/api/1387/102618)
* [DescribeDatabaseAuditRecords](https://cloud.tencent.com/document/api/1387/102617)
* [DescribeInstanceNodesInfo](https://cloud.tencent.com/document/api/1387/102616)
* [DescribeInstanceState](https://cloud.tencent.com/document/api/1387/102615)
* [DescribeSlowQueryRecords](https://cloud.tencent.com/document/api/1387/102614)
* [DescribeSlowQueryRecordsDownload](https://cloud.tencent.com/document/api/1387/102613)
* [DestroyInstance](https://cloud.tencent.com/document/api/1387/102610)
* [ModifyInstance](https://cloud.tencent.com/document/api/1387/102612)
* [ResizeDisk](https://cloud.tencent.com/document/api/1387/102609)
* [RestartClusterForNode](https://cloud.tencent.com/document/api/1387/102608)
* [ScaleOutInstance](https://cloud.tencent.com/document/api/1387/102607)
* [ScaleUpInstance](https://cloud.tencent.com/document/api/1387/102606)

新增数据结构：

* [ChargeProperties](https://cloud.tencent.com/document/api/1387/102385#ChargeProperties)
* [ClusterConfigsInfoFromEMR](https://cloud.tencent.com/document/api/1387/102385#ClusterConfigsInfoFromEMR)
* [ConfigKeyValue](https://cloud.tencent.com/document/api/1387/102385#ConfigKeyValue)
* [CreateInstanceSpec](https://cloud.tencent.com/document/api/1387/102385#CreateInstanceSpec)
* [DataBaseAuditRecord](https://cloud.tencent.com/document/api/1387/102385#DataBaseAuditRecord)
* [NodeInfo](https://cloud.tencent.com/document/api/1387/102385#NodeInfo)
* [SlowQueryRecord](https://cloud.tencent.com/document/api/1387/102385#SlowQueryRecord)

### 第 5 次发布

发布时间：2023-12-25 00:04:35

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [InstanceInfo](https://cloud.tencent.com/document/api/1387/102385#InstanceInfo)

	* 新增成员：GraceShutdownWaitSeconds, CaseSensitive


### 第 4 次发布

发布时间：2023-12-22 01:09:56

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [InstanceInfo](https://cloud.tencent.com/document/api/1387/102385#InstanceInfo)

	* 新增成员：RestartTimeout


### 第 3 次发布

发布时间：2023-12-20 01:16:54

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [InstanceInfo](https://cloud.tencent.com/document/api/1387/102385#InstanceInfo)

	* 新增成员：Characteristic


### 第 2 次发布

发布时间：2023-12-19 01:19:18

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [InstanceInfo](https://cloud.tencent.com/document/api/1387/102385#InstanceInfo)

	* 新增成员：IfExistCatalog


### 第 1 次发布

发布时间：2023-12-11 11:31:16

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeInstance](https://cloud.tencent.com/document/api/1387/102384)
* [DescribeInstanceNodes](https://cloud.tencent.com/document/api/1387/102383)
* [DescribeInstances](https://cloud.tencent.com/document/api/1387/102382)

新增数据结构：

* [AttachCBSSpec](https://cloud.tencent.com/document/api/1387/102385#AttachCBSSpec)
* [InstanceInfo](https://cloud.tencent.com/document/api/1387/102385#InstanceInfo)
* [InstanceNode](https://cloud.tencent.com/document/api/1387/102385#InstanceNode)
* [NodesSummary](https://cloud.tencent.com/document/api/1387/102385#NodesSummary)
* [SearchTags](https://cloud.tencent.com/document/api/1387/102385#SearchTags)
* [Tag](https://cloud.tencent.com/document/api/1387/102385#Tag)




## 云数据仓库 PostgreSQL(cdwpg) 版本：2020-12-30

### 第 7 次发布

发布时间：2024-03-28 01:10:53

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateInstanceByApi](https://cloud.tencent.com/document/api/878/98894)

	* 新增入参：ProductVersion


### 第 6 次发布

发布时间：2023-10-24 01:08:56

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeInstanceInfo](https://cloud.tencent.com/document/api/878/100615)

新增数据结构：

* [CBSSpecInfo](https://cloud.tencent.com/document/api/878/98895#CBSSpecInfo)
* [ResourceInfo](https://cloud.tencent.com/document/api/878/98895#ResourceInfo)
* [SimpleInstanceInfo](https://cloud.tencent.com/document/api/878/98895#SimpleInstanceInfo)

### 第 5 次发布

发布时间：2023-10-19 15:58:54

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeInstances](https://cloud.tencent.com/document/api/878/100444)

新增数据结构：

* [SearchTags](https://cloud.tencent.com/document/api/878/98895#SearchTags)

### 第 4 次发布

发布时间：2023-10-13 01:10:05

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeInstance](https://cloud.tencent.com/document/api/878/100195)

新增数据结构：

* [InstanceInfo](https://cloud.tencent.com/document/api/878/98895#InstanceInfo)
* [InstanceNodeGroup](https://cloud.tencent.com/document/api/878/98895#InstanceNodeGroup)
* [InstanceStateInfo](https://cloud.tencent.com/document/api/878/98895#InstanceStateInfo)

### 第 3 次发布

发布时间：2023-10-12 01:20:34

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeInstanceState](https://cloud.tencent.com/document/api/878/100160)
* [ModifyInstance](https://cloud.tencent.com/document/api/878/100159)

### 第 2 次发布

发布时间：2023-10-11 01:19:09

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeSimpleInstances](https://cloud.tencent.com/document/api/878/100126)

新增数据结构：

* [InstanceSimpleInfoNew](https://cloud.tencent.com/document/api/878/98895#InstanceSimpleInfoNew)

### 第 1 次发布

发布时间：2023-09-27 11:25:41

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateInstanceByApi](https://cloud.tencent.com/document/api/878/98894)
* [DestroyInstanceByApi](https://cloud.tencent.com/document/api/878/98893)

新增数据结构：

* [CBSSpec](https://cloud.tencent.com/document/api/878/98895#CBSSpec)
* [ChargeProperties](https://cloud.tencent.com/document/api/878/98895#ChargeProperties)
* [ResourceSpecNew](https://cloud.tencent.com/document/api/878/98895#ResourceSpecNew)
* [Tag](https://cloud.tencent.com/document/api/878/98895#Tag)




## 专属可用区(cdz) 版本：2022-11-23

### 第 1 次发布

发布时间：2024-07-15 09:37:14

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeCloudDedicatedZoneHosts](https://cloud.tencent.com/document/api/1629/108682)
* [DescribeCloudDedicatedZoneResourceSummary](https://cloud.tencent.com/document/api/1629/108681)

新增数据结构：

* [CloudDedicatedZoneHostsInfo](https://cloud.tencent.com/document/api/1629/108683#CloudDedicatedZoneHostsInfo)
* [CloudDedicatedZoneResourceStatisticsInfo](https://cloud.tencent.com/document/api/1629/108683#CloudDedicatedZoneResourceStatisticsInfo)
* [CloudDedicatedZoneResourceSummaryInfo](https://cloud.tencent.com/document/api/1629/108683#CloudDedicatedZoneResourceSummaryInfo)




## 混沌演练平台(cfg) 版本：2021-08-20

### 第 16 次发布

发布时间：2024-07-26 14:53:06

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateTaskFromAction](https://cloud.tencent.com/document/api/1500/109362)
* [DescribeActionFieldConfigList](https://cloud.tencent.com/document/api/1500/109361)
* [DescribeActionLibraryList](https://cloud.tencent.com/document/api/1500/109360)
* [DescribeObjectTypeList](https://cloud.tencent.com/document/api/1500/109359)

新增数据结构：

* [ActionFieldConfigDetail](https://cloud.tencent.com/document/api/1500/71784#ActionFieldConfigDetail)
* [ActionFieldConfigResult](https://cloud.tencent.com/document/api/1500/71784#ActionFieldConfigResult)
* [ActionLibraryListResult](https://cloud.tencent.com/document/api/1500/71784#ActionLibraryListResult)
* [ObjectType](https://cloud.tencent.com/document/api/1500/71784#ObjectType)
* [ObjectTypeConfig](https://cloud.tencent.com/document/api/1500/71784#ObjectTypeConfig)
* [ObjectTypeConfigFields](https://cloud.tencent.com/document/api/1500/71784#ObjectTypeConfigFields)
* [ObjectTypeJsonParse](https://cloud.tencent.com/document/api/1500/71784#ObjectTypeJsonParse)
* [ResourceOffline](https://cloud.tencent.com/document/api/1500/71784#ResourceOffline)

### 第 15 次发布

发布时间：2024-01-19 01:08:39

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [TaskGroupInstance](https://cloud.tencent.com/document/api/1500/71784#TaskGroupInstance)

	* <font color="#dd0000">**修改成员**：</font>TaskGroupInstanceExecuteLog


### 第 14 次发布

发布时间：2023-11-24 01:09:00

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [Task](https://cloud.tencent.com/document/api/1500/71784#Task)

	* 新增成员：PolicyDealType

* [TaskConfig](https://cloud.tencent.com/document/api/1500/71784#TaskConfig)

	* 新增成员：PolicyDealType

* [Template](https://cloud.tencent.com/document/api/1500/71784#Template)

	* 新增成员：PolicyDealType


### 第 13 次发布

发布时间：2023-11-22 01:45:21

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeTaskPolicyTriggerLog](https://cloud.tencent.com/document/api/1500/101818)
* [TriggerPolicy](https://cloud.tencent.com/document/api/1500/101817)

新增数据结构：

* [PolicyTriggerLog](https://cloud.tencent.com/document/api/1500/71784#PolicyTriggerLog)

### 第 12 次发布

发布时间：2023-11-10 01:09:57

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeTaskList](https://cloud.tencent.com/document/api/1500/71779)

	* 新增入参：TaskUpdateTime, TaskStatusList


修改数据结构：

* [Task](https://cloud.tencent.com/document/api/1500/71784#Task)

	* 新增成员：VerifyId

* [TaskListItem](https://cloud.tencent.com/document/api/1500/71784#TaskListItem)

	* 新增成员：VerifyId, TaskStatusType


### 第 11 次发布

发布时间：2023-10-10 01:10:06

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeTaskList](https://cloud.tencent.com/document/api/1500/71779)

	* 新增入参：TaskId, ApplicationId, ApplicationName


新增数据结构：

* [ApmServiceInfo](https://cloud.tencent.com/document/api/1500/71784#ApmServiceInfo)

修改数据结构：

* [Task](https://cloud.tencent.com/document/api/1500/71784#Task)

	* 新增成员：ApplicationId, ApplicationName, AlarmPolicy, ApmServiceList

* [TaskListItem](https://cloud.tencent.com/document/api/1500/71784#TaskListItem)

	* 新增成员：ApplicationId, ApplicationName

* [Template](https://cloud.tencent.com/document/api/1500/71784#Template)

	* 新增成员：ApmServiceList, AlarmPolicy


### 第 10 次发布

发布时间：2023-08-23 01:12:18

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [TaskMonitor](https://cloud.tencent.com/document/api/1500/71784#TaskMonitor)

	* 新增成员：MetricId

* [TemplateMonitor](https://cloud.tencent.com/document/api/1500/71784#TemplateMonitor)

	* 新增成员：MetricId


### 第 9 次发布

发布时间：2023-07-25 10:44:01

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeTaskList](https://cloud.tencent.com/document/api/1500/71779)

	* 新增入参：Filters

* [DescribeTemplateList](https://cloud.tencent.com/document/api/1500/71773)

	* 新增入参：Filters


新增数据结构：

* [ActionFilter](https://cloud.tencent.com/document/api/1500/71784#ActionFilter)

### 第 8 次发布

发布时间：2023-06-29 01:09:00

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeTemplateList](https://cloud.tencent.com/document/api/1500/71773)

	* 新增入参：TemplateSource, TemplateIdList


修改数据结构：

* [TaskListItem](https://cloud.tencent.com/document/api/1500/71784#TaskListItem)

	* 新增成员：TaskExpect

* [Template](https://cloud.tencent.com/document/api/1500/71784#Template)

	* 新增成员：TemplateSource

* [TemplateListItem](https://cloud.tencent.com/document/api/1500/71784#TemplateListItem)

	* 新增成员：TemplateSource


### 第 7 次发布

发布时间：2023-06-08 01:11:18

本次发布包含了以下内容：

改善已有的文档。

新增数据结构：

* [TaskGroupInstancesExecuteRules](https://cloud.tencent.com/document/api/1500/71784#TaskGroupInstancesExecuteRules)

修改数据结构：

* [TaskGroup](https://cloud.tencent.com/document/api/1500/71784#TaskGroup)

	* 新增成员：TaskGroupDiscardInstanceList, TaskGroupSelectedInstanceList, TaskGroupInstancesExecuteRule


### 第 6 次发布

发布时间：2023-05-16 01:15:24

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [Task](https://cloud.tencent.com/document/api/1500/71784#Task)

	* 新增成员：TaskPlanId, TaskPlanTitle


### 第 5 次发布

发布时间：2022-12-26 01:15:15

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeTask](https://cloud.tencent.com/document/api/1500/71781)

	* 新增出参：ReportInfo


新增数据结构：

* [TaskReportInfo](https://cloud.tencent.com/document/api/1500/71784#TaskReportInfo)

### 第 4 次发布

发布时间：2022-09-26 06:16:02

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [TaskListItem](https://cloud.tencent.com/document/api/1500/71784#TaskListItem)

	* 新增成员：TaskPreCheckStatus, TaskPreCheckSuccess


### 第 3 次发布

发布时间：2022-07-22 06:04:01

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [TaskGroupAction](https://cloud.tencent.com/document/api/1500/71784#TaskGroupAction)

	* 新增成员：TaskGroupActionExecuteTime

* [TaskGroupInstance](https://cloud.tencent.com/document/api/1500/71784#TaskGroupInstance)

	* 新增成员：TaskGroupInstanceExecuteTime


### 第 2 次发布

发布时间：2022-07-20 06:02:51

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [TaskGroupAction](https://cloud.tencent.com/document/api/1500/71784#TaskGroupAction)

	* 新增成员：IsExecuteRedo, ActionRisk

* [TaskGroupInstance](https://cloud.tencent.com/document/api/1500/71784#TaskGroupInstance)

	* 新增成员：TaskGroupInstanceIsRedo


### 第 1 次发布

发布时间：2022-03-30 12:59:20

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateTaskFromTemplate](https://cloud.tencent.com/document/api/1500/71783)
* [DeleteTask](https://cloud.tencent.com/document/api/1500/71782)
* [DescribeTask](https://cloud.tencent.com/document/api/1500/71781)
* [DescribeTaskExecuteLogs](https://cloud.tencent.com/document/api/1500/71780)
* [DescribeTaskList](https://cloud.tencent.com/document/api/1500/71779)
* [DescribeTemplate](https://cloud.tencent.com/document/api/1500/71778)
* [DescribeTemplateList](https://cloud.tencent.com/document/api/1500/71773)
* [ExecuteTask](https://cloud.tencent.com/document/api/1500/71777)
* [ExecuteTaskInstance](https://cloud.tencent.com/document/api/1500/71776)
* [ModifyTaskRunStatus](https://cloud.tencent.com/document/api/1500/71775)

新增数据结构：

* [DescribePolicy](https://cloud.tencent.com/document/api/1500/71784#DescribePolicy)
* [TagWithCreate](https://cloud.tencent.com/document/api/1500/71784#TagWithCreate)
* [TagWithDescribe](https://cloud.tencent.com/document/api/1500/71784#TagWithDescribe)
* [Task](https://cloud.tencent.com/document/api/1500/71784#Task)
* [TaskConfig](https://cloud.tencent.com/document/api/1500/71784#TaskConfig)
* [TaskGroup](https://cloud.tencent.com/document/api/1500/71784#TaskGroup)
* [TaskGroupAction](https://cloud.tencent.com/document/api/1500/71784#TaskGroupAction)
* [TaskGroupActionConfig](https://cloud.tencent.com/document/api/1500/71784#TaskGroupActionConfig)
* [TaskGroupConfig](https://cloud.tencent.com/document/api/1500/71784#TaskGroupConfig)
* [TaskGroupInstance](https://cloud.tencent.com/document/api/1500/71784#TaskGroupInstance)
* [TaskListItem](https://cloud.tencent.com/document/api/1500/71784#TaskListItem)
* [TaskMonitor](https://cloud.tencent.com/document/api/1500/71784#TaskMonitor)
* [Template](https://cloud.tencent.com/document/api/1500/71784#Template)
* [TemplateGroup](https://cloud.tencent.com/document/api/1500/71784#TemplateGroup)
* [TemplateGroupAction](https://cloud.tencent.com/document/api/1500/71784#TemplateGroupAction)
* [TemplateListItem](https://cloud.tencent.com/document/api/1500/71784#TemplateListItem)
* [TemplateMonitor](https://cloud.tencent.com/document/api/1500/71784#TemplateMonitor)
* [TemplatePolicy](https://cloud.tencent.com/document/api/1500/71784#TemplatePolicy)




## 文件存储(cfs) 版本：2019-07-19

### 第 30 次发布

发布时间：2024-08-05 01:14:34

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [UserQuota](https://cloud.tencent.com/document/api/582/38175#UserQuota)

	* 新增成员：DirectoryPath, Status


### 第 29 次发布

发布时间：2024-08-02 01:14:53

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DeleteUserQuota](https://cloud.tencent.com/document/api/582/82655)

	* 新增入参：DirectoryPath

	* <font color="#dd0000">**修改入参**：</font>UserId

* [SetUserQuota](https://cloud.tencent.com/document/api/582/82653)

	* 新增入参：DirectoryPath

	* <font color="#dd0000">**修改入参**：</font>UserId


### 第 28 次发布

发布时间：2024-01-09 01:09:35

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeCfsFileSystems](https://cloud.tencent.com/document/api/582/38170)

	* 新增入参：CreationToken


### 第 27 次发布

发布时间：2023-11-09 01:08:52

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [UpdateFileSystemBandwidthLimit](https://cloud.tencent.com/document/api/582/101428)

### 第 26 次发布

发布时间：2023-09-01 01:09:12

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeCfsFileSystemClients](https://cloud.tencent.com/document/api/582/47581)

	* 新增入参：Offset, Limit

	* 新增出参：TotalCount


### 第 25 次发布

发布时间：2023-07-27 01:09:08

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeCfsFileSystems](https://cloud.tencent.com/document/api/582/38170)

	* 新增入参：Offset, Limit


### 第 24 次发布

发布时间：2023-07-14 01:07:56

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [AutoSnapshotPolicyInfo](https://cloud.tencent.com/document/api/582/38175#AutoSnapshotPolicyInfo)

	* <font color="#dd0000">**修改成员**：</font>DayOfMonth, IntervalDays, CrossRegionsAliveDays


### 第 23 次发布

发布时间：2023-07-12 01:12:32

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateCfsFileSystem](https://cloud.tencent.com/document/api/582/38174)

	* 新增入参：SnapshotId, AutoSnapshotPolicyId, EnableAutoScaleUp


修改数据结构：

* [SnapshotInfo](https://cloud.tencent.com/document/api/582/38175#SnapshotInfo)

	* 新增成员：SnapshotTime

	* <font color="#dd0000">**修改成员**：</font>SnapshotType


### 第 22 次发布

发布时间：2023-06-20 01:12:06

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [AutoSnapshotPolicyInfo](https://cloud.tencent.com/document/api/582/38175#AutoSnapshotPolicyInfo)

	* 新增成员：CrossRegionsAliveDays


### 第 21 次发布

发布时间：2023-06-06 01:12:18

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [TieringDetailInfo](https://cloud.tencent.com/document/api/582/38175#TieringDetailInfo)

	* 新增成员：TieringSizeInBytes


### 第 20 次发布

发布时间：2023-05-24 01:10:16

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [SnapshotInfo](https://cloud.tencent.com/document/api/582/38175#SnapshotInfo)

	* 新增成员：SnapshotType


### 第 19 次发布

发布时间：2023-04-25 01:11:04

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [ModifyFileSystemAutoScaleUpRule](https://cloud.tencent.com/document/api/582/90591)

### 第 18 次发布

发布时间：2023-04-24 01:08:05

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [ScaleUpFileSystem](https://cloud.tencent.com/document/api/582/90456)

### 第 17 次发布

发布时间：2023-04-17 01:08:20

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateMigrationTask](https://cloud.tencent.com/document/api/582/90217)
* [DeleteMigrationTask](https://cloud.tencent.com/document/api/582/90216)
* [DescribeBucketList](https://cloud.tencent.com/document/api/582/90215)
* [DescribeMigrationTasks](https://cloud.tencent.com/document/api/582/90214)
* [StopMigrationTask](https://cloud.tencent.com/document/api/582/90213)

新增数据结构：

* [BucketInfo](https://cloud.tencent.com/document/api/582/38175#BucketInfo)
* [MigrationTaskInfo](https://cloud.tencent.com/document/api/582/38175#MigrationTaskInfo)

### 第 16 次发布

发布时间：2023-03-23 01:17:23

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateAutoSnapshotPolicy](https://cloud.tencent.com/document/api/582/80210)

	* 新增入参：DayOfMonth, IntervalDays

	* <font color="#dd0000">**修改入参**：</font>DayOfWeek

* [UpdateAutoSnapshotPolicy](https://cloud.tencent.com/document/api/582/80203)

	* 新增入参：DayOfMonth, IntervalDays


修改数据结构：

* [AutoSnapshotPolicyInfo](https://cloud.tencent.com/document/api/582/38175#AutoSnapshotPolicyInfo)

	* 新增成员：DayOfMonth, IntervalDays


### 第 15 次发布

发布时间：2023-03-20 01:11:04

本次发布包含了以下内容：

改善已有的文档。

新增数据结构：

* [TieringDetailInfo](https://cloud.tencent.com/document/api/582/38175#TieringDetailInfo)

修改数据结构：

* [FileSystemInfo](https://cloud.tencent.com/document/api/582/38175#FileSystemInfo)

	* 新增成员：TieringState, TieringDetail


### 第 14 次发布

发布时间：2022-12-19 01:23:20

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [UserQuota](https://cloud.tencent.com/document/api/582/38175#UserQuota)

	* 新增成员：CapacityUsed, FileUsed


### 第 13 次发布

发布时间：2022-11-21 06:14:58

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DeleteCfsSnapshot](https://cloud.tencent.com/document/api/582/80199)

	* 新增入参：SnapshotIds

	* <font color="#dd0000">**修改入参**：</font>SnapshotId


### 第 12 次发布

发布时间：2022-11-11 06:15:57

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DeleteUserQuota](https://cloud.tencent.com/document/api/582/82655)
* [DescribeUserQuota](https://cloud.tencent.com/document/api/582/82654)
* [SetUserQuota](https://cloud.tencent.com/document/api/582/82653)

新增数据结构：

* [UserQuota](https://cloud.tencent.com/document/api/582/38175#UserQuota)

### 第 11 次发布

发布时间：2022-09-07 06:15:13

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [BindAutoSnapshotPolicy](https://cloud.tencent.com/document/api/582/80211)
* [CreateAutoSnapshotPolicy](https://cloud.tencent.com/document/api/582/80210)
* [CreateCfsSnapshot](https://cloud.tencent.com/document/api/582/80200)
* [DeleteAutoSnapshotPolicy](https://cloud.tencent.com/document/api/582/80209)
* [DeleteCfsSnapshot](https://cloud.tencent.com/document/api/582/80199)
* [DescribeAutoSnapshotPolicies](https://cloud.tencent.com/document/api/582/80208)
* [DescribeCfsSnapshotOverview](https://cloud.tencent.com/document/api/582/80207)
* [DescribeCfsSnapshots](https://cloud.tencent.com/document/api/582/80206)
* [DescribeSnapshotOperationLogs](https://cloud.tencent.com/document/api/582/80205)
* [UnbindAutoSnapshotPolicy](https://cloud.tencent.com/document/api/582/80204)
* [UpdateAutoSnapshotPolicy](https://cloud.tencent.com/document/api/582/80203)
* [UpdateCfsSnapshotAttribute](https://cloud.tencent.com/document/api/582/80202)

新增数据结构：

* [AutoSnapshotPolicyInfo](https://cloud.tencent.com/document/api/582/38175#AutoSnapshotPolicyInfo)
* [FileSystemByPolicy](https://cloud.tencent.com/document/api/582/38175#FileSystemByPolicy)
* [Filter](https://cloud.tencent.com/document/api/582/38175#Filter)
* [SnapshotInfo](https://cloud.tencent.com/document/api/582/38175#SnapshotInfo)
* [SnapshotOperateLog](https://cloud.tencent.com/document/api/582/38175#SnapshotOperateLog)
* [SnapshotStatistics](https://cloud.tencent.com/document/api/582/38175#SnapshotStatistics)

### 第 10 次发布

发布时间：2022-02-11 08:03:37

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [FileSystemInfo](https://cloud.tencent.com/document/api/582/38175#FileSystemInfo)

	* 新增成员：Tags


### 第 9 次发布

发布时间：2021-08-26 08:04:29

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateCfsFileSystem](https://cloud.tencent.com/document/api/582/38174)

	* 新增入参：CcnId, CidrBlock, Capacity


修改数据结构：

* [FileSystemInfo](https://cloud.tencent.com/document/api/582/38175#FileSystemInfo)

	* 新增成员：Capacity

* [MountInfo](https://cloud.tencent.com/document/api/582/38175#MountInfo)

	* 新增成员：CcnID, CidrBlock


### 第 8 次发布

发布时间：2020-11-05 08:02:47

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateCfsFileSystem](https://cloud.tencent.com/document/api/582/38174)

	* 新增出参：CreationTime, CreationToken, FileSystemId, LifeCycleState, SizeByte, ZoneId, FsName, Encrypted


### 第 7 次发布

发布时间：2020-11-03 08:03:16

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateCfsFileSystem](https://cloud.tencent.com/document/api/582/38174)

	* 新增入参：ClientToken

	* <font color="#dd0000">**删除出参**：</font>CreationTime, CreationToken, FileSystemId, LifeCycleState, SizeByte, ZoneId, FsName, Encrypted


### 第 6 次发布

发布时间：2020-08-19 08:07:50

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [AvailableType](https://cloud.tencent.com/document/api/582/38175#AvailableType)

	* 新增成员：Prepayment


### 第 5 次发布

发布时间：2020-08-18 08:08:49

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeCfsFileSystemClients](https://cloud.tencent.com/document/api/582/47581)

新增数据结构：

* [FileSystemClient](https://cloud.tencent.com/document/api/582/38175#FileSystemClient)

### 第 4 次发布

发布时间：2020-08-14 08:07:54

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [FileSystemInfo](https://cloud.tencent.com/document/api/582/38175#FileSystemInfo)

	* 新增成员：BandwidthLimit


### 第 3 次发布

发布时间：2020-03-16 08:05:52

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [FileSystemInfo](https://cloud.tencent.com/document/api/582/38175#FileSystemInfo)

	* 新增成员：AppId


### 第 2 次发布

发布时间：2020-02-26 22:43:53

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateCfsFileSystem](https://cloud.tencent.com/document/api/582/38174)

	* 新增入参：ResourceTags

* [DescribeCfsFileSystems](https://cloud.tencent.com/document/api/582/38170)

	* 新增出参：TotalCount


新增数据结构：

* [TagInfo](https://cloud.tencent.com/document/api/582/38175#TagInfo)

修改数据结构：

* [AvailableZone](https://cloud.tencent.com/document/api/582/38175#AvailableZone)

	* 新增成员：ZoneName


### 第 1 次发布

发布时间：2019-09-26 22:06:14

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateCfsFileSystem](https://cloud.tencent.com/document/api/582/38174)
* [CreateCfsPGroup](https://cloud.tencent.com/document/api/582/38161)
* [CreateCfsRule](https://cloud.tencent.com/document/api/582/38160)
* [DeleteCfsFileSystem](https://cloud.tencent.com/document/api/582/38173)
* [DeleteCfsPGroup](https://cloud.tencent.com/document/api/582/38159)
* [DeleteCfsRule](https://cloud.tencent.com/document/api/582/38158)
* [DeleteMountTarget](https://cloud.tencent.com/document/api/582/38172)
* [DescribeAvailableZoneInfo](https://cloud.tencent.com/document/api/582/38171)
* [DescribeCfsFileSystems](https://cloud.tencent.com/document/api/582/38170)
* [DescribeCfsPGroups](https://cloud.tencent.com/document/api/582/38157)
* [DescribeCfsRules](https://cloud.tencent.com/document/api/582/38156)
* [DescribeCfsServiceStatus](https://cloud.tencent.com/document/api/582/38164)
* [DescribeMountTargets](https://cloud.tencent.com/document/api/582/38169)
* [SignUpCfsService](https://cloud.tencent.com/document/api/582/38163)
* [UpdateCfsFileSystemName](https://cloud.tencent.com/document/api/582/38168)
* [UpdateCfsFileSystemPGroup](https://cloud.tencent.com/document/api/582/38167)
* [UpdateCfsFileSystemSizeLimit](https://cloud.tencent.com/document/api/582/38166)
* [UpdateCfsPGroup](https://cloud.tencent.com/document/api/582/38155)
* [UpdateCfsRule](https://cloud.tencent.com/document/api/582/38154)

新增数据结构：

* [AvailableProtoStatus](https://cloud.tencent.com/document/api/582/38175#AvailableProtoStatus)
* [AvailableRegion](https://cloud.tencent.com/document/api/582/38175#AvailableRegion)
* [AvailableType](https://cloud.tencent.com/document/api/582/38175#AvailableType)
* [AvailableZone](https://cloud.tencent.com/document/api/582/38175#AvailableZone)
* [FileSystemInfo](https://cloud.tencent.com/document/api/582/38175#FileSystemInfo)
* [MountInfo](https://cloud.tencent.com/document/api/582/38175#MountInfo)
* [PGroup](https://cloud.tencent.com/document/api/582/38175#PGroup)
* [PGroupInfo](https://cloud.tencent.com/document/api/582/38175#PGroupInfo)
* [PGroupRuleInfo](https://cloud.tencent.com/document/api/582/38175#PGroupRuleInfo)




## 云防火墙(cfw) 版本：2019-09-04

### 第 61 次发布

发布时间：2024-07-30 01:19:22

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [DescAcItem](https://cloud.tencent.com/document/api/1132/49071#DescAcItem)

	* 新增成员：LastHitTime


### 第 60 次发布

发布时间：2024-07-26 01:19:51

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeNatFwDnatRule](https://cloud.tencent.com/document/api/1132/109336)

新增数据结构：

* [DescNatDnatRule](https://cloud.tencent.com/document/api/1132/49071#DescNatDnatRule)

修改数据结构：

* [VpcFwGroupInfo](https://cloud.tencent.com/document/api/1132/49071#VpcFwGroupInfo)

	* 新增成员：NeedSwitchCcnOverlap, CcnId


### 第 59 次发布

发布时间：2024-07-25 01:19:29

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeAddressTemplateList](https://cloud.tencent.com/document/api/1132/97918)

	* 新增出参：UsedTemplateCount, TemplateQuotaCount

* [DescribeLogs](https://cloud.tencent.com/document/api/1132/91646)

	* 新增出参：AppProtocolList


### 第 58 次发布

发布时间：2024-06-06 01:22:29

本次发布包含了以下内容：

改善已有的文档。

<font color="#dd0000">**预下线接口**：</font>

* DeleteVpcInstance

### 第 57 次发布

发布时间：2024-04-19 01:11:12

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [ExpandCfwVertical](https://cloud.tencent.com/document/api/1132/54258)

	* 新增入参：ElasticSwitch, ElasticBandwidth, Tags


新增数据结构：

* [TagInfo](https://cloud.tencent.com/document/api/1132/49071#TagInfo)

修改数据结构：

* [NatInstanceInfo](https://cloud.tencent.com/document/api/1132/49071#NatInstanceInfo)

	* 新增成员：ReserveTime, ReserveVersion, ReserveVersionState, ElasticSwitch, ElasticBandwidth, IsFirstAfterPay

* [VpcFwInstanceInfo](https://cloud.tencent.com/document/api/1132/49071#VpcFwInstanceInfo)

	* 新增成员：ReserveTime, ReserveVersion, ReserveVersionState, ElasticSwitch, ElasticBandwidth, IsFirstAfterPay


### 第 56 次发布

发布时间：2024-03-01 01:11:09

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateBlockIgnoreRuleNew](https://cloud.tencent.com/document/api/1132/104038)
* [DeleteBlockIgnoreRuleNew](https://cloud.tencent.com/document/api/1132/104037)
* [ModifyBlockIgnoreRuleNew](https://cloud.tencent.com/document/api/1132/104036)

新增数据结构：

* [BanAndAllowRule](https://cloud.tencent.com/document/api/1132/49071#BanAndAllowRule)
* [BanAndAllowRuleDel](https://cloud.tencent.com/document/api/1132/49071#BanAndAllowRuleDel)

### 第 55 次发布

发布时间：2024-02-29 01:10:25

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [TemplateListInfo](https://cloud.tencent.com/document/api/1132/49071#TemplateListInfo)

	* 新增成员：IPNum


### 第 54 次发布

发布时间：2024-01-23 14:38:08

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [AddEnterpriseSecurityGroupRules](https://cloud.tencent.com/document/api/1132/64234)

	* 新增入参：From, IsUseId

* [DescribeBlockIgnoreList](https://cloud.tencent.com/document/api/1132/86691)

	* 新增入参：ShowType

	* <font color="#dd0000">**修改入参**：</font>RuleType

	* 新增出参：RuleTypeDataList


新增数据结构：

* [CustomWhiteRule](https://cloud.tencent.com/document/api/1132/49071#CustomWhiteRule)

修改数据结构：

* [BlockIgnoreRule](https://cloud.tencent.com/document/api/1132/49071#BlockIgnoreRule)

	* 新增成员：RuleType, IocName, IocInfo, DirectionList, LastHitTime, CustomRule

* [CreateNatRuleItem](https://cloud.tencent.com/document/api/1132/49071#CreateNatRuleItem)

	* 新增成员：InternalUuid

* [DescAcItem](https://cloud.tencent.com/document/api/1132/49071#DescAcItem)

	* 新增成员：SourceName, TargetName

* [SecurityGroupListData](https://cloud.tencent.com/document/api/1132/49071#SecurityGroupListData)

	* 新增成员：ProtocolPortName

* [SecurityGroupRule](https://cloud.tencent.com/document/api/1132/49071#SecurityGroupRule)

	* 新增成员：Uid

* [VpcRuleItem](https://cloud.tencent.com/document/api/1132/49071#VpcRuleItem)

	* 新增成员：TargetName, SourceName


### 第 53 次发布

发布时间：2024-01-09 01:09:43

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeIdsWhiteRule](https://cloud.tencent.com/document/api/1132/102105)

	* 新增出参：Data


新增数据结构：

* [IdsWhiteInfo](https://cloud.tencent.com/document/api/1132/49071#IdsWhiteInfo)

### 第 52 次发布

发布时间：2024-01-05 01:09:38

本次发布包含了以下内容：

改善已有的文档。

<font color="#dd0000">**删除接口**：</font>

* ModifyPublicIPSwitchStatus

### 第 51 次发布

发布时间：2023-12-19 01:19:59

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [CreateNatRuleItem](https://cloud.tencent.com/document/api/1132/49071#CreateNatRuleItem)

	* 新增成员：ParamTemplateId

* [CreateRuleItem](https://cloud.tencent.com/document/api/1132/49071#CreateRuleItem)

	* 新增成员：ParamTemplateId

* [DescAcItem](https://cloud.tencent.com/document/api/1132/49071#DescAcItem)

	* 新增成员：ParamTemplateName, ParamTemplateId

* [VpcRuleItem](https://cloud.tencent.com/document/api/1132/49071#VpcRuleItem)

	* 新增成员：ParamTemplateId, ParamTemplateName


### 第 50 次发布

发布时间：2023-12-01 01:10:27

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateIdsWhiteRule](https://cloud.tencent.com/document/api/1132/102107)
* [DeleteIdsWhiteRule](https://cloud.tencent.com/document/api/1132/102106)
* [DescribeIdsWhiteRule](https://cloud.tencent.com/document/api/1132/102105)

### 第 49 次发布

发布时间：2023-11-28 01:09:22

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeResourceGroup](https://cloud.tencent.com/document/api/1132/60246)

	* 新增入参：ShowType


### 第 48 次发布

发布时间：2023-11-15 01:17:59

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateAddressTemplate](https://cloud.tencent.com/document/api/1132/95034)

	* 新增入参：ProtocolType

* [DescribeAddressTemplateList](https://cloud.tencent.com/document/api/1132/97918)

	* 新增入参：TemplateType, TemplateId

	* 新增出参：IpTemplateCount, DomainTemplateCount, PortTemplateCount

* [ModifyAddressTemplate](https://cloud.tencent.com/document/api/1132/97919)

	* 新增入参：ProtocolType


修改数据结构：

* [EdgeIpInfo](https://cloud.tencent.com/document/api/1132/49071#EdgeIpInfo)

	* 新增成员：Domain

* [TemplateListInfo](https://cloud.tencent.com/document/api/1132/49071#TemplateListInfo)

	* 新增成员：TemplateId, ProtocolType


### 第 47 次发布

发布时间：2023-10-27 01:19:30

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateAlertCenterIsolate](https://cloud.tencent.com/document/api/1132/100807)
* [CreateAlertCenterOmit](https://cloud.tencent.com/document/api/1132/100806)
* [CreateAlertCenterRule](https://cloud.tencent.com/document/api/1132/100805)

修改数据结构：

* [FwGroupSwitchShow](https://cloud.tencent.com/document/api/1132/49071#FwGroupSwitchShow)

	* <font color="#dd0000">**修改成员**：</font>SwitchName, SwitchMode, ConnectType, ConnectId, ConnectName, SrcInstancesInfo, DstInstancesInfo, FwGroupId, FwGroupName, Enable, Status, AttachWithEdge, CrossEdgeStatus, FwInsRegion, IpsAction, FwInsLst, BypassStatus

* [NatInstanceInfo](https://cloud.tencent.com/document/api/1132/49071#NatInstanceInfo)

	* 新增成员：TrafficMode, Zone, ZoneBak

* [VpcFwCvmInsInfo](https://cloud.tencent.com/document/api/1132/49071#VpcFwCvmInsInfo)

	* 新增成员：Zone, ZoneBak

* [VpcFwGroupInfo](https://cloud.tencent.com/document/api/1132/49071#VpcFwGroupInfo)

	* <font color="#dd0000">**修改成员**：</font>FwGroupId, FwGroupName, FwSwitchNum, RegionLst, Mode, SwitchMode, FwInstanceLst, Status, FwVpcCidr, CdcId, CdcName, CrossUserMode

* [VpcFwInstanceInfo](https://cloud.tencent.com/document/api/1132/49071#VpcFwInstanceInfo)

	* 新增成员：TrafficMode


### 第 46 次发布

发布时间：2023-09-26 01:09:36

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateBlockIgnoreRuleList](https://cloud.tencent.com/document/api/1132/97724)

	* 新增入参：CoverDuplicate

* [ModifyEdgeIpSwitch](https://cloud.tencent.com/document/api/1132/97839)

	* 新增入参：AutoChooseSubnet, SwitchMode

	* <font color="#dd0000">**修改入参**：</font>Enable


修改数据结构：

* [BlockIgnoreRule](https://cloud.tencent.com/document/api/1132/49071#BlockIgnoreRule)

	* 新增成员：IP

* [EdgeIpInfo](https://cloud.tencent.com/document/api/1132/49071#EdgeIpInfo)

	* 新增成员：SwitchWeight

* [NatInstanceInfo](https://cloud.tencent.com/document/api/1132/49071#NatInstanceInfo)

	* 新增成员：NeedProbeEngineUpdate


### 第 45 次发布

发布时间：2023-09-22 01:21:17

本次发布包含了以下内容：

改善已有的文档。

<font color="#dd0000">**预下线接口**：</font>

* ModifyPublicIPSwitchStatus

### 第 44 次发布

发布时间：2023-09-11 01:23:41

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeAddressTemplateList](https://cloud.tencent.com/document/api/1132/97918)
* [DescribeAssetSync](https://cloud.tencent.com/document/api/1132/97917)
* [DescribeFwSyncStatus](https://cloud.tencent.com/document/api/1132/97920)
* [DescribeNatSwitchList](https://cloud.tencent.com/document/api/1132/97915)
* [ModifyAddressTemplate](https://cloud.tencent.com/document/api/1132/97919)
* [ModifyAssetSync](https://cloud.tencent.com/document/api/1132/97921)
* [ModifyNatInstance](https://cloud.tencent.com/document/api/1132/97914)
* [SyncFwOperate](https://cloud.tencent.com/document/api/1132/97916)

新增数据结构：

* [NatSwitchListData](https://cloud.tencent.com/document/api/1132/49071#NatSwitchListData)
* [TemplateListInfo](https://cloud.tencent.com/document/api/1132/49071#TemplateListInfo)

### 第 43 次发布

发布时间：2023-09-08 01:22:02

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [AddAclRule](https://cloud.tencent.com/document/api/1132/97847)
* [AddVpcAcRule](https://cloud.tencent.com/document/api/1132/97846)
* [CreateVpcFwGroup](https://cloud.tencent.com/document/api/1132/97855)
* [DeleteBlockIgnoreRuleList](https://cloud.tencent.com/document/api/1132/97856)
* [DeleteVpcFwGroup](https://cloud.tencent.com/document/api/1132/97854)
* [DescribeAclRule](https://cloud.tencent.com/document/api/1132/97845)
* [DescribeFwEdgeIps](https://cloud.tencent.com/document/api/1132/97841)
* [DescribeFwGroupInstanceInfo](https://cloud.tencent.com/document/api/1132/97853)
* [DescribeVpcAcRule](https://cloud.tencent.com/document/api/1132/97844)
* [DescribeVpcFwGroupSwitch](https://cloud.tencent.com/document/api/1132/97840)
* [ModifyAclRule](https://cloud.tencent.com/document/api/1132/97843)
* [ModifyBlockIgnoreRule](https://cloud.tencent.com/document/api/1132/97852)
* [ModifyEdgeIpSwitch](https://cloud.tencent.com/document/api/1132/97839)
* [ModifyFwGroupSwitch](https://cloud.tencent.com/document/api/1132/97851)
* [ModifySequenceAclRules](https://cloud.tencent.com/document/api/1132/97850)
* [ModifyVpcAcRule](https://cloud.tencent.com/document/api/1132/97842)
* [ModifyVpcFwGroup](https://cloud.tencent.com/document/api/1132/97849)
* [ModifyVpcFwSequenceRules](https://cloud.tencent.com/document/api/1132/97848)
* [RemoveAclRule](https://cloud.tencent.com/document/api/1132/97838)
* [RemoveVpcAcRule](https://cloud.tencent.com/document/api/1132/97837)

修改接口：

* [CreateAddressTemplate](https://cloud.tencent.com/document/api/1132/95034)

	* 新增出参：Uuid

* [CreateBlockIgnoreRuleList](https://cloud.tencent.com/document/api/1132/97724)

	* 新增出参：List


新增数据结构：

* [CreateRuleItem](https://cloud.tencent.com/document/api/1132/49071#CreateRuleItem)
* [EdgeIpInfo](https://cloud.tencent.com/document/api/1132/49071#EdgeIpInfo)
* [EdgeIpSwitch](https://cloud.tencent.com/document/api/1132/49071#EdgeIpSwitch)
* [FwDeploy](https://cloud.tencent.com/document/api/1132/49071#FwDeploy)
* [FwGateway](https://cloud.tencent.com/document/api/1132/49071#FwGateway)
* [FwGroupSwitch](https://cloud.tencent.com/document/api/1132/49071#FwGroupSwitch)
* [FwGroupSwitchShow](https://cloud.tencent.com/document/api/1132/49071#FwGroupSwitchShow)
* [NetInstancesInfo](https://cloud.tencent.com/document/api/1132/49071#NetInstancesInfo)
* [VpcFwCvmInsInfo](https://cloud.tencent.com/document/api/1132/49071#VpcFwCvmInsInfo)
* [VpcFwGroupInfo](https://cloud.tencent.com/document/api/1132/49071#VpcFwGroupInfo)
* [VpcFwInstance](https://cloud.tencent.com/document/api/1132/49071#VpcFwInstance)
* [VpcFwInstanceInfo](https://cloud.tencent.com/document/api/1132/49071#VpcFwInstanceInfo)
* [VpcFwInstanceShow](https://cloud.tencent.com/document/api/1132/49071#VpcFwInstanceShow)
* [VpcFwJoinInstanceType](https://cloud.tencent.com/document/api/1132/49071#VpcFwJoinInstanceType)
* [VpcRuleItem](https://cloud.tencent.com/document/api/1132/49071#VpcRuleItem)

### 第 42 次发布

发布时间：2023-09-04 01:25:21

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateBlockIgnoreRuleList](https://cloud.tencent.com/document/api/1132/97724)
* [ModifyEWRuleStatus](https://cloud.tencent.com/document/api/1132/97723)

新增数据结构：

* [IntrusionDefenseRule](https://cloud.tencent.com/document/api/1132/49071#IntrusionDefenseRule)

修改数据结构：

* [RuleInfoData](https://cloud.tencent.com/document/api/1132/49071#RuleInfoData)

	* 新增成员：RegionIso


### 第 41 次发布

发布时间：2023-08-15 01:07:59

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [DescAcItem](https://cloud.tencent.com/document/api/1132/49071#DescAcItem)

	* 新增成员：Scope, InternetBorderUuid

	* <font color="#dd0000">**修改成员**：</font>Direction, InstanceName, InternalUuid, Status, BetaList

* [NatInstanceInfo](https://cloud.tencent.com/document/api/1132/49071#NatInstanceInfo)

	* 新增成员：EngineVersion, UpdateEnable

	* <font color="#dd0000">**修改成员**：</font>RuleUsed, RuleMax

* [VpcDnsInfo](https://cloud.tencent.com/document/api/1132/49071#VpcDnsInfo)

	* 新增成员：ProtectedStatus, SupportDNSFW


### 第 40 次发布

发布时间：2023-07-14 01:08:16

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateAddressTemplate](https://cloud.tencent.com/document/api/1132/95034)
* [DeleteAddressTemplate](https://cloud.tencent.com/document/api/1132/95033)

### 第 39 次发布

发布时间：2023-06-30 01:13:38

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeBlockIgnoreList](https://cloud.tencent.com/document/api/1132/86691)

	* 新增出参：SourceList


修改数据结构：

* [InstanceInfo](https://cloud.tencent.com/document/api/1132/49071#InstanceInfo)

	* 新增成员：RegionKey


### 第 38 次发布

发布时间：2023-06-12 01:07:56

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeEnterpriseSGRuleProgress](https://cloud.tencent.com/document/api/1132/93416)

### 第 37 次发布

发布时间：2023-06-02 01:13:34

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [AssociatedInstanceInfo](https://cloud.tencent.com/document/api/1132/49071#AssociatedInstanceInfo)

	* 新增成员：SecurityGroupRuleCount, CdbId

* [InstanceInfo](https://cloud.tencent.com/document/api/1132/49071#InstanceInfo)

	* 新增成员：Server


### 第 36 次发布

发布时间：2023-05-19 01:21:55

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeLogs](https://cloud.tencent.com/document/api/1132/91646)

### 第 35 次发布

发布时间：2023-05-17 01:12:41

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [AddEnterpriseSecurityGroupRules](https://cloud.tencent.com/document/api/1132/64234)

	* 新增出参：Rules

* [DescribeEnterpriseSecurityGroupRule](https://cloud.tencent.com/document/api/1132/64233)

	* 新增入参：RuleUuid


新增数据结构：

* [SecurityGroupSimplifyRule](https://cloud.tencent.com/document/api/1132/49071#SecurityGroupSimplifyRule)

### 第 34 次发布

发布时间：2023-05-16 01:16:01

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [SecurityGroupListData](https://cloud.tencent.com/document/api/1132/49071#SecurityGroupListData)

	* 新增成员：Uuid, Region, AssetGroupNameIn, AssetGroupNameOut, ParameterName


### 第 33 次发布

发布时间：2023-04-28 01:12:37

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [BlockIgnoreRule](https://cloud.tencent.com/document/api/1132/49071#BlockIgnoreRule)

	* 新增成员：Comment


### 第 32 次发布

发布时间：2023-04-05 01:16:43

本次发布包含了以下内容：

改善已有的文档。

新增数据结构：

* [BetaInfoByACL](https://cloud.tencent.com/document/api/1132/49071#BetaInfoByACL)

修改数据结构：

* [DescAcItem](https://cloud.tencent.com/document/api/1132/49071#DescAcItem)

	* 新增成员：BetaList


### 第 31 次发布

发布时间：2023-02-28 01:12:39

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [ModifyEnterpriseSecurityDispatchStatus](https://cloud.tencent.com/document/api/1132/86969)
* [ModifyEnterpriseSecurityGroupRule](https://cloud.tencent.com/document/api/1132/86971)
* [ModifyNatSequenceRules](https://cloud.tencent.com/document/api/1132/86970)

新增数据结构：

* [RuleChangeItem](https://cloud.tencent.com/document/api/1132/49071#RuleChangeItem)

### 第 30 次发布

发布时间：2023-02-24 01:07:43

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [AddNatAcRule](https://cloud.tencent.com/document/api/1132/86861)
* [DescribeNatAcRule](https://cloud.tencent.com/document/api/1132/86860)
* [ModifyNatAcRule](https://cloud.tencent.com/document/api/1132/86859)
* [RemoveNatAcRule](https://cloud.tencent.com/document/api/1132/86858)

新增数据结构：

* [CommonFilter](https://cloud.tencent.com/document/api/1132/49071#CommonFilter)
* [CreateNatRuleItem](https://cloud.tencent.com/document/api/1132/49071#CreateNatRuleItem)
* [DescAcItem](https://cloud.tencent.com/document/api/1132/49071#DescAcItem)

### 第 29 次发布

发布时间：2023-02-22 01:11:48

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [ModifyStorageSetting](https://cloud.tencent.com/document/api/1132/86751)

修改数据结构：

* [NatInstanceInfo](https://cloud.tencent.com/document/api/1132/49071#NatInstanceInfo)

	* 新增成员：RuleUsed, RuleMax


### 第 28 次发布

发布时间：2023-02-20 01:16:09

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeBlockIgnoreList](https://cloud.tencent.com/document/api/1132/86691)

新增数据结构：

* [BlockIgnoreRule](https://cloud.tencent.com/document/api/1132/49071#BlockIgnoreRule)

### 第 27 次发布

发布时间：2023-01-04 01:09:46

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateNatFwInstance](https://cloud.tencent.com/document/api/1132/60250)

	* 新增入参：FwCidrInfo

* [CreateNatFwInstanceWithDomain](https://cloud.tencent.com/document/api/1132/61923)

	* 新增入参：FwCidrInfo

* [ModifyNatFwReSelect](https://cloud.tencent.com/document/api/1132/60243)

	* 新增入参：FwCidrInfo


新增数据结构：

* [FwCidrInfo](https://cloud.tencent.com/document/api/1132/49071#FwCidrInfo)
* [FwVpcCidr](https://cloud.tencent.com/document/api/1132/49071#FwVpcCidr)

### 第 26 次发布

发布时间：2022-09-20 06:15:17

本次发布包含了以下内容：

改善已有的文档。

<font color="#dd0000">**删除接口**：</font>

* DescribeVpcRuleOverview

### 第 25 次发布

发布时间：2022-09-15 06:13:28

本次发布包含了以下内容：

改善已有的文档。

<font color="#dd0000">**删除接口**：</font>

* CreateSecurityGroupApiRules
* DescribeAddrTemplateList
* DescribeSyncAssetStatus
* ModifyAllSwitchStatus
* ModifyItemSwitchStatus
* ModifySecurityGroupAllRuleStatus

<font color="#dd0000">**删除数据结构**：</font>

* SecurityGroupApiRuleData
* TemplateListInfo

### 第 24 次发布

发布时间：2022-09-09 06:13:35

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeDefenseSwitch](https://cloud.tencent.com/document/api/1132/80322)

### 第 23 次发布

发布时间：2022-09-08 06:13:55

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [NatInstanceInfo](https://cloud.tencent.com/document/api/1132/49071#NatInstanceInfo)

	* 新增成员：RegionDetail, ZoneZh, ZoneZhBak


### 第 22 次发布

发布时间：2022-09-06 06:16:40

本次发布包含了以下内容：

改善已有的文档。

<font color="#dd0000">**删除接口**：</font>

* ModifyVPCSwitchStatus

### 第 21 次发布

发布时间：2022-08-29 06:15:32

本次发布包含了以下内容：

改善已有的文档。

<font color="#dd0000">**删除接口**：</font>

* DeleteSecurityGroupAllRule
* DescribeNatRuleOverview

### 第 20 次发布

发布时间：2022-08-26 06:15:17

本次发布包含了以下内容：

改善已有的文档。

<font color="#dd0000">**删除接口**：</font>

* RunSyncAsset

### 第 19 次发布

发布时间：2022-05-12 06:07:30

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [AddEnterpriseSecurityGroupRules](https://cloud.tencent.com/document/api/1132/64234)

	* 新增入参：IsDelay


### 第 18 次发布

发布时间：2022-04-08 06:03:52

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeBlockByIpTimesList](https://cloud.tencent.com/document/api/1132/58282)

	* 新增入参：EdgeId, LogSource


修改数据结构：

* [UnHandleEvent](https://cloud.tencent.com/document/api/1132/49071#UnHandleEvent)

	* 新增成员：VpcFwCount


### 第 17 次发布

发布时间：2022-03-16 08:05:40

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeIPStatusList](https://cloud.tencent.com/document/api/1132/71274)

新增数据结构：

* [IPDefendStatus](https://cloud.tencent.com/document/api/1132/49071#IPDefendStatus)

### 第 16 次发布

发布时间：2022-01-17 08:04:37

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [ModifyRunSyncAsset](https://cloud.tencent.com/document/api/1132/68255)

### 第 15 次发布

发布时间：2022-01-13 08:15:21

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateNatFwInstance](https://cloud.tencent.com/document/api/1132/60250)

	* 新增出参：CfwInsId

* [CreateNatFwInstanceWithDomain](https://cloud.tencent.com/document/api/1132/61923)

	* 新增出参：CfwInsId

* [DescribeVpcRuleOverview](https://cloud.tencent.com/document/api/1132/49065)

	* 新增出参：Total


### 第 14 次发布

发布时间：2021-11-26 08:05:36

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeAddrTemplateList](https://cloud.tencent.com/document/api/1132/64831)

新增数据结构：

* [TemplateListInfo](https://cloud.tencent.com/document/api/1132/49071#TemplateListInfo)

修改数据结构：

* [SecurityGroupRule](https://cloud.tencent.com/document/api/1132/49071#SecurityGroupRule)

	* 新增成员：Id, Enable


### 第 13 次发布

发布时间：2021-11-18 08:04:19

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [AddEnterpriseSecurityGroupRules](https://cloud.tencent.com/document/api/1132/64234)
* [DescribeEnterpriseSecurityGroupRule](https://cloud.tencent.com/document/api/1132/64233)
* [RemoveEnterpriseSecurityGroupRule](https://cloud.tencent.com/document/api/1132/64232)

新增数据结构：

* [SecurityGroupRule](https://cloud.tencent.com/document/api/1132/49071#SecurityGroupRule)

### 第 12 次发布

发布时间：2021-11-17 08:07:57

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [StopSecurityGroupRuleDispatch](https://cloud.tencent.com/document/api/1132/60228)

	* 新增入参：StopType


### 第 11 次发布

发布时间：2021-09-27 08:08:06

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [AddAcRule](https://cloud.tencent.com/document/api/1132/61922)
* [CreateNatFwInstanceWithDomain](https://cloud.tencent.com/document/api/1132/61923)
* [RemoveAcRule](https://cloud.tencent.com/document/api/1132/61921)

### 第 10 次发布

发布时间：2021-09-14 08:12:02

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateDatabaseWhiteListRules](https://cloud.tencent.com/document/api/1132/61483)

新增数据结构：

* [DatabaseWhiteListRuleData](https://cloud.tencent.com/document/api/1132/49071#DatabaseWhiteListRuleData)

修改数据结构：

* [NatFwInstance](https://cloud.tencent.com/document/api/1132/49071#NatFwInstance)

	* 新增成员：NatIp


### 第 9 次发布

发布时间：2021-08-27 08:11:17

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeResourceGroupNew](https://cloud.tencent.com/document/api/1132/60781)

### 第 8 次发布

发布时间：2021-08-20 08:11:35

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [SecurityGroupBothWayInfo](https://cloud.tencent.com/document/api/1132/49071#SecurityGroupBothWayInfo)

	* 新增成员：ProtocolPortType

* [SecurityGroupListData](https://cloud.tencent.com/document/api/1132/49071#SecurityGroupListData)

	* 新增成员：ProtocolPortType


### 第 7 次发布

发布时间：2021-08-13 08:11:30

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateChooseVpcs](https://cloud.tencent.com/document/api/1132/60251)
* [CreateNatFwInstance](https://cloud.tencent.com/document/api/1132/60250)
* [CreateSecurityGroupRules](https://cloud.tencent.com/document/api/1132/60255)
* [DeleteNatFwInstance](https://cloud.tencent.com/document/api/1132/60235)
* [DeleteResourceGroup](https://cloud.tencent.com/document/api/1132/60249)
* [DeleteVpcInstance](https://cloud.tencent.com/document/api/1132/60248)
* [DescribeNatFwInfoCount](https://cloud.tencent.com/document/api/1132/60239)
* [DescribeNatFwInstance](https://cloud.tencent.com/document/api/1132/60238)
* [DescribeNatFwInstanceWithRegion](https://cloud.tencent.com/document/api/1132/60247)
* [DescribeNatFwInstancesInfo](https://cloud.tencent.com/document/api/1132/60237)
* [DescribeNatFwVpcDnsLst](https://cloud.tencent.com/document/api/1132/60236)
* [DescribeResourceGroup](https://cloud.tencent.com/document/api/1132/60246)
* [DescribeSourceAsset](https://cloud.tencent.com/document/api/1132/60245)
* [ModifyAllPublicIPSwitchStatus](https://cloud.tencent.com/document/api/1132/60233)
* [ModifyAllVPCSwitchStatus](https://cloud.tencent.com/document/api/1132/60232)
* [ModifyAssetScan](https://cloud.tencent.com/document/api/1132/60244)
* [ModifyNatFwReSelect](https://cloud.tencent.com/document/api/1132/60243)
* [ModifyNatFwSwitch](https://cloud.tencent.com/document/api/1132/60242)
* [ModifyNatFwVpcDnsSwitch](https://cloud.tencent.com/document/api/1132/60231)
* [ModifyPublicIPSwitchStatus](https://cloud.tencent.com/document/api/1132/60230)
* [ModifyResourceGroup](https://cloud.tencent.com/document/api/1132/60241)
* [ModifySecurityGroupItemRuleStatus](https://cloud.tencent.com/document/api/1132/60254)
* [ModifySecurityGroupRule](https://cloud.tencent.com/document/api/1132/60253)
* [ModifySecurityGroupSequenceRules](https://cloud.tencent.com/document/api/1132/60252)
* [ModifyVPCSwitchStatus](https://cloud.tencent.com/document/api/1132/60229)
* [SetNatFwEip](https://cloud.tencent.com/document/api/1132/60240)
* [StopSecurityGroupRuleDispatch](https://cloud.tencent.com/document/api/1132/60228)

新增数据结构：

* [AssetZone](https://cloud.tencent.com/document/api/1132/49071#AssetZone)
* [DnsVpcSwitch](https://cloud.tencent.com/document/api/1132/49071#DnsVpcSwitch)
* [InstanceInfo](https://cloud.tencent.com/document/api/1132/49071#InstanceInfo)
* [NatFwFilter](https://cloud.tencent.com/document/api/1132/49071#NatFwFilter)
* [NatFwInstance](https://cloud.tencent.com/document/api/1132/49071#NatFwInstance)
* [NatInstanceInfo](https://cloud.tencent.com/document/api/1132/49071#NatInstanceInfo)
* [NewModeItems](https://cloud.tencent.com/document/api/1132/49071#NewModeItems)
* [SecurityGroupBothWayInfo](https://cloud.tencent.com/document/api/1132/49071#SecurityGroupBothWayInfo)
* [SecurityGroupOrderIndexData](https://cloud.tencent.com/document/api/1132/49071#SecurityGroupOrderIndexData)
* [VpcDnsInfo](https://cloud.tencent.com/document/api/1132/49071#VpcDnsInfo)
* [VpcZoneData](https://cloud.tencent.com/document/api/1132/49071#VpcZoneData)

修改数据结构：

* [SecurityGroupListData](https://cloud.tencent.com/document/api/1132/49071#SecurityGroupListData)

	* 新增成员：ServiceTemplateId, BothWayInfo, Direction

	* <font color="#dd0000">**修改成员**：</font>Id, Status, IsNew, VpcId, SubnetId, InstanceName, PublicIp, PrivateIp, Cidr


### 第 6 次发布

发布时间：2021-07-08 08:11:41

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeBlockByIpTimesList](https://cloud.tencent.com/document/api/1132/58282)
* [DescribeBlockStaticList](https://cloud.tencent.com/document/api/1132/58281)
* [DescribeTLogInfo](https://cloud.tencent.com/document/api/1132/58280)
* [DescribeTLogIpList](https://cloud.tencent.com/document/api/1132/58279)
* [DescribeUnHandleEventTabList](https://cloud.tencent.com/document/api/1132/58278)
* [ModifyBlockTop](https://cloud.tencent.com/document/api/1132/58277)

新增数据结构：

* [IpStatic](https://cloud.tencent.com/document/api/1132/49071#IpStatic)
* [StaticInfo](https://cloud.tencent.com/document/api/1132/49071#StaticInfo)
* [TLogInfo](https://cloud.tencent.com/document/api/1132/49071#TLogInfo)
* [UnHandleEvent](https://cloud.tencent.com/document/api/1132/49071#UnHandleEvent)
* [UnHandleEventDetail](https://cloud.tencent.com/document/api/1132/49071#UnHandleEventDetail)

### 第 5 次发布

发布时间：2021-05-14 08:11:06

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeGuideScanInfo](https://cloud.tencent.com/document/api/1132/55761)

新增数据结构：

* [ScanInfo](https://cloud.tencent.com/document/api/1132/49071#ScanInfo)
* [ScanResultInfo](https://cloud.tencent.com/document/api/1132/49071#ScanResultInfo)

### 第 4 次发布

发布时间：2021-04-28 08:13:47

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [ModifyBlockIgnoreList](https://cloud.tencent.com/document/api/1132/55248)

新增数据结构：

* [IocListData](https://cloud.tencent.com/document/api/1132/49071#IocListData)

### 第 3 次发布

发布时间：2021-04-01 08:10:23

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeCfwEips](https://cloud.tencent.com/document/api/1132/54259)
* [ExpandCfwVertical](https://cloud.tencent.com/document/api/1132/54258)
* [SetNatFwDnatRule](https://cloud.tencent.com/document/api/1132/54257)

新增数据结构：

* [CfwNatDnatRule](https://cloud.tencent.com/document/api/1132/49071#CfwNatDnatRule)
* [NatFwEipsInfo](https://cloud.tencent.com/document/api/1132/49071#NatFwEipsInfo)

### 第 2 次发布

发布时间：2020-12-28 08:09:13

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateSecurityGroupApiRules](https://cloud.tencent.com/document/api/1132/51527)
* [DeleteSecurityGroupAllRule](https://cloud.tencent.com/document/api/1132/51526)
* [DeleteSecurityGroupRule](https://cloud.tencent.com/document/api/1132/51525)
* [DescribeAssociatedInstanceList](https://cloud.tencent.com/document/api/1132/51524)
* [DescribeSecurityGroupList](https://cloud.tencent.com/document/api/1132/51523)
* [ModifySecurityGroupAllRuleStatus](https://cloud.tencent.com/document/api/1132/51522)

新增数据结构：

* [AssociatedInstanceInfo](https://cloud.tencent.com/document/api/1132/49071#AssociatedInstanceInfo)
* [SecurityGroupApiRuleData](https://cloud.tencent.com/document/api/1132/49071#SecurityGroupApiRuleData)
* [SecurityGroupListData](https://cloud.tencent.com/document/api/1132/49071#SecurityGroupListData)

### 第 1 次发布

发布时间：2020-10-13 08:09:15

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateAcRules](https://cloud.tencent.com/document/api/1132/49070)
* [DeleteAcRule](https://cloud.tencent.com/document/api/1132/49059)
* [DeleteAllAccessControlRule](https://cloud.tencent.com/document/api/1132/49058)
* [DescribeAcLists](https://cloud.tencent.com/document/api/1132/49069)
* [DescribeNatRuleOverview](https://cloud.tencent.com/document/api/1132/49068)
* [DescribeRuleOverview](https://cloud.tencent.com/document/api/1132/49067)
* [DescribeSwitchLists](https://cloud.tencent.com/document/api/1132/49057)
* [DescribeSyncAssetStatus](https://cloud.tencent.com/document/api/1132/49056)
* [DescribeTableStatus](https://cloud.tencent.com/document/api/1132/49066)
* [DescribeVpcRuleOverview](https://cloud.tencent.com/document/api/1132/49065)
* [ModifyAcRule](https://cloud.tencent.com/document/api/1132/49064)
* [ModifyAllRuleStatus](https://cloud.tencent.com/document/api/1132/49063)
* [ModifyAllSwitchStatus](https://cloud.tencent.com/document/api/1132/49055)
* [ModifyItemSwitchStatus](https://cloud.tencent.com/document/api/1132/49054)
* [ModifySequenceRules](https://cloud.tencent.com/document/api/1132/49062)
* [ModifyTableStatus](https://cloud.tencent.com/document/api/1132/49061)
* [RunSyncAsset](https://cloud.tencent.com/document/api/1132/49053)

新增数据结构：

* [AcListsData](https://cloud.tencent.com/document/api/1132/49071#AcListsData)
* [RuleInfoData](https://cloud.tencent.com/document/api/1132/49071#RuleInfoData)
* [SequenceData](https://cloud.tencent.com/document/api/1132/49071#SequenceData)
* [SwitchListsData](https://cloud.tencent.com/document/api/1132/49071#SwitchListsData)




## 云 HDFS(chdfs) 版本：2019-07-18

### 第 5 次发布

发布时间：2020-11-05 08:02:51

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateMountPoint](https://cloud.tencent.com/document/api/1105/37376)

	* 新增出参：MountPoint


### 第 4 次发布

发布时间：2020-10-29 08:02:46

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateLifeCycleRules](https://cloud.tencent.com/document/api/1105/49517)
* [CreateRestoreTasks](https://cloud.tencent.com/document/api/1105/49520)
* [DeleteLifeCycleRules](https://cloud.tencent.com/document/api/1105/49516)
* [DescribeLifeCycleRules](https://cloud.tencent.com/document/api/1105/49515)
* [DescribeResourceTags](https://cloud.tencent.com/document/api/1105/49523)
* [DescribeRestoreTasks](https://cloud.tencent.com/document/api/1105/49519)
* [ModifyLifeCycleRules](https://cloud.tencent.com/document/api/1105/49514)
* [ModifyResourceTags](https://cloud.tencent.com/document/api/1105/49522)

修改接口：

* [CreateMountPoint](https://cloud.tencent.com/document/api/1105/37376)

	* <font color="#dd0000">**删除出参**：</font>MountPoint

* [DescribeFileSystem](https://cloud.tencent.com/document/api/1105/37368)

	* 新增出参：ArchiveCapacityUsed


新增数据结构：

* [LifeCycleRule](https://cloud.tencent.com/document/api/1105/37345#LifeCycleRule)
* [RestoreTask](https://cloud.tencent.com/document/api/1105/37345#RestoreTask)
* [Tag](https://cloud.tencent.com/document/api/1105/37345#Tag)
* [Transition](https://cloud.tencent.com/document/api/1105/37345#Transition)

### 第 3 次发布

发布时间：2020-05-08 08:07:19

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeFileSystem](https://cloud.tencent.com/document/api/1105/37368)

	* 新增出参：CapacityUsed


### 第 2 次发布

发布时间：2019-11-21 19:27:30

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateMountPoint](https://cloud.tencent.com/document/api/1105/37376)

	* 新增入参：VpcType


修改数据结构：

* [MountPoint](https://cloud.tencent.com/document/api/1105/37345#MountPoint)

	* 新增成员：VpcType


### 第 1 次发布

发布时间：2019-08-22 17:27:00

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateAccessGroup](https://cloud.tencent.com/document/api/1105/37364)
* [CreateAccessRules](https://cloud.tencent.com/document/api/1105/37359)
* [CreateFileSystem](https://cloud.tencent.com/document/api/1105/37370)
* [CreateMountPoint](https://cloud.tencent.com/document/api/1105/37376)
* [DeleteAccessGroup](https://cloud.tencent.com/document/api/1105/37363)
* [DeleteAccessRules](https://cloud.tencent.com/document/api/1105/37358)
* [DeleteFileSystem](https://cloud.tencent.com/document/api/1105/37369)
* [DeleteMountPoint](https://cloud.tencent.com/document/api/1105/37375)
* [DescribeAccessGroups](https://cloud.tencent.com/document/api/1105/37362)
* [DescribeAccessRules](https://cloud.tencent.com/document/api/1105/37357)
* [DescribeFileSystem](https://cloud.tencent.com/document/api/1105/37368)
* [DescribeFileSystems](https://cloud.tencent.com/document/api/1105/37367)
* [DescribeMountPoint](https://cloud.tencent.com/document/api/1105/37374)
* [DescribeMountPoints](https://cloud.tencent.com/document/api/1105/37373)
* [ModifyAccessGroup](https://cloud.tencent.com/document/api/1105/37361)
* [ModifyAccessRules](https://cloud.tencent.com/document/api/1105/37356)
* [ModifyFileSystem](https://cloud.tencent.com/document/api/1105/37366)
* [ModifyMountPoint](https://cloud.tencent.com/document/api/1105/37372)

新增数据结构：

* [AccessGroup](https://cloud.tencent.com/document/api/1105/37345#AccessGroup)
* [AccessRule](https://cloud.tencent.com/document/api/1105/37345#AccessRule)
* [FileSystem](https://cloud.tencent.com/document/api/1105/37345#FileSystem)
* [Filter](https://cloud.tencent.com/document/api/1105/37345#Filter)
* [MountPoint](https://cloud.tencent.com/document/api/1105/37345#MountPoint)



## 云 HDFS(chdfs) 版本：2020-11-12

### 第 6 次发布

发布时间：2023-05-24 01:11:05

本次发布包含了以下内容：

改善已有的文档。

新增数据结构：

* [Summary](https://cloud.tencent.com/document/api/1105/51158#Summary)

修改数据结构：

* [LifeCycleRule](https://cloud.tencent.com/document/api/1105/51158#LifeCycleRule)

	* 新增成员：Summary, LastSummaryTime


### 第 5 次发布

发布时间：2023-01-06 18:21:15

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateAccessRules](https://cloud.tencent.com/document/api/1105/52339)

	* 新增出参：AccessRules

* [DescribeFileSystem](https://cloud.tencent.com/document/api/1105/51147)

	* 新增出参：DeepArchiveCapacityUsed, IntelligentCapacityUsed


### 第 4 次发布

发布时间：2022-05-25 06:05:18

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateFileSystem](https://cloud.tencent.com/document/api/1105/51148)

	* 新增入参：Tags


### 第 3 次发布

发布时间：2021-12-21 08:02:31

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateFileSystem](https://cloud.tencent.com/document/api/1105/51148)

	* 新增入参：EnableRanger, RangerServiceAddresses

* [DescribeFileSystem](https://cloud.tencent.com/document/api/1105/51147)

	* 新增出参：StandardCapacityUsed, DegradeCapacityUsed

* [ModifyFileSystem](https://cloud.tencent.com/document/api/1105/51145)

	* 新增入参：EnableRanger, RangerServiceAddresses


修改数据结构：

* [FileSystem](https://cloud.tencent.com/document/api/1105/51158#FileSystem)

	* 新增成员：EnableRanger, RangerServiceAddresses


### 第 2 次发布

发布时间：2021-01-22 08:03:07

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateAccessRules](https://cloud.tencent.com/document/api/1105/52339)
* [CreateLifeCycleRules](https://cloud.tencent.com/document/api/1105/52336)
* [CreateRestoreTasks](https://cloud.tencent.com/document/api/1105/52345)
* [DeleteAccessGroup](https://cloud.tencent.com/document/api/1105/52340)
* [DeleteAccessRules](https://cloud.tencent.com/document/api/1105/52338)
* [DeleteFileSystem](https://cloud.tencent.com/document/api/1105/52341)
* [DeleteLifeCycleRules](https://cloud.tencent.com/document/api/1105/52335)
* [DeleteMountPoint](https://cloud.tencent.com/document/api/1105/52342)
* [DescribeLifeCycleRules](https://cloud.tencent.com/document/api/1105/52334)
* [DescribeResourceTags](https://cloud.tencent.com/document/api/1105/52346)
* [DescribeRestoreTasks](https://cloud.tencent.com/document/api/1105/52344)
* [ModifyAccessRules](https://cloud.tencent.com/document/api/1105/52337)
* [ModifyLifeCycleRules](https://cloud.tencent.com/document/api/1105/52333)

新增数据结构：

* [LifeCycleRule](https://cloud.tencent.com/document/api/1105/51158#LifeCycleRule)
* [RestoreTask](https://cloud.tencent.com/document/api/1105/51158#RestoreTask)
* [Transition](https://cloud.tencent.com/document/api/1105/51158#Transition)

### 第 1 次发布

发布时间：2020-12-18 08:03:19

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [AssociateAccessGroups](https://cloud.tencent.com/document/api/1105/51155)
* [CreateAccessGroup](https://cloud.tencent.com/document/api/1105/51143)
* [CreateFileSystem](https://cloud.tencent.com/document/api/1105/51148)
* [CreateMountPoint](https://cloud.tencent.com/document/api/1105/51154)
* [DescribeAccessGroup](https://cloud.tencent.com/document/api/1105/51142)
* [DescribeAccessGroups](https://cloud.tencent.com/document/api/1105/51141)
* [DescribeAccessRules](https://cloud.tencent.com/document/api/1105/51138)
* [DescribeFileSystem](https://cloud.tencent.com/document/api/1105/51147)
* [DescribeFileSystems](https://cloud.tencent.com/document/api/1105/51146)
* [DescribeMountPoint](https://cloud.tencent.com/document/api/1105/51153)
* [DescribeMountPoints](https://cloud.tencent.com/document/api/1105/51152)
* [DisassociateAccessGroups](https://cloud.tencent.com/document/api/1105/51151)
* [ModifyAccessGroup](https://cloud.tencent.com/document/api/1105/51140)
* [ModifyFileSystem](https://cloud.tencent.com/document/api/1105/51145)
* [ModifyMountPoint](https://cloud.tencent.com/document/api/1105/51150)
* [ModifyResourceTags](https://cloud.tencent.com/document/api/1105/51157)

新增数据结构：

* [AccessGroup](https://cloud.tencent.com/document/api/1105/51158#AccessGroup)
* [AccessRule](https://cloud.tencent.com/document/api/1105/51158#AccessRule)
* [FileSystem](https://cloud.tencent.com/document/api/1105/51158#FileSystem)
* [MountPoint](https://cloud.tencent.com/document/api/1105/51158#MountPoint)
* [Tag](https://cloud.tencent.com/document/api/1105/51158#Tag)




## 账号风控平台(ciam) 版本：2022-03-31

### 第 11 次发布

发布时间：2024-06-17 01:21:02

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [ImportUser](https://cloud.tencent.com/document/api/1441/75643#ImportUser)

	* 新增成员：WeComUserId

* [User](https://cloud.tencent.com/document/api/1441/75643#User)

	* 新增成员：WeComUserId


### 第 10 次发布

发布时间：2023-07-06 01:13:25

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateUserGroup](https://cloud.tencent.com/document/api/1441/94455)

	* 新增出参：UserGroupId

* [CreateUserStore](https://cloud.tencent.com/document/api/1441/94460)

	* 新增出参：UserStoreId


### 第 9 次发布

发布时间：2023-07-04 01:14:49

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateUserGroup](https://cloud.tencent.com/document/api/1441/94455)
* [CreateUserStore](https://cloud.tencent.com/document/api/1441/94460)
* [DeleteUserGroups](https://cloud.tencent.com/document/api/1441/94454)
* [DeleteUserStore](https://cloud.tencent.com/document/api/1441/94459)
* [ListUserGroups](https://cloud.tencent.com/document/api/1441/94453)
* [ListUserStore](https://cloud.tencent.com/document/api/1441/94458)
* [UpdateUserGroup](https://cloud.tencent.com/document/api/1441/94452)
* [UpdateUserStore](https://cloud.tencent.com/document/api/1441/94457)

新增数据结构：

* [AppAssociatedUserGroupIds](https://cloud.tencent.com/document/api/1441/75643#AppAssociatedUserGroupIds)
* [UserGroup](https://cloud.tencent.com/document/api/1441/75643#UserGroup)
* [UserGroupDeleteResp](https://cloud.tencent.com/document/api/1441/75643#UserGroupDeleteResp)
* [UserStore](https://cloud.tencent.com/document/api/1441/75643#UserStore)

### 第 8 次发布

发布时间：2022-09-27 06:14:52

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateUser](https://cloud.tencent.com/document/api/1441/75642)

	* 新增入参：IndexedAttribute1, IndexedAttribute2, IndexedAttribute3, IndexedAttribute4, IndexedAttribute5

* [DescribeUser](https://cloud.tencent.com/document/api/1441/77525)

	* 新增入参：Sort

* [UpdateUser](https://cloud.tencent.com/document/api/1441/75635)

	* 新增入参：IndexedAttribute1, IndexedAttribute2, IndexedAttribute3, IndexedAttribute4, IndexedAttribute5


新增数据结构：

* [Sort](https://cloud.tencent.com/document/api/1441/75643#Sort)

修改数据结构：

* [ImportUser](https://cloud.tencent.com/document/api/1441/75643#ImportUser)

	* 新增成员：IndexedAttribute1, IndexedAttribute2, IndexedAttribute3, IndexedAttribute4, IndexedAttribute5

* [QueryUserFilter](https://cloud.tencent.com/document/api/1441/75643#QueryUserFilter)

	* 新增成员：OperateLogic

* [User](https://cloud.tencent.com/document/api/1441/75643#User)

	* 新增成员：IndexedAttribute1, IndexedAttribute2, IndexedAttribute3, IndexedAttribute4, IndexedAttribute5


### 第 7 次发布

发布时间：2022-07-19 20:27:09

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeUser](https://cloud.tencent.com/document/api/1441/77525)

修改接口：

* [DescribeUserById](https://cloud.tencent.com/document/api/1441/75640)

	* 新增入参：Original

* [ListUser](https://cloud.tencent.com/document/api/1441/75638)

	* 新增入参：Original

* [ListUserByProperty](https://cloud.tencent.com/document/api/1441/75637)

	* 新增入参：Original


新增数据结构：

* [QueryUserFilter](https://cloud.tencent.com/document/api/1441/75643#QueryUserFilter)

### 第 6 次发布

发布时间：2022-06-29 14:44:01

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [ListLogMessageByCondition](https://cloud.tencent.com/document/api/1441/76173)

新增数据结构：

* [LogMessage](https://cloud.tencent.com/document/api/1441/75643#LogMessage)

### 第 5 次发布

发布时间：2022-06-17 10:12:20

本次发布包含了以下内容：

改善已有的文档。

新增数据结构：

* [SaltLocationRule](https://cloud.tencent.com/document/api/1441/75643#SaltLocationRule)

修改数据结构：

* [SaltLocation](https://cloud.tencent.com/document/api/1441/75643#SaltLocation)

	* 新增成员：SaltLocationTypeEnum, SaltLocationRule


### 第 4 次发布

发布时间：2022-06-16 19:58:34

本次发布包含了以下内容：

改善已有的文档。

新增数据结构：

* [Salt](https://cloud.tencent.com/document/api/1441/75643#Salt)
* [SaltLocation](https://cloud.tencent.com/document/api/1441/75643#SaltLocation)

修改数据结构：

* [ImportUser](https://cloud.tencent.com/document/api/1441/75643#ImportUser)

	* 新增成员：UserName, PhoneNumber, Email, ResidentIdentityCard, Nickname, Address, UserGroup, QqOpenId, QqUnionId, WechatOpenId, WechatUnionId, AlipayUserId, Description, Birthdate, Name, Locale, Gender, IdentityVerificationMethod, IdentityVerified, Job, Nationality, Zone, Password, CustomizationAttributes, Salt, PasswordEncryptTypeEnum


### 第 3 次发布

发布时间：2022-06-16 19:08:56

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateApiImportUserJob](https://cloud.tencent.com/document/api/1441/75705)
* [CreateFileExportUserJob](https://cloud.tencent.com/document/api/1441/75704)
* [ListJobs](https://cloud.tencent.com/document/api/1441/75703)

新增数据结构：

* [ErrorDetails](https://cloud.tencent.com/document/api/1441/75643#ErrorDetails)
* [ExportPropertyMap](https://cloud.tencent.com/document/api/1441/75643#ExportPropertyMap)
* [FailedUsers](https://cloud.tencent.com/document/api/1441/75643#FailedUsers)
* [ImportUser](https://cloud.tencent.com/document/api/1441/75643#ImportUser)
* [Job](https://cloud.tencent.com/document/api/1441/75643#Job)

### 第 2 次发布

发布时间：2022-06-15 19:44:55

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateUser](https://cloud.tencent.com/document/api/1441/75642)
* [DeleteUsers](https://cloud.tencent.com/document/api/1441/75641)
* [DescribeUserById](https://cloud.tencent.com/document/api/1441/75640)
* [LinkAccount](https://cloud.tencent.com/document/api/1441/75639)
* [ListUser](https://cloud.tencent.com/document/api/1441/75638)
* [ListUserByProperty](https://cloud.tencent.com/document/api/1441/75637)
* [SetPassword](https://cloud.tencent.com/document/api/1441/75636)
* [UpdateUser](https://cloud.tencent.com/document/api/1441/75635)
* [UpdateUserStatus](https://cloud.tencent.com/document/api/1441/75634)

新增数据结构：

* [Filter](https://cloud.tencent.com/document/api/1441/75643#Filter)
* [MemberMap](https://cloud.tencent.com/document/api/1441/75643#MemberMap)
* [Pageable](https://cloud.tencent.com/document/api/1441/75643#Pageable)
* [User](https://cloud.tencent.com/document/api/1441/75643#User)

### 第 1 次发布

发布时间：2022-06-14 12:05:51

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [ResetPassword](https://cloud.tencent.com/document/api/1441/75525)




## 智能保险助手(cii) 版本：2020-12-10

### 第 1 次发布

发布时间：2021-02-04 08:50:26

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateStructureTask](https://cloud.tencent.com/document/api/1368/52757)
* [DescribeStructCompareData](https://cloud.tencent.com/document/api/1368/52754)
* [DescribeStructureTaskResult](https://cloud.tencent.com/document/api/1368/52756)

新增数据结构：

* [CompareMetricsData](https://cloud.tencent.com/document/api/1368/52758#CompareMetricsData)
* [ResultObject](https://cloud.tencent.com/document/api/1368/52758#ResultObject)



## 智能保险助手(cii) 版本：2021-04-08

### 第 14 次发布

发布时间：2022-06-27 06:06:02

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [OcrRecognise](https://cloud.tencent.com/document/api/1368/56853#OcrRecognise)

	* 新增成员：Field


### 第 13 次发布

发布时间：2022-06-16 06:03:27

本次发布包含了以下内容：

改善已有的文档。

新增数据结构：

* [Location](https://cloud.tencent.com/document/api/1368/56853#Location)
* [OcrRecognise](https://cloud.tencent.com/document/api/1368/56853#OcrRecognise)
* [Point](https://cloud.tencent.com/document/api/1368/56853#Point)

修改数据结构：

* [StructureResultObject](https://cloud.tencent.com/document/api/1368/56853#StructureResultObject)

	* 新增成员：ResultFields


### 第 12 次发布

发布时间：2022-02-18 16:00:08

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [UnderwriteItem](https://cloud.tencent.com/document/api/1368/56853#UnderwriteItem)

	* 新增成员：Range, ReportDate, FileType, InspectProject, Unit, OriginName, YinYang


### 第 11 次发布

发布时间：2022-02-18 14:29:36

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeQualityScore](https://cloud.tencent.com/document/api/1368/70151)

### 第 10 次发布

发布时间：2022-02-17 08:07:32

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [StructureResultObject](https://cloud.tencent.com/document/api/1368/56853#StructureResultObject)

	* 新增成员：TaskFiles


### 第 9 次发布

发布时间：2022-01-20 08:06:41

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [AddSubStructureTasks](https://cloud.tencent.com/document/api/1368/68463)
* [DescribeReportClassify](https://cloud.tencent.com/document/api/1368/68462)
* [DescribeUnderwriteTask](https://cloud.tencent.com/document/api/1368/68464)

新增数据结构：

* [ClassifiedReports](https://cloud.tencent.com/document/api/1368/56853#ClassifiedReports)
* [UnderwriteConclusion](https://cloud.tencent.com/document/api/1368/56853#UnderwriteConclusion)
* [UnderwriteOutput](https://cloud.tencent.com/document/api/1368/56853#UnderwriteOutput)

### 第 8 次发布

发布时间：2021-12-13 08:06:17

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateAutoClassifyStructureTask](https://cloud.tencent.com/document/api/1368/65848)

新增数据结构：

* [CreateAutoClassifyStructureTaskInfo](https://cloud.tencent.com/document/api/1368/56853#CreateAutoClassifyStructureTaskInfo)

### 第 7 次发布

发布时间：2021-11-23 08:04:46

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [UploadMedicalFile](https://cloud.tencent.com/document/api/1368/64633)

### 第 6 次发布

发布时间：2021-09-30 08:02:25

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateUnderwriteTaskById](https://cloud.tencent.com/document/api/1368/62147)
* [DescribeMachineUnderwrite](https://cloud.tencent.com/document/api/1368/62146)
* [DescribeStructureDifference](https://cloud.tencent.com/document/api/1368/62144)

<font color="#dd0000">**删除接口**：</font>

* CreateStructureTaskTest
* DescribeStructureTaskResultTest

新增数据结构：

* [InsuranceResult](https://cloud.tencent.com/document/api/1368/56853#InsuranceResult)
* [MachinePredict](https://cloud.tencent.com/document/api/1368/56853#MachinePredict)
* [MachineUnderwriteOutput](https://cloud.tencent.com/document/api/1368/56853#MachineUnderwriteOutput)
* [PerStructDifference](https://cloud.tencent.com/document/api/1368/56853#PerStructDifference)
* [StructureModifyItem](https://cloud.tencent.com/document/api/1368/56853#StructureModifyItem)
* [StructureOneItem](https://cloud.tencent.com/document/api/1368/56853#StructureOneItem)
* [UnderwriteItem](https://cloud.tencent.com/document/api/1368/56853#UnderwriteItem)

### 第 5 次发布

发布时间：2021-09-24 09:54:37

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeStructureResult](https://cloud.tencent.com/document/api/1368/58068)

	* 新增出参：MainTaskId


修改数据结构：

* [StructureResultObject](https://cloud.tencent.com/document/api/1368/56853#StructureResultObject)

	* 新增成员：SubTaskId


### 第 4 次发布

发布时间：2021-09-23 08:05:48

本次发布包含了以下内容：

改善已有的文档。

新增数据结构：

* [ClassifyInfo](https://cloud.tencent.com/document/api/1368/56853#ClassifyInfo)

修改数据结构：

* [ResultObject](https://cloud.tencent.com/document/api/1368/56853#ResultObject)

	* 新增成员：ReportType


### 第 3 次发布

发布时间：2021-08-03 08:12:34

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateStructureTaskTest](https://cloud.tencent.com/document/api/1368/59418)
* [DescribeStructureTaskResultTest](https://cloud.tencent.com/document/api/1368/59417)

### 第 2 次发布

发布时间：2021-07-01 08:11:12

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeStructureResult](https://cloud.tencent.com/document/api/1368/58068)

修改接口：

* [CreateStructureTask](https://cloud.tencent.com/document/api/1368/56852)

	* 新增入参：CallbackUrl


新增数据结构：

* [StructureResultObject](https://cloud.tencent.com/document/api/1368/56853#StructureResultObject)

### 第 1 次发布

发布时间：2021-05-08 15:29:47

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateStructureTask](https://cloud.tencent.com/document/api/1368/56852)
* [DescribeStructCompareData](https://cloud.tencent.com/document/api/1368/56849)
* [DescribeStructureTaskResult](https://cloud.tencent.com/document/api/1368/56851)

新增数据结构：

* [CompareMetricsData](https://cloud.tencent.com/document/api/1368/56853#CompareMetricsData)
* [CreateStructureTaskInfo](https://cloud.tencent.com/document/api/1368/56853#CreateStructureTaskInfo)
* [ResultObject](https://cloud.tencent.com/document/api/1368/56853#ResultObject)
* [ReviewDataTaskInfo](https://cloud.tencent.com/document/api/1368/56853#ReviewDataTaskInfo)




## (cim) 版本：2019-03-18

### 第 1 次发布

发布时间：2019-04-19 15:02:59

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeSdkAppid](https://cloud.tencent.com/document/api/#/#)




## 容器实例服务(cis) 版本：2018-04-08

### 第 1 次发布

发布时间：2018-06-07 15:01:42

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateContainerInstance](https://cloud.tencent.com/document/api/858/17775)
* [DeleteContainerInstance](https://cloud.tencent.com/document/api/858/17774)
* [DescribeContainerInstance](https://cloud.tencent.com/document/api/858/17773)
* [DescribeContainerInstanceEvents](https://cloud.tencent.com/document/api/858/17772)
* [DescribeContainerInstances](https://cloud.tencent.com/document/api/858/17771)
* [DescribeContainerLog](https://cloud.tencent.com/document/api/858/17770)
* [InquiryPriceCreateCis](https://cloud.tencent.com/document/api/858/17769)

新增数据结构：

* [Container](https://cloud.tencent.com/document/api/858/17776#Container)
* [ContainerInstance](https://cloud.tencent.com/document/api/858/17776#ContainerInstance)
* [ContainerLog](https://cloud.tencent.com/document/api/858/17776#ContainerLog)
* [ContainerState](https://cloud.tencent.com/document/api/858/17776#ContainerState)
* [EnvironmentVar](https://cloud.tencent.com/document/api/858/17776#EnvironmentVar)
* [Event](https://cloud.tencent.com/document/api/858/17776#Event)
* [Filter](https://cloud.tencent.com/document/api/858/17776#Filter)
* [Price](https://cloud.tencent.com/document/api/858/17776#Price)




## 消息队列 CKafka 版(ckafka) 版本：2019-08-19

### 第 106 次发布

发布时间：2024-07-22 01:20:34

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [ModifyRoutineMaintenanceTask](https://cloud.tencent.com/document/api/597/109042)

### 第 105 次发布

发布时间：2024-06-20 01:21:11

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [ZoneResponse](https://cloud.tencent.com/document/api/597/40861#ZoneResponse)

	* 新增成员：RequestId, Version, Offset, Limit, ForceCheckTag


### 第 104 次发布

发布时间：2024-05-28 01:20:25

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [PrometheusDTO](https://cloud.tencent.com/document/api/597/40861#PrometheusDTO)

	* 新增成员：VpcId, SubnetId


### 第 103 次发布

发布时间：2024-05-23 01:20:10

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [PrometheusDTO](https://cloud.tencent.com/document/api/597/40861#PrometheusDTO)

	* 新增成员：BrokerIp


### 第 102 次发布

发布时间：2024-05-17 01:18:54

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateConnectResource](https://cloud.tencent.com/document/api/597/77737)

	* 新增入参：MqttConnectParam

* [ModifyConnectResource](https://cloud.tencent.com/document/api/597/77794)

	* 新增入参：MqttConnectParam


### 第 101 次发布

发布时间：2024-05-16 01:22:41

本次发布包含了以下内容：

改善已有的文档。

新增数据结构：

* [MqttConnectParam](https://cloud.tencent.com/document/api/597/40861#MqttConnectParam)
* [MqttParam](https://cloud.tencent.com/document/api/597/40861#MqttParam)

修改数据结构：

* [DatahubResource](https://cloud.tencent.com/document/api/597/40861#DatahubResource)

	* 新增成员：MqttParam

* [DescribeConnectResource](https://cloud.tencent.com/document/api/597/40861#DescribeConnectResource)

	* 新增成员：MqttConnectParam

	* <font color="#dd0000">**修改成员**：</font>TaskProgress, StepList, KafkaConnectParam

* [DescribeConnectResourceResp](https://cloud.tencent.com/document/api/597/40861#DescribeConnectResourceResp)

	* 新增成员：MqttConnectParam

	* <font color="#dd0000">**修改成员**：</font>KafkaConnectParam


### 第 100 次发布

发布时间：2024-03-28 01:11:33

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreatePrometheus](https://cloud.tencent.com/document/api/597/104631)
* [DescribePrometheus](https://cloud.tencent.com/document/api/597/104630)

新增数据结构：

* [PrometheusDTO](https://cloud.tencent.com/document/api/597/40861#PrometheusDTO)
* [PrometheusResult](https://cloud.tencent.com/document/api/597/40861#PrometheusResult)

### 第 99 次发布

发布时间：2024-03-27 01:11:34

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateInstancePost](https://cloud.tencent.com/document/api/597/83553)

	* <font color="#dd0000">**修改入参**：</font>VpcId, SubnetId


### 第 98 次发布

发布时间：2024-03-26 01:11:10

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [ModifyAclRule](https://cloud.tencent.com/document/api/597/89216)

	* <font color="#dd0000">**修改入参**：</font>IsApplied


### 第 97 次发布

发布时间：2023-10-27 01:21:10

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [InstanceAttributesResponse](https://cloud.tencent.com/document/api/597/40861#InstanceAttributesResponse)

	* <font color="#dd0000">**修改成员**：</font>InstanceChargeType

* [MySQLParam](https://cloud.tencent.com/document/api/597/40861#MySQLParam)

	* 新增成员：DateTimeZone, SelfBuilt


### 第 96 次发布

发布时间：2023-09-14 01:21:26

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DeleteInstancePost](https://cloud.tencent.com/document/api/597/98200)

新增数据结构：

* [InstanceDeleteResponse](https://cloud.tencent.com/document/api/597/40861#InstanceDeleteResponse)

### 第 95 次发布

发布时间：2023-08-31 01:09:45

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateInstancePre](https://cloud.tencent.com/document/api/597/45847)

	* 新增入参：AutoVoucher


新增数据结构：

* [BrokerTopicFlowData](https://cloud.tencent.com/document/api/597/40861#BrokerTopicFlowData)

修改数据结构：

* [TopicFlowRankingResult](https://cloud.tencent.com/document/api/597/40861#TopicFlowRankingResult)

	* 新增成员：BrokerTopicFlowData

	* <font color="#dd0000">**修改成员**：</font>BrokerIp, BrokerTopicData

* [ZoneInfo](https://cloud.tencent.com/document/api/597/40861#ZoneInfo)

	* 新增成员：ExtraFlag


### 第 94 次发布

发布时间：2023-08-29 01:09:11

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [MySQLParam](https://cloud.tencent.com/document/api/597/40861#MySQLParam)

	* 新增成员：SignalTable


### 第 93 次发布

发布时间：2023-08-14 01:12:57

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [ClickHouseParam](https://cloud.tencent.com/document/api/597/40861#ClickHouseParam)

	* 新增成员：BatchSize, ConsumerFetchMinBytes, ConsumerFetchMaxWaitMs


### 第 92 次发布

发布时间：2023-08-11 01:08:23

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [InstanceAttributesResponse](https://cloud.tencent.com/document/api/597/40861#InstanceAttributesResponse)

	* 新增成员：InstanceChargeType


### 第 91 次发布

发布时间：2023-08-10 10:00:48

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [RenewCkafkaInstance](https://cloud.tencent.com/document/api/597/90290)

	* 新增出参：Result, RequestId

	* <font color="#dd0000">**删除出参**：</font>BigDealId, DealName


新增数据结构：

* [RenewCkafkaInstanceResp](https://cloud.tencent.com/document/api/597/40861#RenewCkafkaInstanceResp)

修改数据结构：

* [EsParam](https://cloud.tencent.com/document/api/597/40861#EsParam)

	* 新增成员：RecordMappingMode


### 第 90 次发布

发布时间：2023-07-25 10:45:07

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [InstanceScalingDown](https://cloud.tencent.com/document/api/597/95460)

新增数据结构：

* [ScalingDownResp](https://cloud.tencent.com/document/api/597/40861#ScalingDownResp)

### 第 89 次发布

发布时间：2023-07-18 01:18:06

本次发布包含了以下内容：

改善已有的文档。

新增数据结构：

* [EsRecordMapping](https://cloud.tencent.com/document/api/597/40861#EsRecordMapping)

修改数据结构：

* [EsParam](https://cloud.tencent.com/document/api/597/40861#EsParam)

	* 新增成员：RecordMappingList, DateField


### 第 88 次发布

发布时间：2023-07-12 19:20:51

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [Route](https://cloud.tencent.com/document/api/597/40861#Route)

	* 新增成员：BrokerVipList


### 第 87 次发布

发布时间：2023-07-12 17:31:00

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [Route](https://cloud.tencent.com/document/api/597/40861#Route)

	* 新增成员：Subnet, VpcId


### 第 86 次发布

发布时间：2023-06-27 01:10:06

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateInstancePre](https://cloud.tencent.com/document/api/597/45847)

	* 新增入参：InstanceNum


### 第 85 次发布

发布时间：2023-06-26 01:15:49

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreatePostPaidInstance](https://cloud.tencent.com/document/api/597/94259)

新增数据结构：

* [CreateInstancePostData](https://cloud.tencent.com/document/api/597/40861#CreateInstancePostData)
* [CreateInstancePostResp](https://cloud.tencent.com/document/api/597/40861#CreateInstancePostResp)

### 第 84 次发布

发布时间：2023-06-21 01:08:40

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeTopicFlowRanking](https://cloud.tencent.com/document/api/597/90976)

	* 新增入参：BrokerIp


新增数据结构：

* [BrokerTopicData](https://cloud.tencent.com/document/api/597/40861#BrokerTopicData)

修改数据结构：

* [TopicFlowRankingResult](https://cloud.tencent.com/document/api/597/40861#TopicFlowRankingResult)

	* 新增成员：BrokerIp, BrokerTopicData


### 第 83 次发布

发布时间：2023-06-09 01:09:04

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateInstancePre](https://cloud.tencent.com/document/api/597/45847)

	* 新增入参：PublicNetworkMonthly


新增数据结构：

* [DealInstanceDTO](https://cloud.tencent.com/document/api/597/40861#DealInstanceDTO)

修改数据结构：

* [CreateInstancePreData](https://cloud.tencent.com/document/api/597/40861#CreateInstancePreData)

	* 新增成员：DealNameInstanceIdMapping

* [CreateInstancePreResp](https://cloud.tencent.com/document/api/597/40861#CreateInstancePreResp)

	* <font color="#dd0000">**修改成员**：</font>DeleteRouteTimestamp


### 第 82 次发布

发布时间：2023-06-08 01:12:52

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateInstancePost](https://cloud.tencent.com/document/api/597/83553)

	* 新增入参：InstanceType, KafkaVersion, SpecificationsType, DiskType, DiskSize, Partition, TopicNum, MultiZoneFlag, ZoneIds, InstanceNum, PublicNetworkMonthly


新增数据结构：

* [RouteDTO](https://cloud.tencent.com/document/api/597/40861#RouteDTO)

修改数据结构：

* [OperateResponseData](https://cloud.tencent.com/document/api/597/40861#OperateResponseData)

	* 新增成员：RouteDTO


### 第 81 次发布

发布时间：2023-06-07 01:11:15

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeRoute](https://cloud.tencent.com/document/api/597/45484)

	* 新增入参：RouteId


### 第 80 次发布

发布时间：2023-05-12 01:10:57

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeTopicFlowRanking](https://cloud.tencent.com/document/api/597/90976)

新增数据结构：

* [ConsumerGroupSpeed](https://cloud.tencent.com/document/api/597/40861#ConsumerGroupSpeed)
* [TopicFlowRanking](https://cloud.tencent.com/document/api/597/40861#TopicFlowRanking)
* [TopicFlowRankingResult](https://cloud.tencent.com/document/api/597/40861#TopicFlowRankingResult)
* [TopicMessageHeapRanking](https://cloud.tencent.com/document/api/597/40861#TopicMessageHeapRanking)

### 第 79 次发布

发布时间：2023-05-11 01:11:12

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeTaskStatus](https://cloud.tencent.com/document/api/597/90934)

新增数据结构：

* [TaskStatusResponse](https://cloud.tencent.com/document/api/597/40861#TaskStatusResponse)

### 第 78 次发布

发布时间：2023-04-19 01:12:57

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [RenewCkafkaInstance](https://cloud.tencent.com/document/api/597/90290)

### 第 77 次发布

发布时间：2023-04-10 01:12:49

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [DatahubTopicResp](https://cloud.tencent.com/document/api/597/40861#DatahubTopicResp)

	* 新增成员：TopicId


### 第 76 次发布

发布时间：2023-03-29 03:12:17

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [ModifyDatahubTopic](https://cloud.tencent.com/document/api/597/89542)

修改接口：

* [ModifyConnectResource](https://cloud.tencent.com/document/api/597/77794)

	* 新增入参：KafkaConnectParam


### 第 75 次发布

发布时间：2023-03-27 01:20:43

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeConnectResources](https://cloud.tencent.com/document/api/597/77797)

	* 新增入参：ResourceRegion


### 第 74 次发布

发布时间：2023-03-24 01:21:36

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateAclRule](https://cloud.tencent.com/document/api/597/89218)
* [DescribeAclRule](https://cloud.tencent.com/document/api/597/89217)
* [ModifyAclRule](https://cloud.tencent.com/document/api/597/89216)

新增数据结构：

* [AclRuleResp](https://cloud.tencent.com/document/api/597/40861#AclRuleResp)

修改数据结构：

* [DescribeConnectResource](https://cloud.tencent.com/document/api/597/40861#DescribeConnectResource)

	* 新增成员：TaskProgress, StepList


### 第 73 次发布

发布时间：2023-03-22 01:16:39

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [KafkaParam](https://cloud.tencent.com/document/api/597/40861#KafkaParam)

	* 新增成员：ConnectorSyncType, KeepPartition


### 第 72 次发布

发布时间：2023-03-21 01:15:03

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateDatahubTopic](https://cloud.tencent.com/document/api/597/89017)

修改接口：

* [CreateConnectResource](https://cloud.tencent.com/document/api/597/77737)

	* 新增入参：KafkaConnectParam


新增数据结构：

* [DatahubTopicResp](https://cloud.tencent.com/document/api/597/40861#DatahubTopicResp)
* [KafkaConnectParam](https://cloud.tencent.com/document/api/597/40861#KafkaConnectParam)

修改数据结构：

* [DescribeConnectResource](https://cloud.tencent.com/document/api/597/40861#DescribeConnectResource)

	* 新增成员：KafkaConnectParam

* [DescribeConnectResourceResp](https://cloud.tencent.com/document/api/597/40861#DescribeConnectResourceResp)

	* 新增成员：KafkaConnectParam


### 第 71 次发布

发布时间：2023-03-13 01:17:57

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [TopicAttributesResponse](https://cloud.tencent.com/document/api/597/40861#TopicAttributesResponse)

	* 新增成员：ReplicaNum

* [TopicDetail](https://cloud.tencent.com/document/api/597/40861#TopicDetail)

	* 新增成员：Tags


### 第 70 次发布

发布时间：2023-02-24 01:08:10

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeDatahubTopic](https://cloud.tencent.com/document/api/597/86862)
* [DescribeDatahubTopics](https://cloud.tencent.com/document/api/597/86863)

修改接口：

* [DescribeInstancesDetail](https://cloud.tencent.com/document/api/597/40834)

	* 新增入参：TagList


新增数据结构：

* [DatahubTopicDTO](https://cloud.tencent.com/document/api/597/40861#DatahubTopicDTO)
* [DescribeDatahubTopicResp](https://cloud.tencent.com/document/api/597/40861#DescribeDatahubTopicResp)
* [DescribeDatahubTopicsResp](https://cloud.tencent.com/document/api/597/40861#DescribeDatahubTopicsResp)

### 第 69 次发布

发布时间：2023-02-23 01:11:36

本次发布包含了以下内容：

改善已有的文档。

新增数据结构：

* [LowercaseParam](https://cloud.tencent.com/document/api/597/40861#LowercaseParam)

修改数据结构：

* [ValueParam](https://cloud.tencent.com/document/api/597/40861#ValueParam)

	* 新增成员：Lowercase


### 第 68 次发布

发布时间：2023-02-16 01:14:17

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [ConsumerRecord](https://cloud.tencent.com/document/api/597/40861#ConsumerRecord)

	* 新增成员：Headers


### 第 67 次发布

发布时间：2023-02-02 01:10:38

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [GroupResponse](https://cloud.tencent.com/document/api/597/40861#GroupResponse)

	* 新增成员：GroupCountQuota


### 第 66 次发布

发布时间：2023-01-06 01:10:21

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeTopicProduceConnection](https://cloud.tencent.com/document/api/597/85306)

新增数据结构：

* [DescribeConnectInfoResultDTO](https://cloud.tencent.com/document/api/597/40861#DescribeConnectInfoResultDTO)

### 第 65 次发布

发布时间：2022-12-21 01:24:34

本次发布包含了以下内容：

改善已有的文档。

新增数据结构：

* [BatchAnalyseParam](https://cloud.tencent.com/document/api/597/40861#BatchAnalyseParam)
* [ScfParam](https://cloud.tencent.com/document/api/597/40861#ScfParam)

修改数据结构：

* [DatahubResource](https://cloud.tencent.com/document/api/597/40861#DatahubResource)

	* 新增成员：ScfParam

* [EsParam](https://cloud.tencent.com/document/api/597/40861#EsParam)

	* 新增成员：DropDlq

* [KafkaParam](https://cloud.tencent.com/document/api/597/40861#KafkaParam)

	* 新增成员：MsgMultiple

* [TopicParam](https://cloud.tencent.com/document/api/597/40861#TopicParam)

	* 新增成员：MsgMultiple

* [TransformsParam](https://cloud.tencent.com/document/api/597/40861#TransformsParam)

	* 新增成员：BatchAnalyse


### 第 64 次发布

发布时间：2022-12-02 06:19:08

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateInstancePost](https://cloud.tencent.com/document/api/597/83553)
* [InquireCkafkaPrice](https://cloud.tencent.com/document/api/597/83552)

新增数据结构：

* [InquireCkafkaPriceResp](https://cloud.tencent.com/document/api/597/40861#InquireCkafkaPriceResp)
* [InquiryBasePrice](https://cloud.tencent.com/document/api/597/40861#InquiryBasePrice)
* [InquiryDetailPrice](https://cloud.tencent.com/document/api/597/40861#InquiryDetailPrice)
* [InquiryDiskParam](https://cloud.tencent.com/document/api/597/40861#InquiryDiskParam)
* [InquiryPrice](https://cloud.tencent.com/document/api/597/40861#InquiryPrice)
* [InquiryPublicNetworkParam](https://cloud.tencent.com/document/api/597/40861#InquiryPublicNetworkParam)
* [InstanceChargeParam](https://cloud.tencent.com/document/api/597/40861#InstanceChargeParam)

### 第 63 次发布

发布时间：2022-10-31 06:17:22

本次发布包含了以下内容：

改善已有的文档。

新增数据结构：

* [UrlDecodeParam](https://cloud.tencent.com/document/api/597/40861#UrlDecodeParam)

修改数据结构：

* [ValueParam](https://cloud.tencent.com/document/api/597/40861#ValueParam)

	* 新增成员：UrlDecode


### 第 62 次发布

发布时间：2022-10-25 06:19:36

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [KafkaParam](https://cloud.tencent.com/document/api/597/40861#KafkaParam)

	* 新增成员：UseAutoCreateTopic, CompressionType

* [MySQLParam](https://cloud.tencent.com/document/api/597/40861#MySQLParam)

	* 新增成员：IsTableRegular

* [TopicParam](https://cloud.tencent.com/document/api/597/40861#TopicParam)

	* 新增成员：CompressionType, UseAutoCreateTopic


### 第 61 次发布

发布时间：2022-10-20 06:14:29

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [MySQLParam](https://cloud.tencent.com/document/api/597/40861#MySQLParam)

	* 新增成员：SignalDatabase


### 第 60 次发布

发布时间：2022-10-14 06:17:04

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [ModifyConnectResource](https://cloud.tencent.com/document/api/597/77794)

	* 新增入参：DorisConnectParam


新增数据结构：

* [DorisModifyConnectParam](https://cloud.tencent.com/document/api/597/40861#DorisModifyConnectParam)

### 第 59 次发布

发布时间：2022-09-23 06:16:36

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateConnectResource](https://cloud.tencent.com/document/api/597/77737)

	* 新增入参：DorisConnectParam


新增数据结构：

* [DorisConnectParam](https://cloud.tencent.com/document/api/597/40861#DorisConnectParam)

修改数据结构：

* [DescribeConnectResource](https://cloud.tencent.com/document/api/597/40861#DescribeConnectResource)

	* 新增成员：DorisConnectParam

* [DescribeConnectResourceResp](https://cloud.tencent.com/document/api/597/40861#DescribeConnectResourceResp)

	* 新增成员：DorisConnectParam


### 第 58 次发布

发布时间：2022-09-22 06:16:02

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateDatahubTask](https://cloud.tencent.com/document/api/597/77736)

	* 新增入参：Tags


新增数据结构：

* [JsonPathReplaceParam](https://cloud.tencent.com/document/api/597/40861#JsonPathReplaceParam)

修改数据结构：

* [DescribeDatahubTaskRes](https://cloud.tencent.com/document/api/597/40861#DescribeDatahubTaskRes)

	* 新增成员：Tags

* [ValueParam](https://cloud.tencent.com/document/api/597/40861#ValueParam)

	* 新增成员：JsonPathReplace


### 第 57 次发布

发布时间：2022-09-19 06:16:48

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [ModifyConnectResource](https://cloud.tencent.com/document/api/597/77794)

	* 新增入参：CtsdbConnectParam


新增数据结构：

* [CtsdbConnectParam](https://cloud.tencent.com/document/api/597/40861#CtsdbConnectParam)
* [CtsdbModifyConnectParam](https://cloud.tencent.com/document/api/597/40861#CtsdbModifyConnectParam)
* [CtsdbParam](https://cloud.tencent.com/document/api/597/40861#CtsdbParam)
* [KVParam](https://cloud.tencent.com/document/api/597/40861#KVParam)
* [SplitParam](https://cloud.tencent.com/document/api/597/40861#SplitParam)

修改数据结构：

* [DatahubResource](https://cloud.tencent.com/document/api/597/40861#DatahubResource)

	* 新增成员：CtsdbParam

* [DescribeConnectResource](https://cloud.tencent.com/document/api/597/40861#DescribeConnectResource)

	* 新增成员：MariaDBConnectParam, SQLServerConnectParam, CtsdbConnectParam

* [DescribeConnectResourceResp](https://cloud.tencent.com/document/api/597/40861#DescribeConnectResourceResp)

	* 新增成员：MariaDBConnectParam, SQLServerConnectParam, CtsdbConnectParam

* [MariaDBParam](https://cloud.tencent.com/document/api/597/40861#MariaDBParam)

	* 新增成员：KeyColumns, IsTablePrefix, OutputFormat, IncludeContentChanges, IncludeQuery, RecordWithSchema

* [PostgreSQLParam](https://cloud.tencent.com/document/api/597/40861#PostgreSQLParam)

	* 新增成员：IsTableRegular, KeyColumns, RecordWithSchema

* [TransformsParam](https://cloud.tencent.com/document/api/597/40861#TransformsParam)

	* 新增成员：KeepMetadata

* [ValueParam](https://cloud.tencent.com/document/api/597/40861#ValueParam)

	* 新增成员：Split, KV, Result


### 第 56 次发布

发布时间：2022-08-30 06:16:47

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [ClsParam](https://cloud.tencent.com/document/api/597/40861#ClsParam)

	* 新增成员：TimeField


### 第 55 次发布

发布时间：2022-08-29 06:16:32

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [MySQLParam](https://cloud.tencent.com/document/api/597/40861#MySQLParam)

	* 新增成员：RecordWithSchema

* [PostgreSQLParam](https://cloud.tencent.com/document/api/597/40861#PostgreSQLParam)

	* 新增成员：DataFormat, DataTargetInsertMode, DataTargetPrimaryKeyField, DataTargetRecordMapping, DropInvalidMessage


### 第 54 次发布

发布时间：2022-08-23 06:17:56

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [ModifyInstanceAttributes](https://cloud.tencent.com/document/api/597/40832)

	* 新增入参：MaxMessageByte


### 第 53 次发布

发布时间：2022-08-22 06:16:09

本次发布包含了以下内容：

改善已有的文档。

新增数据结构：

* [RowParam](https://cloud.tencent.com/document/api/597/40861#RowParam)

修改数据结构：

* [TransformsParam](https://cloud.tencent.com/document/api/597/40861#TransformsParam)

	* 新增成员：RowParam


### 第 52 次发布

发布时间：2022-08-19 06:13:13

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [MySQLModifyConnectParam](https://cloud.tencent.com/document/api/597/40861#MySQLModifyConnectParam)

	* 新增成员：SelfBuilt

* [PostgreSQLModifyConnectParam](https://cloud.tencent.com/document/api/597/40861#PostgreSQLModifyConnectParam)

	* 新增成员：SelfBuilt


### 第 51 次发布

发布时间：2022-08-16 06:14:00

本次发布包含了以下内容：

改善已有的文档。

新增数据结构：

* [TableMapping](https://cloud.tencent.com/document/api/597/40861#TableMapping)

修改数据结构：

* [KafkaParam](https://cloud.tencent.com/document/api/597/40861#KafkaParam)

	* 新增成员：TableMappings, UseTableMapping

	* <font color="#dd0000">**修改成员**：</font>Topic

* [MySQLConnectParam](https://cloud.tencent.com/document/api/597/40861#MySQLConnectParam)

	* 新增成员：SelfBuilt

* [MySQLParam](https://cloud.tencent.com/document/api/597/40861#MySQLParam)

	* 新增成员：OutputFormat, IsTablePrefix, IncludeContentChanges, IncludeQuery

* [PostgreSQLConnectParam](https://cloud.tencent.com/document/api/597/40861#PostgreSQLConnectParam)

	* 新增成员：SelfBuilt


### 第 50 次发布

发布时间：2022-08-11 06:18:51

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [MySQLParam](https://cloud.tencent.com/document/api/597/40861#MySQLParam)

	* 新增成员：DropInvalidMessage, DropCls


### 第 49 次发布

发布时间：2022-08-08 06:10:42

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [FetchMessageListByOffset](https://cloud.tencent.com/document/api/597/47896)

### 第 48 次发布

发布时间：2022-07-28 06:07:46

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [MySQLParam](https://cloud.tencent.com/document/api/597/40861#MySQLParam)

	* 新增成员：TopicRegex, TopicReplacement, KeyColumns

* [TdwParam](https://cloud.tencent.com/document/api/597/40861#TdwParam)

	* 新增成员：TdwHost, TdwPort


### 第 47 次发布

发布时间：2022-07-26 06:10:15

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DeleteConnectResource](https://cloud.tencent.com/document/api/597/77800)
* [DeleteDatahubTask](https://cloud.tencent.com/document/api/597/77799)
* [DeleteDatahubTopic](https://cloud.tencent.com/document/api/597/77803)
* [DescribeConnectResource](https://cloud.tencent.com/document/api/597/77798)
* [DescribeConnectResources](https://cloud.tencent.com/document/api/597/77797)
* [DescribeDatahubGroupOffsets](https://cloud.tencent.com/document/api/597/77792)
* [DescribeDatahubTask](https://cloud.tencent.com/document/api/597/77796)
* [DescribeDatahubTasks](https://cloud.tencent.com/document/api/597/77795)
* [FetchDatahubMessageByOffset](https://cloud.tencent.com/document/api/597/77802)
* [FetchLatestDatahubMessageList](https://cloud.tencent.com/document/api/597/77801)
* [ModifyConnectResource](https://cloud.tencent.com/document/api/597/77794)
* [ModifyDatahubTask](https://cloud.tencent.com/document/api/597/77793)

新增数据结构：

* [ClickHouseModifyConnectParam](https://cloud.tencent.com/document/api/597/40861#ClickHouseModifyConnectParam)
* [Connection](https://cloud.tencent.com/document/api/597/40861#Connection)
* [DatahubTaskIdRes](https://cloud.tencent.com/document/api/597/40861#DatahubTaskIdRes)
* [DatahubTaskInfo](https://cloud.tencent.com/document/api/597/40861#DatahubTaskInfo)
* [DescribeConnectResource](https://cloud.tencent.com/document/api/597/40861#DescribeConnectResource)
* [DescribeConnectResourceResp](https://cloud.tencent.com/document/api/597/40861#DescribeConnectResourceResp)
* [DescribeConnectResourcesResp](https://cloud.tencent.com/document/api/597/40861#DescribeConnectResourcesResp)
* [DescribeDatahubTaskRes](https://cloud.tencent.com/document/api/597/40861#DescribeDatahubTaskRes)
* [DescribeDatahubTasksRes](https://cloud.tencent.com/document/api/597/40861#DescribeDatahubTasksRes)
* [DtsModifyConnectParam](https://cloud.tencent.com/document/api/597/40861#DtsModifyConnectParam)
* [EsModifyConnectParam](https://cloud.tencent.com/document/api/597/40861#EsModifyConnectParam)
* [MariaDBModifyConnectParam](https://cloud.tencent.com/document/api/597/40861#MariaDBModifyConnectParam)
* [MongoDBModifyConnectParam](https://cloud.tencent.com/document/api/597/40861#MongoDBModifyConnectParam)
* [MySQLModifyConnectParam](https://cloud.tencent.com/document/api/597/40861#MySQLModifyConnectParam)
* [PostgreSQLModifyConnectParam](https://cloud.tencent.com/document/api/597/40861#PostgreSQLModifyConnectParam)
* [SQLServerModifyConnectParam](https://cloud.tencent.com/document/api/597/40861#SQLServerModifyConnectParam)

修改数据结构：

* [TdwParam](https://cloud.tencent.com/document/api/597/40861#TdwParam)

	* 新增成员：IsDomestic


### 第 46 次发布

发布时间：2022-07-25 06:04:28

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateConnectResource](https://cloud.tencent.com/document/api/597/77737)
* [CreateDatahubTask](https://cloud.tencent.com/document/api/597/77736)

新增数据结构：

* [AnalyseParam](https://cloud.tencent.com/document/api/597/40861#AnalyseParam)
* [ClickHouseConnectParam](https://cloud.tencent.com/document/api/597/40861#ClickHouseConnectParam)
* [ClickHouseParam](https://cloud.tencent.com/document/api/597/40861#ClickHouseParam)
* [ClickHouseSchema](https://cloud.tencent.com/document/api/597/40861#ClickHouseSchema)
* [ClsParam](https://cloud.tencent.com/document/api/597/40861#ClsParam)
* [ConnectResourceResourceIdResp](https://cloud.tencent.com/document/api/597/40861#ConnectResourceResourceIdResp)
* [CosParam](https://cloud.tencent.com/document/api/597/40861#CosParam)
* [CreateDatahubTaskRes](https://cloud.tencent.com/document/api/597/40861#CreateDatahubTaskRes)
* [DatahubResource](https://cloud.tencent.com/document/api/597/40861#DatahubResource)
* [DateParam](https://cloud.tencent.com/document/api/597/40861#DateParam)
* [DropCls](https://cloud.tencent.com/document/api/597/40861#DropCls)
* [DtsConnectParam](https://cloud.tencent.com/document/api/597/40861#DtsConnectParam)
* [DtsParam](https://cloud.tencent.com/document/api/597/40861#DtsParam)
* [EsConnectParam](https://cloud.tencent.com/document/api/597/40861#EsConnectParam)
* [EsParam](https://cloud.tencent.com/document/api/597/40861#EsParam)
* [EventBusParam](https://cloud.tencent.com/document/api/597/40861#EventBusParam)
* [FailureParam](https://cloud.tencent.com/document/api/597/40861#FailureParam)
* [FieldParam](https://cloud.tencent.com/document/api/597/40861#FieldParam)
* [FilterMapParam](https://cloud.tencent.com/document/api/597/40861#FilterMapParam)
* [KafkaParam](https://cloud.tencent.com/document/api/597/40861#KafkaParam)
* [MapParam](https://cloud.tencent.com/document/api/597/40861#MapParam)
* [MariaDBConnectParam](https://cloud.tencent.com/document/api/597/40861#MariaDBConnectParam)
* [MariaDBParam](https://cloud.tencent.com/document/api/597/40861#MariaDBParam)
* [MongoDBConnectParam](https://cloud.tencent.com/document/api/597/40861#MongoDBConnectParam)
* [MongoDBParam](https://cloud.tencent.com/document/api/597/40861#MongoDBParam)
* [MySQLConnectParam](https://cloud.tencent.com/document/api/597/40861#MySQLConnectParam)
* [MySQLParam](https://cloud.tencent.com/document/api/597/40861#MySQLParam)
* [PostgreSQLConnectParam](https://cloud.tencent.com/document/api/597/40861#PostgreSQLConnectParam)
* [PostgreSQLParam](https://cloud.tencent.com/document/api/597/40861#PostgreSQLParam)
* [PrivateLinkParam](https://cloud.tencent.com/document/api/597/40861#PrivateLinkParam)
* [RecordMapping](https://cloud.tencent.com/document/api/597/40861#RecordMapping)
* [RegexReplaceParam](https://cloud.tencent.com/document/api/597/40861#RegexReplaceParam)
* [ReplaceParam](https://cloud.tencent.com/document/api/597/40861#ReplaceParam)
* [SMTParam](https://cloud.tencent.com/document/api/597/40861#SMTParam)
* [SQLServerConnectParam](https://cloud.tencent.com/document/api/597/40861#SQLServerConnectParam)
* [SQLServerParam](https://cloud.tencent.com/document/api/597/40861#SQLServerParam)
* [SecondaryAnalyseParam](https://cloud.tencent.com/document/api/597/40861#SecondaryAnalyseParam)
* [SubstrParam](https://cloud.tencent.com/document/api/597/40861#SubstrParam)
* [TdwParam](https://cloud.tencent.com/document/api/597/40861#TdwParam)
* [TopicParam](https://cloud.tencent.com/document/api/597/40861#TopicParam)
* [TransformParam](https://cloud.tencent.com/document/api/597/40861#TransformParam)
* [TransformsParam](https://cloud.tencent.com/document/api/597/40861#TransformsParam)
* [ValueParam](https://cloud.tencent.com/document/api/597/40861#ValueParam)

### 第 45 次发布

发布时间：2022-07-22 06:04:27

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [InstanceDetail](https://cloud.tencent.com/document/api/597/40861#InstanceDetail)

	* 新增成员：Features


### 第 44 次发布

发布时间：2022-07-20 06:03:16

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [ModifyTopicAttributes](https://cloud.tencent.com/document/api/597/40844)

	* 新增入参：ReplicaNum


### 第 43 次发布

发布时间：2022-07-19 06:07:25

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CheckCdcCluster](https://cloud.tencent.com/document/api/597/77400)
* [CreateCdcCluster](https://cloud.tencent.com/document/api/597/77399)

新增数据结构：

* [CdcClusterResponse](https://cloud.tencent.com/document/api/597/40861#CdcClusterResponse)

### 第 42 次发布

发布时间：2022-07-05 06:09:16

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeCkafkaZone](https://cloud.tencent.com/document/api/597/55246)

	* 新增入参：CdcId

* [DescribeRegion](https://cloud.tencent.com/document/api/597/55245)

	* 新增入参：CdcId


修改数据结构：

* [InstanceDetail](https://cloud.tencent.com/document/api/597/40861#InstanceDetail)

	* 新增成员：ClusterType


### 第 41 次发布

发布时间：2022-05-16 06:05:48

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [ModifyInstancePre](https://cloud.tencent.com/document/api/597/73693)

### 第 40 次发布

发布时间：2022-04-29 06:04:35

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DeleteRoute](https://cloud.tencent.com/document/api/597/73213)

### 第 39 次发布

发布时间：2022-04-21 06:08:41

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateTopic](https://cloud.tencent.com/document/api/597/40851)

	* 新增入参：MaxMessageBytes

* [DescribeInstancesDetail](https://cloud.tencent.com/document/api/597/40834)

	* 新增入参：InstanceIdList


### 第 38 次发布

发布时间：2022-03-17 08:03:56

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateInstancePre](https://cloud.tencent.com/document/api/597/45847)

	* 新增入参：MultiZoneFlag, ZoneIds


### 第 37 次发布

发布时间：2022-03-10 08:06:28

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [ModifyTopicAttributes](https://cloud.tencent.com/document/api/597/40844)

	* 新增入参：QuotaProducerByteRate, QuotaConsumerByteRate


新增数据结构：

* [InstanceQuotaConfigResp](https://cloud.tencent.com/document/api/597/40861#InstanceQuotaConfigResp)

修改数据结构：

* [TopicAttributesResponse](https://cloud.tencent.com/document/api/597/40861#TopicAttributesResponse)

	* 新增成员：QuotaConfig


### 第 36 次发布

发布时间：2022-03-04 08:05:57

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [AuthorizeToken](https://cloud.tencent.com/document/api/597/70646)
* [CancelAuthorizationToken](https://cloud.tencent.com/document/api/597/70645)
* [CreateToken](https://cloud.tencent.com/document/api/597/70644)

### 第 35 次发布

发布时间：2022-02-21 08:03:18

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateConsumer](https://cloud.tencent.com/document/api/597/70173)
* [CreateRoute](https://cloud.tencent.com/document/api/597/70172)

### 第 34 次发布

发布时间：2022-02-10 08:03:19

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DeleteGroup](https://cloud.tencent.com/document/api/597/69059)

### 第 33 次发布

发布时间：2022-01-18 08:06:14

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeInstances](https://cloud.tencent.com/document/api/597/40835)

	* 新增入参：VpcId

* [DescribeInstancesDetail](https://cloud.tencent.com/document/api/597/40834)

	* 新增入参：InstanceIds


修改数据结构：

* [InstanceDetail](https://cloud.tencent.com/document/api/597/40861#InstanceDetail)

	* 新增成员：PartitionNumber, PublicNetworkChargeType, PublicNetwork


### 第 32 次发布

发布时间：2021-12-23 08:07:26

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [SendMessage](https://cloud.tencent.com/document/api/597/66682)

新增数据结构：

* [BatchContent](https://cloud.tencent.com/document/api/597/40861#BatchContent)

### 第 31 次发布

发布时间：2021-12-22 08:08:33

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [ModifyInstanceAttributes](https://cloud.tencent.com/document/api/597/40832)

	* 新增入参：DynamicDiskConfig

* [ModifyTopicAttributes](https://cloud.tencent.com/document/api/597/40844)

	* 新增入参：Tags


新增数据结构：

* [DynamicDiskConfig](https://cloud.tencent.com/document/api/597/40861#DynamicDiskConfig)

修改数据结构：

* [InstanceAttributesResponse](https://cloud.tencent.com/document/api/597/40861#InstanceAttributesResponse)

	* 新增成员：DynamicDiskConfig


### 第 30 次发布

发布时间：2021-12-21 08:02:41

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateTopic](https://cloud.tencent.com/document/api/597/40851)

	* 新增入参：Tags


### 第 29 次发布

发布时间：2021-12-20 08:04:36

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [BatchModifyGroupOffsets](https://cloud.tencent.com/document/api/597/66319)
* [BatchModifyTopicAttributes](https://cloud.tencent.com/document/api/597/66318)

新增数据结构：

* [BatchModifyTopicInfo](https://cloud.tencent.com/document/api/597/40861#BatchModifyTopicInfo)
* [BatchModifyTopicResultDTO](https://cloud.tencent.com/document/api/597/40861#BatchModifyTopicResultDTO)
* [Partitions](https://cloud.tencent.com/document/api/597/40861#Partitions)

修改数据结构：

* [ZoneResponse](https://cloud.tencent.com/document/api/597/40861#ZoneResponse)

	* 新增成员：PublicNetwork, PublicNetworkLimit


### 第 28 次发布

发布时间：2021-12-14 08:07:08

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [InstanceAttributesResponse](https://cloud.tencent.com/document/api/597/40861#InstanceAttributesResponse)

	* 新增成员：RemainingPartitions, RemainingTopics


### 第 27 次发布

发布时间：2021-12-10 08:03:21

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DeleteInstancePre](https://cloud.tencent.com/document/api/597/65806)

### 第 26 次发布

发布时间：2021-12-07 11:23:56

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateInstancePre](https://cloud.tencent.com/document/api/597/45847)

	* 新增出参：Result, RequestId

	* <font color="#dd0000">**删除出参**：</font>ReturnCode, ReturnMessage, Data, DeleteRouteTimestamp


新增数据结构：

* [CreateInstancePreResp](https://cloud.tencent.com/document/api/597/40861#CreateInstancePreResp)

### 第 25 次发布

发布时间：2021-11-30 08:04:22

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateInstancePre](https://cloud.tencent.com/document/api/597/45847)

	* 新增出参：DeleteRouteTimestamp


### 第 24 次发布

发布时间：2021-11-02 08:04:08

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateTopic](https://cloud.tencent.com/document/api/597/40851)

	* 新增入参：RetentionBytes

* [ModifyTopicAttributes](https://cloud.tencent.com/document/api/597/40844)

	* 新增入参：RetentionBytes


修改数据结构：

* [Config](https://cloud.tencent.com/document/api/597/40861#Config)

	* 新增成员：RetentionBytes


### 第 23 次发布

发布时间：2021-10-15 08:08:18

本次发布包含了以下内容：

改善已有的文档。

新增数据结构：

* [SaleInfo](https://cloud.tencent.com/document/api/597/40861#SaleInfo)

修改数据结构：

* [ZoneInfo](https://cloud.tencent.com/document/api/597/40861#ZoneInfo)

	* 新增成员：SalesInfo


### 第 22 次发布

发布时间：2021-09-17 08:05:43

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateTopic](https://cloud.tencent.com/document/api/597/40851)

	* 新增入参：EnableAclRule, AclRuleName

* [DescribeTopic](https://cloud.tencent.com/document/api/597/40847)

	* 新增入参：AclRuleName

* [DescribeTopicDetail](https://cloud.tencent.com/document/api/597/40845)

	* 新增入参：AclRuleName

* [ModifyTopicAttributes](https://cloud.tencent.com/document/api/597/40844)

	* 新增入参：IpWhiteList, EnableAclRule, AclRuleName


新增数据结构：

* [AclRule](https://cloud.tencent.com/document/api/597/40861#AclRule)

修改数据结构：

* [TopicAttributesResponse](https://cloud.tencent.com/document/api/597/40861#TopicAttributesResponse)

	* 新增成员：EnableAclRule, AclRuleList

* [TopicDetail](https://cloud.tencent.com/document/api/597/40861#TopicDetail)

	* 新增成员：Status


### 第 21 次发布

发布时间：2021-09-09 08:10:08

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [BatchCreateAcl](https://cloud.tencent.com/document/api/597/61309)

新增数据结构：

* [AclRuleInfo](https://cloud.tencent.com/document/api/597/40861#AclRuleInfo)

### 第 20 次发布

发布时间：2021-09-02 08:09:02

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateAcl](https://cloud.tencent.com/document/api/597/40860)

	* 新增入参：ResourceNameList


### 第 19 次发布

发布时间：2021-08-31 08:11:07

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DeleteRouteTriggerTime](https://cloud.tencent.com/document/api/597/60878)

修改接口：

* [ModifyInstanceAttributes](https://cloud.tencent.com/document/api/597/40832)

	* 新增入参：PublicNetwork


修改数据结构：

* [InstanceAttributesResponse](https://cloud.tencent.com/document/api/597/40861#InstanceAttributesResponse)

	* 新增成员：MaxConnection, PublicNetwork, DeleteRouteTimestamp


### 第 18 次发布

发布时间：2021-08-30 08:10:09

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeTopicSyncReplica](https://cloud.tencent.com/document/api/597/60811)

新增数据结构：

* [TopicInSyncReplicaInfo](https://cloud.tencent.com/document/api/597/40861#TopicInSyncReplicaInfo)
* [TopicInSyncReplicaResult](https://cloud.tencent.com/document/api/597/40861#TopicInSyncReplicaResult)

### 第 17 次发布

发布时间：2021-08-24 08:11:48

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [Route](https://cloud.tencent.com/document/api/597/40861#Route)

	* 新增成员：DeleteTimestamp


### 第 16 次发布

发布时间：2021-08-13 08:10:15

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeTopicSubscribeGroup](https://cloud.tencent.com/document/api/597/60227)

新增数据结构：

* [TopicSubscribeGroup](https://cloud.tencent.com/document/api/597/40861#TopicSubscribeGroup)

### 第 15 次发布

发布时间：2021-08-05 08:10:33

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [FetchMessageByOffset](https://cloud.tencent.com/document/api/597/47897)

新增数据结构：

* [ConsumerRecord](https://cloud.tencent.com/document/api/597/40861#ConsumerRecord)

### 第 14 次发布

发布时间：2021-07-26 08:28:06

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateInstancePre](https://cloud.tencent.com/document/api/597/45847)

	* 新增入参：KafkaVersion, SpecificationsType, DiskSize, BandWidth, Partition, Tags, DiskType


修改数据结构：

* [CreateInstancePreData](https://cloud.tencent.com/document/api/597/40861#CreateInstancePreData)

	* 新增成员：InstanceId


### 第 13 次发布

发布时间：2021-04-28 08:12:27

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeCkafkaZone](https://cloud.tencent.com/document/api/597/55246)
* [DescribeRegion](https://cloud.tencent.com/document/api/597/55245)

新增数据结构：

* [ClusterInfo](https://cloud.tencent.com/document/api/597/40861#ClusterInfo)
* [Price](https://cloud.tencent.com/document/api/597/40861#Price)
* [Region](https://cloud.tencent.com/document/api/597/40861#Region)
* [ZoneInfo](https://cloud.tencent.com/document/api/597/40861#ZoneInfo)
* [ZoneResponse](https://cloud.tencent.com/document/api/597/40861#ZoneResponse)

### 第 12 次发布

发布时间：2021-04-08 08:09:09

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DeleteAclRule](https://cloud.tencent.com/document/api/597/54394)

修改接口：

* [CreateAcl](https://cloud.tencent.com/document/api/597/40860)

	* <font color="#dd0000">**修改入参**：</font>ResourceName


### 第 11 次发布

发布时间：2021-02-23 08:09:39

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [ModifyInstanceAttributes](https://cloud.tencent.com/document/api/597/40832)

	* 新增入参：DynamicRetentionConfig, RebalanceTime


新增数据结构：

* [DynamicRetentionTime](https://cloud.tencent.com/document/api/597/40861#DynamicRetentionTime)
* [TopicRetentionTimeConfigRsp](https://cloud.tencent.com/document/api/597/40861#TopicRetentionTimeConfigRsp)

修改数据结构：

* [InstanceAttributesResponse](https://cloud.tencent.com/document/api/597/40861#InstanceAttributesResponse)

	* 新增成员：RetentionTimeConfig

* [InstanceDetail](https://cloud.tencent.com/document/api/597/40861#InstanceDetail)

	* 新增成员：InstanceType, DiskType, MaxTopicNumber, MaxPartitionNumber, RebalanceTime

* [TopicDetail](https://cloud.tencent.com/document/api/597/40861#TopicDetail)

	* 新增成员：RetentionTimeConfig


### 第 10 次发布

发布时间：2020-09-25 08:08:08

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [ModifyGroupOffsets](https://cloud.tencent.com/document/api/597/40833)

	* 新增入参：Partitions


### 第 9 次发布

发布时间：2020-09-22 08:08:59

本次发布包含了以下内容：

改善已有的文档。

<font color="#dd0000">**删除接口**：</font>

* FetchMessageByOffset
* FetchMessageListByOffset
* FetchMessageListByTimestamp

<font color="#dd0000">**删除数据结构**：</font>

* ConsumerRecord

### 第 8 次发布

发布时间：2020-09-15 08:09:08

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [SubscribedInfo](https://cloud.tencent.com/document/api/597/40861#SubscribedInfo)

	* 新增成员：TopicId


### 第 7 次发布

发布时间：2020-09-09 08:12:49

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [InstanceAttributesResponse](https://cloud.tencent.com/document/api/597/40861#InstanceAttributesResponse)

	* 新增成员：Features


### 第 6 次发布

发布时间：2020-08-28 08:06:31

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [FetchMessageByOffset](https://cloud.tencent.com/document/api/597/47897)
* [FetchMessageListByOffset](https://cloud.tencent.com/document/api/597/47896)
* [FetchMessageListByTimestamp](https://cloud.tencent.com/document/api/597/47895)

新增数据结构：

* [ConsumerRecord](https://cloud.tencent.com/document/api/597/40861#ConsumerRecord)

### 第 5 次发布

发布时间：2020-08-26 08:07:26

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [InstanceAttributesResponse](https://cloud.tencent.com/document/api/597/40861#InstanceAttributesResponse)

	* 新增成员：InstanceType


### 第 4 次发布

发布时间：2020-06-30 08:24:15

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateInstancePre](https://cloud.tencent.com/document/api/597/45847)

新增数据结构：

* [CreateInstancePreData](https://cloud.tencent.com/document/api/597/40861#CreateInstancePreData)

### 第 3 次发布

发布时间：2020-06-11 08:21:21

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeRoute](https://cloud.tencent.com/document/api/597/45484)

新增数据结构：

* [Route](https://cloud.tencent.com/document/api/597/40861#Route)
* [RouteResponse](https://cloud.tencent.com/document/api/597/40861#RouteResponse)

### 第 2 次发布

发布时间：2020-03-04 17:55:31

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeGroup](https://cloud.tencent.com/document/api/597/40840)

	* <font color="#dd0000">**修改出参**：</font>Result


新增数据结构：

* [GroupResponse](https://cloud.tencent.com/document/api/597/40861#GroupResponse)
* [OperateResponseData](https://cloud.tencent.com/document/api/597/40861#OperateResponseData)
* [PartitionOffset](https://cloud.tencent.com/document/api/597/40861#PartitionOffset)

修改数据结构：

* [InstanceAttributesResponse](https://cloud.tencent.com/document/api/597/40861#InstanceAttributesResponse)

	* 新增成员：ZoneIds, Version, MaxGroupNum, Cvm

* [InstanceDetail](https://cloud.tencent.com/document/api/597/40861#InstanceDetail)

	* 新增成员：Version, ZoneIds, Cvm

	* <font color="#dd0000">**修改成员**：</font>Healthy

* [JgwOperateResponse](https://cloud.tencent.com/document/api/597/40861#JgwOperateResponse)

	* 新增成员：Data

* [SubscribedInfo](https://cloud.tencent.com/document/api/597/40861#SubscribedInfo)

	* 新增成员：PartitionOffset


### 第 1 次发布

发布时间：2020-01-06 19:27:43

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateAcl](https://cloud.tencent.com/document/api/597/40860)
* [CreatePartition](https://cloud.tencent.com/document/api/597/40852)
* [CreateTopic](https://cloud.tencent.com/document/api/597/40851)
* [CreateTopicIpWhiteList](https://cloud.tencent.com/document/api/597/40850)
* [CreateUser](https://cloud.tencent.com/document/api/597/40859)
* [DeleteAcl](https://cloud.tencent.com/document/api/597/40858)
* [DeleteTopic](https://cloud.tencent.com/document/api/597/40849)
* [DeleteTopicIpWhiteList](https://cloud.tencent.com/document/api/597/40848)
* [DeleteUser](https://cloud.tencent.com/document/api/597/40857)
* [DescribeACL](https://cloud.tencent.com/document/api/597/40856)
* [DescribeAppInfo](https://cloud.tencent.com/document/api/597/40842)
* [DescribeConsumerGroup](https://cloud.tencent.com/document/api/597/40841)
* [DescribeGroup](https://cloud.tencent.com/document/api/597/40840)
* [DescribeGroupInfo](https://cloud.tencent.com/document/api/597/40838)
* [DescribeGroupOffsets](https://cloud.tencent.com/document/api/597/40837)
* [DescribeInstanceAttributes](https://cloud.tencent.com/document/api/597/40836)
* [DescribeInstances](https://cloud.tencent.com/document/api/597/40835)
* [DescribeInstancesDetail](https://cloud.tencent.com/document/api/597/40834)
* [DescribeTopic](https://cloud.tencent.com/document/api/597/40847)
* [DescribeTopicAttributes](https://cloud.tencent.com/document/api/597/40846)
* [DescribeTopicDetail](https://cloud.tencent.com/document/api/597/40845)
* [DescribeUser](https://cloud.tencent.com/document/api/597/40855)
* [ModifyGroupOffsets](https://cloud.tencent.com/document/api/597/40833)
* [ModifyInstanceAttributes](https://cloud.tencent.com/document/api/597/40832)
* [ModifyPassword](https://cloud.tencent.com/document/api/597/40854)
* [ModifyTopicAttributes](https://cloud.tencent.com/document/api/597/40844)

新增数据结构：

* [Acl](https://cloud.tencent.com/document/api/597/40861#Acl)
* [AclResponse](https://cloud.tencent.com/document/api/597/40861#AclResponse)
* [AppIdResponse](https://cloud.tencent.com/document/api/597/40861#AppIdResponse)
* [Assignment](https://cloud.tencent.com/document/api/597/40861#Assignment)
* [Config](https://cloud.tencent.com/document/api/597/40861#Config)
* [ConsumerGroup](https://cloud.tencent.com/document/api/597/40861#ConsumerGroup)
* [ConsumerGroupResponse](https://cloud.tencent.com/document/api/597/40861#ConsumerGroupResponse)
* [ConsumerGroupTopic](https://cloud.tencent.com/document/api/597/40861#ConsumerGroupTopic)
* [CreateTopicResp](https://cloud.tencent.com/document/api/597/40861#CreateTopicResp)
* [DescribeGroup](https://cloud.tencent.com/document/api/597/40861#DescribeGroup)
* [Filter](https://cloud.tencent.com/document/api/597/40861#Filter)
* [Group](https://cloud.tencent.com/document/api/597/40861#Group)
* [GroupInfoMember](https://cloud.tencent.com/document/api/597/40861#GroupInfoMember)
* [GroupInfoResponse](https://cloud.tencent.com/document/api/597/40861#GroupInfoResponse)
* [GroupInfoTopics](https://cloud.tencent.com/document/api/597/40861#GroupInfoTopics)
* [GroupOffsetPartition](https://cloud.tencent.com/document/api/597/40861#GroupOffsetPartition)
* [GroupOffsetResponse](https://cloud.tencent.com/document/api/597/40861#GroupOffsetResponse)
* [GroupOffsetTopic](https://cloud.tencent.com/document/api/597/40861#GroupOffsetTopic)
* [Instance](https://cloud.tencent.com/document/api/597/40861#Instance)
* [InstanceAttributesResponse](https://cloud.tencent.com/document/api/597/40861#InstanceAttributesResponse)
* [InstanceConfigDO](https://cloud.tencent.com/document/api/597/40861#InstanceConfigDO)
* [InstanceDetail](https://cloud.tencent.com/document/api/597/40861#InstanceDetail)
* [InstanceDetailResponse](https://cloud.tencent.com/document/api/597/40861#InstanceDetailResponse)
* [InstanceResponse](https://cloud.tencent.com/document/api/597/40861#InstanceResponse)
* [JgwOperateResponse](https://cloud.tencent.com/document/api/597/40861#JgwOperateResponse)
* [ModifyInstanceAttributesConfig](https://cloud.tencent.com/document/api/597/40861#ModifyInstanceAttributesConfig)
* [Partition](https://cloud.tencent.com/document/api/597/40861#Partition)
* [SubscribedInfo](https://cloud.tencent.com/document/api/597/40861#SubscribedInfo)
* [Tag](https://cloud.tencent.com/document/api/597/40861#Tag)
* [Topic](https://cloud.tencent.com/document/api/597/40861#Topic)
* [TopicAttributesResponse](https://cloud.tencent.com/document/api/597/40861#TopicAttributesResponse)
* [TopicDetail](https://cloud.tencent.com/document/api/597/40861#TopicDetail)
* [TopicDetailResponse](https://cloud.tencent.com/document/api/597/40861#TopicDetailResponse)
* [TopicPartitionDO](https://cloud.tencent.com/document/api/597/40861#TopicPartitionDO)
* [TopicResult](https://cloud.tencent.com/document/api/597/40861#TopicResult)
* [User](https://cloud.tencent.com/document/api/597/40861#User)
* [UserResponse](https://cloud.tencent.com/document/api/597/40861#UserResponse)
* [VipEntity](https://cloud.tencent.com/document/api/597/40861#VipEntity)




## 负载均衡(clb) 版本：2018-03-17

### 第 106 次发布

发布时间：2024-07-16 01:11:14

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateLoadBalancer](https://cloud.tencent.com/document/api/214/30692)

	* 新增入参：LBChargePrepaid


### 第 105 次发布

发布时间：2024-05-14 01:28:52

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [TargetGroupAssociation](https://cloud.tencent.com/document/api/214/30694#TargetGroupAssociation)

	* 新增成员：Weight


### 第 104 次发布

发布时间：2024-05-07 01:12:00

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateListener](https://cloud.tencent.com/document/api/214/30693)

	* 新增入参：SnatEnable

* [ModifyListener](https://cloud.tencent.com/document/api/214/30681)

	* 新增入参：SnatEnable


### 第 103 次发布

发布时间：2024-03-06 01:10:51

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [BatchRegisterTargets](https://cloud.tencent.com/document/api/214/38303)

	* 新增出参：Message

* [CreateClsLogSet](https://cloud.tencent.com/document/api/214/46803)


修改数据结构：

* [Cluster](https://cloud.tencent.com/document/api/214/30694#Cluster)

	* 新增成员：IPVersion

* [ExtraInfo](https://cloud.tencent.com/document/api/214/30694#ExtraInfo)

	* <font color="#dd0000">**修改成员**：</font>ZhiTong, TgwGroupName

* [Listener](https://cloud.tencent.com/document/api/214/30694#Listener)

	* 新增成员：RescheduleInterval

* [LoadBalancer](https://cloud.tencent.com/document/api/214/30694#LoadBalancer)

* [RsWeightRule](https://cloud.tencent.com/document/api/214/30694#RsWeightRule)

* [RuleOutput](https://cloud.tencent.com/document/api/214/30694#RuleOutput)

	* <font color="#dd0000">**修改成员**：</font>LocationId, SessionExpireTime, HealthCheck, Certificate, Scheduler

* [ZoneInfo](https://cloud.tencent.com/document/api/214/30694#ZoneInfo)

	* <font color="#dd0000">**修改成员**：</font>ZoneId, Zone, ZoneName, ZoneRegion, LocalZone, EdgeZone


### 第 102 次发布

发布时间：2024-03-05 01:11:04

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [SpecAvailability](https://cloud.tencent.com/document/api/214/30694#SpecAvailability)

	* <font color="#dd0000">**修改成员**：</font>SpecType, Availability


### 第 101 次发布

发布时间：2024-02-28 15:22:33

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [SetLoadBalancerStartStatus](https://cloud.tencent.com/document/api/214/104002)

### 第 100 次发布

发布时间：2023-11-01 01:09:28

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateLoadBalancer](https://cloud.tencent.com/document/api/214/30692)

	* 新增入参：ClusterIds


### 第 99 次发布

发布时间：2023-10-31 01:23:38

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [ModifyLoadBalancerSla](https://cloud.tencent.com/document/api/214/63892)

	* 新增入参：Force


### 第 98 次发布

发布时间：2023-10-20 01:09:37

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [Backend](https://cloud.tencent.com/document/api/214/30694#Backend)

	* 新增成员：Tag


### 第 97 次发布

发布时间：2023-10-19 15:59:42

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [BatchModifyTargetTag](https://cloud.tencent.com/document/api/214/100445)

新增数据结构：

* [RsTagRule](https://cloud.tencent.com/document/api/214/30694#RsTagRule)

修改数据结构：

* [BatchTarget](https://cloud.tencent.com/document/api/214/30694#BatchTarget)

	* 新增成员：Tag

* [Target](https://cloud.tencent.com/document/api/214/30694#Target)

	* 新增成员：Tag


### 第 96 次发布

发布时间：2023-09-21 01:56:45

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [Listener](https://cloud.tencent.com/document/api/214/30694#Listener)

	* <font color="#dd0000">**修改成员**：</font>IdleConnectTimeout


### 第 95 次发布

发布时间：2023-09-20 01:13:18

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [InquiryPriceCreateLoadBalancer](https://cloud.tencent.com/document/api/214/98697)
* [InquiryPriceModifyLoadBalancer](https://cloud.tencent.com/document/api/214/98696)
* [InquiryPriceRefundLoadBalancer](https://cloud.tencent.com/document/api/214/98694)
* [InquiryPriceRenewLoadBalancer](https://cloud.tencent.com/document/api/214/98695)

新增数据结构：

* [ItemPrice](https://cloud.tencent.com/document/api/214/30694#ItemPrice)
* [Price](https://cloud.tencent.com/document/api/214/30694#Price)

### 第 94 次发布

发布时间：2023-09-05 02:16:24

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [Cluster](https://cloud.tencent.com/document/api/214/30694#Cluster)

	* 新增成员：Egress

* [LoadBalancer](https://cloud.tencent.com/document/api/214/30694#LoadBalancer)

	* 新增成员：Egress

* [LoadBalancerDetail](https://cloud.tencent.com/document/api/214/30694#LoadBalancerDetail)

	* 新增成员：Egress

	* <font color="#dd0000">**修改成员**：</font>LoadBalancerDomain

* [ZoneResource](https://cloud.tencent.com/document/api/214/30694#ZoneResource)

	* 新增成员：Egress


### 第 93 次发布

发布时间：2023-09-04 01:28:05

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateLoadBalancer](https://cloud.tencent.com/document/api/214/30692)

	* 新增入参：Egress


### 第 92 次发布

发布时间：2023-08-15 01:09:13

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [ModifyLoadBalancersProject](https://cloud.tencent.com/document/api/214/96177)

### 第 91 次发布

发布时间：2023-06-12 01:09:11

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [TargetGroupAssociation](https://cloud.tencent.com/document/api/214/30694#TargetGroupAssociation)

	* <font color="#dd0000">**修改成员**：</font>ListenerId

* [TargetGroupInstance](https://cloud.tencent.com/document/api/214/30694#TargetGroupInstance)

	* <font color="#dd0000">**修改成员**：</font>Port


### 第 90 次发布

发布时间：2023-06-02 01:14:55

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateLoadBalancer](https://cloud.tencent.com/document/api/214/30692)

	* 新增入参：DynamicVip


新增数据结构：

* [SpecAvailability](https://cloud.tencent.com/document/api/214/30694#SpecAvailability)
* [TypeInfo](https://cloud.tencent.com/document/api/214/30694#TypeInfo)

修改数据结构：

* [Resource](https://cloud.tencent.com/document/api/214/30694#Resource)

	* 新增成员：TypeSet


### 第 89 次发布

发布时间：2023-05-22 11:55:58

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [TargetHealth](https://cloud.tencent.com/document/api/214/30694#TargetHealth)

	* <font color="#dd0000">**修改成员**：</font>HealthStatusDetial


### 第 88 次发布

发布时间：2023-04-24 01:09:35

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [ModifyLoadBalancerAttributes](https://cloud.tencent.com/document/api/214/30680)

	* 新增入参：ModifyClassicDomain


### 第 87 次发布

发布时间：2023-04-10 01:13:36

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateListener](https://cloud.tencent.com/document/api/214/30693)

	* 新增入参：IdleConnectTimeout

* [ModifyListener](https://cloud.tencent.com/document/api/214/30681)

	* 新增入参：IdleConnectTimeout


修改数据结构：

* [Listener](https://cloud.tencent.com/document/api/214/30694#Listener)

	* 新增成员：IdleConnectTimeout


### 第 86 次发布

发布时间：2023-04-07 01:16:50

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [IdleLoadBalancer](https://cloud.tencent.com/document/api/214/30694#IdleLoadBalancer)

	* 新增成员：Domain


### 第 85 次发布

发布时间：2023-03-24 01:22:38

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [ModifyDomainAttributes](https://cloud.tencent.com/document/api/214/38092)

	* 新增入参：Quic


### 第 84 次发布

发布时间：2023-03-08 01:13:04

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [LoadBalancer](https://cloud.tencent.com/document/api/214/30694#LoadBalancer)

	* 新增成员：LoadBalancerDomain

* [LoadBalancerDetail](https://cloud.tencent.com/document/api/214/30694#LoadBalancerDetail)

	* 新增成员：LoadBalancerDomain


### 第 83 次发布

发布时间：2023-03-03 01:09:04

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [LoadBalancerTraffic](https://cloud.tencent.com/document/api/214/30694#LoadBalancerTraffic)

	* 新增成员：Domain


### 第 82 次发布

发布时间：2023-02-24 01:08:31

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeTargets](https://cloud.tencent.com/document/api/214/30684)

	* 新增入参：Filters


### 第 81 次发布

发布时间：2023-02-16 01:14:51

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [ModifyFunctionTargets](https://cloud.tencent.com/document/api/214/86609)

### 第 80 次发布

发布时间：2023-02-08 01:22:37

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [RuleTargets](https://cloud.tencent.com/document/api/214/30694#RuleTargets)

	* 新增成员：FunctionTargets


### 第 79 次发布

发布时间：2023-02-02 01:11:16

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [RegisterFunctionTargets](https://cloud.tencent.com/document/api/214/84625)

	* 新增入参：LoadBalancerId, ListenerId, FunctionTargets, LocationId, Domain, Url


### 第 78 次发布

发布时间：2023-01-18 17:55:46

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [TargetHealth](https://cloud.tencent.com/document/api/214/30694#TargetHealth)

	* 新增成员：HealthStatusDetail


### 第 77 次发布

发布时间：2023-01-04 01:11:19

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateListener](https://cloud.tencent.com/document/api/214/30693)

	* 新增入参：MaxConn, MaxCps

* [ModifyListener](https://cloud.tencent.com/document/api/214/30681)

	* 新增入参：MaxConn, MaxCps


修改数据结构：

* [Listener](https://cloud.tencent.com/document/api/214/30694#Listener)

	* 新增成员：MaxConn, MaxCps


### 第 76 次发布

发布时间：2022-12-29 10:11:28

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DeregisterFunctionTargets](https://cloud.tencent.com/document/api/214/84626)
* [RegisterFunctionTargets](https://cloud.tencent.com/document/api/214/84625)

新增数据结构：

* [FunctionInfo](https://cloud.tencent.com/document/api/214/30694#FunctionInfo)
* [FunctionTarget](https://cloud.tencent.com/document/api/214/30694#FunctionTarget)

### 第 75 次发布

发布时间：2022-12-14 01:16:36

本次发布包含了以下内容：

改善已有的文档。

新增数据结构：

* [ResourceAvailability](https://cloud.tencent.com/document/api/214/30694#ResourceAvailability)

修改数据结构：

* [Cluster](https://cloud.tencent.com/document/api/214/30694#Cluster)

	* 新增成员：DisasterRecoveryType

* [ClusterResource](https://cloud.tencent.com/document/api/214/30694#ClusterResource)

	* 新增成员：ClustersZone

* [Resource](https://cloud.tencent.com/document/api/214/30694#Resource)

	* 新增成员：AvailabilitySet

* [ZoneResource](https://cloud.tencent.com/document/api/214/30694#ZoneResource)

	* 新增成员：ZoneResourceType, EdgeZone


### 第 74 次发布

发布时间：2022-12-09 01:20:31

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [CertificateOutput](https://cloud.tencent.com/document/api/214/30694#CertificateOutput)

	* 新增成员：ExtCertIds

* [Listener](https://cloud.tencent.com/document/api/214/30694#Listener)

	* 新增成员：TargetGroupList

* [LoadBalancerDetail](https://cloud.tencent.com/document/api/214/30694#LoadBalancerDetail)

	* 新增成员：SlaveZone, Zones, SniSwitch

* [RuleOutput](https://cloud.tencent.com/document/api/214/30694#RuleOutput)

	* 新增成员：TargetGroupList

* [ZoneInfo](https://cloud.tencent.com/document/api/214/30694#ZoneInfo)

	* 新增成员：EdgeZone


### 第 73 次发布

发布时间：2022-11-01 06:15:44

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateListener](https://cloud.tencent.com/document/api/214/30693)

	* 新增入参：MultiCertInfo

* [ModifyDomainAttributes](https://cloud.tencent.com/document/api/214/38092)

	* 新增入参：MultiCertInfo

* [ModifyListener](https://cloud.tencent.com/document/api/214/30681)

	* 新增入参：MultiCertInfo


新增数据结构：

* [CertInfo](https://cloud.tencent.com/document/api/214/30694#CertInfo)
* [MultiCertInfo](https://cloud.tencent.com/document/api/214/30694#MultiCertInfo)

修改数据结构：

* [RuleInput](https://cloud.tencent.com/document/api/214/30694#RuleInput)

	* 新增成员：MultiCertInfo


### 第 72 次发布

发布时间：2022-09-09 06:14:53

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateTopic](https://cloud.tencent.com/document/api/214/46802)

	* 新增入参：StorageType


### 第 71 次发布

发布时间：2022-08-30 06:17:26

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeIdleLoadBalancers](https://cloud.tencent.com/document/api/214/79718)

新增数据结构：

* [IdleLoadBalancer](https://cloud.tencent.com/document/api/214/30694#IdleLoadBalancer)

### 第 70 次发布

发布时间：2022-07-19 06:07:41

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [ModifyListener](https://cloud.tencent.com/document/api/214/30681)

	* 新增入参：TargetType


### 第 69 次发布

发布时间：2022-06-29 06:04:25

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [Listener](https://cloud.tencent.com/document/api/214/30694#Listener)

	* 新增成员：AttrFlags


### 第 68 次发布

发布时间：2022-05-10 06:03:18

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [HealthCheck](https://cloud.tencent.com/document/api/214/30694#HealthCheck)

	* 新增成员：ExtendedCode


### 第 67 次发布

发布时间：2022-03-03 08:03:01

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [ModifyLoadBalancerMixIpTarget](https://cloud.tencent.com/document/api/214/70576)

### 第 66 次发布

发布时间：2022-02-22 08:03:47

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeResources](https://cloud.tencent.com/document/api/214/70213)

新增数据结构：

* [Resource](https://cloud.tencent.com/document/api/214/30694#Resource)
* [ZoneResource](https://cloud.tencent.com/document/api/214/30694#ZoneResource)

### 第 65 次发布

发布时间：2022-01-20 08:06:53

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateClsLogSet](https://cloud.tencent.com/document/api/214/46803)

	* <font color="#dd0000">**修改入参**：</font>Period

* [CreateTopic](https://cloud.tencent.com/document/api/214/46802)

	* 新增入参：Period

* [ModifyDomainAttributes](https://cloud.tencent.com/document/api/214/38092)

	* 新增入参：NewDomains


修改数据结构：

* [LoadBalancerDetail](https://cloud.tencent.com/document/api/214/30694#LoadBalancerDetail)

	* 新增成员：Domains

* [RuleOutput](https://cloud.tencent.com/document/api/214/30694#RuleOutput)

	* 新增成员：Domains


### 第 64 次发布

发布时间：2022-01-19 08:07:15

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [RuleInput](https://cloud.tencent.com/document/api/214/30694#RuleInput)

	* 新增成员：Domains

	* <font color="#dd0000">**修改成员**：</font>Domain


### 第 63 次发布

发布时间：2022-01-07 08:05:24

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CloneLoadBalancer](https://cloud.tencent.com/document/api/214/64874)

	* 新增入参：SlaType


### 第 62 次发布

发布时间：2022-01-06 08:06:38

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateLoadBalancer](https://cloud.tencent.com/document/api/214/30692)

	* 新增出参：DealName

* [DescribeTaskStatus](https://cloud.tencent.com/document/api/214/30683)

	* 新增入参：DealName

	* 新增出参：LoadBalancerIds


### 第 61 次发布

发布时间：2021-12-14 08:07:15

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeCrossTargets](https://cloud.tencent.com/document/api/214/65902)

新增数据结构：

* [CrossTargets](https://cloud.tencent.com/document/api/214/30694#CrossTargets)

### 第 60 次发布

发布时间：2021-12-13 08:06:26

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [MigrateClassicalLoadBalancers](https://cloud.tencent.com/document/api/214/65849)

### 第 59 次发布

发布时间：2021-11-30 08:04:28

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeLoadBalancerOverview](https://cloud.tencent.com/document/api/214/64973)

修改数据结构：

* [LoadBalancer](https://cloud.tencent.com/document/api/214/30694#LoadBalancer)

	* 新增成员：ClusterIds, AttributeFlags


### 第 58 次发布

发布时间：2021-11-29 08:05:45

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CloneLoadBalancer](https://cloud.tencent.com/document/api/214/64874)

### 第 57 次发布

发布时间：2021-11-11 10:58:59

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [ModifyLoadBalancerSla](https://cloud.tencent.com/document/api/214/63892)

新增数据结构：

* [SlaUpdateParam](https://cloud.tencent.com/document/api/214/30694#SlaUpdateParam)

### 第 56 次发布

发布时间：2021-11-02 08:04:16

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateLoadBalancerSnatIps](https://cloud.tencent.com/document/api/214/41505)

	* 新增入参：Number


### 第 55 次发布

发布时间：2021-10-21 11:20:09

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateLoadBalancer](https://cloud.tencent.com/document/api/214/30692)

	* 新增入参：LoadBalancerPassToTarget

* [ModifyListener](https://cloud.tencent.com/document/api/214/30681)

	* 新增入参：SessionType


修改数据结构：

* [HealthCheck](https://cloud.tencent.com/document/api/214/30694#HealthCheck)

	* 新增成员：SourceIpType


### 第 54 次发布

发布时间：2021-09-14 08:04:35

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeLBListeners](https://cloud.tencent.com/document/api/214/61478)

修改接口：

* [CreateLoadBalancer](https://cloud.tencent.com/document/api/214/30692)

	* 新增入参：SlaType


新增数据结构：

* [LBItem](https://cloud.tencent.com/document/api/214/30694#LBItem)
* [LbRsItem](https://cloud.tencent.com/document/api/214/30694#LbRsItem)
* [LbRsTargets](https://cloud.tencent.com/document/api/214/30694#LbRsTargets)
* [ListenerItem](https://cloud.tencent.com/document/api/214/30694#ListenerItem)
* [RulesItems](https://cloud.tencent.com/document/api/214/30694#RulesItems)

### 第 53 次发布

发布时间：2021-08-25 08:04:41

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [ModifyLoadBalancerAttributes](https://cloud.tencent.com/document/api/214/30680)

	* 新增入参：DeleteProtect


### 第 52 次发布

发布时间：2021-08-10 08:05:26

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeCustomizedConfigAssociateList](https://cloud.tencent.com/document/api/214/60010)
* [DescribeCustomizedConfigList](https://cloud.tencent.com/document/api/214/60009)
* [SetCustomizedConfigForLoadBalancer](https://cloud.tencent.com/document/api/214/60008)

新增数据结构：

* [BindDetailItem](https://cloud.tencent.com/document/api/214/30694#BindDetailItem)
* [ConfigListItem](https://cloud.tencent.com/document/api/214/30694#ConfigListItem)

### 第 51 次发布

发布时间：2021-08-04 08:04:29

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [ClusterResource](https://cloud.tencent.com/document/api/214/30694#ClusterResource)

	* 新增成员：Isp


### 第 50 次发布

发布时间：2021-07-14 08:04:27

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [LoadBalancerDetail](https://cloud.tencent.com/document/api/214/30694#LoadBalancerDetail)

	* 新增成员：TargetHealth


### 第 49 次发布

发布时间：2021-05-18 08:04:20

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateListener](https://cloud.tencent.com/document/api/214/30693)

	* 新增入参：DeregisterTargetRst

* [ModifyListener](https://cloud.tencent.com/document/api/214/30681)

	* 新增入参：DeregisterTargetRst


修改数据结构：

* [Listener](https://cloud.tencent.com/document/api/214/30694#Listener)

	* 新增成员：DeregisterTargetRst


### 第 48 次发布

发布时间：2021-04-20 08:04:00

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [Cluster](https://cloud.tencent.com/document/api/214/30694#Cluster)

	* 新增成员：ClustersVersion


### 第 47 次发布

发布时间：2021-04-09 08:03:37

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateClsLogSet](https://cloud.tencent.com/document/api/214/46803)

	* 新增入参：LogsetType

* [CreateTopic](https://cloud.tencent.com/document/api/214/46802)

	* 新增入参：TopicType

* [DescribeClsLogSet](https://cloud.tencent.com/document/api/214/46801)

	* 新增出参：HealthLogsetId

* [SetLoadBalancerClsLog](https://cloud.tencent.com/document/api/214/43266)

	* 新增入参：LogType


修改数据结构：

* [LoadBalancer](https://cloud.tencent.com/document/api/214/30694#LoadBalancer)

	* 新增成员：HealthLogSetId, HealthLogTopicId


### 第 46 次发布

发布时间：2021-03-23 08:04:04

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateLoadBalancer](https://cloud.tencent.com/document/api/214/30692)

	* 新增入参：SlaveZoneId


修改数据结构：

* [TargetGroupBackend](https://cloud.tencent.com/document/api/214/30694#TargetGroupBackend)

	* 新增成员：ZoneId


### 第 45 次发布

发布时间：2021-03-19 08:03:41

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [ZoneInfo](https://cloud.tencent.com/document/api/214/30694#ZoneInfo)

	* 新增成员：ZoneRegion, LocalZone


### 第 44 次发布

发布时间：2021-02-26 08:03:27

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateListener](https://cloud.tencent.com/document/api/214/30693)

	* 新增入参：EndPort


### 第 43 次发布

发布时间：2021-01-21 08:03:10

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [Listener](https://cloud.tencent.com/document/api/214/30694#Listener)

	* 新增成员：Toa


### 第 42 次发布

发布时间：2021-01-20 08:03:09

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [LoadBalancer](https://cloud.tencent.com/document/api/214/30694#LoadBalancer)

	* 新增成员：NfvInfo

* [LoadBalancerDetail](https://cloud.tencent.com/document/api/214/30694#LoadBalancerDetail)

	* 新增成员：SecurityGroup, LoadBalancerPassToTarget


### 第 41 次发布

发布时间：2021-01-19 08:04:00

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [AutoRewrite](https://cloud.tencent.com/document/api/214/34901)

	* 新增入参：RewriteCodes, TakeUrls


修改数据结构：

* [RewriteLocationMap](https://cloud.tencent.com/document/api/214/30694#RewriteLocationMap)

	* 新增成员：RewriteCode, TakeUrl, SourceDomain

* [RewriteTarget](https://cloud.tencent.com/document/api/214/30694#RewriteTarget)

	* 新增成员：RewriteCode, TakeUrl, RewriteType


### 第 40 次发布

发布时间：2021-01-07 08:03:33

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateLoadBalancer](https://cloud.tencent.com/document/api/214/30692)

	* 新增入参：EipAddressId


### 第 39 次发布

发布时间：2020-12-09 08:02:50

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeLoadBalancerTraffic](https://cloud.tencent.com/document/api/214/50774)

新增数据结构：

* [LoadBalancerTraffic](https://cloud.tencent.com/document/api/214/30694#LoadBalancerTraffic)

### 第 38 次发布

发布时间：2020-12-08 08:03:20

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateLoadBalancer](https://cloud.tencent.com/document/api/214/30692)

	* 新增入参：BandwidthPackageId


### 第 37 次发布

发布时间：2020-11-20 08:02:55

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [LoadBalancer](https://cloud.tencent.com/document/api/214/30694#LoadBalancer)

	* 新增成员：Zones


### 第 36 次发布

发布时间：2020-11-17 08:03:29

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateLoadBalancer](https://cloud.tencent.com/document/api/214/30692)

	* 新增入参：SnatPro, SnatIps


### 第 35 次发布

发布时间：2020-10-22 08:02:52

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateLoadBalancer](https://cloud.tencent.com/document/api/214/30692)

	* 新增入参：Vip


### 第 34 次发布

发布时间：2020-10-21 08:02:53

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeClusterResources](https://cloud.tencent.com/document/api/214/49279)
* [DescribeExclusiveClusters](https://cloud.tencent.com/document/api/214/49278)

新增数据结构：

* [Cluster](https://cloud.tencent.com/document/api/214/30694#Cluster)
* [ClusterResource](https://cloud.tencent.com/document/api/214/30694#ClusterResource)
* [ClustersZone](https://cloud.tencent.com/document/api/214/30694#ClustersZone)

### 第 33 次发布

发布时间：2020-10-14 08:02:37

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateLoadBalancer](https://cloud.tencent.com/document/api/214/30692)

	* 新增入参：ExclusiveCluster, ClusterTag


### 第 32 次发布

发布时间：2020-09-18 08:02:34

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateListener](https://cloud.tencent.com/document/api/214/30693)

	* 新增入参：KeepaliveEnable

* [ModifyListener](https://cloud.tencent.com/document/api/214/30681)

	* 新增入参：KeepaliveEnable


### 第 31 次发布

发布时间：2020-08-21 08:09:33

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeQuota](https://cloud.tencent.com/document/api/214/47704)

新增数据结构：

* [Quota](https://cloud.tencent.com/document/api/214/30694#Quota)

### 第 30 次发布

发布时间：2020-08-20 08:09:11

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [LoadBalancer](https://cloud.tencent.com/document/api/214/30694#LoadBalancer)

	* 新增成员：ClusterTag, MixIpTarget


### 第 29 次发布

发布时间：2020-08-13 08:08:05

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateListener](https://cloud.tencent.com/document/api/214/30693)

	* 新增入参：SessionType


修改数据结构：

* [Listener](https://cloud.tencent.com/document/api/214/30694#Listener)

	* 新增成员：SessionType, KeepaliveEnable


### 第 28 次发布

发布时间：2020-08-06 08:07:59

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateLoadBalancer](https://cloud.tencent.com/document/api/214/30692)

	* 新增入参：ClientToken


### 第 27 次发布

发布时间：2020-07-28 08:07:36

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeLoadBalancersDetail](https://cloud.tencent.com/document/api/214/46916)

新增数据结构：

* [LoadBalancerDetail](https://cloud.tencent.com/document/api/214/30694#LoadBalancerDetail)

### 第 26 次发布

发布时间：2020-07-24 08:07:28

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateClsLogSet](https://cloud.tencent.com/document/api/214/46803)
* [CreateTopic](https://cloud.tencent.com/document/api/214/46802)
* [DescribeClsLogSet](https://cloud.tencent.com/document/api/214/46801)

### 第 25 次发布

发布时间：2020-06-19 08:07:20

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateListener](https://cloud.tencent.com/document/api/214/30693)

	* 新增入参：TargetType


### 第 24 次发布

发布时间：2020-05-18 08:07:07

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [AutoRewrite](https://cloud.tencent.com/document/api/214/34901)

	* <font color="#dd0000">**修改入参**：</font>Domains

* [DeleteRule](https://cloud.tencent.com/document/api/214/30688)

	* 新增入参：NewDefaultServerDomain

* [ModifyDomainAttributes](https://cloud.tencent.com/document/api/214/38092)

	* 新增入参：NewDefaultServerDomain


### 第 23 次发布

发布时间：2020-04-30 08:07:08

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [LoadBalancer](https://cloud.tencent.com/document/api/214/30694#LoadBalancer)

	* 新增成员：LocalBgp


### 第 22 次发布

发布时间：2020-04-09 08:06:03

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [SetLoadBalancerClsLog](https://cloud.tencent.com/document/api/214/43266)

### 第 21 次发布

发布时间：2020-04-02 08:06:08

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [RuleInput](https://cloud.tencent.com/document/api/214/30694#RuleInput)

	* 新增成员：Quic

* [RuleOutput](https://cloud.tencent.com/document/api/214/30694#RuleOutput)

	* 新增成员：QuicStatus


### 第 20 次发布

发布时间：2020-03-31 08:05:13

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [ModifyRule](https://cloud.tencent.com/document/api/214/30679)

	* 新增入参：TrpcCallee, TrpcFunc


### 第 19 次发布

发布时间：2020-03-30 08:36:44

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeLoadBalancers](https://cloud.tencent.com/document/api/214/30685)

	* 新增入参：Filters


### 第 18 次发布

发布时间：2020-03-26 08:05:08

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [LoadBalancer](https://cloud.tencent.com/document/api/214/30694#LoadBalancer)

	* 新增成员：IsBlockTime


### 第 17 次发布

发布时间：2020-03-16 08:06:26

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [LoadBalancer](https://cloud.tencent.com/document/api/214/30694#LoadBalancer)

	* 新增成员：SlaType, IsBlock


### 第 16 次发布

发布时间：2020-02-25 11:21:09

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateLoadBalancerSnatIps](https://cloud.tencent.com/document/api/214/41505)
* [DeleteLoadBalancerListeners](https://cloud.tencent.com/document/api/214/41504)
* [DeleteLoadBalancerSnatIps](https://cloud.tencent.com/document/api/214/41503)

修改接口：

* [ModifyLoadBalancerAttributes](https://cloud.tencent.com/document/api/214/30680)

	* 新增入参：SnatPro


修改数据结构：

* [ListenerBackend](https://cloud.tencent.com/document/api/214/30694#ListenerBackend)

	* 新增成员：EndPort


### 第 15 次发布

发布时间：2020-01-09 15:30:45

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeLoadBalancerListByCertId](https://cloud.tencent.com/document/api/214/40953)

修改接口：

* [CreateLoadBalancer](https://cloud.tencent.com/document/api/214/30692)

	* 新增入参：VipIsp

* [DescribeListeners](https://cloud.tencent.com/document/api/214/30686)

	* 新增出参：TotalCount

* [DescribeTaskStatus](https://cloud.tencent.com/document/api/214/30683)

	* <font color="#dd0000">**修改入参**：</font>TaskId

* [ModifyLoadBalancerAttributes](https://cloud.tencent.com/document/api/214/30680)

	* 新增入参：LoadBalancerPassToTarget


新增数据结构：

* [CertIdRelatedWithLoadBalancers](https://cloud.tencent.com/document/api/214/30694#CertIdRelatedWithLoadBalancers)

### 第 14 次发布

发布时间：2019-12-30 15:29:51

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [AssociateTargetGroups](https://cloud.tencent.com/document/api/214/40560)
* [CreateTargetGroup](https://cloud.tencent.com/document/api/214/40559)
* [DeleteTargetGroups](https://cloud.tencent.com/document/api/214/40558)
* [DeregisterTargetGroupInstances](https://cloud.tencent.com/document/api/214/40557)
* [DescribeTargetGroupInstances](https://cloud.tencent.com/document/api/214/40556)
* [DescribeTargetGroupList](https://cloud.tencent.com/document/api/214/40555)
* [DescribeTargetGroups](https://cloud.tencent.com/document/api/214/40554)
* [DisassociateTargetGroups](https://cloud.tencent.com/document/api/214/40553)
* [ModifyTargetGroupAttribute](https://cloud.tencent.com/document/api/214/40552)
* [ModifyTargetGroupInstancesPort](https://cloud.tencent.com/document/api/214/40551)
* [ModifyTargetGroupInstancesWeight](https://cloud.tencent.com/document/api/214/40550)
* [RegisterTargetGroupInstances](https://cloud.tencent.com/document/api/214/40549)

新增数据结构：

* [AssociationItem](https://cloud.tencent.com/document/api/214/30694#AssociationItem)
* [Filter](https://cloud.tencent.com/document/api/214/30694#Filter)
* [TargetGroupAssociation](https://cloud.tencent.com/document/api/214/30694#TargetGroupAssociation)
* [TargetGroupBackend](https://cloud.tencent.com/document/api/214/30694#TargetGroupBackend)
* [TargetGroupInfo](https://cloud.tencent.com/document/api/214/30694#TargetGroupInfo)
* [TargetGroupInstance](https://cloud.tencent.com/document/api/214/30694#TargetGroupInstance)

### 第 13 次发布

发布时间：2019-12-26 10:27:03

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeBlockIPList](https://cloud.tencent.com/document/api/214/40459)
* [DescribeBlockIPTask](https://cloud.tencent.com/document/api/214/40460)
* [ModifyBlockIPList](https://cloud.tencent.com/document/api/214/40458)

修改接口：

* [CreateLoadBalancer](https://cloud.tencent.com/document/api/214/30692)

	* <font color="#dd0000">**删除入参**：</font>AnycastZone

* [CreateRule](https://cloud.tencent.com/document/api/214/30691)

	* 新增出参：LocationIds

* [ModifyLoadBalancerAttributes](https://cloud.tencent.com/document/api/214/30680)

	* 新增出参：DealName


新增数据结构：

* [BasicTargetGroupInfo](https://cloud.tencent.com/document/api/214/30694#BasicTargetGroupInfo)
* [BlockedIP](https://cloud.tencent.com/document/api/214/30694#BlockedIP)
* [ClusterItem](https://cloud.tencent.com/document/api/214/30694#ClusterItem)
* [ExclusiveCluster](https://cloud.tencent.com/document/api/214/30694#ExclusiveCluster)
* [SnatIp](https://cloud.tencent.com/document/api/214/30694#SnatIp)

修改数据结构：

* [InternetAccessible](https://cloud.tencent.com/document/api/214/30694#InternetAccessible)

	* 新增成员：BandwidthpkgSubType

* [Listener](https://cloud.tencent.com/document/api/214/30694#Listener)

	* 新增成员：TargetType, TargetGroup

* [LoadBalancer](https://cloud.tencent.com/document/api/214/30694#LoadBalancer)

	* 新增成员：LoadBalancerPassToTarget, ExclusiveCluster, IPv6Mode, SnatPro, SnatIps

* [RuleInput](https://cloud.tencent.com/document/api/214/30694#RuleInput)

	* 新增成员：TrpcCallee, TrpcFunc

* [RuleOutput](https://cloud.tencent.com/document/api/214/30694#RuleOutput)

	* 新增成员：TargetType, TargetGroup, WafDomainId, TrpcCallee, TrpcFunc


### 第 12 次发布

发布时间：2019-11-01 09:59:33

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [ModifyListener](https://cloud.tencent.com/document/api/214/30681)

	* 新增入参：SniSwitch


修改数据结构：

* [Listener](https://cloud.tencent.com/document/api/214/30694#Listener)

	* 新增成员：EndPort

* [LoadBalancer](https://cloud.tencent.com/document/api/214/30694#LoadBalancer)

	* 新增成员：IsDDos, ConfigId

* [RsWeightRule](https://cloud.tencent.com/document/api/214/30694#RsWeightRule)

	* <font color="#dd0000">**修改成员**：</font>LocationId

* [RuleInput](https://cloud.tencent.com/document/api/214/30694#RuleInput)

	* 新增成员：TargetType


### 第 11 次发布

发布时间：2019-10-11 14:42:01

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [BatchDeregisterTargets](https://cloud.tencent.com/document/api/214/38304)
* [BatchRegisterTargets](https://cloud.tencent.com/document/api/214/38303)

新增数据结构：

* [BatchTarget](https://cloud.tencent.com/document/api/214/30694#BatchTarget)

修改数据结构：

* [LoadBalancer](https://cloud.tencent.com/document/api/214/30694#LoadBalancer)

	* <font color="#dd0000">**删除成员**：</font>LoadBalancerPassToTarget


### 第 10 次发布

发布时间：2019-09-20 18:15:25

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [ModifyDomainAttributes](https://cloud.tencent.com/document/api/214/38092)

修改接口：

* [ModifyLoadBalancerAttributes](https://cloud.tencent.com/document/api/214/30680)

	* 新增入参：InternetChargeInfo


修改数据结构：

* [Listener](https://cloud.tencent.com/document/api/214/30694#Listener)

	* 新增成员：CreateTime

* [LoadBalancer](https://cloud.tencent.com/document/api/214/30694#LoadBalancer)

	* 新增成员：LoadBalancerPassToTarget

* [RuleOutput](https://cloud.tencent.com/document/api/214/30694#RuleOutput)

	* 新增成员：CreateTime


### 第 9 次发布

发布时间：2019-08-23 14:33:26

本次发布包含了以下内容：

改善已有的文档。

新增数据结构：

* [ExtraInfo](https://cloud.tencent.com/document/api/214/30694#ExtraInfo)

修改数据结构：

* [LoadBalancer](https://cloud.tencent.com/document/api/214/30694#LoadBalancer)

	* 新增成员：ExtraInfo

* [TargetHealth](https://cloud.tencent.com/document/api/214/30694#TargetHealth)

	* 新增成员：HealthStatusDetial


### 第 8 次发布

发布时间：2019-08-16 17:12:30

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [RuleInput](https://cloud.tencent.com/document/api/214/30694#RuleInput)

	* 新增成员：DefaultServer, Http2


### 第 7 次发布

发布时间：2019-08-08 23:04:58

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [ReplaceCertForLoadBalancers](https://cloud.tencent.com/document/api/214/36907)

修改数据结构：

* [LoadBalancer](https://cloud.tencent.com/document/api/214/30694#LoadBalancer)

	* 新增成员：AddressIPv6


### 第 6 次发布

发布时间：2019-07-26 14:51:04

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateLoadBalancer](https://cloud.tencent.com/document/api/214/30692)

	* 新增入参：Tags

	* <font color="#dd0000">**删除入参**：</font>VipIsp

* [ModifyTargetWeight](https://cloud.tencent.com/document/api/214/30677)

	* <font color="#dd0000">**修改入参**：</font>Weight


修改数据结构：

* [LoadBalancer](https://cloud.tencent.com/document/api/214/30694#LoadBalancer)

	* 新增成员：LogSetId, LogTopicId


### 第 5 次发布

发布时间：2019-07-12 11:21:38

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [SetSecurityGroupForLoadbalancers](https://cloud.tencent.com/document/api/214/36189)

修改接口：

* [CreateLoadBalancer](https://cloud.tencent.com/document/api/214/30692)

	* 新增入参：AddressIPVersion, Number, MasterZoneId, ZoneId, AnycastZone, InternetAccessible, VipIsp

* [DescribeLoadBalancers](https://cloud.tencent.com/document/api/214/30685)

	* 新增入参：MasterZone

* [ModifyRule](https://cloud.tencent.com/document/api/214/30679)

	* 新增入参：ForwardType


新增数据结构：

* [InternetAccessible](https://cloud.tencent.com/document/api/214/30694#InternetAccessible)
* [LBChargePrepaid](https://cloud.tencent.com/document/api/214/30694#LBChargePrepaid)
* [ZoneInfo](https://cloud.tencent.com/document/api/214/30694#ZoneInfo)

修改数据结构：

* [Backend](https://cloud.tencent.com/document/api/214/30694#Backend)

	* 新增成员：EniId

* [HealthCheck](https://cloud.tencent.com/document/api/214/30694#HealthCheck)

	* 新增成员：CheckPort, ContextType, SendContext, RecvContext, CheckType, HttpVersion

* [LoadBalancer](https://cloud.tencent.com/document/api/214/30694#LoadBalancer)

	* 新增成员：VipIsp, MasterZone, BackupZoneSet, IsolatedTime, ExpireTime, ChargeType, NetworkAttributes, PrepaidAttributes

* [RuleInput](https://cloud.tencent.com/document/api/214/30694#RuleInput)

	* 新增成员：ForwardType

* [RuleOutput](https://cloud.tencent.com/document/api/214/30694#RuleOutput)

	* 新增成员：ForwardType

* [Target](https://cloud.tencent.com/document/api/214/30694#Target)

	* 新增成员：EniIp

	* <font color="#dd0000">**修改成员**：</font>InstanceId


### 第 4 次发布

发布时间：2019-05-14 15:03:21

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [AutoRewrite](https://cloud.tencent.com/document/api/214/34901)
* [DeleteRewrite](https://cloud.tencent.com/document/api/214/34900)
* [DescribeRewrite](https://cloud.tencent.com/document/api/214/34899)
* [DescribeTargetHealth](https://cloud.tencent.com/document/api/214/34898)
* [ManualRewrite](https://cloud.tencent.com/document/api/214/34897)
* [SetLoadBalancerSecurityGroups](https://cloud.tencent.com/document/api/214/34903)

修改接口：

* [DescribeLoadBalancers](https://cloud.tencent.com/document/api/214/30685)

	* 新增入参：SecurityGroup

* [ModifyLoadBalancerAttributes](https://cloud.tencent.com/document/api/214/30680)

	* 新增入参：TargetRegionInfo


新增数据结构：

* [ListenerHealth](https://cloud.tencent.com/document/api/214/30694#ListenerHealth)
* [LoadBalancerHealth](https://cloud.tencent.com/document/api/214/30694#LoadBalancerHealth)
* [RewriteLocationMap](https://cloud.tencent.com/document/api/214/30694#RewriteLocationMap)
* [RuleHealth](https://cloud.tencent.com/document/api/214/30694#RuleHealth)
* [TargetHealth](https://cloud.tencent.com/document/api/214/30694#TargetHealth)

### 第 3 次发布

发布时间：2019-04-18 16:07:00

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [BatchModifyTargetWeight](https://cloud.tencent.com/document/api/214/34309)

修改接口：

* [DescribeLoadBalancers](https://cloud.tencent.com/document/api/214/30685)

	* 新增入参：VpcId


新增数据结构：

* [RewriteTarget](https://cloud.tencent.com/document/api/214/30694#RewriteTarget)
* [RsWeightRule](https://cloud.tencent.com/document/api/214/30694#RsWeightRule)
* [TagInfo](https://cloud.tencent.com/document/api/214/30694#TagInfo)
* [TargetRegionInfo](https://cloud.tencent.com/document/api/214/30694#TargetRegionInfo)

修改数据结构：

* [CertificateInput](https://cloud.tencent.com/document/api/214/30694#CertificateInput)

	* <font color="#dd0000">**修改成员**：</font>SSLMode

* [LoadBalancer](https://cloud.tencent.com/document/api/214/30694#LoadBalancer)

	* 新增成员：Tags, SecureGroups, TargetRegionInfo, AnycastZone, AddressIPVersion, NumericalVpcId

* [RuleOutput](https://cloud.tencent.com/document/api/214/30694#RuleOutput)

	* 新增成员：ListenerId, RewriteTarget, HttpGzip, BeAutoCreated, DefaultServer, Http2


### 第 2 次发布

发布时间：2018-12-20 20:33:57

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DeregisterTargetsFromClassicalLB](https://cloud.tencent.com/document/api/214/31794)
* [DescribeClassicalLBByInstanceId](https://cloud.tencent.com/document/api/214/31793)
* [DescribeClassicalLBHealthStatus](https://cloud.tencent.com/document/api/214/31792)
* [DescribeClassicalLBListeners](https://cloud.tencent.com/document/api/214/31791)
* [DescribeClassicalLBTargets](https://cloud.tencent.com/document/api/214/31790)
* [RegisterTargetsWithClassicalLB](https://cloud.tencent.com/document/api/214/31789)

新增数据结构：

* [ClassicalHealth](https://cloud.tencent.com/document/api/214/30694#ClassicalHealth)
* [ClassicalListener](https://cloud.tencent.com/document/api/214/30694#ClassicalListener)
* [ClassicalLoadBalancerInfo](https://cloud.tencent.com/document/api/214/30694#ClassicalLoadBalancerInfo)
* [ClassicalTarget](https://cloud.tencent.com/document/api/214/30694#ClassicalTarget)
* [ClassicalTargetInfo](https://cloud.tencent.com/document/api/214/30694#ClassicalTargetInfo)

### 第 1 次发布

发布时间：2018-11-22 20:16:31

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateListener](https://cloud.tencent.com/document/api/214/30693)
* [CreateLoadBalancer](https://cloud.tencent.com/document/api/214/30692)
* [CreateRule](https://cloud.tencent.com/document/api/214/30691)
* [DeleteListener](https://cloud.tencent.com/document/api/214/30690)
* [DeleteLoadBalancer](https://cloud.tencent.com/document/api/214/30689)
* [DeleteRule](https://cloud.tencent.com/document/api/214/30688)
* [DeregisterTargets](https://cloud.tencent.com/document/api/214/30687)
* [DescribeListeners](https://cloud.tencent.com/document/api/214/30686)
* [DescribeLoadBalancers](https://cloud.tencent.com/document/api/214/30685)
* [DescribeTargets](https://cloud.tencent.com/document/api/214/30684)
* [DescribeTaskStatus](https://cloud.tencent.com/document/api/214/30683)
* [ModifyDomain](https://cloud.tencent.com/document/api/214/30682)
* [ModifyListener](https://cloud.tencent.com/document/api/214/30681)
* [ModifyLoadBalancerAttributes](https://cloud.tencent.com/document/api/214/30680)
* [ModifyRule](https://cloud.tencent.com/document/api/214/30679)
* [ModifyTargetPort](https://cloud.tencent.com/document/api/214/30678)
* [ModifyTargetWeight](https://cloud.tencent.com/document/api/214/30677)
* [RegisterTargets](https://cloud.tencent.com/document/api/214/30676)

新增数据结构：

* [Backend](https://cloud.tencent.com/document/api/214/30694#Backend)
* [CertificateInput](https://cloud.tencent.com/document/api/214/30694#CertificateInput)
* [CertificateOutput](https://cloud.tencent.com/document/api/214/30694#CertificateOutput)
* [HealthCheck](https://cloud.tencent.com/document/api/214/30694#HealthCheck)
* [Listener](https://cloud.tencent.com/document/api/214/30694#Listener)
* [ListenerBackend](https://cloud.tencent.com/document/api/214/30694#ListenerBackend)
* [LoadBalancer](https://cloud.tencent.com/document/api/214/30694#LoadBalancer)
* [RuleInput](https://cloud.tencent.com/document/api/214/30694#RuleInput)
* [RuleOutput](https://cloud.tencent.com/document/api/214/30694#RuleOutput)
* [RuleTargets](https://cloud.tencent.com/document/api/214/30694#RuleTargets)
* [Target](https://cloud.tencent.com/document/api/214/30694#Target)




## 云应用(cloudapp) 版本：2022-05-30

### 第 1 次发布

发布时间：2024-07-17 10:02:42

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [VerifyLicense](https://cloud.tencent.com/document/api/1689/108874)

新增数据结构：

* [License](https://cloud.tencent.com/document/api/1689/108875#License)
* [SaleParam](https://cloud.tencent.com/document/api/1689/108875#SaleParam)




## 操作审计(cloudaudit) 版本：2019-03-19

### 第 13 次发布

发布时间：2024-01-11 01:09:52

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [Storage](https://cloud.tencent.com/document/api/629/35353#Storage)

	* 新增成员：StorageAccountId, StorageAppId


### 第 12 次发布

发布时间：2022-11-24 06:19:10

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeAuditTrack](https://cloud.tencent.com/document/api/629/83247)

修改接口：

* [CreateAuditTrack](https://cloud.tencent.com/document/api/629/70383)

	* 新增入参：Name, ActionType, ResourceType, Status, EventNames, Storage, TrackForAllMembers

	* 新增出参：TrackId

* [DeleteAuditTrack](https://cloud.tencent.com/document/api/629/70382)

	* 新增入参：TrackId

* [DescribeAuditTracks](https://cloud.tencent.com/document/api/629/69204)

	* 新增入参：PageNumber, PageSize

	* 新增出参：Tracks, TotalCount

* [ModifyAuditTrack](https://cloud.tencent.com/document/api/629/70381)

	* 新增入参：TrackId, Name, ActionType, ResourceType, Status, EventNames, Storage, TrackForAllMembers


新增数据结构：

* [Storage](https://cloud.tencent.com/document/api/629/35353#Storage)
* [Tracks](https://cloud.tencent.com/document/api/629/35353#Tracks)

### 第 11 次发布

发布时间：2022-02-28 08:08:23

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateAuditTrack](https://cloud.tencent.com/document/api/629/70383)
* [DeleteAuditTrack](https://cloud.tencent.com/document/api/629/70382)
* [ModifyAuditTrack](https://cloud.tencent.com/document/api/629/70381)

### 第 10 次发布

发布时间：2022-02-14 08:08:17

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeAuditTracks](https://cloud.tencent.com/document/api/629/69204)

### 第 9 次发布

发布时间：2021-11-16 08:07:51

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeEvents](https://cloud.tencent.com/document/api/629/54488)

	* 新增出参：TotalCount


### 第 8 次发布

发布时间：2021-06-17 08:11:39

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeEvents](https://cloud.tencent.com/document/api/629/54488)

	* 新增入参：IsReturnLocation


### 第 7 次发布

发布时间：2021-05-26 08:10:55

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [Event](https://cloud.tencent.com/document/api/629/35353#Event)

	* 新增成员：Location


### 第 6 次发布

发布时间：2021-04-09 08:10:33

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeEvents](https://cloud.tencent.com/document/api/629/54488)

### 第 5 次发布

发布时间：2020-09-09 08:03:42

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [ListKeyAliasByRegion](https://cloud.tencent.com/document/api/629/48173)

新增数据结构：

* [KeyMetadata](https://cloud.tencent.com/document/api/629/35353#KeyMetadata)

### 第 4 次发布

发布时间：2020-03-24 08:05:13

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [LookUpEvents](https://cloud.tencent.com/document/api/629/35344)

	* 新增入参：Mode


### 第 3 次发布

发布时间：2020-03-10 00:51:28

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateAudit](https://cloud.tencent.com/document/api/629/35352)

	* 新增入参：IsEnableKmsEncry, KeyId, KmsRegion

* [DescribeAudit](https://cloud.tencent.com/document/api/629/35350)

	* 新增出参：IsEnableKmsEncry, KeyId, KmsAlias, KmsRegion

* [UpdateAudit](https://cloud.tencent.com/document/api/629/35341)

	* 新增入参：IsEnableKmsEncry, KeyId, KmsRegion


修改数据结构：

* [Event](https://cloud.tencent.com/document/api/629/35353#Event)

	* 新增成员：ResourceRegion


### 第 2 次发布

发布时间：2019-06-13 14:55:26

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [LookUpEvents](https://cloud.tencent.com/document/api/629/35344)

	* <font color="#dd0000">**删除入参**：</font>IsApiV3


### 第 1 次发布

发布时间：2019-06-07 10:19:56

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateAudit](https://cloud.tencent.com/document/api/629/35352)
* [DeleteAudit](https://cloud.tencent.com/document/api/629/35351)
* [DescribeAudit](https://cloud.tencent.com/document/api/629/35350)
* [GetAttributeKey](https://cloud.tencent.com/document/api/629/35349)
* [InquireAuditCredit](https://cloud.tencent.com/document/api/629/35348)
* [ListAudits](https://cloud.tencent.com/document/api/629/35347)
* [ListCmqEnableRegion](https://cloud.tencent.com/document/api/629/35346)
* [ListCosEnableRegion](https://cloud.tencent.com/document/api/629/35345)
* [LookUpEvents](https://cloud.tencent.com/document/api/629/35344)
* [StartLogging](https://cloud.tencent.com/document/api/629/35343)
* [StopLogging](https://cloud.tencent.com/document/api/629/35342)
* [UpdateAudit](https://cloud.tencent.com/document/api/629/35341)

新增数据结构：

* [AttributeKeyDetail](https://cloud.tencent.com/document/api/629/35353#AttributeKeyDetail)
* [AuditSummary](https://cloud.tencent.com/document/api/629/35353#AuditSummary)
* [CmqRegionInfo](https://cloud.tencent.com/document/api/629/35353#CmqRegionInfo)
* [CosRegionInfo](https://cloud.tencent.com/document/api/629/35353#CosRegionInfo)
* [Event](https://cloud.tencent.com/document/api/629/35353#Event)
* [LookupAttribute](https://cloud.tencent.com/document/api/629/35353#LookupAttribute)
* [Resource](https://cloud.tencent.com/document/api/629/35353#Resource)




## 云加密机(cloudhsm) 版本：2019-11-12

### 第 7 次发布

发布时间：2024-02-29 01:11:23

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [ResourceInfo](https://cloud.tencent.com/document/api/639/41450#ResourceInfo)

	* <font color="#dd0000">**修改成员**：</font>AlarmStatus


### 第 6 次发布

发布时间：2023-03-10 01:16:51

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [GetAlarmEvent](https://cloud.tencent.com/document/api/639/88097)
* [GetVsmMonitorInfo](https://cloud.tencent.com/document/api/639/88095)
* [ModifyAlarmEvent](https://cloud.tencent.com/document/api/639/88096)

修改接口：

* [ModifyVsmAttributes](https://cloud.tencent.com/document/api/639/41441)

	* 新增入参：AlarmStatus


新增数据结构：

* [AlarmPolicy](https://cloud.tencent.com/document/api/639/41450#AlarmPolicy)

修改数据结构：

* [HsmInfo](https://cloud.tencent.com/document/api/639/41450#HsmInfo)

	* 新增成员：HsmType

* [ResourceInfo](https://cloud.tencent.com/document/api/639/41450#ResourceInfo)

	* 新增成员：AlarmStatus


### 第 5 次发布

发布时间：2022-06-20 06:05:03

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeSupportedHsm](https://cloud.tencent.com/document/api/639/56372)

	* 新增入参：HsmType

* [DescribeVsms](https://cloud.tencent.com/document/api/639/41443)

	* 新增入参：HsmType

* [InquiryPriceBuyVsm](https://cloud.tencent.com/document/api/639/41442)

	* 新增入参：HsmType


### 第 4 次发布

发布时间：2021-05-28 08:09:58

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeSupportedHsm](https://cloud.tencent.com/document/api/639/56372)

修改接口：

* [DescribeVsmAttributes](https://cloud.tencent.com/document/api/639/41444)

	* 新增出参：Manufacturer

* [DescribeVsms](https://cloud.tencent.com/document/api/639/41443)

	* 新增入参：Manufacturer


新增数据结构：

* [DeviceInfo](https://cloud.tencent.com/document/api/639/41450#DeviceInfo)
* [HsmInfo](https://cloud.tencent.com/document/api/639/41450#HsmInfo)
* [VsmInfo](https://cloud.tencent.com/document/api/639/41450#VsmInfo)

修改数据结构：

* [ResourceInfo](https://cloud.tencent.com/document/api/639/41450#ResourceInfo)

	* 新增成员：Manufacturer


### 第 3 次发布

发布时间：2020-10-27 08:09:14

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeVsmAttributes](https://cloud.tencent.com/document/api/639/41444)

	* 新增出参：Tags, RenewFlag

* [DescribeVsms](https://cloud.tencent.com/document/api/639/41443)

	* 新增入参：TagFilters


新增数据结构：

* [Tag](https://cloud.tencent.com/document/api/639/41450#Tag)
* [TagFilter](https://cloud.tencent.com/document/api/639/41450#TagFilter)

修改数据结构：

* [ResourceInfo](https://cloud.tencent.com/document/api/639/41450#ResourceInfo)

	* 新增成员：CreateUin, RenewFlag, Tags


### 第 2 次发布

发布时间：2020-03-23 08:17:13

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeHSMBySubnetId](https://cloud.tencent.com/document/api/639/42767)
* [DescribeHSMByVpcId](https://cloud.tencent.com/document/api/639/42766)

### 第 1 次发布

发布时间：2020-02-21 14:29:13

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeSubnet](https://cloud.tencent.com/document/api/639/41449)
* [DescribeUsg](https://cloud.tencent.com/document/api/639/41448)
* [DescribeUsgRule](https://cloud.tencent.com/document/api/639/41447)
* [DescribeVpc](https://cloud.tencent.com/document/api/639/41446)
* [DescribeVsmAttributes](https://cloud.tencent.com/document/api/639/41444)
* [DescribeVsms](https://cloud.tencent.com/document/api/639/41443)
* [InquiryPriceBuyVsm](https://cloud.tencent.com/document/api/639/41442)
* [ModifyVsmAttributes](https://cloud.tencent.com/document/api/639/41441)

新增数据结构：

* [ResourceInfo](https://cloud.tencent.com/document/api/639/41450#ResourceInfo)
* [SgUnit](https://cloud.tencent.com/document/api/639/41450#SgUnit)
* [Subnet](https://cloud.tencent.com/document/api/639/41450#Subnet)
* [UsgPolicy](https://cloud.tencent.com/document/api/639/41450#UsgPolicy)
* [UsgRuleDetail](https://cloud.tencent.com/document/api/639/41450#UsgRuleDetail)
* [Vpc](https://cloud.tencent.com/document/api/639/41450#Vpc)




## Cloud Studio（云端 IDE）(cloudstudio) 版本：2023-05-08

### 第 6 次发布

发布时间：2024-04-26 01:11:33

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateWorkspace](https://cloud.tencent.com/document/api/1039/94096)

	* 新增入参：TenantAppId, TenantUin, TenantUniqVpcId, TenantSubnetId, Region

	* <font color="#dd0000">**删除入参**：</font>AppId, Uin, UniqVpcId, SubnetId


### 第 5 次发布

发布时间：2024-03-29 01:12:12

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateWorkspace](https://cloud.tencent.com/document/api/1039/94096)

	* 新增入参：AppId, Uin, UniqVpcId, SubnetId


### 第 4 次发布

发布时间：2023-07-24 01:17:40

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateWorkspaceToken](https://cloud.tencent.com/document/api/1039/94095)

	* 新增入参：Policies


### 第 3 次发布

发布时间：2023-07-20 01:17:13

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateWorkspaceToken](https://cloud.tencent.com/document/api/1039/94095)

	* <font color="#dd0000">**修改入参**：</font>SpaceKey


### 第 2 次发布

发布时间：2023-06-16 10:55:41

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeConfig](https://cloud.tencent.com/document/api/1039/94111)

### 第 1 次发布

发布时间：2023-06-16 10:50:49

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateWorkspace](https://cloud.tencent.com/document/api/1039/94096)
* [CreateWorkspaceToken](https://cloud.tencent.com/document/api/1039/94095)
* [DescribeImages](https://cloud.tencent.com/document/api/1039/94094)
* [DescribeWorkspaces](https://cloud.tencent.com/document/api/1039/94093)
* [ModifyWorkspace](https://cloud.tencent.com/document/api/1039/94092)
* [RemoveWorkspace](https://cloud.tencent.com/document/api/1039/94091)
* [RunWorkspace](https://cloud.tencent.com/document/api/1039/94090)
* [StopWorkspace](https://cloud.tencent.com/document/api/1039/94089)

新增数据结构：

* [Env](https://cloud.tencent.com/document/api/1039/94097#Env)
* [GitRepository](https://cloud.tencent.com/document/api/1039/94097#GitRepository)
* [Image](https://cloud.tencent.com/document/api/1039/94097#Image)
* [LifeCycle](https://cloud.tencent.com/document/api/1039/94097#LifeCycle)
* [LifeCycleCommand](https://cloud.tencent.com/document/api/1039/94097#LifeCycleCommand)
* [WorkspaceStatusInfo](https://cloud.tencent.com/document/api/1039/94097#WorkspaceStatusInfo)




## 日志服务(cls) 版本：2020-10-16

### 第 101 次发布

发布时间：2024-07-30 01:22:32

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [DataTransformTaskInfo](https://cloud.tencent.com/document/api/614/56471#DataTransformTaskInfo)

	* 新增成员：DataTransformType


### 第 100 次发布

发布时间：2024-07-25 01:22:39

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [UploadLog](https://cloud.tencent.com/document/api/614/59470)


### 第 99 次发布

发布时间：2024-07-05 01:06:07

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeMachines](https://cloud.tencent.com/document/api/614/56437)

	* 新增入参：Filters, Offset, Limit

	* 新增出参：TotalCount


### 第 98 次发布

发布时间：2024-06-28 01:07:19

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [AlarmTargetInfo](https://cloud.tencent.com/document/api/614/56471#AlarmTargetInfo)

	* 新增成员：SyntaxRule, BizType


### 第 97 次发布

发布时间：2024-06-27 01:08:10

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [ModifyTopic](https://cloud.tencent.com/document/api/614/56453)

	* 新增入参：Extends


修改数据结构：

* [MonitorTime](https://cloud.tencent.com/document/api/614/56471#MonitorTime)

	* <font color="#dd0000">**修改成员**：</font>Time

* [TopicInfo](https://cloud.tencent.com/document/api/614/56471#TopicInfo)

	* 新增成员：Extends


### 第 96 次发布

发布时间：2024-06-26 01:12:03

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateTopic](https://cloud.tencent.com/document/api/614/56456)

	* 新增入参：Extends


新增数据结构：

* [AnonymousInfo](https://cloud.tencent.com/document/api/614/56471#AnonymousInfo)
* [ConditionInfo](https://cloud.tencent.com/document/api/614/56471#ConditionInfo)
* [TopicExtendInfo](https://cloud.tencent.com/document/api/614/56471#TopicExtendInfo)

### 第 95 次发布

发布时间：2024-06-13 01:22:31

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [ModifyTopic](https://cloud.tencent.com/document/api/614/56453)

	* 新增入参：PartitionCount


### 第 94 次发布

发布时间：2024-06-12 01:26:26

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateExport](https://cloud.tencent.com/document/api/614/56451)

	* 新增入参：DerivedFields


修改数据结构：

* [ExportInfo](https://cloud.tencent.com/document/api/614/56471#ExportInfo)

	* 新增成员：DerivedFields


### 第 93 次发布

发布时间：2024-05-30 01:22:05

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeLogContext](https://cloud.tencent.com/document/api/614/56448)

	* 新增入参：Query, From, To


### 第 92 次发布

发布时间：2024-05-17 01:21:01

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateCosRecharge](https://cloud.tencent.com/document/api/614/88100)

	* <font color="#dd0000">**修改入参**：</font>Prefix

* [SearchCosRechargeInfo](https://cloud.tencent.com/document/api/614/97126)

	* <font color="#dd0000">**修改入参**：</font>Prefix


### 第 91 次发布

发布时间：2024-05-08 01:12:18

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [PreviewLogStatistic](https://cloud.tencent.com/document/api/614/56471#PreviewLogStatistic)

* [ScheduledSqlTaskInfo](https://cloud.tencent.com/document/api/614/56471#ScheduledSqlTaskInfo)

	* 新增成员：HasServicesLog


### 第 90 次发布

发布时间：2024-05-01 01:13:17

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [SearchDashboardSubscribe](https://cloud.tencent.com/document/api/614/105777)

	* 新增入参：DashboardId, SubscribeData, Id, Name


新增数据结构：

* [DashboardNoticeMode](https://cloud.tencent.com/document/api/614/56471#DashboardNoticeMode)
* [DashboardSubscribeData](https://cloud.tencent.com/document/api/614/56471#DashboardSubscribeData)
* [DashboardTemplateVariable](https://cloud.tencent.com/document/api/614/56471#DashboardTemplateVariable)

### 第 89 次发布

发布时间：2024-04-30 01:11:49

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateDashboardSubscribe](https://cloud.tencent.com/document/api/614/105781)
* [DeleteDashboardSubscribe](https://cloud.tencent.com/document/api/614/105780)
* [DescribeDashboardSubscribes](https://cloud.tencent.com/document/api/614/105779)
* [ModifyDashboardSubscribe](https://cloud.tencent.com/document/api/614/105778)
* [SearchDashboardSubscribe](https://cloud.tencent.com/document/api/614/105777)

### 第 88 次发布

发布时间：2024-04-29 01:11:58

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateCosRecharge](https://cloud.tencent.com/document/api/614/88100)

	* 新增入参：TaskType, Metadata

* [ModifyCosRecharge](https://cloud.tencent.com/document/api/614/88098)

	* 新增入参：Bucket, BucketRegion, Prefix, LogType, Compress, ExtractRuleInfo, TaskType, Metadata


### 第 87 次发布

发布时间：2024-04-26 01:11:35

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [CosRechargeInfo](https://cloud.tencent.com/document/api/614/56471#CosRechargeInfo)

	* 新增成员：TaskType, Metadata


### 第 86 次发布

发布时间：2024-03-15 01:10:50

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateKafkaRecharge](https://cloud.tencent.com/document/api/614/94448)

	* <font color="#dd0000">**修改入参**：</font>LogRechargeRule


### 第 85 次发布

发布时间：2024-03-14 01:11:38

本次发布包含了以下内容：

改善已有的文档。

<font color="#dd0000">**删除接口**：</font>

* DescribeKafkaUser

### 第 84 次发布

发布时间：2024-03-13 01:11:37

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateConfigExtra](https://cloud.tencent.com/document/api/614/71166)

	* 新增入参：CollectInfos


### 第 83 次发布

发布时间：2024-03-07 01:11:18

本次发布包含了以下内容：

改善已有的文档。

新增数据结构：

* [CollectConfig](https://cloud.tencent.com/document/api/614/56471#CollectConfig)
* [CollectInfo](https://cloud.tencent.com/document/api/614/56471#CollectInfo)

修改数据结构：

* [ConfigExtraInfo](https://cloud.tencent.com/document/api/614/56471#ConfigExtraInfo)

	* 新增成员：CollectInfos

* [ConsumerContent](https://cloud.tencent.com/document/api/614/56471#ConsumerContent)

	* 新增成员：JsonType

* [LogInfo](https://cloud.tencent.com/document/api/614/56471#LogInfo)

	* <font color="#dd0000">**修改成员**：</font>RawLog, IndexStatus


### 第 82 次发布

发布时间：2024-03-01 01:12:07

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateMachineGroup](https://cloud.tencent.com/document/api/614/56440)

	* 新增入参：DelayCleanupTime

* [ModifyMachineGroup](https://cloud.tencent.com/document/api/614/56436)

	* 新增入参：DelayCleanupTime


修改数据结构：

* [MachineGroupInfo](https://cloud.tencent.com/document/api/614/56471#MachineGroupInfo)

	* 新增成员：DelayCleanupTime

	* <font color="#dd0000">**修改成员**：</font>MetaTags, OSType


### 第 81 次发布

发布时间：2024-02-05 10:48:52

本次发布包含了以下内容：

改善已有的文档。

新增数据结构：

* [HighLightItem](https://cloud.tencent.com/document/api/614/56471#HighLightItem)

修改数据结构：

* [LogContextInfo](https://cloud.tencent.com/document/api/614/56471#LogContextInfo)

	* 新增成员：HighLights


### 第 80 次发布

发布时间：2024-01-31 01:10:12

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateAlarmShield](https://cloud.tencent.com/document/api/614/103652)
* [DeleteAlarmShield](https://cloud.tencent.com/document/api/614/103651)
* [DescribeAlarmShields](https://cloud.tencent.com/document/api/614/103650)
* [ModifyAlarmShield](https://cloud.tencent.com/document/api/614/103649)

新增数据结构：

* [AlarmShieldInfo](https://cloud.tencent.com/document/api/614/56471#AlarmShieldInfo)

### 第 79 次发布

发布时间：2024-01-19 01:09:34

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateShipper](https://cloud.tencent.com/document/api/614/58747)

	* 新增入参：StorageType

* [ModifyShipper](https://cloud.tencent.com/document/api/614/58743)

	* 新增入参：StorageType


修改数据结构：

* [ShipperInfo](https://cloud.tencent.com/document/api/614/56471#ShipperInfo)

	* 新增成员：StorageType


### 第 78 次发布

发布时间：2023-11-27 00:05:31

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateDeliverCloudFunction](https://cloud.tencent.com/document/api/614/101967)

### 第 77 次发布

发布时间：2023-11-24 01:10:04

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateAlarm](https://cloud.tencent.com/document/api/614/56466)

	* 新增入参：Enable, Classifications

* [ModifyAlarm](https://cloud.tencent.com/document/api/614/56459)

	* 新增入参：Enable, Tags, Classifications


新增数据结构：

* [AlarmClassification](https://cloud.tencent.com/document/api/614/56471#AlarmClassification)
* [MetricLabel](https://cloud.tencent.com/document/api/614/56471#MetricLabel)

修改数据结构：

* [LogContextInfo](https://cloud.tencent.com/document/api/614/56471#LogContextInfo)

	* <font color="#dd0000">**修改成员**：</font>RawLog, IndexStatus

* [ScheduledSqlResouceInfo](https://cloud.tencent.com/document/api/614/56471#ScheduledSqlResouceInfo)

	* 新增成员：MetricNames, MetricLabels, CustomTime, CustomMetricLabels

* [TopicInfo](https://cloud.tencent.com/document/api/614/56471#TopicInfo)

	* 新增成员：BizType, IsWebTracking


### 第 76 次发布

发布时间：2023-11-08 01:21:44

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CheckFunction](https://cloud.tencent.com/document/api/614/101381)

### 第 75 次发布

发布时间：2023-10-27 01:23:28

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [ModifyDataTransform](https://cloud.tencent.com/document/api/614/72181)

	* 新增入参：HasServicesLog


### 第 74 次发布

发布时间：2023-10-26 01:09:45

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateAlarm](https://cloud.tencent.com/document/api/614/56466)

	* 新增入参：AlarmLevel, GroupTriggerStatus, GroupTriggerCondition, Tags, MonitorObjectType

* [ModifyAlarm](https://cloud.tencent.com/document/api/614/56459)

	* 新增入参：GroupTriggerStatus, GroupTriggerCondition, MonitorObjectType


修改数据结构：

* [AlarmInfo](https://cloud.tencent.com/document/api/614/56471#AlarmInfo)

	* 新增成员：GroupTriggerStatus, GroupTriggerCondition, MonitorObjectType, AlarmLevel


### 第 73 次发布

发布时间：2023-10-25 01:11:22

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeScheduledSqlInfo](https://cloud.tencent.com/document/api/614/95519)

	* 新增入参：Filters


### 第 72 次发布

发布时间：2023-09-26 01:14:30

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateExport](https://cloud.tencent.com/document/api/614/56451)

	* 新增入参：SyntaxRule


### 第 71 次发布

发布时间：2023-09-21 02:03:11

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [QueryMetric](https://cloud.tencent.com/document/api/614/98729)
* [QueryRangeMetric](https://cloud.tencent.com/document/api/614/98728)

### 第 70 次发布

发布时间：2023-09-06 01:23:36

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [ExportInfo](https://cloud.tencent.com/document/api/614/56471#ExportInfo)

	* 新增成员：SyntaxRule


### 第 69 次发布

发布时间：2023-09-05 02:24:29

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [MachineInfo](https://cloud.tencent.com/document/api/614/56471#MachineInfo)

	* 新增成员：InstanceID


### 第 68 次发布

发布时间：2023-08-25 01:21:09

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [SearchCosRechargeInfo](https://cloud.tencent.com/document/api/614/97126)

### 第 67 次发布

发布时间：2023-08-22 01:09:04

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateAlarm](https://cloud.tencent.com/document/api/614/56466)

	* 新增入参：MultiConditions

	* <font color="#dd0000">**修改入参**：</font>Condition

* [CreateAlarmNotice](https://cloud.tencent.com/document/api/614/56465)

	* 新增入参：NoticeRules

	* <font color="#dd0000">**修改入参**：</font>Type

* [ModifyAlarm](https://cloud.tencent.com/document/api/614/56459)

	* 新增入参：AlarmLevel, MultiConditions

* [ModifyAlarmNotice](https://cloud.tencent.com/document/api/614/56458)

	* 新增入参：NoticeRules


新增数据结构：

* [FilePathInfo](https://cloud.tencent.com/document/api/614/56471#FilePathInfo)
* [MultiCondition](https://cloud.tencent.com/document/api/614/56471#MultiCondition)
* [NoticeRule](https://cloud.tencent.com/document/api/614/56471#NoticeRule)

修改数据结构：

* [AlarmInfo](https://cloud.tencent.com/document/api/614/56471#AlarmInfo)

	* 新增成员：MultiConditions

* [AlarmNotice](https://cloud.tencent.com/document/api/614/56471#AlarmNotice)

	* 新增成员：NoticeRules

* [ContainerFileInfo](https://cloud.tencent.com/document/api/614/56471#ContainerFileInfo)

	* 新增成员：FilePaths, CustomLabels

* [ContainerStdoutInfo](https://cloud.tencent.com/document/api/614/56471#ContainerStdoutInfo)

	* 新增成员：CustomLabels


### 第 66 次发布

发布时间：2023-08-14 01:14:15

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [SearchLog](https://cloud.tencent.com/document/api/614/56447)

	* 新增出参：Topics


新增数据结构：

* [SearchLogErrors](https://cloud.tencent.com/document/api/614/56471#SearchLogErrors)
* [SearchLogInfos](https://cloud.tencent.com/document/api/614/56471#SearchLogInfos)
* [SearchLogTopics](https://cloud.tencent.com/document/api/614/56471#SearchLogTopics)

### 第 65 次发布

发布时间：2023-08-08 01:11:32

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateMachineGroup](https://cloud.tencent.com/document/api/614/56440)

	* 新增入参：OSType


新增数据结构：

* [EventLog](https://cloud.tencent.com/document/api/614/56471#EventLog)

修改数据结构：

* [ExtractRuleInfo](https://cloud.tencent.com/document/api/614/56471#ExtractRuleInfo)

	* 新增成员：EventLogRules

* [MachineGroupInfo](https://cloud.tencent.com/document/api/614/56471#MachineGroupInfo)

	* 新增成员：OSType


### 第 64 次发布

发布时间：2023-08-03 01:03:31

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeKafkaConsumer](https://cloud.tencent.com/document/api/614/95719)

	* 新增出参：ConsumerContent

* [ModifyKafkaConsumer](https://cloud.tencent.com/document/api/614/95720)

	* 新增入参：ConsumerContent


### 第 63 次发布

发布时间：2023-08-02 01:08:23

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeKafkaUser](https://cloud.tencent.com/document/api/#/#)

### 第 62 次发布

发布时间：2023-08-01 01:11:03

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeKafkaConsumer](https://cloud.tencent.com/document/api/614/95719)
* [ModifyKafkaConsumer](https://cloud.tencent.com/document/api/614/95720)

### 第 61 次发布

发布时间：2023-07-31 16:20:55

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateConfigExtra](https://cloud.tencent.com/document/api/614/71166)

	* 新增入参：AdvancedConfig

* [ModifyConfig](https://cloud.tencent.com/document/api/614/58614)

	* 新增入参：AdvancedConfig

* [ModifyConfigExtra](https://cloud.tencent.com/document/api/614/71163)

	* 新增入参：AdvancedConfig


修改数据结构：

* [ConfigExtraInfo](https://cloud.tencent.com/document/api/614/56471#ConfigExtraInfo)

	* 新增成员：AdvancedConfig

* [ConfigInfo](https://cloud.tencent.com/document/api/614/56471#ConfigInfo)

	* 新增成员：AdvancedConfig


### 第 60 次发布

发布时间：2023-07-28 01:15:40

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeDashboards](https://cloud.tencent.com/document/api/614/95636)

新增数据结构：

* [DashboardInfo](https://cloud.tencent.com/document/api/614/56471#DashboardInfo)
* [DashboardTopicInfo](https://cloud.tencent.com/document/api/614/56471#DashboardTopicInfo)
* [TopicIdAndRegion](https://cloud.tencent.com/document/api/614/56471#TopicIdAndRegion)

修改数据结构：

* [ScheduledSqlResouceInfo](https://cloud.tencent.com/document/api/614/56471#ScheduledSqlResouceInfo)

	* 新增成员：BizType, MetricName


### 第 59 次发布

发布时间：2023-07-27 01:09:55

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [MachineGroupTypeInfo](https://cloud.tencent.com/document/api/614/56471#MachineGroupTypeInfo)

	* <font color="#dd0000">**修改成员**：</font>Values


### 第 58 次发布

发布时间：2023-07-26 01:10:44

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DeleteScheduledSql](https://cloud.tencent.com/document/api/614/95520)
* [DescribeScheduledSqlInfo](https://cloud.tencent.com/document/api/614/95519)
* [ModifyScheduledSql](https://cloud.tencent.com/document/api/614/95518)

新增数据结构：

* [ScheduledSqlTaskInfo](https://cloud.tencent.com/document/api/614/56471#ScheduledSqlTaskInfo)

### 第 57 次发布

发布时间：2023-07-20 01:17:22

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [KafkaRechargeInfo](https://cloud.tencent.com/document/api/614/56471#KafkaRechargeInfo)

	* <font color="#dd0000">**修改成员**：</font>KafkaType, KafkaInstance, IsEncryptionAddr, Protocol, Offset


### 第 56 次发布

发布时间：2023-07-19 01:14:47

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateScheduledSql](https://cloud.tencent.com/document/api/614/95138)

新增数据结构：

* [ScheduledSqlResouceInfo](https://cloud.tencent.com/document/api/614/56471#ScheduledSqlResouceInfo)

### 第 55 次发布

发布时间：2023-07-10 01:15:21

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateDataTransform](https://cloud.tencent.com/document/api/614/72184)
* [DeleteDataTransform](https://cloud.tencent.com/document/api/614/72183)
* [DescribeDataTransformInfo](https://cloud.tencent.com/document/api/614/72182)
* [ModifyDataTransform](https://cloud.tencent.com/document/api/614/72181)

新增数据结构：

* [DataTransformResouceInfo](https://cloud.tencent.com/document/api/614/56471#DataTransformResouceInfo)
* [DataTransformTaskInfo](https://cloud.tencent.com/document/api/614/56471#DataTransformTaskInfo)
* [PreviewLogStatistic](https://cloud.tencent.com/document/api/614/56471#PreviewLogStatistic)

### 第 54 次发布

发布时间：2023-07-05 01:15:21

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeTopics](https://cloud.tencent.com/document/api/614/56454)

	* 新增入参：PreciseSearch, BizType


### 第 53 次发布

发布时间：2023-07-03 17:15:42

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [OpenKafkaConsumer](https://cloud.tencent.com/document/api/614/72339)

	* 新增入参：ConsumerContent


新增数据结构：

* [KafkaConsumerContent](https://cloud.tencent.com/document/api/614/56471#KafkaConsumerContent)

### 第 52 次发布

发布时间：2023-07-03 16:20:49

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CheckRechargeKafkaServer](https://cloud.tencent.com/document/api/614/94449)
* [CreateKafkaRecharge](https://cloud.tencent.com/document/api/614/94448)
* [DeleteKafkaRecharge](https://cloud.tencent.com/document/api/614/94447)
* [DescribeKafkaRecharges](https://cloud.tencent.com/document/api/614/94446)
* [ModifyKafkaRecharge](https://cloud.tencent.com/document/api/614/94445)
* [PreviewKafkaRecharge](https://cloud.tencent.com/document/api/614/94444)

新增数据结构：

* [KafkaProtocolInfo](https://cloud.tencent.com/document/api/614/56471#KafkaProtocolInfo)
* [KafkaRechargeInfo](https://cloud.tencent.com/document/api/614/56471#KafkaRechargeInfo)
* [LogRechargeRuleInfo](https://cloud.tencent.com/document/api/614/56471#LogRechargeRuleInfo)

### 第 51 次发布

发布时间：2023-06-19 01:10:34

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [SearchLog](https://cloud.tencent.com/document/api/614/56447)

	* 新增入参：Topics


新增数据结构：

* [MultiTopicSearchInformation](https://cloud.tencent.com/document/api/614/56471#MultiTopicSearchInformation)

### 第 50 次发布

发布时间：2023-06-13 01:10:07

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateConfig](https://cloud.tencent.com/document/api/614/58620)

	* 新增入参：AdvancedConfig


### 第 49 次发布

发布时间：2023-05-29 01:15:07

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeLogHistogram](https://cloud.tencent.com/document/api/614/71726)

	* 新增入参：SyntaxRule


### 第 48 次发布

发布时间：2023-05-24 01:13:13

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateCosRecharge](https://cloud.tencent.com/document/api/614/88100)

	* 新增出参：Id


### 第 47 次发布

发布时间：2023-05-17 01:17:51

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [AlarmTarget](https://cloud.tencent.com/document/api/614/56471#AlarmTarget)

	* 新增成员：SyntaxRule


### 第 46 次发布

发布时间：2023-05-11 01:12:58

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [JsonInfo](https://cloud.tencent.com/document/api/614/56471#JsonInfo)

	* 新增成员：JsonType


### 第 45 次发布

发布时间：2023-05-10 01:13:17

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateShipper](https://cloud.tencent.com/document/api/614/58747)

	* 新增入参：StartTime, EndTime


### 第 44 次发布

发布时间：2023-05-08 01:15:09

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [ShipperInfo](https://cloud.tencent.com/document/api/614/56471#ShipperInfo)

	* 新增成员：StartTime, EndTime, Progress, RemainTime, HistoryStatus


### 第 43 次发布

发布时间：2023-04-27 01:12:13

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateMachineGroup](https://cloud.tencent.com/document/api/614/56440)

	* 新增入参：MetaTags

* [ModifyMachineGroup](https://cloud.tencent.com/document/api/614/56436)

	* 新增入参：MetaTags


新增数据结构：

* [MetaTagInfo](https://cloud.tencent.com/document/api/614/56471#MetaTagInfo)

修改数据结构：

* [ExtractRuleInfo](https://cloud.tencent.com/document/api/614/56471#ExtractRuleInfo)

	* 新增成员：MetadataType, PathRegex, MetaTags

* [MachineGroupInfo](https://cloud.tencent.com/document/api/614/56471#MachineGroupInfo)

	* 新增成员：MetaTags


### 第 42 次发布

发布时间：2023-04-19 01:14:14

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeAlertRecordHistory](https://cloud.tencent.com/document/api/614/90291)

新增数据结构：

* [AlertHistoryNotice](https://cloud.tencent.com/document/api/614/56471#AlertHistoryNotice)
* [AlertHistoryRecord](https://cloud.tencent.com/document/api/614/56471#AlertHistoryRecord)
* [GroupTriggerConditionInfo](https://cloud.tencent.com/document/api/614/56471#GroupTriggerConditionInfo)

### 第 41 次发布

发布时间：2023-04-14 01:13:53

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateTopic](https://cloud.tencent.com/document/api/614/56456)

	* 新增入参：IsWebTracking

* [ModifyTopic](https://cloud.tencent.com/document/api/614/56453)

	* 新增入参：IsWebTracking


### 第 40 次发布

发布时间：2023-04-11 01:09:59

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [SearchLog](https://cloud.tencent.com/document/api/614/56447)

	* 新增出参：SamplingRate


新增数据结构：

* [DynamicIndex](https://cloud.tencent.com/document/api/614/56471#DynamicIndex)

修改数据结构：

* [RuleInfo](https://cloud.tencent.com/document/api/614/56471#RuleInfo)

	* 新增成员：DynamicIndex


### 第 39 次发布

发布时间：2023-04-10 01:14:51

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateTopic](https://cloud.tencent.com/document/api/614/56456)

	* 新增入参：Describes, HotPeriod

* [ModifyTopic](https://cloud.tencent.com/document/api/614/56453)

	* 新增入参：Describes, HotPeriod


### 第 38 次发布

发布时间：2023-03-28 01:16:03

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [SearchLog](https://cloud.tencent.com/document/api/614/56447)

	* 新增入参：SyntaxRule


修改数据结构：

* [LogContextInfo](https://cloud.tencent.com/document/api/614/56471#LogContextInfo)

	* 新增成员：RawLog, IndexStatus

* [LogInfo](https://cloud.tencent.com/document/api/614/56471#LogInfo)

	* 新增成员：RawLog, IndexStatus


### 第 37 次发布

发布时间：2023-03-10 01:17:25

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateCosRecharge](https://cloud.tencent.com/document/api/614/88100)
* [DescribeCosRecharges](https://cloud.tencent.com/document/api/614/88099)
* [ModifyCosRecharge](https://cloud.tencent.com/document/api/614/88098)

新增数据结构：

* [CosRechargeInfo](https://cloud.tencent.com/document/api/614/56471#CosRechargeInfo)

### 第 36 次发布

发布时间：2023-03-09 01:14:48

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [TopicInfo](https://cloud.tencent.com/document/api/614/56471#TopicInfo)

	* 新增成员：HotPeriod


### 第 35 次发布

发布时间：2023-01-13 01:13:52

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeLogHistogram](https://cloud.tencent.com/document/api/614/71726)

	* <font color="#dd0000">**修改入参**：</font>TopicId

* [SearchLog](https://cloud.tencent.com/document/api/614/56447)

	* <font color="#dd0000">**修改入参**：</font>TopicId


### 第 34 次发布

发布时间：2022-11-07 06:12:05

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [AddMachineGroupInfo](https://cloud.tencent.com/document/api/614/82425)
* [DeleteMachineGroupInfo](https://cloud.tencent.com/document/api/614/82424)

### 第 33 次发布

发布时间：2022-11-01 06:16:55

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [LogsetInfo](https://cloud.tencent.com/document/api/614/56471#LogsetInfo)

	* 新增成员：AssumerName

* [TopicInfo](https://cloud.tencent.com/document/api/614/56471#TopicInfo)

	* 新增成员：AssumerName, SubAssumerName, Describes


### 第 32 次发布

发布时间：2022-10-28 06:17:28

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [ConfigInfo](https://cloud.tencent.com/document/api/614/56471#ConfigInfo)

	* 新增成员：Name


### 第 31 次发布

发布时间：2022-10-26 06:21:36

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [SearchLog](https://cloud.tencent.com/document/api/614/56447)

	* 新增入参：SamplingRate


### 第 30 次发布

发布时间：2022-09-22 06:17:52

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [ExtractRuleInfo](https://cloud.tencent.com/document/api/614/56471#ExtractRuleInfo)

	* 新增成员：Protocol, Address, ParseProtocol


### 第 29 次发布

发布时间：2022-08-24 06:18:24

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateShipper](https://cloud.tencent.com/document/api/614/58747)

	* 新增入参：FilenameMode

* [ModifyShipper](https://cloud.tencent.com/document/api/614/58743)

	* 新增入参：FilenameMode


### 第 28 次发布

发布时间：2022-08-18 06:14:59

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [OpenKafkaConsumer](https://cloud.tencent.com/document/api/614/72339)

	* 新增入参：Compression


### 第 27 次发布

发布时间：2022-08-11 06:20:21

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateConsumer](https://cloud.tencent.com/document/api/614/66228)

	* 新增入参：Compression

* [DescribeConsumer](https://cloud.tencent.com/document/api/614/66226)

	* 新增出参：Compression

* [ModifyConsumer](https://cloud.tencent.com/document/api/614/66225)

	* 新增入参：Compression


### 第 26 次发布

发布时间：2022-08-01 11:31:08

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [ShipperInfo](https://cloud.tencent.com/document/api/614/56471#ShipperInfo)

	* 新增成员：FilenameMode


### 第 25 次发布

发布时间：2022-07-18 06:07:30

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [ExtractRuleInfo](https://cloud.tencent.com/document/api/614/56471#ExtractRuleInfo)

	* 新增成员：IsGBK, JsonStandard


### 第 24 次发布

发布时间：2022-07-08 06:05:35

本次发布包含了以下内容：

改善已有的文档。

新增数据结构：

* [AlarmAnalysisConfig](https://cloud.tencent.com/document/api/614/56471#AlarmAnalysisConfig)

修改数据结构：

* [AnalysisDimensional](https://cloud.tencent.com/document/api/614/56471#AnalysisDimensional)

	* 新增成员：ConfigInfo


### 第 23 次发布

发布时间：2022-06-29 06:04:44

本次发布包含了以下内容：

改善已有的文档。

<font color="#dd0000">**删除接口**：</font>

* CreateDataTransform
* DeleteDataTransform
* DescribeDataTransformInfo
* ModifyDataTransform

<font color="#dd0000">**删除数据结构**：</font>

* DataTransformResouceInfo
* DataTransformTaskInfo
* PreviewLogStatistic

### 第 22 次发布

发布时间：2022-06-08 06:06:22

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [ConsumerContent](https://cloud.tencent.com/document/api/614/56471#ConsumerContent)

	* 新增成员：TimestampAccuracy


### 第 21 次发布

发布时间：2022-04-29 06:05:02

本次发布包含了以下内容：

改善已有的文档。

新增数据结构：

* [ParquetInfo](https://cloud.tencent.com/document/api/614/56471#ParquetInfo)
* [ParquetKeyInfo](https://cloud.tencent.com/document/api/614/56471#ParquetKeyInfo)

修改数据结构：

* [ContentInfo](https://cloud.tencent.com/document/api/614/56471#ContentInfo)

	* 新增成员：Parquet


### 第 20 次发布

发布时间：2022-04-21 06:09:08

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [LogContextInfo](https://cloud.tencent.com/document/api/614/56471#LogContextInfo)

	* 新增成员：HostName

* [LogInfo](https://cloud.tencent.com/document/api/614/56471#LogInfo)

	* 新增成员：HostName


### 第 19 次发布

发布时间：2022-04-12 06:09:41

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateIndex](https://cloud.tencent.com/document/api/614/56445)

	* 新增入参：IncludeInternalFields, MetadataFlag

* [DescribeIndex](https://cloud.tencent.com/document/api/614/56443)

	* 新增出参：IncludeInternalFields, MetadataFlag

* [ModifyIndex](https://cloud.tencent.com/document/api/614/56442)

	* 新增入参：IncludeInternalFields, MetadataFlag


### 第 18 次发布

发布时间：2022-04-11 06:09:13

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CloseKafkaConsumer](https://cloud.tencent.com/document/api/614/72340)
* [OpenKafkaConsumer](https://cloud.tencent.com/document/api/614/72339)

### 第 17 次发布

发布时间：2022-04-07 06:21:48

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateDataTransform](https://cloud.tencent.com/document/api/614/72184)
* [DeleteDataTransform](https://cloud.tencent.com/document/api/614/72183)
* [DescribeDataTransformInfo](https://cloud.tencent.com/document/api/614/72182)
* [ModifyDataTransform](https://cloud.tencent.com/document/api/614/72181)

新增数据结构：

* [DataTransformResouceInfo](https://cloud.tencent.com/document/api/614/56471#DataTransformResouceInfo)
* [DataTransformTaskInfo](https://cloud.tencent.com/document/api/614/56471#DataTransformTaskInfo)
* [PreviewLogStatistic](https://cloud.tencent.com/document/api/614/56471#PreviewLogStatistic)

### 第 16 次发布

发布时间：2022-03-29 08:06:55

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeLogHistogram](https://cloud.tencent.com/document/api/614/71726)

新增数据结构：

* [HistogramInfo](https://cloud.tencent.com/document/api/614/56471#HistogramInfo)

### 第 15 次发布

发布时间：2022-03-15 08:06:28

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateConfigExtra](https://cloud.tencent.com/document/api/614/71166)
* [DeleteConfigExtra](https://cloud.tencent.com/document/api/614/71165)
* [DescribeConfigExtras](https://cloud.tencent.com/document/api/614/71164)
* [ModifyConfigExtra](https://cloud.tencent.com/document/api/614/71163)

新增数据结构：

* [ConfigExtraInfo](https://cloud.tencent.com/document/api/614/56471#ConfigExtraInfo)
* [ContainerFileInfo](https://cloud.tencent.com/document/api/614/56471#ContainerFileInfo)
* [ContainerStdoutInfo](https://cloud.tencent.com/document/api/614/56471#ContainerStdoutInfo)
* [ContainerWorkLoadInfo](https://cloud.tencent.com/document/api/614/56471#ContainerWorkLoadInfo)
* [HostFileInfo](https://cloud.tencent.com/document/api/614/56471#HostFileInfo)

修改数据结构：

* [ConsumerContent](https://cloud.tencent.com/document/api/614/56471#ConsumerContent)

	* 新增成员：TagJsonNotTiled


### 第 14 次发布

发布时间：2022-01-05 08:06:03

本次发布包含了以下内容：

改善已有的文档。

<font color="#dd0000">**删除接口**：</font>

* CreateAsyncContextTask
* CreateAsyncSearchTask
* DeleteAsyncContextTask
* DeleteAsyncSearchTask
* DescribeAsyncContextResult
* DescribeAsyncContextTasks
* DescribeAsyncSearchResult
* DescribeAsyncSearchTasks

<font color="#dd0000">**删除数据结构**：</font>

* AsyncContextTask
* AsyncSearchTask

### 第 13 次发布

发布时间：2021-12-17 08:08:49

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateConsumer](https://cloud.tencent.com/document/api/614/66228)
* [DeleteConsumer](https://cloud.tencent.com/document/api/614/66227)
* [DescribeConsumer](https://cloud.tencent.com/document/api/614/66226)
* [ModifyConsumer](https://cloud.tencent.com/document/api/614/66225)

新增数据结构：

* [Ckafka](https://cloud.tencent.com/document/api/614/56471#Ckafka)
* [ConsumerContent](https://cloud.tencent.com/document/api/614/56471#ConsumerContent)

### 第 12 次发布

发布时间：2021-11-01 08:07:18

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [UploadLog](https://cloud.tencent.com/document/api/614/59470)

	* 新增入参：TopicId, HashKey, CompressType


### 第 11 次发布

发布时间：2021-10-27 08:04:57

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [GetAlarmLog](https://cloud.tencent.com/document/api/614/56460)

	* 新增入参：UseNewAnalysis

	* 新增出参：AnalysisRecords, Columns


### 第 10 次发布

发布时间：2021-09-03 08:00:19

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateConfig](https://cloud.tencent.com/document/api/614/58620)

	* 新增入参：UserDefineRule

* [ModifyConfig](https://cloud.tencent.com/document/api/614/58614)

	* 新增入参：UserDefineRule


修改数据结构：

* [ConfigInfo](https://cloud.tencent.com/document/api/614/56471#ConfigInfo)

	* 新增成员：UserDefineRule


### 第 9 次发布

发布时间：2021-08-24 08:00:18

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [SearchLog](https://cloud.tencent.com/document/api/614/56447)

	* 新增入参：UseNewAnalysis

	* 新增出参：AnalysisRecords, Columns


新增数据结构：

* [Column](https://cloud.tencent.com/document/api/614/56471#Column)

### 第 8 次发布

发布时间：2021-08-13 08:00:14

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateAlarm](https://cloud.tencent.com/document/api/614/56466)

	* 新增入参：MessageTemplate, CallBack, Analysis

* [ModifyAlarm](https://cloud.tencent.com/document/api/614/56459)

	* 新增入参：MessageTemplate, CallBack, Analysis


新增数据结构：

* [AnalysisDimensional](https://cloud.tencent.com/document/api/614/56471#AnalysisDimensional)

修改数据结构：

* [AlarmInfo](https://cloud.tencent.com/document/api/614/56471#AlarmInfo)

	* 新增成员：Analysis


### 第 7 次发布

发布时间：2021-08-11 08:00:16

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateAsyncContextTask](https://cloud.tencent.com/document/api/614/60073)
* [CreateAsyncSearchTask](https://cloud.tencent.com/document/api/614/60072)
* [DeleteAsyncContextTask](https://cloud.tencent.com/document/api/614/60071)
* [DeleteAsyncSearchTask](https://cloud.tencent.com/document/api/614/60070)
* [DescribeAsyncContextResult](https://cloud.tencent.com/document/api/614/60069)
* [DescribeAsyncContextTasks](https://cloud.tencent.com/document/api/614/60068)
* [DescribeAsyncSearchResult](https://cloud.tencent.com/document/api/614/60067)
* [DescribeAsyncSearchTasks](https://cloud.tencent.com/document/api/614/60066)

新增数据结构：

* [AsyncContextTask](https://cloud.tencent.com/document/api/614/56471#AsyncContextTask)
* [AsyncSearchTask](https://cloud.tencent.com/document/api/614/56471#AsyncSearchTask)

### 第 6 次发布

发布时间：2021-08-04 08:00:17

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [UploadLog](https://cloud.tencent.com/document/api/614/59470)

### 第 5 次发布

发布时间：2021-07-16 08:00:12

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateShipper](https://cloud.tencent.com/document/api/614/58747)
* [DeleteShipper](https://cloud.tencent.com/document/api/614/58746)
* [DescribeShipperTasks](https://cloud.tencent.com/document/api/614/58745)
* [DescribeShippers](https://cloud.tencent.com/document/api/614/58744)
* [ModifyShipper](https://cloud.tencent.com/document/api/614/58743)
* [RetryShipperTask](https://cloud.tencent.com/document/api/614/58742)

新增数据结构：

* [CompressInfo](https://cloud.tencent.com/document/api/614/56471#CompressInfo)
* [ContentInfo](https://cloud.tencent.com/document/api/614/56471#ContentInfo)
* [CsvInfo](https://cloud.tencent.com/document/api/614/56471#CsvInfo)
* [FilterRuleInfo](https://cloud.tencent.com/document/api/614/56471#FilterRuleInfo)
* [JsonInfo](https://cloud.tencent.com/document/api/614/56471#JsonInfo)
* [ShipperInfo](https://cloud.tencent.com/document/api/614/56471#ShipperInfo)
* [ShipperTaskInfo](https://cloud.tencent.com/document/api/614/56471#ShipperTaskInfo)

### 第 4 次发布

发布时间：2021-07-14 18:58:43

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [ApplyConfigToMachineGroup](https://cloud.tencent.com/document/api/614/58621)
* [CreateConfig](https://cloud.tencent.com/document/api/614/58620)
* [CreateLogset](https://cloud.tencent.com/document/api/614/58626)
* [DeleteConfig](https://cloud.tencent.com/document/api/614/58619)
* [DeleteConfigFromMachineGroup](https://cloud.tencent.com/document/api/614/58618)
* [DeleteLogset](https://cloud.tencent.com/document/api/614/58625)
* [DescribeConfigMachineGroups](https://cloud.tencent.com/document/api/614/58617)
* [DescribeConfigs](https://cloud.tencent.com/document/api/614/58616)
* [DescribeLogsets](https://cloud.tencent.com/document/api/614/58624)
* [DescribeMachineGroupConfigs](https://cloud.tencent.com/document/api/614/58615)
* [ModifyConfig](https://cloud.tencent.com/document/api/614/58614)
* [ModifyLogset](https://cloud.tencent.com/document/api/614/58623)

修改接口：

* [CreateTopic](https://cloud.tencent.com/document/api/614/56456)

	* 新增入参：Period

* [ModifyTopic](https://cloud.tencent.com/document/api/614/56453)

	* 新增入参：Period


新增数据结构：

* [ConfigInfo](https://cloud.tencent.com/document/api/614/56471#ConfigInfo)
* [ExcludePathInfo](https://cloud.tencent.com/document/api/614/56471#ExcludePathInfo)
* [ExtractRuleInfo](https://cloud.tencent.com/document/api/614/56471#ExtractRuleInfo)
* [KeyRegexInfo](https://cloud.tencent.com/document/api/614/56471#KeyRegexInfo)
* [LogsetInfo](https://cloud.tencent.com/document/api/614/56471#LogsetInfo)

### 第 3 次发布

发布时间：2021-07-14 08:00:12

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [TopicInfo](https://cloud.tencent.com/document/api/614/56471#TopicInfo)

	* 新增成员：Period


### 第 2 次发布

发布时间：2021-07-09 08:00:12

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [FullTextInfo](https://cloud.tencent.com/document/api/614/56471#FullTextInfo)

	* 新增成员：ContainZH

* [ValueInfo](https://cloud.tencent.com/document/api/614/56471#ValueInfo)

	* 新增成员：ContainZH


### 第 1 次发布

发布时间：2021-05-31 17:22:23

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateAlarm](https://cloud.tencent.com/document/api/614/56466)
* [CreateAlarmNotice](https://cloud.tencent.com/document/api/614/56465)
* [CreateExport](https://cloud.tencent.com/document/api/614/56451)
* [CreateIndex](https://cloud.tencent.com/document/api/614/56445)
* [CreateMachineGroup](https://cloud.tencent.com/document/api/614/56440)
* [CreateTopic](https://cloud.tencent.com/document/api/614/56456)
* [DeleteAlarm](https://cloud.tencent.com/document/api/614/56464)
* [DeleteAlarmNotice](https://cloud.tencent.com/document/api/614/56463)
* [DeleteExport](https://cloud.tencent.com/document/api/614/56450)
* [DeleteIndex](https://cloud.tencent.com/document/api/614/56444)
* [DeleteMachineGroup](https://cloud.tencent.com/document/api/614/56439)
* [DeleteTopic](https://cloud.tencent.com/document/api/614/56455)
* [DescribeAlarmNotices](https://cloud.tencent.com/document/api/614/56462)
* [DescribeAlarms](https://cloud.tencent.com/document/api/614/56461)
* [DescribeExports](https://cloud.tencent.com/document/api/614/56449)
* [DescribeIndex](https://cloud.tencent.com/document/api/614/56443)
* [DescribeLogContext](https://cloud.tencent.com/document/api/614/56448)
* [DescribeMachineGroups](https://cloud.tencent.com/document/api/614/56438)
* [DescribeMachines](https://cloud.tencent.com/document/api/614/56437)
* [DescribePartitions](https://cloud.tencent.com/document/api/614/56470)
* [DescribeTopics](https://cloud.tencent.com/document/api/614/56454)
* [GetAlarmLog](https://cloud.tencent.com/document/api/614/56460)
* [MergePartition](https://cloud.tencent.com/document/api/614/56469)
* [ModifyAlarm](https://cloud.tencent.com/document/api/614/56459)
* [ModifyAlarmNotice](https://cloud.tencent.com/document/api/614/56458)
* [ModifyIndex](https://cloud.tencent.com/document/api/614/56442)
* [ModifyMachineGroup](https://cloud.tencent.com/document/api/614/56436)
* [ModifyTopic](https://cloud.tencent.com/document/api/614/56453)
* [SearchLog](https://cloud.tencent.com/document/api/614/56447)
* [SplitPartition](https://cloud.tencent.com/document/api/614/56468)

新增数据结构：

* [AlarmInfo](https://cloud.tencent.com/document/api/614/56471#AlarmInfo)
* [AlarmNotice](https://cloud.tencent.com/document/api/614/56471#AlarmNotice)
* [AlarmTarget](https://cloud.tencent.com/document/api/614/56471#AlarmTarget)
* [AlarmTargetInfo](https://cloud.tencent.com/document/api/614/56471#AlarmTargetInfo)
* [CallBackInfo](https://cloud.tencent.com/document/api/614/56471#CallBackInfo)
* [ExportInfo](https://cloud.tencent.com/document/api/614/56471#ExportInfo)
* [Filter](https://cloud.tencent.com/document/api/614/56471#Filter)
* [FullTextInfo](https://cloud.tencent.com/document/api/614/56471#FullTextInfo)
* [KeyValueInfo](https://cloud.tencent.com/document/api/614/56471#KeyValueInfo)
* [LogContextInfo](https://cloud.tencent.com/document/api/614/56471#LogContextInfo)
* [LogInfo](https://cloud.tencent.com/document/api/614/56471#LogInfo)
* [LogItem](https://cloud.tencent.com/document/api/614/56471#LogItem)
* [LogItems](https://cloud.tencent.com/document/api/614/56471#LogItems)
* [MachineGroupInfo](https://cloud.tencent.com/document/api/614/56471#MachineGroupInfo)
* [MachineGroupTypeInfo](https://cloud.tencent.com/document/api/614/56471#MachineGroupTypeInfo)
* [MachineInfo](https://cloud.tencent.com/document/api/614/56471#MachineInfo)
* [MonitorTime](https://cloud.tencent.com/document/api/614/56471#MonitorTime)
* [NoticeReceiver](https://cloud.tencent.com/document/api/614/56471#NoticeReceiver)
* [PartitionInfo](https://cloud.tencent.com/document/api/614/56471#PartitionInfo)
* [RuleInfo](https://cloud.tencent.com/document/api/614/56471#RuleInfo)
* [RuleKeyValueInfo](https://cloud.tencent.com/document/api/614/56471#RuleKeyValueInfo)
* [RuleTagInfo](https://cloud.tencent.com/document/api/614/56471#RuleTagInfo)
* [Tag](https://cloud.tencent.com/document/api/614/56471#Tag)
* [TopicInfo](https://cloud.tencent.com/document/api/614/56471#TopicInfo)
* [ValueInfo](https://cloud.tencent.com/document/api/614/56471#ValueInfo)
* [WebCallback](https://cloud.tencent.com/document/api/614/56471#WebCallback)




## 多媒体创作引擎(cme) 版本：2019-10-29

### 第 58 次发布

发布时间：2024-07-29 01:23:21

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [VideoEditProjectOutput](https://cloud.tencent.com/document/api/1156/40360#VideoEditProjectOutput)

	* <font color="#dd0000">**修改成员**：</font>CoverURL


### 第 57 次发布

发布时间：2023-10-19 16:00:29

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [ExportVideoByEditorTrackData](https://cloud.tencent.com/document/api/1156/44159)

	* 新增入参：ExportExtensionArgs

* [ExportVideoByTemplate](https://cloud.tencent.com/document/api/1156/53890)

	* 新增入参：ExportExtensionArgs


### 第 56 次发布

发布时间：2023-08-09 01:16:08

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [MediaCastOutputMediaSetting](https://cloud.tencent.com/document/api/1156/40360#MediaCastOutputMediaSetting)

	* 新增成员：FollowSourceInfo


### 第 55 次发布

发布时间：2023-07-21 01:14:51

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [MediaCastProjectInfo](https://cloud.tencent.com/document/api/1156/40360#MediaCastProjectInfo)

	* 新增成员：Duration


### 第 54 次发布

发布时间：2023-06-29 01:11:59

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [MediaCastPlaySetting](https://cloud.tencent.com/document/api/1156/40360#MediaCastPlaySetting)

	* 新增成员：AutoStartTime

* [MediaCastSourceInfo](https://cloud.tencent.com/document/api/1156/40360#MediaCastSourceInfo)

	* 新增成员：Offset, Duration, Url


### 第 53 次发布

发布时间：2023-03-24 01:25:23

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [HandleMediaCastProject](https://cloud.tencent.com/document/api/1156/87841)

修改接口：

* [CreateProject](https://cloud.tencent.com/document/api/1156/40350)

	* 新增入参：MediaCastProjectInput


新增数据结构：

* [MediaCastDestinationStatus](https://cloud.tencent.com/document/api/1156/40360#MediaCastDestinationStatus)
* [MediaCastPlayInfo](https://cloud.tencent.com/document/api/1156/40360#MediaCastPlayInfo)
* [MediaCastProjectInput](https://cloud.tencent.com/document/api/1156/40360#MediaCastProjectInput)

修改数据结构：

* [MediaCastDestinationInfo](https://cloud.tencent.com/document/api/1156/40360#MediaCastDestinationInfo)

	* 新增成员：Id

	* <font color="#dd0000">**删除成员**：</font>Index

* [MediaCastSourceInfo](https://cloud.tencent.com/document/api/1156/40360#MediaCastSourceInfo)

	* 新增成员：Id

	* <font color="#dd0000">**删除成员**：</font>Index

	* <font color="#dd0000">**修改成员**：</font>Type

* [VideoEditProjectOutput](https://cloud.tencent.com/document/api/1156/40360#VideoEditProjectOutput)

	* 新增成员：CoverURL


### 第 52 次发布

发布时间：2022-12-05 06:32:09

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [MaterialInfo](https://cloud.tencent.com/document/api/1156/40360#MaterialInfo)

	* <font color="#dd0000">**修改成员**：</font>BasicInfo, VideoMaterial, AudioMaterial, ImageMaterial, LinkMaterial, VideoEditTemplateMaterial, OtherMaterial


### 第 51 次发布

发布时间：2022-08-24 06:19:05

本次发布包含了以下内容：

改善已有的文档。

新增数据结构：

* [MediaCastDestinationInfo](https://cloud.tencent.com/document/api/1156/40360#MediaCastDestinationInfo)
* [MediaCastDestinationInterruptInfo](https://cloud.tencent.com/document/api/1156/40360#MediaCastDestinationInterruptInfo)
* [MediaCastOutputMediaSetting](https://cloud.tencent.com/document/api/1156/40360#MediaCastOutputMediaSetting)
* [MediaCastPlaySetting](https://cloud.tencent.com/document/api/1156/40360#MediaCastPlaySetting)
* [MediaCastProjectInfo](https://cloud.tencent.com/document/api/1156/40360#MediaCastProjectInfo)
* [MediaCastSourceInfo](https://cloud.tencent.com/document/api/1156/40360#MediaCastSourceInfo)
* [MediaCastSourceInterruptInfo](https://cloud.tencent.com/document/api/1156/40360#MediaCastSourceInterruptInfo)
* [MediaCastVideoSetting](https://cloud.tencent.com/document/api/1156/40360#MediaCastVideoSetting)
* [ProjectMediaCastStatusChangedEvent](https://cloud.tencent.com/document/api/1156/40360#ProjectMediaCastStatusChangedEvent)

修改数据结构：

* [EventContent](https://cloud.tencent.com/document/api/1156/40360#EventContent)

	* 新增成员：ProjectMediaCastStatusChangedEvent

* [ProjectInfo](https://cloud.tencent.com/document/api/1156/40360#ProjectInfo)

	* 新增成员：MediaCastProjectInfo


### 第 50 次发布

发布时间：2022-06-24 06:09:00

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [HandleStreamConnectProject](https://cloud.tencent.com/document/api/1156/54998)

	* 新增出参：VodPullInputPlayInfo


新增数据结构：

* [VodPullInputPlayInfo](https://cloud.tencent.com/document/api/1156/40360#VodPullInputPlayInfo)

### 第 49 次发布

发布时间：2022-06-10 06:04:57

本次发布包含了以下内容：

改善已有的文档。

新增数据结构：

* [StreamConnectInputInterruptInfo](https://cloud.tencent.com/document/api/1156/40360#StreamConnectInputInterruptInfo)
* [StreamConnectOutputInterruptInfo](https://cloud.tencent.com/document/api/1156/40360#StreamConnectOutputInterruptInfo)

修改数据结构：

* [ProjectStreamConnectStatusChangedEvent](https://cloud.tencent.com/document/api/1156/40360#ProjectStreamConnectStatusChangedEvent)

	* 新增成员：InputInterruptInfo, OutputInterruptInfo


### 第 48 次发布

发布时间：2022-04-22 06:07:06

本次发布包含了以下内容：

改善已有的文档。

新增数据结构：

* [VideoExportCompletedEvent](https://cloud.tencent.com/document/api/1156/40360#VideoExportCompletedEvent)

修改数据结构：

* [EventContent](https://cloud.tencent.com/document/api/1156/40360#EventContent)

	* 新增成员：VideoExportCompletedEvent


### 第 47 次发布

发布时间：2022-01-27 08:22:16

本次发布包含了以下内容：

改善已有的文档。

新增数据结构：

* [ClassCreatedEvent](https://cloud.tencent.com/document/api/1156/40360#ClassCreatedEvent)
* [ClassDeletedEvent](https://cloud.tencent.com/document/api/1156/40360#ClassDeletedEvent)
* [ClassMovedEvent](https://cloud.tencent.com/document/api/1156/40360#ClassMovedEvent)
* [ImportMediaInfo](https://cloud.tencent.com/document/api/1156/40360#ImportMediaInfo)
* [MaterialAddedEvent](https://cloud.tencent.com/document/api/1156/40360#MaterialAddedEvent)
* [MaterialDeletedEvent](https://cloud.tencent.com/document/api/1156/40360#MaterialDeletedEvent)
* [MaterialImportedEvent](https://cloud.tencent.com/document/api/1156/40360#MaterialImportedEvent)
* [MaterialModifiedEvent](https://cloud.tencent.com/document/api/1156/40360#MaterialModifiedEvent)
* [MaterialMovedEvent](https://cloud.tencent.com/document/api/1156/40360#MaterialMovedEvent)
* [ProjectSwitcherStatusChangedEvent](https://cloud.tencent.com/document/api/1156/40360#ProjectSwitcherStatusChangedEvent)

修改数据结构：

* [EventContent](https://cloud.tencent.com/document/api/1156/40360#EventContent)

	* 新增成员：Operator, ProjectSwitcherStatusChangedEvent, MaterialImportedEvent, MaterialAddedEvent, MaterialMovedEvent, MaterialModifiedEvent, MaterialDeletedEvent, ClassCreatedEvent, ClassMovedEvent, ClassDeletedEvent

* [StorageNewFileCreatedEvent](https://cloud.tencent.com/document/api/1156/40360#StorageNewFileCreatedEvent)

	* 新增成员：TaskId, SourceContext


### 第 46 次发布

发布时间：2021-12-24 08:07:24

本次发布包含了以下内容：

改善已有的文档。

新增数据结构：

* [TextSlotInfo](https://cloud.tencent.com/document/api/1156/40360#TextSlotInfo)

修改数据结构：

* [SlotInfo](https://cloud.tencent.com/document/api/1156/40360#SlotInfo)

	* 新增成员：DefaultTextSlotInfo


### 第 45 次发布

发布时间：2021-12-14 08:07:36

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [ExternalMediaInfo](https://cloud.tencent.com/document/api/1156/40360#ExternalMediaInfo)

	* 新增成员：StorageId

	* <font color="#dd0000">**修改成员**：</font>Definition


### 第 44 次发布

发布时间：2021-12-02 08:04:53

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [VideoExportExtensionArgs](https://cloud.tencent.com/document/api/1156/40360#VideoExportExtensionArgs)

	* 新增成员：FrameRate


### 第 43 次发布

发布时间：2021-11-26 08:06:20

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [HandleStreamConnectProject](https://cloud.tencent.com/document/api/1156/54998)

	* 新增入参：Operator


### 第 42 次发布

发布时间：2021-11-17 08:08:41

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateVideoEncodingPreset](https://cloud.tencent.com/document/api/1156/64067)
* [DeleteVideoEncodingPreset](https://cloud.tencent.com/document/api/1156/64066)
* [DescribeVideoEncodingPresets](https://cloud.tencent.com/document/api/1156/64065)
* [ModifyVideoEncodingPreset](https://cloud.tencent.com/document/api/1156/64064)

修改接口：

* [ExportVideoEditProject](https://cloud.tencent.com/document/api/1156/40353)

	* 新增入参：ExportExtensionArgs


新增数据结构：

* [VideoEncodingPreset](https://cloud.tencent.com/document/api/1156/40360#VideoEncodingPreset)
* [VideoEncodingPresetAudioSetting](https://cloud.tencent.com/document/api/1156/40360#VideoEncodingPresetAudioSetting)
* [VideoEncodingPresetAudioSettingForUpdate](https://cloud.tencent.com/document/api/1156/40360#VideoEncodingPresetAudioSettingForUpdate)
* [VideoEncodingPresetVideoSetting](https://cloud.tencent.com/document/api/1156/40360#VideoEncodingPresetVideoSetting)
* [VideoEncodingPresetVideoSettingForUpdate](https://cloud.tencent.com/document/api/1156/40360#VideoEncodingPresetVideoSettingForUpdate)
* [VideoExportExtensionArgs](https://cloud.tencent.com/document/api/1156/40360#VideoExportExtensionArgs)

### 第 41 次发布

发布时间：2021-11-16 08:08:03

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeResourceAuthorization](https://cloud.tencent.com/document/api/1156/43251)

	* <font color="#dd0000">**修改入参**：</font>Owner, Resource


### 第 40 次发布

发布时间：2021-11-01 08:07:26

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [ExportVideoByEditorTrackData](https://cloud.tencent.com/document/api/1156/44159)

	* 新增入参：AspectRatio


### 第 39 次发布

发布时间：2021-09-15 08:03:30

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [PlatformInfo](https://cloud.tencent.com/document/api/1156/40360#PlatformInfo)

	* 新增成员：Status


### 第 38 次发布

发布时间：2021-08-12 08:03:28

本次发布包含了以下内容：

改善已有的文档。

新增数据结构：

* [MediaPreprocessOperation](https://cloud.tencent.com/document/api/1156/40360#MediaPreprocessOperation)

修改数据结构：

* [MediaReplacementInfo](https://cloud.tencent.com/document/api/1156/40360#MediaReplacementInfo)

	* 新增成员：MediaType, MediaUrl, PreprocessOperation

	* <font color="#dd0000">**修改成员**：</font>MaterialId


### 第 37 次发布

发布时间：2021-07-16 08:03:02

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [ExportVideoByEditorTrackData](https://cloud.tencent.com/document/api/1156/44159)

	* 新增入参：CoverData


### 第 36 次发布

发布时间：2021-07-08 08:02:59

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CopyProject](https://cloud.tencent.com/document/api/1156/58269)

### 第 35 次发布

发布时间：2021-06-22 08:03:11

本次发布包含了以下内容：

改善已有的文档。

新增数据结构：

* [TextReplacementInfo](https://cloud.tencent.com/document/api/1156/40360#TextReplacementInfo)

修改数据结构：

* [SlotReplacementInfo](https://cloud.tencent.com/document/api/1156/40360#SlotReplacementInfo)

	* 新增成员：TextReplacementInfo


### 第 34 次发布

发布时间：2021-06-17 08:02:44

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [VideoEditTemplateMaterial](https://cloud.tencent.com/document/api/1156/40360#VideoEditTemplateMaterial)

	* 新增成员：PreviewVideoUrl


### 第 33 次发布

发布时间：2021-06-16 08:02:54

本次发布包含了以下内容：

改善已有的文档。

新增数据结构：

* [ProjectStreamConnectStatusChangedEvent](https://cloud.tencent.com/document/api/1156/40360#ProjectStreamConnectStatusChangedEvent)

修改数据结构：

* [EventContent](https://cloud.tencent.com/document/api/1156/40360#EventContent)

	* 新增成员：ProjectStreamConnectStatusChangedEvent


### 第 32 次发布

发布时间：2021-05-26 08:02:29

本次发布包含了以下内容：

改善已有的文档。

新增数据结构：

* [CosPublishInputInfo](https://cloud.tencent.com/document/api/1156/40360#CosPublishInputInfo)

修改数据结构：

* [ThirdPartyPublishInfo](https://cloud.tencent.com/document/api/1156/40360#ThirdPartyPublishInfo)

	* 新增成员：CosPublishInfo


### 第 31 次发布

发布时间：2021-05-24 08:02:19

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [ParseEvent](https://cloud.tencent.com/document/api/1156/56199)

新增数据结构：

* [EventContent](https://cloud.tencent.com/document/api/1156/40360#EventContent)
* [StorageNewFileCreatedEvent](https://cloud.tencent.com/document/api/1156/40360#StorageNewFileCreatedEvent)

### 第 30 次发布

发布时间：2021-04-30 08:02:08

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateProject](https://cloud.tencent.com/document/api/1156/40350)

	* 新增出参：RtmpPushInputInfoSet

* [HandleStreamConnectProject](https://cloud.tencent.com/document/api/1156/54998)

	* 新增出参：StreamInputRtmpPushUrl


### 第 29 次发布

发布时间：2021-04-28 08:03:12

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateProject](https://cloud.tencent.com/document/api/1156/40350)

	* 新增入参：Mode

* [DescribeProjects](https://cloud.tencent.com/document/api/1156/40348)

	* 新增入参：Modes

* [ModifyProject](https://cloud.tencent.com/document/api/1156/40347)

	* 新增入参：Mode


### 第 28 次发布

发布时间：2021-04-27 08:02:11

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeAccounts](https://cloud.tencent.com/document/api/1156/55196)

新增数据结构：

* [AccountInfo](https://cloud.tencent.com/document/api/1156/40360#AccountInfo)

### 第 27 次发布

发布时间：2021-04-23 08:01:59

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [HandleStreamConnectProject](https://cloud.tencent.com/document/api/1156/54998)

新增数据结构：

* [StreamConnectOutputInfo](https://cloud.tencent.com/document/api/1156/40360#StreamConnectOutputInfo)
* [StreamConnectProjectInfo](https://cloud.tencent.com/document/api/1156/40360#StreamConnectProjectInfo)

修改数据结构：

* [ProjectInfo](https://cloud.tencent.com/document/api/1156/40360#ProjectInfo)

	* 新增成员：StreamConnectProjectInfo


### 第 26 次发布

发布时间：2021-04-15 08:02:12

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateProject](https://cloud.tencent.com/document/api/1156/40350)

	* 新增入参：RecordReplayProjectInput

* [ExportVideoEditProject](https://cloud.tencent.com/document/api/1156/40353)

	* 新增入参：CoverData


新增数据结构：

* [RecordReplayProjectInput](https://cloud.tencent.com/document/api/1156/40360#RecordReplayProjectInput)

### 第 25 次发布

发布时间：2021-04-07 08:02:01

本次发布包含了以下内容：

改善已有的文档。

新增数据结构：

* [SlotInfo](https://cloud.tencent.com/document/api/1156/40360#SlotInfo)
* [VideoEditTemplateMaterial](https://cloud.tencent.com/document/api/1156/40360#VideoEditTemplateMaterial)

修改数据结构：

* [MaterialInfo](https://cloud.tencent.com/document/api/1156/40360#MaterialInfo)

	* 新增成员：VideoEditTemplateMaterial


### 第 24 次发布

发布时间：2021-04-05 08:02:04

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateProject](https://cloud.tencent.com/document/api/1156/40350)

	* 新增入参：StreamConnectProjectInput


新增数据结构：

* [LivePullInputInfo](https://cloud.tencent.com/document/api/1156/40360#LivePullInputInfo)
* [MediaTransitionItem](https://cloud.tencent.com/document/api/1156/40360#MediaTransitionItem)
* [RtmpPushInputInfo](https://cloud.tencent.com/document/api/1156/40360#RtmpPushInputInfo)
* [StreamConnectOutput](https://cloud.tencent.com/document/api/1156/40360#StreamConnectOutput)
* [StreamConnectProjectInput](https://cloud.tencent.com/document/api/1156/40360#StreamConnectProjectInput)
* [StreamInputInfo](https://cloud.tencent.com/document/api/1156/40360#StreamInputInfo)
* [VodPullInputInfo](https://cloud.tencent.com/document/api/1156/40360#VodPullInputInfo)

修改数据结构：

* [MediaTrackItem](https://cloud.tencent.com/document/api/1156/40360#MediaTrackItem)

	* 新增成员：TransitionItem


### 第 23 次发布

发布时间：2021-03-22 08:02:05

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [ExportVideoByTemplate](https://cloud.tencent.com/document/api/1156/53890)

新增数据结构：

* [MediaReplacementInfo](https://cloud.tencent.com/document/api/1156/40360#MediaReplacementInfo)
* [SlotReplacementInfo](https://cloud.tencent.com/document/api/1156/40360#SlotReplacementInfo)

### 第 22 次发布

发布时间：2021-03-17 08:02:14

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [MoveResource](https://cloud.tencent.com/document/api/1156/53700)

修改接口：

* [DeleteProject](https://cloud.tencent.com/document/api/1156/40349)

	* 新增入参：Operator

* [DescribeProjects](https://cloud.tencent.com/document/api/1156/40348)

	* 新增入参：Operator

* [DescribeTaskDetail](https://cloud.tencent.com/document/api/1156/40359)

	* 新增入参：Operator

* [DescribeTasks](https://cloud.tencent.com/document/api/1156/40358)

	* 新增入参：Operator

* [ModifyMaterial](https://cloud.tencent.com/document/api/1156/43241)

	* <font color="#dd0000">**修改入参**：</font>Owner


新增数据结构：

* [OtherMaterial](https://cloud.tencent.com/document/api/1156/40360#OtherMaterial)
* [PresetTagInfo](https://cloud.tencent.com/document/api/1156/40360#PresetTagInfo)
* [ResourceInfo](https://cloud.tencent.com/document/api/1156/40360#ResourceInfo)

修改数据结构：

* [MaterialBasicInfo](https://cloud.tencent.com/document/api/1156/40360#MaterialBasicInfo)

	* 新增成员：PresetTagSet, TagSet

* [MaterialInfo](https://cloud.tencent.com/document/api/1156/40360#MaterialInfo)

	* 新增成员：OtherMaterial


### 第 21 次发布

发布时间：2021-03-01 08:01:55

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [VideoEditProjectInput](https://cloud.tencent.com/document/api/1156/40360#VideoEditProjectInput)

	* 新增成员：AspectRatio

* [VideoSegmentationProjectInput](https://cloud.tencent.com/document/api/1156/40360#VideoSegmentationProjectInput)

	* 新增成员：AspectRatio


### 第 20 次发布

发布时间：2021-01-19 08:01:58

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateProject](https://cloud.tencent.com/document/api/1156/40350)

	* <font color="#dd0000">**修改入参**：</font>AspectRatio

* [ExportVideoEditProject](https://cloud.tencent.com/document/api/1156/40353)

	* 新增入参：Operator

* [ImportMediaToProject](https://cloud.tencent.com/document/api/1156/40352)

	* 新增入参：Operator


### 第 19 次发布

发布时间：2020-12-29 08:01:48

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeTeams](https://cloud.tencent.com/document/api/1156/43255)

	* 新增入参：Offset, Limit

	* <font color="#dd0000">**修改入参**：</font>TeamIds

	* 新增出参：TotalCount

* [ImportMaterial](https://cloud.tencent.com/document/api/1156/43243)

	* 新增入参：SourceType, ExternalMediaInfo

	* <font color="#dd0000">**修改入参**：</font>VodFileId

* [ImportMediaToProject](https://cloud.tencent.com/document/api/1156/40352)

	* 新增入参：SourceType, ExternalMediaInfo

	* <font color="#dd0000">**修改入参**：</font>VodFileId


新增数据结构：

* [ExternalMediaInfo](https://cloud.tencent.com/document/api/1156/40360#ExternalMediaInfo)

修改数据结构：

* [AddMemberInfo](https://cloud.tencent.com/document/api/1156/40360#AddMemberInfo)

	* 新增成员：Role


### 第 18 次发布

发布时间：2020-12-17 08:01:45

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribePlatforms](https://cloud.tencent.com/document/api/1156/51096)

新增数据结构：

* [PlatformInfo](https://cloud.tencent.com/document/api/1156/40360#PlatformInfo)

### 第 17 次发布

发布时间：2020-12-15 08:03:01

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [ExportVideoByVideoSegmentationData](https://cloud.tencent.com/document/api/1156/50982)
* [GenerateVideoSegmentationSchemeByAi](https://cloud.tencent.com/document/api/1156/50981)

修改接口：

* [CreateProject](https://cloud.tencent.com/document/api/1156/40350)

	* 新增入参：VideoSegmentationProjectInput


新增数据结构：

* [VideoSegmentationProjectInput](https://cloud.tencent.com/document/api/1156/40360#VideoSegmentationProjectInput)

### 第 16 次发布

发布时间：2020-12-04 08:01:32

本次发布包含了以下内容：

改善已有的文档。

新增数据结构：

* [KuaishouPublishInfo](https://cloud.tencent.com/document/api/1156/40360#KuaishouPublishInfo)
* [PenguinMediaPlatformPublishInfo](https://cloud.tencent.com/document/api/1156/40360#PenguinMediaPlatformPublishInfo)
* [ThirdPartyPublishInfo](https://cloud.tencent.com/document/api/1156/40360#ThirdPartyPublishInfo)
* [WeiboPublishInfo](https://cloud.tencent.com/document/api/1156/40360#WeiboPublishInfo)

修改数据结构：

* [CMEExportInfo](https://cloud.tencent.com/document/api/1156/40360#CMEExportInfo)

	* 新增成员：ThirdPartyPublishInfos

* [VODExportInfo](https://cloud.tencent.com/document/api/1156/40360#VODExportInfo)

	* 新增成员：ThirdPartyPublishInfos

* [VideoEditProjectInput](https://cloud.tencent.com/document/api/1156/40360#VideoEditProjectInput)

	* 新增成员：VideoEditTemplateId


### 第 15 次发布

发布时间：2020-10-30 08:01:35

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateProject](https://cloud.tencent.com/document/api/1156/40350)

	* 新增入参：LiveStreamClipProjectInput, VideoEditProjectInput


新增数据结构：

* [AudioTrackItem](https://cloud.tencent.com/document/api/1156/40360#AudioTrackItem)
* [EmptyTrackItem](https://cloud.tencent.com/document/api/1156/40360#EmptyTrackItem)
* [LiveStreamClipProjectInput](https://cloud.tencent.com/document/api/1156/40360#LiveStreamClipProjectInput)
* [MediaTrack](https://cloud.tencent.com/document/api/1156/40360#MediaTrack)
* [MediaTrackItem](https://cloud.tencent.com/document/api/1156/40360#MediaTrackItem)
* [VideoEditProjectInput](https://cloud.tencent.com/document/api/1156/40360#VideoEditProjectInput)
* [VideoTrackItem](https://cloud.tencent.com/document/api/1156/40360#VideoTrackItem)

### 第 14 次发布

发布时间：2020-08-24 08:01:09

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateProject](https://cloud.tencent.com/document/api/1156/40350)

	* 新增入参：Description, SwitcherProjectInput


新增数据结构：

* [SwitcherPgmOutputConfig](https://cloud.tencent.com/document/api/1156/40360#SwitcherPgmOutputConfig)
* [SwitcherProjectInput](https://cloud.tencent.com/document/api/1156/40360#SwitcherProjectInput)

### 第 13 次发布

发布时间：2020-08-20 08:04:39

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [VideoEditProjectOutput](https://cloud.tencent.com/document/api/1156/40360#VideoEditProjectOutput)

	* 新增成员：MaterialId


### 第 12 次发布

发布时间：2020-07-10 08:03:28

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [AudioMaterial](https://cloud.tencent.com/document/api/1156/40360#AudioMaterial)

	* 新增成员：OriginalUrl, VodFileId

* [ImageMaterial](https://cloud.tencent.com/document/api/1156/40360#ImageMaterial)

	* 新增成员：OriginalUrl, VodFileId

* [VideoMaterial](https://cloud.tencent.com/document/api/1156/40360#VideoMaterial)

	* 新增成员：OriginalUrl, VodFileId


### 第 11 次发布

发布时间：2020-05-26 08:03:13

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [SearchMaterial](https://cloud.tencent.com/document/api/1156/43240)

	* 新增入参：Tags


新增数据结构：

* [MaterialTagInfo](https://cloud.tencent.com/document/api/1156/40360#MaterialTagInfo)

修改数据结构：

* [MaterialBasicInfo](https://cloud.tencent.com/document/api/1156/40360#MaterialBasicInfo)

	* 新增成员：TagInfoSet


### 第 10 次发布

发布时间：2020-05-15 08:03:10

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateLink](https://cloud.tencent.com/document/api/1156/43366)

	* <font color="#dd0000">**删除入参**：</font>Tags

* [SearchMaterial](https://cloud.tencent.com/document/api/1156/43240)

	* <font color="#dd0000">**删除入参**：</font>Tags


### 第 9 次发布

发布时间：2020-05-14 08:04:13

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [ImportMaterial](https://cloud.tencent.com/document/api/1156/43243)

	* <font color="#dd0000">**删除入参**：</font>Tags

* [ModifyMaterial](https://cloud.tencent.com/document/api/1156/43241)

	* <font color="#dd0000">**删除入参**：</font>Tags


修改数据结构：

* [MaterialBasicInfo](https://cloud.tencent.com/document/api/1156/40360#MaterialBasicInfo)

	* <font color="#dd0000">**删除成员**：</font>TagSet


### 第 8 次发布

发布时间：2020-04-30 08:03:12

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [ExportVideoByEditorTrackData](https://cloud.tencent.com/document/api/1156/44159)

### 第 7 次发布

发布时间：2020-04-29 08:03:24

本次发布包含了以下内容：

改善已有的文档。

新增数据结构：

* [MaterialStatus](https://cloud.tencent.com/document/api/1156/40360#MaterialStatus)

<font color="#dd0000">**删除数据结构**：</font>

* MaterialBaseInfo

修改数据结构：

* [AudioMaterial](https://cloud.tencent.com/document/api/1156/40360#AudioMaterial)

	* 新增成员：MaterialStatus

* [VideoEditProjectOutput](https://cloud.tencent.com/document/api/1156/40360#VideoEditProjectOutput)

	* <font color="#dd0000">**删除成员**：</font>MaterialBaseInfo

* [VideoMaterial](https://cloud.tencent.com/document/api/1156/40360#VideoMaterial)

	* 新增成员：MaterialStatus


### 第 6 次发布

发布时间：2020-04-13 08:02:23

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateLink](https://cloud.tencent.com/document/api/1156/43366)

### 第 5 次发布

发布时间：2020-04-10 08:02:25

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [MoveClass](https://cloud.tencent.com/document/api/1156/43351)

### 第 4 次发布

发布时间：2020-04-09 08:02:18

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [AddTeamMember](https://cloud.tencent.com/document/api/1156/43261)
* [CreateClass](https://cloud.tencent.com/document/api/1156/43265)
* [CreateTeam](https://cloud.tencent.com/document/api/1156/43260)
* [DeleteClass](https://cloud.tencent.com/document/api/1156/43264)
* [DeleteMaterial](https://cloud.tencent.com/document/api/1156/43246)
* [DeleteTeam](https://cloud.tencent.com/document/api/1156/43259)
* [DeleteTeamMembers](https://cloud.tencent.com/document/api/1156/43258)
* [DescribeClass](https://cloud.tencent.com/document/api/1156/43263)
* [DescribeJoinTeams](https://cloud.tencent.com/document/api/1156/43257)
* [DescribeMaterials](https://cloud.tencent.com/document/api/1156/43245)
* [DescribeResourceAuthorization](https://cloud.tencent.com/document/api/1156/43251)
* [DescribeSharedSpace](https://cloud.tencent.com/document/api/1156/43250)
* [DescribeTeamMembers](https://cloud.tencent.com/document/api/1156/43256)
* [DescribeTeams](https://cloud.tencent.com/document/api/1156/43255)
* [FlattenListMedia](https://cloud.tencent.com/document/api/1156/43244)
* [GrantResourceAuthorization](https://cloud.tencent.com/document/api/1156/43249)
* [ImportMaterial](https://cloud.tencent.com/document/api/1156/43243)
* [ListMedia](https://cloud.tencent.com/document/api/1156/43242)
* [ModifyMaterial](https://cloud.tencent.com/document/api/1156/43241)
* [ModifyTeam](https://cloud.tencent.com/document/api/1156/43254)
* [ModifyTeamMember](https://cloud.tencent.com/document/api/1156/43253)
* [RevokeResourceAuthorization](https://cloud.tencent.com/document/api/1156/43248)
* [SearchMaterial](https://cloud.tencent.com/document/api/1156/43240)

修改接口：

* [DescribeProjects](https://cloud.tencent.com/document/api/1156/40348)

	* 新增入参：Sort

* [ModifyProject](https://cloud.tencent.com/document/api/1156/40347)

	* 新增入参：AspectRatio


新增数据结构：

* [AddMemberInfo](https://cloud.tencent.com/document/api/1156/40360#AddMemberInfo)
* [AudioMaterial](https://cloud.tencent.com/document/api/1156/40360#AudioMaterial)
* [AuthorizationInfo](https://cloud.tencent.com/document/api/1156/40360#AuthorizationInfo)
* [Authorizer](https://cloud.tencent.com/document/api/1156/40360#Authorizer)
* [ClassInfo](https://cloud.tencent.com/document/api/1156/40360#ClassInfo)
* [ImageMaterial](https://cloud.tencent.com/document/api/1156/40360#ImageMaterial)
* [IntegerRange](https://cloud.tencent.com/document/api/1156/40360#IntegerRange)
* [JoinTeamInfo](https://cloud.tencent.com/document/api/1156/40360#JoinTeamInfo)
* [LinkMaterial](https://cloud.tencent.com/document/api/1156/40360#LinkMaterial)
* [LinkMaterialInfo](https://cloud.tencent.com/document/api/1156/40360#LinkMaterialInfo)
* [MaterialBasicInfo](https://cloud.tencent.com/document/api/1156/40360#MaterialBasicInfo)
* [MaterialInfo](https://cloud.tencent.com/document/api/1156/40360#MaterialInfo)
* [MediaImageSpriteInfo](https://cloud.tencent.com/document/api/1156/40360#MediaImageSpriteInfo)
* [Resource](https://cloud.tencent.com/document/api/1156/40360#Resource)
* [SearchScope](https://cloud.tencent.com/document/api/1156/40360#SearchScope)
* [SortBy](https://cloud.tencent.com/document/api/1156/40360#SortBy)
* [TeamInfo](https://cloud.tencent.com/document/api/1156/40360#TeamInfo)
* [TeamMemberInfo](https://cloud.tencent.com/document/api/1156/40360#TeamMemberInfo)
* [TimeRange](https://cloud.tencent.com/document/api/1156/40360#TimeRange)
* [VideoMaterial](https://cloud.tencent.com/document/api/1156/40360#VideoMaterial)

### 第 3 次发布

发布时间：2020-03-27 08:01:55

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [MediaMetaData](https://cloud.tencent.com/document/api/1156/40360#MediaMetaData)

	* 新增成员：Rotate


### 第 2 次发布

发布时间：2020-03-16 08:01:06

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [ProjectInfo](https://cloud.tencent.com/document/api/1156/40360#ProjectInfo)

	* 新增成员：CoverUrl, CreateTime, UpdateTime


### 第 1 次发布

发布时间：2019-12-18 16:28:24

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateProject](https://cloud.tencent.com/document/api/1156/40350)
* [DeleteLoginStatus](https://cloud.tencent.com/document/api/1156/40356)
* [DeleteProject](https://cloud.tencent.com/document/api/1156/40349)
* [DescribeLoginStatus](https://cloud.tencent.com/document/api/1156/40355)
* [DescribeProjects](https://cloud.tencent.com/document/api/1156/40348)
* [DescribeTaskDetail](https://cloud.tencent.com/document/api/1156/40359)
* [DescribeTasks](https://cloud.tencent.com/document/api/1156/40358)
* [ExportVideoEditProject](https://cloud.tencent.com/document/api/1156/40353)
* [ImportMediaToProject](https://cloud.tencent.com/document/api/1156/40352)
* [ModifyProject](https://cloud.tencent.com/document/api/1156/40347)

新增数据结构：

* [AudioStreamInfo](https://cloud.tencent.com/document/api/1156/40360#AudioStreamInfo)
* [CMEExportInfo](https://cloud.tencent.com/document/api/1156/40360#CMEExportInfo)
* [Entity](https://cloud.tencent.com/document/api/1156/40360#Entity)
* [LoginStatusInfo](https://cloud.tencent.com/document/api/1156/40360#LoginStatusInfo)
* [MaterialBaseInfo](https://cloud.tencent.com/document/api/1156/40360#MaterialBaseInfo)
* [MediaMetaData](https://cloud.tencent.com/document/api/1156/40360#MediaMetaData)
* [ProjectInfo](https://cloud.tencent.com/document/api/1156/40360#ProjectInfo)
* [TaskBaseInfo](https://cloud.tencent.com/document/api/1156/40360#TaskBaseInfo)
* [VODExportInfo](https://cloud.tencent.com/document/api/1156/40360#VODExportInfo)
* [VideoEditProjectOutput](https://cloud.tencent.com/document/api/1156/40360#VideoEditProjectOutput)
* [VideoStreamInfo](https://cloud.tencent.com/document/api/1156/40360#VideoStreamInfo)




## 消息队列 CMQ(cmq) 版本：2019-03-04

### 第 2 次发布

发布时间：2022-03-03 08:03:36

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [QueueSet](https://cloud.tencent.com/document/api/406/42640#QueueSet)

	* 新增成员：Migrate

* [TopicSet](https://cloud.tencent.com/document/api/406/42640#TopicSet)

	* 新增成员：Migrate


### 第 1 次发布

发布时间：2020-03-19 11:37:32

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [ClearQueue](https://cloud.tencent.com/document/api/406/42628)
* [ClearSubscriptionFilterTags](https://cloud.tencent.com/document/api/406/42634)
* [CreateQueue](https://cloud.tencent.com/document/api/406/42627)
* [CreateSubscribe](https://cloud.tencent.com/document/api/406/42633)
* [CreateTopic](https://cloud.tencent.com/document/api/406/42639)
* [DeleteQueue](https://cloud.tencent.com/document/api/406/42626)
* [DeleteSubscribe](https://cloud.tencent.com/document/api/406/42632)
* [DeleteTopic](https://cloud.tencent.com/document/api/406/42638)
* [DescribeDeadLetterSourceQueues](https://cloud.tencent.com/document/api/406/42625)
* [DescribeQueueDetail](https://cloud.tencent.com/document/api/406/42624)
* [DescribeSubscriptionDetail](https://cloud.tencent.com/document/api/406/42631)
* [DescribeTopicDetail](https://cloud.tencent.com/document/api/406/42637)
* [ModifyQueueAttribute](https://cloud.tencent.com/document/api/406/42623)
* [ModifySubscriptionAttribute](https://cloud.tencent.com/document/api/406/42630)
* [ModifyTopicAttribute](https://cloud.tencent.com/document/api/406/42636)
* [RewindQueue](https://cloud.tencent.com/document/api/406/42622)
* [UnbindDeadLetter](https://cloud.tencent.com/document/api/406/42621)

新增数据结构：

* [DeadLetterPolicy](https://cloud.tencent.com/document/api/406/42640#DeadLetterPolicy)
* [DeadLetterSource](https://cloud.tencent.com/document/api/406/42640#DeadLetterSource)
* [Filter](https://cloud.tencent.com/document/api/406/42640#Filter)
* [QueueSet](https://cloud.tencent.com/document/api/406/42640#QueueSet)
* [Subscription](https://cloud.tencent.com/document/api/406/42640#Subscription)
* [Tag](https://cloud.tencent.com/document/api/406/42640#Tag)
* [TopicSet](https://cloud.tencent.com/document/api/406/42640#TopicSet)
* [TransactionPolicy](https://cloud.tencent.com/document/api/406/42640#TransactionPolicy)




## 内容安全(cms) 版本：2019-03-21

### 第 17 次发布

发布时间：2023-07-11 01:11:56

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateKeywordsSamples](https://cloud.tencent.com/document/api/669/93038)

	* 新增出参：SuccessInfos

* [DeleteLibSamples](https://cloud.tencent.com/document/api/669/93037)

	* 新增入参：SampleContents

* [DescribeLibSamples](https://cloud.tencent.com/document/api/669/93035)

	* 新增入参：SampleIDs


### 第 16 次发布

发布时间：2023-05-31 21:26:41

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateKeywordsSamples](https://cloud.tencent.com/document/api/669/93038)
* [DeleteLibSamples](https://cloud.tencent.com/document/api/669/93037)
* [DescribeKeywordsLibs](https://cloud.tencent.com/document/api/669/93036)
* [DescribeLibSamples](https://cloud.tencent.com/document/api/669/93035)

<font color="#dd0000">**删除接口**：</font>

* CreateFileSample
* CreateTextSample
* DeleteFileSample
* DeleteTextSample
* DescribeFileSample
* DescribeTextSample
* ManualReview

新增数据结构：

* [DeleteSampleDetails](https://cloud.tencent.com/document/api/669/34506#DeleteSampleDetails)
* [Filters](https://cloud.tencent.com/document/api/669/34506#Filters)
* [InvalidSample](https://cloud.tencent.com/document/api/669/34506#InvalidSample)
* [KeywordsLibInfo](https://cloud.tencent.com/document/api/669/34506#KeywordsLibInfo)
* [UserKeyword](https://cloud.tencent.com/document/api/669/34506#UserKeyword)
* [UserKeywordInfo](https://cloud.tencent.com/document/api/669/34506#UserKeywordInfo)

<font color="#dd0000">**删除数据结构**：</font>

* FileSample
* FileSampleInfo
* Filter
* ManualReviewContent
* ManualReviewData
* TextSample

修改数据结构：

* [CodeDetail](https://cloud.tencent.com/document/api/669/34506#CodeDetail)

	* 新增成员：StrCharset, QrCodePosition, StrQrCodeText, Uint32QrCodeType


### 第 15 次发布

发布时间：2020-07-30 08:07:34

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [TextData](https://cloud.tencent.com/document/api/669/34506#TextData)

	* 新增成员：DataId, Extra


### 第 14 次发布

发布时间：2020-07-24 08:07:51

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [ManualReview](https://cloud.tencent.com/document/api/669/46804)

新增数据结构：

* [ManualReviewContent](https://cloud.tencent.com/document/api/669/34506#ManualReviewContent)
* [ManualReviewData](https://cloud.tencent.com/document/api/669/34506#ManualReviewData)

修改数据结构：

* [RiskDetails](https://cloud.tencent.com/document/api/669/34506#RiskDetails)

	* 新增成员：Label


### 第 13 次发布

发布时间：2020-07-17 08:07:40

本次发布包含了以下内容：

改善已有的文档。

新增数据结构：

* [RiskDetails](https://cloud.tencent.com/document/api/669/34506#RiskDetails)

修改数据结构：

* [TextData](https://cloud.tencent.com/document/api/669/34506#TextData)

	* 新增成员：RiskDetails


### 第 12 次发布

发布时间：2020-07-09 08:07:45

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [TextModeration](https://cloud.tencent.com/document/api/669/34502)

	* 新增入参：Device, User


新增数据结构：

* [Device](https://cloud.tencent.com/document/api/669/34506#Device)
* [User](https://cloud.tencent.com/document/api/669/34506#User)

修改数据结构：

* [CustomResult](https://cloud.tencent.com/document/api/669/34506#CustomResult)

	* 新增成员：Type


### 第 11 次发布

发布时间：2020-05-27 08:08:35

本次发布包含了以下内容：

改善已有的文档。

<font color="#dd0000">**删除接口**：</font>

* CommonMediaRecognition

<font color="#dd0000">**删除数据结构**：</font>

* CallBackAck
* CallBackData
* ContentMsgGjh
* MediaGjh
* MediaInfoTypeGjh
* MessageCommonGjh
* MessageContentGjh
* MessageIdGjh
* UserInfoGjh

### 第 10 次发布

发布时间：2020-05-22 20:13:51

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CommonMediaRecognition](https://cloud.tencent.com/document/api/669/44845)

新增数据结构：

* [CallBackAck](https://cloud.tencent.com/document/api/669/34506#CallBackAck)
* [CallBackData](https://cloud.tencent.com/document/api/669/34506#CallBackData)
* [ContentMsgGjh](https://cloud.tencent.com/document/api/669/34506#ContentMsgGjh)
* [MediaGjh](https://cloud.tencent.com/document/api/669/34506#MediaGjh)
* [MediaInfoTypeGjh](https://cloud.tencent.com/document/api/669/34506#MediaInfoTypeGjh)
* [MessageCommonGjh](https://cloud.tencent.com/document/api/669/34506#MessageCommonGjh)
* [MessageContentGjh](https://cloud.tencent.com/document/api/669/34506#MessageContentGjh)
* [MessageIdGjh](https://cloud.tencent.com/document/api/669/34506#MessageIdGjh)
* [UserInfoGjh](https://cloud.tencent.com/document/api/669/34506#UserInfoGjh)

### 第 9 次发布

发布时间：2020-05-15 08:07:21

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [TextModeration](https://cloud.tencent.com/document/api/669/34502)

	* 新增入参：BizType, DataId, SdkAppId


新增数据结构：

* [Coordinate](https://cloud.tencent.com/document/api/669/34506#Coordinate)
* [CustomResult](https://cloud.tencent.com/document/api/669/34506#CustomResult)
* [DetailResult](https://cloud.tencent.com/document/api/669/34506#DetailResult)
* [OCRItem](https://cloud.tencent.com/document/api/669/34506#OCRItem)

修改数据结构：

* [OCRDetect](https://cloud.tencent.com/document/api/669/34506#OCRDetect)

	* 新增成员：Item

* [TextData](https://cloud.tencent.com/document/api/669/34506#TextData)

	* 新增成员：CustomResult, DetailResult, BizType, EvilLabel, Score, Suggestion


### 第 8 次发布

发布时间：2020-05-11 10:03:36

本次发布包含了以下内容：

改善已有的文档。

新增数据结构：

* [PhoneDetect](https://cloud.tencent.com/document/api/669/34506#PhoneDetect)

修改数据结构：

* [ImageData](https://cloud.tencent.com/document/api/669/34506#ImageData)

	* 新增成员：PhoneDetect


### 第 7 次发布

发布时间：2020-03-12 22:16:03

本次发布包含了以下内容：

改善已有的文档。

<font color="#dd0000">**删除接口**：</font>

* AudioModeration
* DescribeModerationOverview
* VideoModeration

<font color="#dd0000">**删除数据结构**：</font>

* OverviewRecord

### 第 6 次发布

发布时间：2020-03-10 00:51:35

本次发布包含了以下内容：

改善已有的文档。

新增数据结构：

* [TextOutputComm](https://cloud.tencent.com/document/api/669/34506#TextOutputComm)
* [TextOutputID](https://cloud.tencent.com/document/api/669/34506#TextOutputID)
* [TextOutputRes](https://cloud.tencent.com/document/api/669/34506#TextOutputRes)

修改数据结构：

* [TextData](https://cloud.tencent.com/document/api/669/34506#TextData)

	* 新增成员：Common, ID, Res


### 第 5 次发布

发布时间：2020-02-27 20:16:44

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateTextSample](https://cloud.tencent.com/document/api/669/35620)

	* 新增入参：Test

	* 新增出参：ErrMsg


新增数据结构：

* [Logo](https://cloud.tencent.com/document/api/669/34506#Logo)
* [LogoDetail](https://cloud.tencent.com/document/api/669/34506#LogoDetail)
* [RrectF](https://cloud.tencent.com/document/api/669/34506#RrectF)

修改数据结构：

* [FileSample](https://cloud.tencent.com/document/api/669/34506#FileSample)

	* 新增成员：CompressFileUrl

* [FileSampleInfo](https://cloud.tencent.com/document/api/669/34506#FileSampleInfo)

	* 新增成员：CompressFileUrl

* [ImageData](https://cloud.tencent.com/document/api/669/34506#ImageData)

	* 新增成员：LogoDetect

* [ImagePolityDetect](https://cloud.tencent.com/document/api/669/34506#ImagePolityDetect)

	* 新增成员：PolityLogoDetail


### 第 4 次发布

发布时间：2019-10-11 14:21:52

本次发布包含了以下内容：

改善已有的文档。

新增数据结构：

* [CodeDetail](https://cloud.tencent.com/document/api/669/34506#CodeDetail)
* [CodeDetect](https://cloud.tencent.com/document/api/669/34506#CodeDetect)
* [CodePosition](https://cloud.tencent.com/document/api/669/34506#CodePosition)

修改数据结构：

* [ImageData](https://cloud.tencent.com/document/api/669/34506#ImageData)

	* 新增成员：CodeDetect


### 第 3 次发布

发布时间：2019-08-15 23:21:19

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateFileSample](https://cloud.tencent.com/document/api/669/37189)
* [DeleteFileSample](https://cloud.tencent.com/document/api/669/37188)
* [DescribeFileSample](https://cloud.tencent.com/document/api/669/37187)

新增数据结构：

* [FileSample](https://cloud.tencent.com/document/api/669/34506#FileSample)
* [FileSampleInfo](https://cloud.tencent.com/document/api/669/34506#FileSampleInfo)
* [OCRDetect](https://cloud.tencent.com/document/api/669/34506#OCRDetect)

修改数据结构：

* [ImageData](https://cloud.tencent.com/document/api/669/34506#ImageData)

	* 新增成员：OCRDetect


### 第 2 次发布

发布时间：2019-06-21 18:58:55

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateTextSample](https://cloud.tencent.com/document/api/669/35620)
* [DeleteTextSample](https://cloud.tencent.com/document/api/669/35619)
* [DescribeTextSample](https://cloud.tencent.com/document/api/669/35618)

新增数据结构：

* [Filter](https://cloud.tencent.com/document/api/669/34506#Filter)
* [ImageHotDetect](https://cloud.tencent.com/document/api/669/34506#ImageHotDetect)
* [TextSample](https://cloud.tencent.com/document/api/669/34506#TextSample)

修改数据结构：

* [ImageData](https://cloud.tencent.com/document/api/669/34506#ImageData)

	* 新增成员：HotDetect

* [ImagePolityDetect](https://cloud.tencent.com/document/api/669/34506#ImagePolityDetect)

	* 新增成员：PolityItems


### 第 1 次发布

发布时间：2019-04-26 16:49:17

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [AudioModeration](https://cloud.tencent.com/document/api/669/34505)
* [DescribeModerationOverview](https://cloud.tencent.com/document/api/669/34504)
* [ImageModeration](https://cloud.tencent.com/document/api/669/34503)
* [TextModeration](https://cloud.tencent.com/document/api/669/34502)
* [VideoModeration](https://cloud.tencent.com/document/api/669/34501)

新增数据结构：

* [ImageData](https://cloud.tencent.com/document/api/669/34506#ImageData)
* [ImageIllegalDetect](https://cloud.tencent.com/document/api/669/34506#ImageIllegalDetect)
* [ImagePolityDetect](https://cloud.tencent.com/document/api/669/34506#ImagePolityDetect)
* [ImagePornDetect](https://cloud.tencent.com/document/api/669/34506#ImagePornDetect)
* [ImageTerrorDetect](https://cloud.tencent.com/document/api/669/34506#ImageTerrorDetect)
* [OverviewRecord](https://cloud.tencent.com/document/api/669/34506#OverviewRecord)
* [Similar](https://cloud.tencent.com/document/api/669/34506#Similar)
* [TextData](https://cloud.tencent.com/document/api/669/34506#TextData)




## 配置审计(config) 版本：2022-08-02

### 第 2 次发布

发布时间：2023-11-27 00:06:03

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [PutEvaluations](https://cloud.tencent.com/document/api/1579/101968)

新增数据结构：

* [Evaluation](https://cloud.tencent.com/document/api/1579/101783#Evaluation)

### 第 1 次发布

发布时间：2023-11-21 15:26:06

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [ListAggregateConfigRules](https://cloud.tencent.com/document/api/1579/101782)
* [ListConfigRules](https://cloud.tencent.com/document/api/1579/101781)

新增数据结构：

* [Annotation](https://cloud.tencent.com/document/api/1579/101783#Annotation)
* [ConfigRule](https://cloud.tencent.com/document/api/1579/101783#ConfigRule)
* [InputParameter](https://cloud.tencent.com/document/api/1579/101783#InputParameter)
* [InputParameterForManage](https://cloud.tencent.com/document/api/1579/101783#InputParameterForManage)
* [SourceConditionForManage](https://cloud.tencent.com/document/api/1579/101783#SourceConditionForManage)
* [Tag](https://cloud.tencent.com/document/api/1579/101783#Tag)
* [TriggerType](https://cloud.tencent.com/document/api/1579/101783#TriggerType)




## 腾讯微卡收付通(cpdp) 版本：2019-08-20

### 第 101 次发布

发布时间：2023-09-21 02:09:54

本次发布包含了以下内容：

改善已有的文档。

<font color="#dd0000">**删除接口**：</font>

* RevResigterBillSupportWithdraw

### 第 100 次发布

发布时间：2023-06-19 01:11:32

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [PayeeAccountBalanceResult](https://cloud.tencent.com/document/api/1122/40683#PayeeAccountBalanceResult)

	* 新增成员：PaidIncomeTax, InPayIncomeTax, PaidValueAddedTax, InPayValueAddedTax, PaidAttachTax, InPayAttachTax


### 第 99 次发布

发布时间：2023-05-01 01:14:33

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [ApplyFlexWechatPreAuth](https://cloud.tencent.com/document/api/#/#)
* [QueryFlexWechatAuthResult](https://cloud.tencent.com/document/api/#/#)

新增数据结构：

* [QueryWechatAuthResult](https://cloud.tencent.com/document/api/1122/40683#QueryWechatAuthResult)
* [WechatPreAuthResult](https://cloud.tencent.com/document/api/1122/40683#WechatPreAuthResult)

### 第 98 次发布

发布时间：2023-04-28 01:15:09

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [PaymentOrderResult](https://cloud.tencent.com/document/api/1122/40683#PaymentOrderResult)

	* 新增成员：FundingAccountSubType


### 第 97 次发布

发布时间：2022-12-28 11:40:24

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [AddFlexFundingAccount](https://cloud.tencent.com/document/api/#/#)
* [ModifyFlexFundingAccount](https://cloud.tencent.com/document/api/#/#)
* [QueryFlexServiceProviderAccountBalance](https://cloud.tencent.com/document/api/#/#)

新增数据结构：

* [PayeeFundingAccountResult](https://cloud.tencent.com/document/api/1122/40683#PayeeFundingAccountResult)
* [ServiceProviderAccountBalanceResult](https://cloud.tencent.com/document/api/1122/40683#ServiceProviderAccountBalanceResult)

### 第 96 次发布

发布时间：2022-12-14 11:33:48

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [QueryFlexPlatformAccountBalance](https://cloud.tencent.com/document/api/#/#)

新增数据结构：

* [PlatformAccountBalanceResult](https://cloud.tencent.com/document/api/1122/40683#PlatformAccountBalanceResult)

### 第 95 次发布

发布时间：2022-12-08 01:21:58

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [PaymentOrderResult](https://cloud.tencent.com/document/api/1122/40683#PaymentOrderResult)

	* 新增成员：FailReason

* [PaymentOrderStatusResult](https://cloud.tencent.com/document/api/1122/40683#PaymentOrderStatusResult)

	* 新增成员：FailReason


### 第 94 次发布

发布时间：2022-12-05 06:33:06

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [QueryFlexPayeeAccountBalance](https://cloud.tencent.com/document/api/#/#)

	* 新增入参：SnapshotDate


修改数据结构：

* [ApplyFlexPaymentResult](https://cloud.tencent.com/document/api/1122/40683#ApplyFlexPaymentResult)

	* 新增成员：Vat, IndividualIncomeTax, AdditionalTaxSum, AdditionalTaxItem

* [PaymentOrderResult](https://cloud.tencent.com/document/api/1122/40683#PaymentOrderResult)

	* 新增成员：Vat, IndividualIncomeTax, AdditionalTaxSum, AdditionalTaxItem


### 第 93 次发布

发布时间：2022-11-25 06:20:42

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [CloudOrderReturn](https://cloud.tencent.com/document/api/1122/40683#CloudOrderReturn)

	* 新增成员：TotalPlatformIncome, TotalMchIncome


### 第 92 次发布

发布时间：2022-10-26 06:23:03

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [UnifiedCloudOrder](https://cloud.tencent.com/document/api/#/#)

	* 新增入参：ExternalAttachmentDataList


新增数据结构：

* [CloudExternalAttachmentData](https://cloud.tencent.com/document/api/1122/40683#CloudExternalAttachmentData)

修改数据结构：

* [CloudSubOrder](https://cloud.tencent.com/document/api/1122/40683#CloudSubOrder)

	* 新增成员：ExternalAttachmentDataList


### 第 91 次发布

发布时间：2022-10-25 06:22:30

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [BindOpenBankProfitSharePayee](https://cloud.tencent.com/document/api/#/#)
* [QueryOpenBankProfitSharePayee](https://cloud.tencent.com/document/api/#/#)

修改接口：

* [ApplyOpenBankSettleOrder](https://cloud.tencent.com/document/api/#/#)

	* 新增入参：Remark, ExternalSettleData, Environment

* [CreateCloudSubMerchant](https://cloud.tencent.com/document/api/#/#)

	* 新增出参：ChannelAppId

* [DownloadBill](https://cloud.tencent.com/document/api/#/#)

	* 新增出参：StateType

* [QueryOpenBankSettleOrder](https://cloud.tencent.com/document/api/#/#)

	* 新增入参：Environment

* [QueryRefund](https://cloud.tencent.com/document/api/#/#)

	* 新增出参：ChannelExternalOrderId, ChannelExternalRefundId, ChannelOrderId, TotalRefundAmt, CurrencyType, OutTradeNo, RefundId, MidasAppId, UsedRefundId, SubRefundList


新增数据结构：

* [BindOpenBankProfitSharePayeeResult](https://cloud.tencent.com/document/api/1122/40683#BindOpenBankProfitSharePayeeResult)
* [OldAttachmentInfo](https://cloud.tencent.com/document/api/1122/40683#OldAttachmentInfo)
* [OldChannelExternalUserInfo](https://cloud.tencent.com/document/api/1122/40683#OldChannelExternalUserInfo)
* [OldSubRefund](https://cloud.tencent.com/document/api/1122/40683#OldSubRefund)
* [OpenBankProfitSharePayeeInfo](https://cloud.tencent.com/document/api/1122/40683#OpenBankProfitSharePayeeInfo)
* [QueryOpenBankProfitSharePayeeResult](https://cloud.tencent.com/document/api/1122/40683#QueryOpenBankProfitSharePayeeResult)

修改数据结构：

* [CloudOrderReturn](https://cloud.tencent.com/document/api/1122/40683#CloudOrderReturn)

	* 新增成员：SubAppId, PayScene, PaymentMethod

* [CloudSubOrderReturn](https://cloud.tencent.com/document/api/1122/40683#CloudSubOrderReturn)

	* 新增成员：ChannelSubPayOrderId, ProductId

* [QueryOpenBankSettleOrderResult](https://cloud.tencent.com/document/api/1122/40683#QueryOpenBankSettleOrderResult)

	* 新增成员：Currency

* [QueryOrderOutOrderList](https://cloud.tencent.com/document/api/1122/40683#QueryOrderOutOrderList)

	* 新增成员：SettleCheck, ChannelExternalUserInfoList, AttachmentInfoList


### 第 90 次发布

发布时间：2022-10-20 06:16:38

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateOpenBankGlobalPaymentOrder](https://cloud.tencent.com/document/api/#/#)

	* 新增入参：Environment


### 第 89 次发布

发布时间：2022-10-19 06:17:23

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateOpenBankGlobalPaymentOrder](https://cloud.tencent.com/document/api/#/#)

新增数据结构：

* [CreateOpenBankUnifiedOrderPaymentResult](https://cloud.tencent.com/document/api/1122/40683#CreateOpenBankUnifiedOrderPaymentResult)
* [OpenBankBillingInfo](https://cloud.tencent.com/document/api/1122/40683#OpenBankBillingInfo)
* [OpenBankOrderRedirectInfo](https://cloud.tencent.com/document/api/1122/40683#OpenBankOrderRedirectInfo)
* [OpenBankShippingInfo](https://cloud.tencent.com/document/api/1122/40683#OpenBankShippingInfo)

修改数据结构：

* [OpenBankGoodsInfo](https://cloud.tencent.com/document/api/1122/40683#OpenBankGoodsInfo)

	* 新增成员：Sku, Price, Quantity, ProductImage, ProductUrl


### 第 88 次发布

发布时间：2022-10-14 06:19:40

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [CreateOpenBankOrderRechargeResult](https://cloud.tencent.com/document/api/1122/40683#CreateOpenBankOrderRechargeResult)

	* 新增成员：DealStatus, DealMessage, PcWebUrl

* [CreateSinglePaymentData](https://cloud.tencent.com/document/api/1122/40683#CreateSinglePaymentData)

	* 新增成员：AgentId, AgentName


### 第 87 次发布

发布时间：2022-10-11 06:20:53

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [QueryCompanyTitle](https://cloud.tencent.com/document/api/#/#)

新增数据结构：

* [CompanyTitleResult](https://cloud.tencent.com/document/api/1122/40683#CompanyTitleResult)

### 第 86 次发布

发布时间：2022-09-27 06:17:24

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [QueryFinancialDataUrl](https://cloud.tencent.com/document/api/#/#)

修改数据结构：

* [PaymentOrderResult](https://cloud.tencent.com/document/api/1122/40683#PaymentOrderResult)

	* 新增成员：ChannelOrderId


### 第 85 次发布

发布时间：2022-09-09 06:16:31

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [CreateOpenBankOrderPaymentResult](https://cloud.tencent.com/document/api/1122/40683#CreateOpenBankOrderPaymentResult)

	* 新增成员：PayInfo, PayInfoType

* [QueryOpenBankPaymentOrderResult](https://cloud.tencent.com/document/api/1122/40683#QueryOpenBankPaymentOrderResult)

	* 新增成员：TimeFinish


### 第 84 次发布

发布时间：2022-09-05 06:18:54

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateAcct](https://cloud.tencent.com/document/api/#/#)

	* 新增入参：SubMerchantIdType, SubMerchantIdCode


### 第 83 次发布

发布时间：2022-08-31 06:18:54

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [ApplyOpenBankSettleOrder](https://cloud.tencent.com/document/api/#/#)
* [ApplyOpenBankSubMerchantSignOnline](https://cloud.tencent.com/document/api/#/#)
* [QueryOpenBankSettleOrder](https://cloud.tencent.com/document/api/#/#)
* [QueryOpenBankSubMerchantSignOnline](https://cloud.tencent.com/document/api/#/#)

修改接口：

* [AddFlexIdInfo](https://cloud.tencent.com/document/api/#/#)

	* 新增入参：Name

* [RefundOpenBankOrder](https://cloud.tencent.com/document/api/#/#)

	* 新增入参：ProfitShareInfoList


新增数据结构：

* [ApplyOpenBankSettleOrderResult](https://cloud.tencent.com/document/api/1122/40683#ApplyOpenBankSettleOrderResult)
* [ApplyOpenBankSubMerchantSignOnlineResult](https://cloud.tencent.com/document/api/1122/40683#ApplyOpenBankSubMerchantSignOnlineResult)
* [OpenBankProfitShareRespInfo](https://cloud.tencent.com/document/api/1122/40683#OpenBankProfitShareRespInfo)
* [QueryOpenBankSettleOrderResult](https://cloud.tencent.com/document/api/1122/40683#QueryOpenBankSettleOrderResult)
* [QueryOpenBankSubMerchantSignOnlineResult](https://cloud.tencent.com/document/api/1122/40683#QueryOpenBankSubMerchantSignOnlineResult)

修改数据结构：

* [OpenBankQueryRefundOrderResult](https://cloud.tencent.com/document/api/1122/40683#OpenBankQueryRefundOrderResult)

	* 新增成员：ProfitShareRespInfoList

* [QueryOpenBankPaymentOrderResult](https://cloud.tencent.com/document/api/1122/40683#QueryOpenBankPaymentOrderResult)

	* 新增成员：ProfitShareRespInfoList


### 第 82 次发布

发布时间：2022-08-30 06:19:38

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateOpenBankPaymentOrder](https://cloud.tencent.com/document/api/#/#)

	* 新增入参：SettlementRulesInfo, ExternalPaymentData


新增数据结构：

* [OpenBankSettlementRulesInfo](https://cloud.tencent.com/document/api/1122/40683#OpenBankSettlementRulesInfo)

### 第 81 次发布

发布时间：2022-08-11 06:21:37

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [UnifiedCloudOrder](https://cloud.tencent.com/document/api/#/#)

	* 新增入参：ExternalUserInfoList


新增数据结构：

* [CloudExternalUserInfo](https://cloud.tencent.com/document/api/1122/40683#CloudExternalUserInfo)

### 第 80 次发布

发布时间：2022-08-09 12:03:26

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [ApplyFlexPayment](https://cloud.tencent.com/document/api/#/#)

	* 新增入参：NotifyUrl


### 第 79 次发布

发布时间：2022-08-04 06:19:24

本次发布包含了以下内容：

改善已有的文档。

<font color="#dd0000">**删除接口**：</font>

* CreateSinglePay
* QuerySinglePay

<font color="#dd0000">**删除数据结构**：</font>

* CreateSinglePayResult
* QuerySinglePayItem
* QuerySinglePayResult

### 第 78 次发布

发布时间：2022-07-27 06:06:57

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [AmountBeforeTaxResult](https://cloud.tencent.com/document/api/1122/40683#AmountBeforeTaxResult)

	* 新增成员：AmountBeforeTaxWithTwoDigitPrecision


### 第 77 次发布

发布时间：2022-07-13 06:08:02

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [PayeeAccountBalanceResult](https://cloud.tencent.com/document/api/1122/40683#PayeeAccountBalanceResult)

	* 新增成员：SumSettlementAmount


### 第 76 次发布

发布时间：2022-07-11 06:09:01

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateOpenBankVerificationOrder](https://cloud.tencent.com/document/api/#/#)
* [QueryOpenBankVerificationOrder](https://cloud.tencent.com/document/api/#/#)
* [VerifyOpenBankAccount](https://cloud.tencent.com/document/api/#/#)

新增数据结构：

* [CreateOpenBankVerificationResult](https://cloud.tencent.com/document/api/1122/40683#CreateOpenBankVerificationResult)
* [QueryOpenBankVerificationResult](https://cloud.tencent.com/document/api/1122/40683#QueryOpenBankVerificationResult)
* [VerifyOpenBankAccountResult](https://cloud.tencent.com/document/api/1122/40683#VerifyOpenBankAccountResult)

修改数据结构：

* [FlexFundingAccountInfo](https://cloud.tencent.com/document/api/1122/40683#FlexFundingAccountInfo)

	* 新增成员：FundingAccountName


### 第 75 次发布

发布时间：2022-07-08 06:05:56

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [QueryFlexPaymentOrderList](https://cloud.tencent.com/document/api/#/#)

	* <font color="#dd0000">**修改入参**：</font>PayeeId


修改数据结构：

* [FreezeOrderResult](https://cloud.tencent.com/document/api/1122/40683#FreezeOrderResult)

	* 新增成员：PayeeId, OutUserId

* [OrderSummaryResult](https://cloud.tencent.com/document/api/1122/40683#OrderSummaryResult)

	* 新增成员：OutUserId

* [PaymentOrderResult](https://cloud.tencent.com/document/api/1122/40683#PaymentOrderResult)

	* 新增成员：OutUserId

* [SettlementOrderResult](https://cloud.tencent.com/document/api/1122/40683#SettlementOrderResult)

	* 新增成员：PayeeId, OutUserId, OperationType


### 第 74 次发布

发布时间：2022-07-05 06:10:03

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [AddFlexIdInfo](https://cloud.tencent.com/document/api/#/#)
* [AddFlexPhoneNo](https://cloud.tencent.com/document/api/#/#)
* [QueryFlexBillDownloadUrl](https://cloud.tencent.com/document/api/#/#)
* [QueryFlexOrderSummaryList](https://cloud.tencent.com/document/api/#/#)

新增数据结构：

* [FlexBillDownloadUrlResult](https://cloud.tencent.com/document/api/1122/40683#FlexBillDownloadUrlResult)
* [OrderSummaries](https://cloud.tencent.com/document/api/1122/40683#OrderSummaries)
* [OrderSummaryResult](https://cloud.tencent.com/document/api/1122/40683#OrderSummaryResult)

### 第 73 次发布

发布时间：2022-07-04 06:05:30

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [ApplyFlexPayment](https://cloud.tencent.com/document/api/#/#)

	* 新增入参：Environment

* [ApplyFlexSettlement](https://cloud.tencent.com/document/api/#/#)

	* 新增入参：Environment

* [CreateFlexPayee](https://cloud.tencent.com/document/api/#/#)

	* 新增入参：PhoneNo, Environment

* [FreezeFlexBalance](https://cloud.tencent.com/document/api/#/#)

	* 新增入参：Environment

* [ModifyFlexPayeeAccountRightStatus](https://cloud.tencent.com/document/api/#/#)

	* 新增入参：Environment

* [QueryFlexAmountBeforeTax](https://cloud.tencent.com/document/api/#/#)

	* 新增入参：Environment

* [QueryFlexFreezeOrderList](https://cloud.tencent.com/document/api/#/#)

	* 新增入参：Environment

* [QueryFlexPayeeAccountBalance](https://cloud.tencent.com/document/api/#/#)

	* 新增入参：Environment

* [QueryFlexPayeeAccountInfo](https://cloud.tencent.com/document/api/#/#)

	* 新增入参：Environment

* [QueryFlexPayeeAccountList](https://cloud.tencent.com/document/api/#/#)

	* 新增入参：Environment

* [QueryFlexPayeeInfo](https://cloud.tencent.com/document/api/#/#)

	* 新增入参：Environment

* [QueryFlexPaymentOrderList](https://cloud.tencent.com/document/api/#/#)

	* 新增入参：Environment

* [QueryFlexPaymentOrderStatus](https://cloud.tencent.com/document/api/#/#)

	* 新增入参：Environment

* [QueryFlexSettlementOrderList](https://cloud.tencent.com/document/api/#/#)

	* 新增入参：OperationType, Environment


修改数据结构：

* [PaymentOrderResult](https://cloud.tencent.com/document/api/1122/40683#PaymentOrderResult)

	* 新增成员：PayeeId


### 第 72 次发布

发布时间：2022-07-01 06:08:45

本次发布包含了以下内容：

改善已有的文档。

新增数据结构：

* [OpenBankFormInfo](https://cloud.tencent.com/document/api/1122/40683#OpenBankFormInfo)

修改数据结构：

* [OpenBankRedirectInfo](https://cloud.tencent.com/document/api/1122/40683#OpenBankRedirectInfo)

	* 新增成员：FormInfo


### 第 71 次发布

发布时间：2022-06-28 06:07:23

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateOpenBankAggregatedSubMerchantRegistration](https://cloud.tencent.com/document/api/#/#)
* [CreateOpenBankSubMerchantRateConfigure](https://cloud.tencent.com/document/api/#/#)
* [CreateOpenBankUnifiedOrder](https://cloud.tencent.com/document/api/#/#)
* [QueryOpenBankBillDataPage](https://cloud.tencent.com/document/api/#/#)
* [QueryOpenBankRefundOrder](https://cloud.tencent.com/document/api/#/#)
* [QueryOpenBankSubMerchantCredential](https://cloud.tencent.com/document/api/#/#)
* [QueryOpenBankSubMerchantRateConfigure](https://cloud.tencent.com/document/api/#/#)
* [RefundOpenBankOrder](https://cloud.tencent.com/document/api/#/#)
* [UploadOpenBankSubMerchantCredential](https://cloud.tencent.com/document/api/#/#)

新增数据结构：

* [BusinessLicenseInfo](https://cloud.tencent.com/document/api/1122/40683#BusinessLicenseInfo)
* [CreateOpenBankExternalAggregatedSubMerchantRegistrationResult](https://cloud.tencent.com/document/api/1122/40683#CreateOpenBankExternalAggregatedSubMerchantRegistrationResult)
* [CreateOpenBankSubMerchantRateConfigureResult](https://cloud.tencent.com/document/api/1122/40683#CreateOpenBankSubMerchantRateConfigureResult)
* [FeeRangInfo](https://cloud.tencent.com/document/api/1122/40683#FeeRangInfo)
* [LegalPersonInfo](https://cloud.tencent.com/document/api/1122/40683#LegalPersonInfo)
* [NaturalPersonInfo](https://cloud.tencent.com/document/api/1122/40683#NaturalPersonInfo)
* [OpenBankPayLimitInfo](https://cloud.tencent.com/document/api/1122/40683#OpenBankPayLimitInfo)
* [OpenBankQueryRefundOrderResult](https://cloud.tencent.com/document/api/1122/40683#OpenBankQueryRefundOrderResult)
* [OpenBankRefundOrderApplyResult](https://cloud.tencent.com/document/api/1122/40683#OpenBankRefundOrderApplyResult)
* [OpenBankStoreInfo](https://cloud.tencent.com/document/api/1122/40683#OpenBankStoreInfo)
* [OutSubMerchantExtensionInfo](https://cloud.tencent.com/document/api/1122/40683#OutSubMerchantExtensionInfo)
* [QueryOpenBankBillData](https://cloud.tencent.com/document/api/1122/40683#QueryOpenBankBillData)
* [QueryOpenBankBillDataPageResult](https://cloud.tencent.com/document/api/1122/40683#QueryOpenBankBillDataPageResult)
* [QueryOpenBankSubMerchantCredentialResult](https://cloud.tencent.com/document/api/1122/40683#QueryOpenBankSubMerchantCredentialResult)
* [QueryOpenBankSubMerchantRateConfigureResult](https://cloud.tencent.com/document/api/1122/40683#QueryOpenBankSubMerchantRateConfigureResult)
* [SettleInfo](https://cloud.tencent.com/document/api/1122/40683#SettleInfo)
* [UploadOpenBankSubMerchantCredentialResult](https://cloud.tencent.com/document/api/1122/40683#UploadOpenBankSubMerchantCredentialResult)

### 第 70 次发布

发布时间：2022-06-24 06:09:13

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [QueryOpenBankPaymentOrderResult](https://cloud.tencent.com/document/api/1122/40683#QueryOpenBankPaymentOrderResult)

	* 新增成员：FeeAmount, FeeRate


### 第 69 次发布

发布时间：2022-06-22 06:05:01

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [OpenBankGoodsInfo](https://cloud.tencent.com/document/api/1122/40683#OpenBankGoodsInfo)

	* 新增成员：GoodsBizType

* [OpenBankPayerInfo](https://cloud.tencent.com/document/api/1122/40683#OpenBankPayerInfo)

	* 新增成员：BankCardType

* [OpenBankSceneInfo](https://cloud.tencent.com/document/api/1122/40683#OpenBankSceneInfo)

	* 新增成员：DeviceType

* [SupportBankInfo](https://cloud.tencent.com/document/api/1122/40683#SupportBankInfo)

	* 新增成员：BankId, CardType


### 第 68 次发布

发布时间：2022-06-20 06:05:27

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [ApplyOpenBankOrderDetailReceipt](https://cloud.tencent.com/document/api/#/#)

	* 新增入参：Environment

* [CreateOpenBankExternalSubMerchantAccountBook](https://cloud.tencent.com/document/api/#/#)

	* 新增入参：Environment

* [CreateOpenBankRechargeOrder](https://cloud.tencent.com/document/api/#/#)

	* 新增入参：Environment

* [QueryOpenBankExternalSubAccountBookBalance](https://cloud.tencent.com/document/api/#/#)

	* 新增入参：Environment

* [QueryOpenBankOrderDetailReceiptInfo](https://cloud.tencent.com/document/api/#/#)

	* 新增入参：Environment


### 第 67 次发布

发布时间：2022-06-07 06:04:05

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [ApplyFlexPayment](https://cloud.tencent.com/document/api/#/#)
* [ApplyFlexSettlement](https://cloud.tencent.com/document/api/#/#)
* [CreateFlexPayee](https://cloud.tencent.com/document/api/#/#)
* [FreezeFlexBalance](https://cloud.tencent.com/document/api/#/#)
* [ModifyFlexPayeeAccountRightStatus](https://cloud.tencent.com/document/api/#/#)
* [QueryFlexAmountBeforeTax](https://cloud.tencent.com/document/api/#/#)
* [QueryFlexFreezeOrderList](https://cloud.tencent.com/document/api/#/#)
* [QueryFlexPayeeAccountBalance](https://cloud.tencent.com/document/api/#/#)
* [QueryFlexPayeeAccountInfo](https://cloud.tencent.com/document/api/#/#)
* [QueryFlexPayeeAccountList](https://cloud.tencent.com/document/api/#/#)
* [QueryFlexPayeeInfo](https://cloud.tencent.com/document/api/#/#)
* [QueryFlexPaymentOrderList](https://cloud.tencent.com/document/api/#/#)
* [QueryFlexPaymentOrderStatus](https://cloud.tencent.com/document/api/#/#)
* [QueryFlexSettlementOrderList](https://cloud.tencent.com/document/api/#/#)

新增数据结构：

* [AmountBeforeTaxResult](https://cloud.tencent.com/document/api/1122/40683#AmountBeforeTaxResult)
* [ApplyFlexPaymentResult](https://cloud.tencent.com/document/api/1122/40683#ApplyFlexPaymentResult)
* [ApplyFlexSettlementResult](https://cloud.tencent.com/document/api/1122/40683#ApplyFlexSettlementResult)
* [CreateFlexPayeeResult](https://cloud.tencent.com/document/api/1122/40683#CreateFlexPayeeResult)
* [FlexFundingAccountInfo](https://cloud.tencent.com/document/api/1122/40683#FlexFundingAccountInfo)
* [FreezeFlexBalanceResult](https://cloud.tencent.com/document/api/1122/40683#FreezeFlexBalanceResult)
* [FreezeOrderResult](https://cloud.tencent.com/document/api/1122/40683#FreezeOrderResult)
* [FreezeOrders](https://cloud.tencent.com/document/api/1122/40683#FreezeOrders)
* [PayeeAccountBalanceResult](https://cloud.tencent.com/document/api/1122/40683#PayeeAccountBalanceResult)
* [PayeeAccountInfoResult](https://cloud.tencent.com/document/api/1122/40683#PayeeAccountInfoResult)
* [PayeeAccountInfos](https://cloud.tencent.com/document/api/1122/40683#PayeeAccountInfos)
* [PayeeAccountPropertyInfo](https://cloud.tencent.com/document/api/1122/40683#PayeeAccountPropertyInfo)
* [PayeeAccountUserInfo](https://cloud.tencent.com/document/api/1122/40683#PayeeAccountUserInfo)
* [PayeeInfoResult](https://cloud.tencent.com/document/api/1122/40683#PayeeInfoResult)
* [PayeeTaxInfo](https://cloud.tencent.com/document/api/1122/40683#PayeeTaxInfo)
* [PayeeTaxTemplateInfo](https://cloud.tencent.com/document/api/1122/40683#PayeeTaxTemplateInfo)
* [PaymentOrderResult](https://cloud.tencent.com/document/api/1122/40683#PaymentOrderResult)
* [PaymentOrderStatusResult](https://cloud.tencent.com/document/api/1122/40683#PaymentOrderStatusResult)
* [PaymentOrders](https://cloud.tencent.com/document/api/1122/40683#PaymentOrders)
* [SettlementOrderResult](https://cloud.tencent.com/document/api/1122/40683#SettlementOrderResult)
* [SettlementOrders](https://cloud.tencent.com/document/api/1122/40683#SettlementOrders)

### 第 66 次发布

发布时间：2022-05-20 06:04:11

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreatePayRollPreOrder](https://cloud.tencent.com/document/api/#/#)
* [CreatePayRollPreOrderWithAuth](https://cloud.tencent.com/document/api/#/#)
* [CreatePayRollToken](https://cloud.tencent.com/document/api/#/#)
* [GetPayRollAuth](https://cloud.tencent.com/document/api/#/#)
* [GetPayRollAuthList](https://cloud.tencent.com/document/api/#/#)
* [GetPayRollAuthResult](https://cloud.tencent.com/document/api/#/#)

新增数据结构：

* [PayRollAuthResult](https://cloud.tencent.com/document/api/1122/40683#PayRollAuthResult)

### 第 65 次发布

发布时间：2022-05-05 11:48:14

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [GetDistributeBillDownloadUrl](https://cloud.tencent.com/document/api/#/#)

### 第 64 次发布

发布时间：2022-04-25 06:04:06

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [ApplyOpenBankOrderDetailReceipt](https://cloud.tencent.com/document/api/#/#)
* [CreateOpenBankExternalSubMerchantAccountBook](https://cloud.tencent.com/document/api/#/#)
* [CreateOpenBankRechargeOrder](https://cloud.tencent.com/document/api/#/#)
* [QueryOpenBankExternalSubAccountBookBalance](https://cloud.tencent.com/document/api/#/#)
* [QueryOpenBankOrderDetailReceiptInfo](https://cloud.tencent.com/document/api/#/#)

修改接口：

* [QueryOpenBankDownLoadUrl](https://cloud.tencent.com/document/api/#/#)

	* 新增入参：ChannelName, PaymentMethod


新增数据结构：

* [ApplyOpenBankOrderDetailReceiptResult](https://cloud.tencent.com/document/api/1122/40683#ApplyOpenBankOrderDetailReceiptResult)
* [CreateExternalAccountBookResult](https://cloud.tencent.com/document/api/1122/40683#CreateExternalAccountBookResult)
* [CreateOpenBankOrderRechargeResult](https://cloud.tencent.com/document/api/1122/40683#CreateOpenBankOrderRechargeResult)
* [OpenBankRechargePayeeInfo](https://cloud.tencent.com/document/api/1122/40683#OpenBankRechargePayeeInfo)
* [OpenBankRechargeRedirectInfo](https://cloud.tencent.com/document/api/1122/40683#OpenBankRechargeRedirectInfo)
* [QueryExternalAccountBookResult](https://cloud.tencent.com/document/api/1122/40683#QueryExternalAccountBookResult)
* [QueryOpenBankOrderDetailReceiptInfoResult](https://cloud.tencent.com/document/api/1122/40683#QueryOpenBankOrderDetailReceiptInfoResult)

### 第 63 次发布

发布时间：2022-04-22 06:07:18

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [OpenBankPayeeInfo](https://cloud.tencent.com/document/api/1122/40683#OpenBankPayeeInfo)

	* 新增成员：AccountType

* [OpenBankPayerInfo](https://cloud.tencent.com/document/api/1122/40683#OpenBankPayerInfo)

	* 新增成员：AccountType


### 第 62 次发布

发布时间：2022-04-15 06:04:58

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CloseCloudOrder](https://cloud.tencent.com/document/api/#/#)
* [CreateCloudSubMerchant](https://cloud.tencent.com/document/api/#/#)
* [QueryCloudChannelData](https://cloud.tencent.com/document/api/#/#)
* [QueryCloudOrder](https://cloud.tencent.com/document/api/#/#)
* [QueryCloudRefundOrder](https://cloud.tencent.com/document/api/#/#)
* [RefundCloudOrder](https://cloud.tencent.com/document/api/#/#)
* [UnifiedCloudOrder](https://cloud.tencent.com/document/api/#/#)

新增数据结构：

* [CloudAttachmentInfo](https://cloud.tencent.com/document/api/1122/40683#CloudAttachmentInfo)
* [CloudChannelExternalUserInfo](https://cloud.tencent.com/document/api/1122/40683#CloudChannelExternalUserInfo)
* [CloudClientInfo](https://cloud.tencent.com/document/api/1122/40683#CloudClientInfo)
* [CloudExternalChannelData](https://cloud.tencent.com/document/api/1122/40683#CloudExternalChannelData)
* [CloudExternalPromptGroup](https://cloud.tencent.com/document/api/1122/40683#CloudExternalPromptGroup)
* [CloudExternalPromptInfo](https://cloud.tencent.com/document/api/1122/40683#CloudExternalPromptInfo)
* [CloudGlobalPayTimeInfo](https://cloud.tencent.com/document/api/1122/40683#CloudGlobalPayTimeInfo)
* [CloudOrderReturn](https://cloud.tencent.com/document/api/1122/40683#CloudOrderReturn)
* [CloudSettleInfo](https://cloud.tencent.com/document/api/1122/40683#CloudSettleInfo)
* [CloudStoreInfo](https://cloud.tencent.com/document/api/1122/40683#CloudStoreInfo)
* [CloudSubOrder](https://cloud.tencent.com/document/api/1122/40683#CloudSubOrder)
* [CloudSubOrderRefund](https://cloud.tencent.com/document/api/1122/40683#CloudSubOrderRefund)
* [CloudSubOrderReturn](https://cloud.tencent.com/document/api/1122/40683#CloudSubOrderReturn)
* [CloudSubRefundItem](https://cloud.tencent.com/document/api/1122/40683#CloudSubRefundItem)

### 第 61 次发布

发布时间：2022-03-29 08:07:17

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [GetBillDownloadUrl](https://cloud.tencent.com/document/api/#/#)

新增数据结构：

* [BillDownloadUrlResult](https://cloud.tencent.com/document/api/1122/40683#BillDownloadUrlResult)

### 第 60 次发布

发布时间：2022-03-24 08:09:21

本次发布包含了以下内容：

改善已有的文档。

新增数据结构：

* [OpenBankApprovalGuideInfo](https://cloud.tencent.com/document/api/1122/40683#OpenBankApprovalGuideInfo)

修改数据结构：

* [QueryOpenBankPaymentOrderResult](https://cloud.tencent.com/document/api/1122/40683#QueryOpenBankPaymentOrderResult)

	* 新增成员：BankApprovalGuideInfo


### 第 59 次发布

发布时间：2022-03-15 08:06:54

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [OpenBankGoodsInfo](https://cloud.tencent.com/document/api/1122/40683#OpenBankGoodsInfo)

	* <font color="#dd0000">**修改成员**：</font>GoodsName

* [OpenBankSceneInfo](https://cloud.tencent.com/document/api/1122/40683#OpenBankSceneInfo)

	* <font color="#dd0000">**修改成员**：</font>PayerClientIp, PayerUa


### 第 58 次发布

发布时间：2022-03-08 08:09:49

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [QueryOpenBankBankAccountBalance](https://cloud.tencent.com/document/api/#/#)
* [QueryOpenBankDailyReceiptDownloadUrl](https://cloud.tencent.com/document/api/#/#)

新增数据结构：

* [QueryOpenBankBankAccountBalanceResult](https://cloud.tencent.com/document/api/1122/40683#QueryOpenBankBankAccountBalanceResult)
* [QueryOpenBankDailyReceiptDownloadUrlResult](https://cloud.tencent.com/document/api/1122/40683#QueryOpenBankDailyReceiptDownloadUrlResult)

### 第 57 次发布

发布时间：2022-03-07 08:05:12

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [QueryOpenBankBankBranchList](https://cloud.tencent.com/document/api/#/#)
* [QueryOpenBankSupportBankList](https://cloud.tencent.com/document/api/#/#)

新增数据结构：

* [BankBranchInfo](https://cloud.tencent.com/document/api/1122/40683#BankBranchInfo)
* [QueryOpenBankBankBranchListResult](https://cloud.tencent.com/document/api/1122/40683#QueryOpenBankBankBranchListResult)
* [QueryOpenBankSupportBankListResult](https://cloud.tencent.com/document/api/1122/40683#QueryOpenBankSupportBankListResult)
* [SupportBankInfo](https://cloud.tencent.com/document/api/1122/40683#SupportBankInfo)

修改数据结构：

* [OpenBankPayeeInfo](https://cloud.tencent.com/document/api/1122/40683#OpenBankPayeeInfo)

	* 新增成员：BindSerialNo


### 第 56 次发布

发布时间：2022-03-04 08:06:47

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [ApplyReconciliationFile](https://cloud.tencent.com/document/api/#/#)
* [QueryFundsTransactionDetails](https://cloud.tencent.com/document/api/#/#)
* [QueryMemberTransactionDetails](https://cloud.tencent.com/document/api/#/#)
* [QueryReconciliationFileApplyInfo](https://cloud.tencent.com/document/api/#/#)

新增数据结构：

* [ApplyReconciliationFileResult](https://cloud.tencent.com/document/api/1122/40683#ApplyReconciliationFileResult)
* [FundsTransactionItem](https://cloud.tencent.com/document/api/1122/40683#FundsTransactionItem)
* [MemberTransactionItem](https://cloud.tencent.com/document/api/1122/40683#MemberTransactionItem)
* [QueryFundsTransactionDetailsResult](https://cloud.tencent.com/document/api/1122/40683#QueryFundsTransactionDetailsResult)
* [QueryMemberTransactionDetailsResult](https://cloud.tencent.com/document/api/1122/40683#QueryMemberTransactionDetailsResult)
* [QueryReconciliationFileApplyInfoResult](https://cloud.tencent.com/document/api/1122/40683#QueryReconciliationFileApplyInfoResult)

### 第 55 次发布

发布时间：2022-02-25 08:06:26

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [QueryExceedingInfo](https://cloud.tencent.com/document/api/#/#)

新增数据结构：

* [Paging](https://cloud.tencent.com/document/api/1122/40683#Paging)
* [QueryExceedingInfoData](https://cloud.tencent.com/document/api/1122/40683#QueryExceedingInfoData)
* [QueryExceedingInfoResult](https://cloud.tencent.com/document/api/1122/40683#QueryExceedingInfoResult)

### 第 54 次发布

发布时间：2022-02-21 08:04:03

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [BindOpenBankExternalSubMerchantBankAccount](https://cloud.tencent.com/document/api/#/#)
* [CloseOpenBankPaymentOrder](https://cloud.tencent.com/document/api/#/#)
* [CreateOpenBankExternalSubMerchantRegistration](https://cloud.tencent.com/document/api/#/#)
* [CreateOpenBankMerchant](https://cloud.tencent.com/document/api/#/#)
* [CreateOpenBankPaymentOrder](https://cloud.tencent.com/document/api/#/#)
* [QueryOpenBankBindExternalSubMerchantBankAccount](https://cloud.tencent.com/document/api/#/#)
* [QueryOpenBankDownLoadUrl](https://cloud.tencent.com/document/api/#/#)
* [QueryOpenBankExternalSubMerchantBankAccount](https://cloud.tencent.com/document/api/#/#)
* [QueryOpenBankExternalSubMerchantRegistration](https://cloud.tencent.com/document/api/#/#)
* [QueryOpenBankPaymentOrder](https://cloud.tencent.com/document/api/#/#)
* [QueryOpenBankUnbindExternalSubMerchantBankAccount](https://cloud.tencent.com/document/api/#/#)
* [UnbindOpenBankExternalSubMerchantBankAccount](https://cloud.tencent.com/document/api/#/#)

新增数据结构：

* [BindOpenBankExternalSubMerchantBankAccountResult](https://cloud.tencent.com/document/api/1122/40683#BindOpenBankExternalSubMerchantBankAccountResult)
* [CloseOpenBankPaymentOrderResult](https://cloud.tencent.com/document/api/1122/40683#CloseOpenBankPaymentOrderResult)
* [CreateOpenBankExternalSubMerchantRegistrationResult](https://cloud.tencent.com/document/api/1122/40683#CreateOpenBankExternalSubMerchantRegistrationResult)
* [CreateOpenBankMerchantResult](https://cloud.tencent.com/document/api/1122/40683#CreateOpenBankMerchantResult)
* [CreateOpenBankOrderPaymentResult](https://cloud.tencent.com/document/api/1122/40683#CreateOpenBankOrderPaymentResult)
* [OpenBankGoodsInfo](https://cloud.tencent.com/document/api/1122/40683#OpenBankGoodsInfo)
* [OpenBankPayeeInfo](https://cloud.tencent.com/document/api/1122/40683#OpenBankPayeeInfo)
* [OpenBankPayerInfo](https://cloud.tencent.com/document/api/1122/40683#OpenBankPayerInfo)
* [OpenBankProfitShareInfo](https://cloud.tencent.com/document/api/1122/40683#OpenBankProfitShareInfo)
* [OpenBankRedirectInfo](https://cloud.tencent.com/document/api/1122/40683#OpenBankRedirectInfo)
* [OpenBankSceneInfo](https://cloud.tencent.com/document/api/1122/40683#OpenBankSceneInfo)
* [QueryOpenBankBindExternalSubMerchantBankAccountResult](https://cloud.tencent.com/document/api/1122/40683#QueryOpenBankBindExternalSubMerchantBankAccountResult)
* [QueryOpenBankDownLoadUrlResult](https://cloud.tencent.com/document/api/1122/40683#QueryOpenBankDownLoadUrlResult)
* [QueryOpenBankExternalSubMerchantBankAccountData](https://cloud.tencent.com/document/api/1122/40683#QueryOpenBankExternalSubMerchantBankAccountData)
* [QueryOpenBankExternalSubMerchantBankAccountResult](https://cloud.tencent.com/document/api/1122/40683#QueryOpenBankExternalSubMerchantBankAccountResult)
* [QueryOpenBankExternalSubMerchantRegistrationResult](https://cloud.tencent.com/document/api/1122/40683#QueryOpenBankExternalSubMerchantRegistrationResult)
* [QueryOpenBankPaymentOrderResult](https://cloud.tencent.com/document/api/1122/40683#QueryOpenBankPaymentOrderResult)
* [QueryOpenBankUnbindExternalSubMerchantBankAccountResult](https://cloud.tencent.com/document/api/1122/40683#QueryOpenBankUnbindExternalSubMerchantBankAccountResult)
* [UnbindOpenBankExternalSubMerchantBankAccountResult](https://cloud.tencent.com/document/api/1122/40683#UnbindOpenBankExternalSubMerchantBankAccountResult)

### 第 53 次发布

发布时间：2021-12-09 08:03:47

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [UnifiedTlinxOrder](https://cloud.tencent.com/document/api/#/#)

	* 新增入参：Jsapi, SubAppId, SubOpenId


修改数据结构：

* [PayOrderResult](https://cloud.tencent.com/document/api/1122/40683#PayOrderResult)

	* 新增成员：WechatAppId, WechatTimeStamp, WechatNonceStr, WechatSignType, WechatPackage, WechatPaySign


### 第 52 次发布

发布时间：2021-12-06 08:03:46

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DeduceQuota](https://cloud.tencent.com/document/api/#/#)
* [QueryAssignment](https://cloud.tencent.com/document/api/#/#)

新增数据结构：

* [AssignmentData](https://cloud.tencent.com/document/api/1122/40683#AssignmentData)

### 第 51 次发布

发布时间：2021-11-17 08:08:58

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [AddContract](https://cloud.tencent.com/document/api/#/#)
* [AddMerchant](https://cloud.tencent.com/document/api/#/#)
* [AddShop](https://cloud.tencent.com/document/api/#/#)
* [DistributeAccreditQuery](https://cloud.tencent.com/document/api/#/#)
* [DistributeAccreditTlinx](https://cloud.tencent.com/document/api/#/#)
* [DistributeAddReceiver](https://cloud.tencent.com/document/api/#/#)
* [DistributeApply](https://cloud.tencent.com/document/api/#/#)
* [DistributeCancel](https://cloud.tencent.com/document/api/#/#)
* [DistributeQuery](https://cloud.tencent.com/document/api/#/#)
* [DistributeQueryReceiver](https://cloud.tencent.com/document/api/#/#)
* [DistributeRemoveReceiver](https://cloud.tencent.com/document/api/#/#)
* [DownloadOrgFile](https://cloud.tencent.com/document/api/#/#)
* [QueryCityCode](https://cloud.tencent.com/document/api/#/#)
* [QueryContractPayFee](https://cloud.tencent.com/document/api/#/#)
* [QueryContractPayWayList](https://cloud.tencent.com/document/api/#/#)
* [QueryContractRelateShop](https://cloud.tencent.com/document/api/#/#)
* [QueryMerchantClassification](https://cloud.tencent.com/document/api/#/#)
* [QueryShopOpenId](https://cloud.tencent.com/document/api/#/#)
* [UploadOrgFile](https://cloud.tencent.com/document/api/#/#)
* [ViewContract](https://cloud.tencent.com/document/api/#/#)
* [ViewMerchant](https://cloud.tencent.com/document/api/#/#)
* [ViewShop](https://cloud.tencent.com/document/api/#/#)

新增数据结构：

* [AddContractResult](https://cloud.tencent.com/document/api/1122/40683#AddContractResult)
* [AddMerchantResult](https://cloud.tencent.com/document/api/1122/40683#AddMerchantResult)
* [AddShopResult](https://cloud.tencent.com/document/api/1122/40683#AddShopResult)
* [CityCodeResult](https://cloud.tencent.com/document/api/1122/40683#CityCodeResult)
* [ContractPayListResult](https://cloud.tencent.com/document/api/1122/40683#ContractPayListResult)
* [DistributeAccreditQueryResult](https://cloud.tencent.com/document/api/1122/40683#DistributeAccreditQueryResult)
* [DistributeAccreditResult](https://cloud.tencent.com/document/api/1122/40683#DistributeAccreditResult)
* [DistributeCancelResult](https://cloud.tencent.com/document/api/1122/40683#DistributeCancelResult)
* [DistributeMultiApplyResult](https://cloud.tencent.com/document/api/1122/40683#DistributeMultiApplyResult)
* [DistributeQueryResult](https://cloud.tencent.com/document/api/1122/40683#DistributeQueryResult)
* [DistributeReceiverResult](https://cloud.tencent.com/document/api/1122/40683#DistributeReceiverResult)
* [DownloadFileResult](https://cloud.tencent.com/document/api/1122/40683#DownloadFileResult)
* [MerchantClassificationId](https://cloud.tencent.com/document/api/1122/40683#MerchantClassificationId)
* [MultiApplyDetail](https://cloud.tencent.com/document/api/1122/40683#MultiApplyDetail)
* [MultiApplyOrder](https://cloud.tencent.com/document/api/1122/40683#MultiApplyOrder)
* [PayDataResult](https://cloud.tencent.com/document/api/1122/40683#PayDataResult)
* [PayFeeDataResult](https://cloud.tencent.com/document/api/1122/40683#PayFeeDataResult)
* [QueryContractPayFeeResult](https://cloud.tencent.com/document/api/1122/40683#QueryContractPayFeeResult)
* [QueryContractRelateShopResult](https://cloud.tencent.com/document/api/1122/40683#QueryContractRelateShopResult)
* [QueryShopOpenIdResult](https://cloud.tencent.com/document/api/1122/40683#QueryShopOpenIdResult)
* [UploadFileResult](https://cloud.tencent.com/document/api/1122/40683#UploadFileResult)
* [ViewContractResult](https://cloud.tencent.com/document/api/1122/40683#ViewContractResult)
* [ViewMerchantResult](https://cloud.tencent.com/document/api/1122/40683#ViewMerchantResult)
* [ViewShopResult](https://cloud.tencent.com/document/api/1122/40683#ViewShopResult)

### 第 50 次发布

发布时间：2021-11-12 15:56:31

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateAnchor](https://cloud.tencent.com/document/api/#/#)
* [UploadFile](https://cloud.tencent.com/document/api/#/#)

新增数据结构：

* [AnchorExtendInfo](https://cloud.tencent.com/document/api/1122/40683#AnchorExtendInfo)

### 第 49 次发布

发布时间：2021-11-04 08:06:43

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [QueryMaliciousRegistration](https://cloud.tencent.com/document/api/#/#)

修改接口：

* [UnifiedTlinxOrder](https://cloud.tencent.com/document/api/#/#)

	* 新增入参：Royalty

	* <font color="#dd0000">**修改入参**：</font>Tag


新增数据结构：

* [MerchantRiskInfo](https://cloud.tencent.com/document/api/1122/40683#MerchantRiskInfo)

### 第 48 次发布

发布时间：2021-10-13 08:05:27

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [QueryOrderStatus](https://cloud.tencent.com/document/api/#/#)
* [RefundTlinxOrder](https://cloud.tencent.com/document/api/#/#)
* [UnifiedTlinxOrder](https://cloud.tencent.com/document/api/#/#)

新增数据结构：

* [PayOrderResult](https://cloud.tencent.com/document/api/1122/40683#PayOrderResult)
* [QueryOrderStatusResult](https://cloud.tencent.com/document/api/1122/40683#QueryOrderStatusResult)
* [RefundOrderResult](https://cloud.tencent.com/document/api/1122/40683#RefundOrderResult)

### 第 47 次发布

发布时间：2021-10-09 11:10:00

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [QueryMerchantPayWayList](https://cloud.tencent.com/document/api/#/#)

新增数据结构：

* [MerchantPayWayData](https://cloud.tencent.com/document/api/1122/40683#MerchantPayWayData)

### 第 46 次发布

发布时间：2021-09-22 08:05:35

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [QuerySinglePaymentResultData](https://cloud.tencent.com/document/api/1122/40683#QuerySinglePaymentResultData)

	* 新增成员：TradeStatusDesc


### 第 45 次发布

发布时间：2021-08-31 08:11:55

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [QueryInvoiceResultData](https://cloud.tencent.com/document/api/1122/40683#QueryInvoiceResultData)

	* 新增成员：ImageUrl


### 第 44 次发布

发布时间：2021-08-26 08:11:04

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateExternalAnchor](https://cloud.tencent.com/document/api/#/#)

	* 新增入参：AgentId


### 第 43 次发布

发布时间：2021-08-25 08:11:07

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DownloadReconciliationUrl](https://cloud.tencent.com/document/api/#/#)

### 第 42 次发布

发布时间：2021-08-18 08:11:06

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateBatchPayment](https://cloud.tencent.com/document/api/#/#)
* [CreateSinglePayment](https://cloud.tencent.com/document/api/#/#)
* [QueryBatchPaymentResult](https://cloud.tencent.com/document/api/#/#)
* [QuerySinglePaymentResult](https://cloud.tencent.com/document/api/#/#)

新增数据结构：

* [CreateBatchPaymentBatchData](https://cloud.tencent.com/document/api/1122/40683#CreateBatchPaymentBatchData)
* [CreateBatchPaymentData](https://cloud.tencent.com/document/api/1122/40683#CreateBatchPaymentData)
* [CreateBatchPaymentRecipient](https://cloud.tencent.com/document/api/1122/40683#CreateBatchPaymentRecipient)
* [CreateSinglePaymentData](https://cloud.tencent.com/document/api/1122/40683#CreateSinglePaymentData)
* [QueryBatchPaymentResultData](https://cloud.tencent.com/document/api/1122/40683#QueryBatchPaymentResultData)
* [QueryBatchPaymentResultDataInfo](https://cloud.tencent.com/document/api/1122/40683#QueryBatchPaymentResultDataInfo)
* [QuerySinglePaymentResultData](https://cloud.tencent.com/document/api/1122/40683#QuerySinglePaymentResultData)

### 第 41 次发布

发布时间：2021-08-16 08:11:50

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [BindAccount](https://cloud.tencent.com/document/api/#/#)
* [CreateExternalAnchor](https://cloud.tencent.com/document/api/#/#)
* [ModifyBindedAccount](https://cloud.tencent.com/document/api/#/#)
* [UploadExternalAnchorInfo](https://cloud.tencent.com/document/api/#/#)

新增数据结构：

* [CreateExternalAnchorData](https://cloud.tencent.com/document/api/1122/40683#CreateExternalAnchorData)

### 第 40 次发布

发布时间：2021-08-10 08:13:08

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [QueryDownloadBillURL](https://cloud.tencent.com/document/api/#/#)

### 第 39 次发布

发布时间：2021-08-05 08:11:13

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [ConfirmOrder](https://cloud.tencent.com/document/api/#/#)
* [CreateOrder](https://cloud.tencent.com/document/api/#/#)
* [CreatePayMerchant](https://cloud.tencent.com/document/api/#/#)
* [ModifyMerchant](https://cloud.tencent.com/document/api/#/#)
* [QueryMerchant](https://cloud.tencent.com/document/api/#/#)
* [QueryMerchantOrder](https://cloud.tencent.com/document/api/#/#)
* [RefundOrder](https://cloud.tencent.com/document/api/#/#)

### 第 38 次发布

发布时间：2021-07-28 08:11:20

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [QueryContract](https://cloud.tencent.com/document/api/#/#)

	* 新增入参：MigrateMode, ContractMethod

* [TerminateContract](https://cloud.tencent.com/document/api/#/#)

	* 新增入参：ContractMethod, MigrateMode


### 第 37 次发布

发布时间：2021-06-02 08:10:27

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [RegisterBehavior](https://cloud.tencent.com/document/api/#/#)

修改接口：

* [BindAcct](https://cloud.tencent.com/document/api/#/#)

	* 新增入参：AgencyClientInfo

* [CreateAcct](https://cloud.tencent.com/document/api/#/#)

	* 新增入参：SubMerchantStoreName, OrganizationInfo


新增数据结构：

* [AgencyClientInfo](https://cloud.tencent.com/document/api/1122/40683#AgencyClientInfo)
* [OrganizationInfo](https://cloud.tencent.com/document/api/1122/40683#OrganizationInfo)
* [RegisterInfo](https://cloud.tencent.com/document/api/1122/40683#RegisterInfo)

### 第 36 次发布

发布时间：2021-05-28 20:59:36

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [ContractOrder](https://cloud.tencent.com/document/api/#/#)
* [QueryContract](https://cloud.tencent.com/document/api/#/#)
* [SyncContractData](https://cloud.tencent.com/document/api/#/#)
* [TerminateContract](https://cloud.tencent.com/document/api/#/#)

新增数据结构：

* [ChannelContractInfo](https://cloud.tencent.com/document/api/1122/40683#ChannelContractInfo)
* [ChannelReturnContractInfo](https://cloud.tencent.com/document/api/1122/40683#ChannelReturnContractInfo)
* [ContractInfo](https://cloud.tencent.com/document/api/1122/40683#ContractInfo)
* [ContractOrderInSubOrder](https://cloud.tencent.com/document/api/1122/40683#ContractOrderInSubOrder)
* [ContractSyncInfo](https://cloud.tencent.com/document/api/1122/40683#ContractSyncInfo)
* [ContractUserInfo](https://cloud.tencent.com/document/api/1122/40683#ContractUserInfo)
* [ExternalContractUserInfo](https://cloud.tencent.com/document/api/1122/40683#ExternalContractUserInfo)
* [ExternalReturnContractInfo](https://cloud.tencent.com/document/api/1122/40683#ExternalReturnContractInfo)
* [ResponseQueryContract](https://cloud.tencent.com/document/api/1122/40683#ResponseQueryContract)
* [ResponseTerminateContract](https://cloud.tencent.com/document/api/1122/40683#ResponseTerminateContract)
* [ReturnContractInfo](https://cloud.tencent.com/document/api/1122/40683#ReturnContractInfo)
* [SceneInfo](https://cloud.tencent.com/document/api/1122/40683#SceneInfo)

### 第 35 次发布

发布时间：2021-04-16 08:09:33

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [UploadTaxList](https://cloud.tencent.com/document/api/#/#)
* [UploadTaxPayment](https://cloud.tencent.com/document/api/#/#)

### 第 34 次发布

发布时间：2021-04-13 08:11:15

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateInvoiceV2](https://cloud.tencent.com/document/api/#/#)
* [CreateRedInvoiceV2](https://cloud.tencent.com/document/api/#/#)
* [QueryInvoiceV2](https://cloud.tencent.com/document/api/#/#)

新增数据结构：

* [CreateInvoiceResultV2](https://cloud.tencent.com/document/api/1122/40683#CreateInvoiceResultV2)
* [CreateRedInvoiceResultV2](https://cloud.tencent.com/document/api/1122/40683#CreateRedInvoiceResultV2)

### 第 33 次发布

发布时间：2021-01-13 08:08:39

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [UnifiedOrder](https://cloud.tencent.com/document/api/#/#)

	* 新增入参：PaymentNotifyUrl


### 第 32 次发布

发布时间：2021-01-07 08:10:52

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [QueryBillDownloadURL](https://cloud.tencent.com/document/api/#/#)

新增数据结构：

* [QueryBillDownloadURLData](https://cloud.tencent.com/document/api/1122/40683#QueryBillDownloadURLData)

### 第 31 次发布

发布时间：2020-12-14 08:08:27

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [QueryTransferResult](https://cloud.tencent.com/document/api/#/#)
* [TransferSinglePay](https://cloud.tencent.com/document/api/#/#)

新增数据结构：

* [QueryTransferResultData](https://cloud.tencent.com/document/api/1122/40683#QueryTransferResultData)
* [TransferSinglePayData](https://cloud.tencent.com/document/api/1122/40683#TransferSinglePayData)

### 第 30 次发布

发布时间：2020-09-14 08:07:06

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [UnifiedOrder](https://cloud.tencent.com/document/api/#/#)

	* 新增入参：WxAppId, WxSubAppId


### 第 29 次发布

发布时间：2020-08-18 08:27:18

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [MigrateOrderRefund](https://cloud.tencent.com/document/api/#/#)

	* 新增入参：RefundReason


### 第 28 次发布

发布时间：2020-08-14 08:24:18

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateTransferBatch](https://cloud.tencent.com/document/api/#/#)
* [QueryTransferBatch](https://cloud.tencent.com/document/api/#/#)
* [QueryTransferDetail](https://cloud.tencent.com/document/api/#/#)

新增数据结构：

* [TransferDetailRequest](https://cloud.tencent.com/document/api/1122/40683#TransferDetailRequest)
* [TransferDetailResponse](https://cloud.tencent.com/document/api/1122/40683#TransferDetailResponse)

### 第 27 次发布

发布时间：2020-07-31 08:30:31

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [MigrateOrderRefund](https://cloud.tencent.com/document/api/#/#)
* [MigrateOrderRefundQuery](https://cloud.tencent.com/document/api/#/#)

### 第 26 次发布

发布时间：2020-07-24 08:22:55

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateSinglePay](https://cloud.tencent.com/document/api/1122/46816)
* [QuerySinglePay](https://cloud.tencent.com/document/api/1122/46815)

新增数据结构：

* [CreateSinglePayResult](https://cloud.tencent.com/document/api/1122/40683#CreateSinglePayResult)
* [QuerySinglePayItem](https://cloud.tencent.com/document/api/1122/40683#QuerySinglePayItem)
* [QuerySinglePayResult](https://cloud.tencent.com/document/api/1122/40683#QuerySinglePayResult)

### 第 25 次发布

发布时间：2020-07-23 08:22:41

本次发布包含了以下内容：

改善已有的文档。

新增数据结构：

* [Order](https://cloud.tencent.com/document/api/1122/40683#Order)
* [OrderItem](https://cloud.tencent.com/document/api/1122/40683#OrderItem)

修改数据结构：

* [QueryInvoiceResult](https://cloud.tencent.com/document/api/1122/40683#QueryInvoiceResult)

	* 新增成员：Order


### 第 24 次发布

发布时间：2020-07-14 08:23:00

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DownloadBill](https://cloud.tencent.com/document/api/#/#)

	* 新增入参：MidasEnvironment


### 第 23 次发布

发布时间：2020-07-06 08:22:03

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [ApplyWithdrawal](https://cloud.tencent.com/document/api/#/#)

	* 新增入参：WithdrawOrderId


### 第 22 次发布

发布时间：2020-07-03 08:22:22

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeOrderStatus](https://cloud.tencent.com/document/api/#/#)

### 第 21 次发布

发布时间：2020-07-02 08:22:32

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [QueryInvoice](https://cloud.tencent.com/document/api/#/#)

	* 新增入参：SellerTaxpayerNum


### 第 20 次发布

发布时间：2020-07-01 20:10:26

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeChargeDetail](https://cloud.tencent.com/document/api/#/#)
* [ExecuteMemberTransaction](https://cloud.tencent.com/document/api/#/#)
* [QueryAnchorContractInfo](https://cloud.tencent.com/document/api/#/#)
* [RechargeByThirdPay](https://cloud.tencent.com/document/api/#/#)
* [RefundMemberTransaction](https://cloud.tencent.com/document/api/#/#)
* [RevokeRechargeByThirdPay](https://cloud.tencent.com/document/api/#/#)

<font color="#dd0000">**删除接口**：</font>

* RevRegisterBillSupportWithdraw

修改接口：

* [ApplyWithdrawal](https://cloud.tencent.com/document/api/#/#)

	* 新增入参：CommissionAmount

* [CreateInvoice](https://cloud.tencent.com/document/api/#/#)

	* 新增入参：InvoiceChannel

* [CreateRedInvoice](https://cloud.tencent.com/document/api/#/#)

	* 新增入参：InvoiceChannel

* [QueryInvoice](https://cloud.tencent.com/document/api/#/#)

	* 新增入参：InvoiceChannel

* [RegisterBill](https://cloud.tencent.com/document/api/#/#)

	* 新增入参：MidasEnvironment


新增数据结构：

* [AnchorContractInfo](https://cloud.tencent.com/document/api/1122/40683#AnchorContractInfo)

### 第 19 次发布

发布时间：2020-06-12 08:24:11

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CloseOrder](https://cloud.tencent.com/document/api/#/#)

	* 新增入参：MidasEnvironment

* [CreateInvoice](https://cloud.tencent.com/document/api/#/#)

	* 新增入参：OrderDate, Discount, StoreNo

* [QueryOrder](https://cloud.tencent.com/document/api/#/#)

	* 新增入参：MidasEnvironment

* [QueryRefund](https://cloud.tencent.com/document/api/#/#)

	* 新增入参：MidasEnvironment

* [Refund](https://cloud.tencent.com/document/api/#/#)

	* 新增入参：MidasEnvironment

* [UnifiedOrder](https://cloud.tencent.com/document/api/#/#)

	* 新增入参：MidasEnvironment


修改数据结构：

* [CreateRedInvoiceItem](https://cloud.tencent.com/document/api/1122/40683#CreateRedInvoiceItem)

	* 新增成员：StoreNo


### 第 18 次发布

发布时间：2020-06-10 08:21:03

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [BindRelateAccReUnionPay](https://cloud.tencent.com/document/api/#/#)

	* 新增入参：Profile

* [BindRelateAcctSmallAmount](https://cloud.tencent.com/document/api/#/#)

	* 新增入参：Profile

* [BindRelateAcctUnionPay](https://cloud.tencent.com/document/api/#/#)

	* 新增入参：Profile

* [CheckAmount](https://cloud.tencent.com/document/api/#/#)

	* 新增入参：Profile

* [CreateCustAcctId](https://cloud.tencent.com/document/api/#/#)

	* 新增入参：Profile

* [ModifyMntMbrBindRelateAcctBankCode](https://cloud.tencent.com/document/api/#/#)

	* 新增入参：Profile

* [QueryBankClear](https://cloud.tencent.com/document/api/#/#)

	* 新增入参：Profile

* [QueryBankTransactionDetails](https://cloud.tencent.com/document/api/#/#)

	* 新增入参：Profile

* [QueryBankWithdrawCashDetails](https://cloud.tencent.com/document/api/#/#)

	* 新增入参：Profile

* [QueryCommonTransferRecharge](https://cloud.tencent.com/document/api/#/#)

	* 新增入参：Profile

* [QueryCustAcctIdBalance](https://cloud.tencent.com/document/api/#/#)

	* 新增入参：Profile

* [QueryMemberBind](https://cloud.tencent.com/document/api/#/#)

	* 新增入参：Profile

* [QueryMemberTransaction](https://cloud.tencent.com/document/api/#/#)

	* 新增入参：Profile

* [QueryReconciliationDocument](https://cloud.tencent.com/document/api/#/#)

	* 新增入参：Profile

* [QuerySingleTransactionStatus](https://cloud.tencent.com/document/api/#/#)

	* 新增入参：Profile

* [QuerySmallAmountTransfer](https://cloud.tencent.com/document/api/#/#)

	* 新增入参：Profile

* [RechargeMemberThirdPay](https://cloud.tencent.com/document/api/#/#)

	* 新增入参：Profile

* [RegisterBillSupportWithdraw](https://cloud.tencent.com/document/api/#/#)

	* 新增入参：Profile

* [RevResigterBillSupportWithdraw](https://cloud.tencent.com/document/api/1122/40654)

	* 新增入参：Profile

* [ReviseMbrProperty](https://cloud.tencent.com/document/api/#/#)

	* 新增入参：Profile

* [RevokeMemberRechargeThirdPay](https://cloud.tencent.com/document/api/#/#)

	* 新增入参：Profile

* [UnbindRelateAcct](https://cloud.tencent.com/document/api/#/#)

	* 新增入参：Profile

* [WithdrawCashMembership](https://cloud.tencent.com/document/api/#/#)

	* 新增入参：Profile


### 第 17 次发布

发布时间：2020-06-05 08:20:43

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [ApplyReWithdrawal](https://cloud.tencent.com/document/api/#/#)

	* 新增入参：MidasEnvironment


### 第 16 次发布

发布时间：2020-05-29 08:19:58

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [QueryAgentStatements](https://cloud.tencent.com/document/api/#/#)

修改接口：

* [ApplyWithdrawal](https://cloud.tencent.com/document/api/#/#)

	* 新增入参：EncryptType, MidasEnvironment

* [BindAcct](https://cloud.tencent.com/document/api/#/#)

	* 新增入参：MidasEnvironment

* [CheckAcct](https://cloud.tencent.com/document/api/#/#)

	* 新增入参：EncryptType, MidasEnvironment

* [CreateAcct](https://cloud.tencent.com/document/api/#/#)

	* 新增入参：MidasEnvironment

* [QueryAcctBinding](https://cloud.tencent.com/document/api/#/#)

	* 新增入参：EncryptType, MidasEnvironment

* [QueryAcctInfo](https://cloud.tencent.com/document/api/#/#)

	* 新增入参：EncryptType, MidasEnvironment

* [QueryAcctInfoList](https://cloud.tencent.com/document/api/#/#)

	* 新增入参：EncryptType, MidasEnvironment

* [QueryBalance](https://cloud.tencent.com/document/api/#/#)

	* 新增入参：MidasEnvironment

* [UnBindAcct](https://cloud.tencent.com/document/api/#/#)

	* 新增入参：EncryptType, MidasEnvironment


### 第 15 次发布

发布时间：2020-05-20 08:20:55

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [QueryMerchantInfoForManagement](https://cloud.tencent.com/document/api/#/#)

新增数据结构：

* [MerchantManagementList](https://cloud.tencent.com/document/api/1122/40683#MerchantManagementList)
* [MerchantManagementResult](https://cloud.tencent.com/document/api/1122/40683#MerchantManagementResult)

### 第 14 次发布

发布时间：2020-05-19 08:19:57

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [BindAcct](https://cloud.tencent.com/document/api/#/#)

	* 新增入参：EncryptType

* [CreateAcct](https://cloud.tencent.com/document/api/#/#)

	* 新增入参：SubMerchantKey, SubMerchantPrivateKey, EncryptType, SubAcctNo


### 第 13 次发布

发布时间：2020-05-12 08:19:41

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [RegisterBill](https://cloud.tencent.com/document/api/#/#)

### 第 12 次发布

发布时间：2020-05-11 10:20:46

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateAgentTaxPaymentInfos](https://cloud.tencent.com/document/api/#/#)

	* 新增入参：Profile

* [DeleteAgentTaxPaymentInfo](https://cloud.tencent.com/document/api/#/#)

	* 新增入参：Profile

* [ModifyAgentTaxPaymentInfo](https://cloud.tencent.com/document/api/#/#)

	* 新增入参：Profile

* [QueryAgentTaxPaymentBatch](https://cloud.tencent.com/document/api/#/#)

	* 新增入参：Profile


### 第 11 次发布

发布时间：2020-05-08 08:20:37

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateAgentTaxPaymentInfos](https://cloud.tencent.com/document/api/#/#)
* [DeleteAgentTaxPaymentInfo](https://cloud.tencent.com/document/api/#/#)
* [DeleteAgentTaxPaymentInfos](https://cloud.tencent.com/document/api/#/#)
* [ModifyAgentTaxPaymentInfo](https://cloud.tencent.com/document/api/#/#)
* [QueryAgentTaxPaymentBatch](https://cloud.tencent.com/document/api/#/#)

新增数据结构：

* [AgentTaxPayment](https://cloud.tencent.com/document/api/1122/40683#AgentTaxPayment)
* [AgentTaxPaymentBatch](https://cloud.tencent.com/document/api/1122/40683#AgentTaxPaymentBatch)

### 第 10 次发布

发布时间：2020-04-30 08:19:59

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateInvoice](https://cloud.tencent.com/document/api/#/#)

	* 新增入参：UndoPart


### 第 9 次发布

发布时间：2020-04-27 08:19:44

本次发布包含了以下内容：

改善已有的文档。

<font color="#dd0000">**删除接口**：</font>

* QueryInvoiceForManagement
* QueryMerchantInfoForManagement

<font color="#dd0000">**删除数据结构**：</font>

* InvoiceManagementList
* InvoiceManangementResult
* MerchantManagementList
* MerchantManagementResult

### 第 8 次发布

发布时间：2020-04-20 08:19:12

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [ApplyApplicationMaterial](https://cloud.tencent.com/document/api/#/#)
* [ApplyOutwardOrder](https://cloud.tencent.com/document/api/#/#)
* [ApplyPayerInfo](https://cloud.tencent.com/document/api/#/#)
* [ApplyTrade](https://cloud.tencent.com/document/api/#/#)
* [QueryApplicationMaterial](https://cloud.tencent.com/document/api/#/#)
* [QueryExchangeRate](https://cloud.tencent.com/document/api/#/#)
* [QueryMerchantBalance](https://cloud.tencent.com/document/api/#/#)
* [QueryOutwardOrder](https://cloud.tencent.com/document/api/#/#)
* [QueryPayerInfo](https://cloud.tencent.com/document/api/#/#)
* [QueryTrade](https://cloud.tencent.com/document/api/#/#)

新增数据结构：

* [ApplyDeclareData](https://cloud.tencent.com/document/api/1122/40683#ApplyDeclareData)
* [ApplyDeclareResult](https://cloud.tencent.com/document/api/1122/40683#ApplyDeclareResult)
* [ApplyOutwardOrderData](https://cloud.tencent.com/document/api/1122/40683#ApplyOutwardOrderData)
* [ApplyOutwardOrderResult](https://cloud.tencent.com/document/api/1122/40683#ApplyOutwardOrderResult)
* [ApplyPayerinfoData](https://cloud.tencent.com/document/api/1122/40683#ApplyPayerinfoData)
* [ApplyPayerinfoResult](https://cloud.tencent.com/document/api/1122/40683#ApplyPayerinfoResult)
* [ApplyTradeData](https://cloud.tencent.com/document/api/1122/40683#ApplyTradeData)
* [ApplyTradeResult](https://cloud.tencent.com/document/api/1122/40683#ApplyTradeResult)
* [QueryDeclareData](https://cloud.tencent.com/document/api/1122/40683#QueryDeclareData)
* [QueryDeclareResult](https://cloud.tencent.com/document/api/1122/40683#QueryDeclareResult)
* [QueryExchangerateData](https://cloud.tencent.com/document/api/1122/40683#QueryExchangerateData)
* [QueryExchangerateResult](https://cloud.tencent.com/document/api/1122/40683#QueryExchangerateResult)
* [QueryMerchantBalanceData](https://cloud.tencent.com/document/api/1122/40683#QueryMerchantBalanceData)
* [QueryMerchantBalanceResult](https://cloud.tencent.com/document/api/1122/40683#QueryMerchantBalanceResult)
* [QueryOutwardOrderData](https://cloud.tencent.com/document/api/1122/40683#QueryOutwardOrderData)
* [QueryOutwardOrderResult](https://cloud.tencent.com/document/api/1122/40683#QueryOutwardOrderResult)
* [QueryPayerinfoData](https://cloud.tencent.com/document/api/1122/40683#QueryPayerinfoData)
* [QueryPayerinfoResult](https://cloud.tencent.com/document/api/1122/40683#QueryPayerinfoResult)
* [QueryTradeData](https://cloud.tencent.com/document/api/1122/40683#QueryTradeData)
* [QueryTradeResult](https://cloud.tencent.com/document/api/1122/40683#QueryTradeResult)

### 第 7 次发布

发布时间：2020-04-14 08:18:55

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [ApplyReWithdrawal](https://cloud.tencent.com/document/api/#/#)
* [QueryAcctInfo](https://cloud.tencent.com/document/api/#/#)
* [QueryAcctInfoList](https://cloud.tencent.com/document/api/#/#)

新增数据结构：

* [QueryAcctItem](https://cloud.tencent.com/document/api/1122/40683#QueryAcctItem)
* [WithdrawBill](https://cloud.tencent.com/document/api/1122/40683#WithdrawBill)

### 第 6 次发布

发布时间：2020-04-08 08:17:50

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateInvoice](https://cloud.tencent.com/document/api/#/#)
* [CreateMerchant](https://cloud.tencent.com/document/api/#/#)
* [CreateRedInvoice](https://cloud.tencent.com/document/api/#/#)
* [QueryInvoice](https://cloud.tencent.com/document/api/#/#)
* [QueryInvoiceForManagement](https://cloud.tencent.com/document/api/1122/43186)
* [QueryMerchantInfoForManagement](https://cloud.tencent.com/document/api/#/#)
* [RevResigterBillSupportWithdraw](https://cloud.tencent.com/document/api/1122/40654)

修改接口：

* [CreateAcct](https://cloud.tencent.com/document/api/#/#)

	* 新增入参：SubMerchantMemberType


新增数据结构：

* [CreateInvoiceItem](https://cloud.tencent.com/document/api/1122/40683#CreateInvoiceItem)
* [CreateInvoiceResult](https://cloud.tencent.com/document/api/1122/40683#CreateInvoiceResult)
* [CreateInvoiceResultData](https://cloud.tencent.com/document/api/1122/40683#CreateInvoiceResultData)
* [CreateMerchantResult](https://cloud.tencent.com/document/api/1122/40683#CreateMerchantResult)
* [CreateMerchantResultData](https://cloud.tencent.com/document/api/1122/40683#CreateMerchantResultData)
* [CreateRedInvoiceItem](https://cloud.tencent.com/document/api/1122/40683#CreateRedInvoiceItem)
* [CreateRedInvoiceResult](https://cloud.tencent.com/document/api/1122/40683#CreateRedInvoiceResult)
* [CreateRedInvoiceResultData](https://cloud.tencent.com/document/api/1122/40683#CreateRedInvoiceResultData)
* [InvoiceManagementList](https://cloud.tencent.com/document/api/1122/40683#InvoiceManagementList)
* [InvoiceManangementResult](https://cloud.tencent.com/document/api/1122/40683#InvoiceManangementResult)
* [MerchantManagementList](https://cloud.tencent.com/document/api/1122/40683#MerchantManagementList)
* [MerchantManagementResult](https://cloud.tencent.com/document/api/1122/40683#MerchantManagementResult)
* [QueryInvoiceResult](https://cloud.tencent.com/document/api/1122/40683#QueryInvoiceResult)
* [QueryInvoiceResultData](https://cloud.tencent.com/document/api/1122/40683#QueryInvoiceResultData)

### 第 5 次发布

发布时间：2020-04-07 08:18:11

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [Refund](https://cloud.tencent.com/document/api/#/#)

	* <font color="#dd0000">**修改入参**：</font>SubOrderRefundList


### 第 4 次发布

发布时间：2020-04-01 08:54:23

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [UnifiedOrder](https://cloud.tencent.com/document/api/#/#)

	* <font color="#dd0000">**修改入参**：</font>SubOrderList


### 第 3 次发布

发布时间：2020-03-19 08:17:33

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateAcct](https://cloud.tencent.com/document/api/#/#)

	* <font color="#dd0000">**删除入参**：</font>PlatformId

* [QueryAcctBinding](https://cloud.tencent.com/document/api/#/#)

	* <font color="#dd0000">**删除入参**：</font>PlatformId


### 第 2 次发布

发布时间：2020-03-17 08:00:12

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [QueryAcctBinding](https://cloud.tencent.com/document/api/#/#)

修改接口：

* [CreateAcct](https://cloud.tencent.com/document/api/#/#)

	* 新增入参：PlatformId


新增数据结构：

* [BankCardItem](https://cloud.tencent.com/document/api/1122/40683#BankCardItem)

### 第 1 次发布

发布时间：2020-01-02 16:53:22

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [ApplyWithdrawal](https://cloud.tencent.com/document/api/#/#)
* [BindAcct](https://cloud.tencent.com/document/api/#/#)
* [BindRelateAccReUnionPay](https://cloud.tencent.com/document/api/#/#)
* [BindRelateAcctSmallAmount](https://cloud.tencent.com/document/api/#/#)
* [BindRelateAcctUnionPay](https://cloud.tencent.com/document/api/#/#)
* [CheckAcct](https://cloud.tencent.com/document/api/#/#)
* [CheckAmount](https://cloud.tencent.com/document/api/#/#)
* [CloseOrder](https://cloud.tencent.com/document/api/#/#)
* [CreateAcct](https://cloud.tencent.com/document/api/#/#)
* [CreateCustAcctId](https://cloud.tencent.com/document/api/#/#)
* [DownloadBill](https://cloud.tencent.com/document/api/#/#)
* [ModifyMntMbrBindRelateAcctBankCode](https://cloud.tencent.com/document/api/#/#)
* [QueryBalance](https://cloud.tencent.com/document/api/#/#)
* [QueryBankClear](https://cloud.tencent.com/document/api/#/#)
* [QueryBankTransactionDetails](https://cloud.tencent.com/document/api/#/#)
* [QueryBankWithdrawCashDetails](https://cloud.tencent.com/document/api/#/#)
* [QueryCommonTransferRecharge](https://cloud.tencent.com/document/api/#/#)
* [QueryCustAcctIdBalance](https://cloud.tencent.com/document/api/#/#)
* [QueryMemberBind](https://cloud.tencent.com/document/api/#/#)
* [QueryMemberTransaction](https://cloud.tencent.com/document/api/#/#)
* [QueryOrder](https://cloud.tencent.com/document/api/#/#)
* [QueryReconciliationDocument](https://cloud.tencent.com/document/api/#/#)
* [QueryRefund](https://cloud.tencent.com/document/api/#/#)
* [QuerySingleTransactionStatus](https://cloud.tencent.com/document/api/#/#)
* [QuerySmallAmountTransfer](https://cloud.tencent.com/document/api/#/#)
* [RechargeMemberThirdPay](https://cloud.tencent.com/document/api/#/#)
* [Refund](https://cloud.tencent.com/document/api/#/#)
* [RegisterBillSupportWithdraw](https://cloud.tencent.com/document/api/#/#)
* [RevRegisterBillSupportWithdraw](https://cloud.tencent.com/document/api/1122/40654)
* [ReviseMbrProperty](https://cloud.tencent.com/document/api/#/#)
* [RevokeMemberRechargeThirdPay](https://cloud.tencent.com/document/api/#/#)
* [UnBindAcct](https://cloud.tencent.com/document/api/#/#)
* [UnbindRelateAcct](https://cloud.tencent.com/document/api/#/#)
* [UnifiedOrder](https://cloud.tencent.com/document/api/#/#)
* [WithdrawCashMembership](https://cloud.tencent.com/document/api/#/#)

新增数据结构：

* [Acct](https://cloud.tencent.com/document/api/1122/40683#Acct)
* [ClearItem](https://cloud.tencent.com/document/api/1122/40683#ClearItem)
* [FileItem](https://cloud.tencent.com/document/api/1122/40683#FileItem)
* [QueryItem](https://cloud.tencent.com/document/api/1122/40683#QueryItem)
* [QueryOrderOutOrderList](https://cloud.tencent.com/document/api/1122/40683#QueryOrderOutOrderList)
* [QueryOrderOutSubOrderList](https://cloud.tencent.com/document/api/1122/40683#QueryOrderOutSubOrderList)
* [RefundOutSubOrderRefundList](https://cloud.tencent.com/document/api/1122/40683#RefundOutSubOrderRefundList)
* [TranItem](https://cloud.tencent.com/document/api/1122/40683#TranItem)
* [TransactionItem](https://cloud.tencent.com/document/api/1122/40683#TransactionItem)
* [TransferItem](https://cloud.tencent.com/document/api/1122/40683#TransferItem)
* [UnifiedOrderInSubOrderList](https://cloud.tencent.com/document/api/1122/40683#UnifiedOrderInSubOrderList)
* [WithdrawItem](https://cloud.tencent.com/document/api/1122/40683#WithdrawItem)




## 金融联络机器人(cr) 版本：2018-03-21

### 第 17 次发布

发布时间：2021-02-24 08:03:24

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [QueryBlackListData](https://cloud.tencent.com/document/api/656/53039)

### 第 16 次发布

发布时间：2021-02-01 08:03:26

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [ApplyBlackListData](https://cloud.tencent.com/document/api/656/52653)
* [ChangeBotCallStatus](https://cloud.tencent.com/document/api/656/52652)
* [ChangeBotTaskStatus](https://cloud.tencent.com/document/api/656/52651)
* [QueryCallList](https://cloud.tencent.com/document/api/656/52650)
* [UpdateBotTask](https://cloud.tencent.com/document/api/656/52649)

修改接口：

* [CreateBotTask](https://cloud.tencent.com/document/api/656/50873)

	* 新增入参：CallType, CallStartDate, CallEndDate

	* <font color="#dd0000">**修改入参**：</font>CallTimeCollection, StartTimeBan, EndTimeBan

	* 新增出参：BotId


新增数据结构：

* [BlackListData](https://cloud.tencent.com/document/api/656/30994#BlackListData)
* [CallInfo](https://cloud.tencent.com/document/api/656/30994#CallInfo)

修改数据结构：

* [CallTimeDict](https://cloud.tencent.com/document/api/656/30994#CallTimeDict)

	* <font color="#dd0000">**修改成员**：</font>Monday, Tuesday, Wednesday, Thursday, Friday, Saturday, Sunday

* [CallTimeInfo](https://cloud.tencent.com/document/api/656/30994#CallTimeInfo)

	* <font color="#dd0000">**修改成员**：</font>StartTime, EndTime

* [RecordInfo](https://cloud.tencent.com/document/api/656/30994#RecordInfo)

	* 新增成员：CosFileName


### 第 15 次发布

发布时间：2021-01-15 08:03:19

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DownloadBotRecord](https://cloud.tencent.com/document/api/656/52063)

### 第 14 次发布

发布时间：2021-01-13 08:03:17

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [QueryBotList](https://cloud.tencent.com/document/api/656/51905)
* [QueryRecordList](https://cloud.tencent.com/document/api/656/51904)
* [UploadBotData](https://cloud.tencent.com/document/api/656/51903)

新增数据结构：

* [BotInfo](https://cloud.tencent.com/document/api/656/30994#BotInfo)
* [RecordInfo](https://cloud.tencent.com/document/api/656/30994#RecordInfo)

### 第 13 次发布

发布时间：2021-01-01 08:03:08

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [ExportBotData](https://cloud.tencent.com/document/api/656/51671)

新增数据结构：

* [BotFileData](https://cloud.tencent.com/document/api/656/30994#BotFileData)

### 第 12 次发布

发布时间：2020-12-11 08:03:22

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateBotTask](https://cloud.tencent.com/document/api/656/50873)
* [DescribeBotFlow](https://cloud.tencent.com/document/api/656/50872)
* [DescribeFileModel](https://cloud.tencent.com/document/api/656/50871)
* [UploadBotFile](https://cloud.tencent.com/document/api/656/50870)

新增数据结构：

* [BotFlow](https://cloud.tencent.com/document/api/656/30994#BotFlow)
* [CallTimeDict](https://cloud.tencent.com/document/api/656/30994#CallTimeDict)
* [CallTimeInfo](https://cloud.tencent.com/document/api/656/30994#CallTimeInfo)
* [PhonePool](https://cloud.tencent.com/document/api/656/30994#PhonePool)
* [SmsSign](https://cloud.tencent.com/document/api/656/30994#SmsSign)
* [SmsTemplate](https://cloud.tencent.com/document/api/656/30994#SmsTemplate)

### 第 11 次发布

发布时间：2020-11-23 08:03:42

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [QueryProducts](https://cloud.tencent.com/document/api/656/50187)

新增数据结构：

* [ProductQueryInfo](https://cloud.tencent.com/document/api/656/30994#ProductQueryInfo)

### 第 10 次发布

发布时间：2020-04-24 08:06:49

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [QueryInstantData](https://cloud.tencent.com/document/api/656/43742)
* [UploadDataJson](https://cloud.tencent.com/document/api/656/43741)

### 第 9 次发布

发布时间：2019-08-16 16:58:13

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DownloadDialogueText](https://cloud.tencent.com/document/api/656/37199)
* [DownloadRecordList](https://cloud.tencent.com/document/api/656/37198)

### 第 8 次发布

发布时间：2019-08-13 19:56:47

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeTaskStatus](https://cloud.tencent.com/document/api/656/18291)

	* 新增入参：InstId


### 第 7 次发布

发布时间：2019-05-30 20:58:03

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeTaskStatus](https://cloud.tencent.com/document/api/656/18291)

	* 新增出参：TaskFileUrl


修改数据结构：

* [SingleBlackApply](https://cloud.tencent.com/document/api/656/30994#SingleBlackApply)

	* 新增成员：BlackValidDate


### 第 6 次发布

发布时间：2019-03-22 14:48:33

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [ApplyCreditAudit](https://cloud.tencent.com/document/api/656/33893)
* [DescribeCreditResult](https://cloud.tencent.com/document/api/656/33892)

修改接口：

* [DownloadReport](https://cloud.tencent.com/document/api/656/18290)

	* 新增入参：InstId

	* 新增出参：CallbackDailyReportUrl, CallbackResultReportUrl, CallbackDetailReportUrl


### 第 5 次发布

发布时间：2019-03-01 19:58:53

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [ApplyBlackList](https://cloud.tencent.com/document/api/656/30993)

	* 新增入参：InstId

* [DescribeRecords](https://cloud.tencent.com/document/api/656/30992)

	* 新增入参：InstId

* [UploadDataFile](https://cloud.tencent.com/document/api/656/30991)

	* 新增入参：InstId


### 第 4 次发布

发布时间：2018-12-20 19:45:54

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeTaskStatus](https://cloud.tencent.com/document/api/656/18291)

	* <font color="#dd0000">**修改入参**：</font>TaskId


### 第 3 次发布

发布时间：2018-11-29 19:21:43

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [ApplyBlackList](https://cloud.tencent.com/document/api/656/30993)
* [DescribeRecords](https://cloud.tencent.com/document/api/656/30992)
* [UploadDataFile](https://cloud.tencent.com/document/api/656/30991)

新增数据结构：

* [SingleBlackApply](https://cloud.tencent.com/document/api/656/30994#SingleBlackApply)
* [SingleRecord](https://cloud.tencent.com/document/api/656/30994#SingleRecord)

### 第 2 次发布

发布时间：2018-08-30 16:14:59

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DownloadReport](https://cloud.tencent.com/document/api/656/18290)

	* 新增出参：DailyReportUrl, ResultReportUrl, DetailReportUrl

	* <font color="#dd0000">**删除出参**：</font>ReportUrl


### 第 1 次发布

发布时间：2018-07-12 15:09:22

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeTaskStatus](https://cloud.tencent.com/document/api/656/18291)
* [DownloadReport](https://cloud.tencent.com/document/api/656/18290)




## 云安全一体化平台(csip) 版本：2022-11-21

### 第 43 次发布

发布时间：2024-08-02 01:20:09

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeAlertList](https://cloud.tencent.com/document/api/664/105563)

	* 新增出参：ReturnCode, ReturnMsg


### 第 42 次发布

发布时间：2024-07-30 01:24:16

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeCFWAssetStatistics](https://cloud.tencent.com/document/api/664/109405)

### 第 41 次发布

发布时间：2024-07-03 01:12:26

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [TaskLogURL](https://cloud.tencent.com/document/api/664/90825#TaskLogURL)

	* <font color="#dd0000">**修改成员**：</font>URL, LogId, TaskLogName, AppId


### 第 40 次发布

发布时间：2024-06-20 01:24:58

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateDomainAndIp](https://cloud.tencent.com/document/api/664/93274)

	* 新增入参：MemberId

* [CreateRiskCenterScanTask](https://cloud.tencent.com/document/api/664/94177)

	* 新增入参：FinishWebHook

* [DeleteDomainAndIp](https://cloud.tencent.com/document/api/664/98743)

	* 新增入参：MemberId

* [ModifyRiskCenterScanTask](https://cloud.tencent.com/document/api/664/103117)

	* 新增入参：FinishWebHook


修改数据结构：

* [AssetViewVULRiskData](https://cloud.tencent.com/document/api/664/90825#AssetViewVULRiskData)

	* 新增成员：TvdID, IsOneClick

* [CVMAssetVO](https://cloud.tencent.com/document/api/664/90825#CVMAssetVO)

	* 新增成员：RealAppid, CloudType

* [VULViewVULRiskData](https://cloud.tencent.com/document/api/664/90825#VULViewVULRiskData)

	* 新增成员：TvdID, IsOneClick


### 第 39 次发布

发布时间：2024-06-19 01:24:50

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeVULRiskDetail](https://cloud.tencent.com/document/api/664/107483)
* [DescribeVulViewVulRiskList](https://cloud.tencent.com/document/api/664/107482)

新增数据结构：

* [VULRiskInfo](https://cloud.tencent.com/document/api/664/90825#VULRiskInfo)
* [VULViewVULRiskData](https://cloud.tencent.com/document/api/664/90825#VULViewVULRiskData)
* [VulImpactComponentInfo](https://cloud.tencent.com/document/api/664/90825#VulImpactComponentInfo)
* [VulTrend](https://cloud.tencent.com/document/api/664/90825#VulTrend)

### 第 38 次发布

发布时间：2024-05-16 01:26:49

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [UpdateAlertStatusList](https://cloud.tencent.com/document/api/664/106208)

新增数据结构：

* [NewAlertKey](https://cloud.tencent.com/document/api/664/90825#NewAlertKey)

### 第 37 次发布

发布时间：2024-05-10 01:27:43

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeCVMAssets](https://cloud.tencent.com/document/api/664/90821)

	* 新增出参：PublicPrivateAttr

* [DescribeDbAssets](https://cloud.tencent.com/document/api/664/90819)

	* 新增入参：MemberId

	* 新增出参：PublicPrivateAttr

* [DescribeOrganizationUserInfo](https://cloud.tencent.com/document/api/664/102512)

	* 新增入参：MemberId

	* 新增出参：JoinTypeLst, CloudTypeLst


修改数据结构：

* [OrganizationUserInfo](https://cloud.tencent.com/document/api/664/90825#OrganizationUserInfo)

	* 新增成员：SubUserCount, JoinTypeInfo


### 第 36 次发布

发布时间：2024-05-07 01:12:54

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateRiskCenterScanTask](https://cloud.tencent.com/document/api/664/94177)

	* 新增入参：MemberId

* [DeleteRiskScanTask](https://cloud.tencent.com/document/api/664/98745)

	* 新增入参：MemberId

* [DescribeRiskCenterAssetViewCFGRiskList](https://cloud.tencent.com/document/api/664/98822)

	* 新增入参：MemberId

* [DescribeRiskCenterAssetViewPortRiskList](https://cloud.tencent.com/document/api/664/93509)

	* 新增入参：MemberId

* [DescribeRiskCenterAssetViewVULRiskList](https://cloud.tencent.com/document/api/664/93508)

	* 新增入参：MemberId

* [DescribeRiskCenterAssetViewWeakPasswordRiskList](https://cloud.tencent.com/document/api/664/98821)

	* 新增入参：MemberId

* [DescribeRiskCenterPortViewPortRiskList](https://cloud.tencent.com/document/api/664/100198)

	* 新增入参：MemberId

* [DescribeRiskCenterServerRiskList](https://cloud.tencent.com/document/api/664/98820)

	* 新增入参：MemberId

* [DescribeRiskCenterVULViewVULRiskList](https://cloud.tencent.com/document/api/664/100197)

	* 新增入参：MemberId

* [DescribeRiskCenterWebsiteRiskList](https://cloud.tencent.com/document/api/664/98819)

	* 新增入参：MemberId

* [DescribeScanReportList](https://cloud.tencent.com/document/api/664/90815)

	* 新增入参：MemberId

* [DescribeScanTaskList](https://cloud.tencent.com/document/api/664/97683)

	* 新增入参：MemberId

* [DescribeTaskLogList](https://cloud.tencent.com/document/api/664/97682)

	* 新增入参：MemberId

* [DescribeTaskLogURL](https://cloud.tencent.com/document/api/664/97681)

	* 新增入参：MemberId

* [ModifyRiskCenterRiskStatus](https://cloud.tencent.com/document/api/664/100196)

	* 新增入参：MemberId

* [ModifyRiskCenterScanTask](https://cloud.tencent.com/document/api/664/103117)

	* 新增入参：MemberId

* [StopRiskCenterTask](https://cloud.tencent.com/document/api/664/98744)

	* 新增入参：MemberId


### 第 35 次发布

发布时间：2024-04-23 01:12:12

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeAlertList](https://cloud.tencent.com/document/api/664/105563)

新增数据结构：

* [AlertExtraInfo](https://cloud.tencent.com/document/api/664/90825#AlertExtraInfo)
* [AlertInfo](https://cloud.tencent.com/document/api/664/90825#AlertInfo)
* [KeyValue](https://cloud.tencent.com/document/api/664/90825#KeyValue)
* [RelatedEvent](https://cloud.tencent.com/document/api/664/90825#RelatedEvent)
* [RoleInfo](https://cloud.tencent.com/document/api/664/90825#RoleInfo)

### 第 34 次发布

发布时间：2024-04-08 01:11:35

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeAssetViewVulRiskList](https://cloud.tencent.com/document/api/664/104896)

新增数据结构：

* [AssetViewVULRiskData](https://cloud.tencent.com/document/api/664/90825#AssetViewVULRiskData)

### 第 33 次发布

发布时间：2024-03-28 01:12:39

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [AssetViewWeakPassRisk](https://cloud.tencent.com/document/api/664/90825#AssetViewWeakPassRisk)

	* <font color="#dd0000">**修改成员**：</font>AffectAsset, Level, InstanceType, Component, Service, RecentTime, FirstTime, Status, Id, Index, InstanceId, InstanceName, AppId, Nick, Uin, PasswordType, From, VULType, VULURL, Fix, Payload

* [PortViewPortRisk](https://cloud.tencent.com/document/api/664/90825#PortViewPortRisk)

	* <font color="#dd0000">**修改成员**：</font>NoHandleCount, Level, Protocol, Component, Port, RecentTime, FirstTime, Suggestion, AffectAssetCount, Id, From, Index, AppId, Nick, Uin, Service

* [WebsiteRisk](https://cloud.tencent.com/document/api/664/90825#WebsiteRisk)

	* <font color="#dd0000">**修改成员**：</font>AffectAsset, Level, RecentTime, FirstTime, Status, Id, Index, InstanceId, InstanceName, AppId, Nick, Uin, URL, URLPath, InstanceType, DetectEngine, ResultDescribe, SourceURL, SourceURLPath


### 第 32 次发布

发布时间：2024-03-04 01:11:59

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeTopAttackInfo](https://cloud.tencent.com/document/api/664/104060)

新增数据结构：

* [TagCount](https://cloud.tencent.com/document/api/664/90825#TagCount)

### 第 31 次发布

发布时间：2024-02-02 01:09:24

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeCVMAssets](https://cloud.tencent.com/document/api/664/90821)

	* 新增入参：MemberId

	* 新增出参：AssetMapInstanceTypeList

* [DescribeVULRiskAdvanceCFGList](https://cloud.tencent.com/document/api/664/100951)

	* 新增入参：MemberId

	* 新增出参：VulTagList


新增数据结构：

* [AssetInstanceTypeMap](https://cloud.tencent.com/document/api/664/90825#AssetInstanceTypeMap)
* [Element](https://cloud.tencent.com/document/api/664/90825#Element)
* [ServiceSupport](https://cloud.tencent.com/document/api/664/90825#ServiceSupport)

修改数据结构：

* [CVMAssetVO](https://cloud.tencent.com/document/api/664/90825#CVMAssetVO)

	* 新增成员：CVMAgentStatus, CVMStatus, DefenseModel, TatStatus, CpuTrend, MemoryTrend, AgentStatus, CloseDefenseCount, InstanceState, SecurityGroupIds, AgentMemRss, AgentCpuPer

* [RiskCenterStatusKey](https://cloud.tencent.com/document/api/664/90825#RiskCenterStatusKey)

	* <font color="#dd0000">**修改成员**：</font>AppId

* [VULRiskAdvanceCFGList](https://cloud.tencent.com/document/api/664/90825#VULRiskAdvanceCFGList)

	* 新增成员：Payload, References, CVSS, AttackHeat, ServiceSupport, RecentScanTime


### 第 30 次发布

发布时间：2024-01-31 01:10:44

本次发布包含了以下内容：

改善已有的文档。

新增数据结构：

* [PortRiskAdvanceCFGParamItem](https://cloud.tencent.com/document/api/664/90825#PortRiskAdvanceCFGParamItem)

修改数据结构：

* [TaskAdvanceCFG](https://cloud.tencent.com/document/api/664/90825#TaskAdvanceCFG)

	* 新增成员：PortRisk


### 第 29 次发布

发布时间：2024-01-22 01:09:58

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [ModifyRiskCenterScanTask](https://cloud.tencent.com/document/api/664/103117)

### 第 28 次发布

发布时间：2024-01-19 01:09:59

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [ModifyOrganizationAccountStatus](https://cloud.tencent.com/document/api/664/103094)

### 第 27 次发布

发布时间：2023-12-19 01:25:03

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeDomainAssets](https://cloud.tencent.com/document/api/664/93511)

	* 新增入参：MemberId

* [DescribeGatewayAssets](https://cloud.tencent.com/document/api/664/102291)

	* 新增入参：MemberId

* [DescribeListenerList](https://cloud.tencent.com/document/api/664/96103)

	* 新增入参：MemberId

* [DescribeNICAssets](https://cloud.tencent.com/document/api/664/102406)

	* 新增入参：MemberId

* [DescribePublicIpAssets](https://cloud.tencent.com/document/api/664/93510)

	* 新增入参：MemberId


### 第 26 次发布

发布时间：2023-12-15 19:18:42

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeOrganizationUserInfo](https://cloud.tencent.com/document/api/664/102512)

新增数据结构：

* [OrganizationUserInfo](https://cloud.tencent.com/document/api/664/90825#OrganizationUserInfo)

### 第 25 次发布

发布时间：2023-12-12 01:27:48

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeNICAssets](https://cloud.tencent.com/document/api/664/102406)

新增数据结构：

* [NICAsset](https://cloud.tencent.com/document/api/664/90825#NICAsset)

### 第 24 次发布

发布时间：2023-12-08 01:27:48

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeGatewayAssets](https://cloud.tencent.com/document/api/664/102291)

新增数据结构：

* [GateWayAsset](https://cloud.tencent.com/document/api/664/90825#GateWayAsset)

### 第 23 次发布

发布时间：2023-11-16 01:12:23

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [AssetViewVULRisk](https://cloud.tencent.com/document/api/664/90825#AssetViewVULRisk)

	* <font color="#dd0000">**修改成员**：</font>AffectAsset, Level, InstanceType, Component, Service, RecentTime, FirstTime, Status, Id, Index, InstanceId, InstanceName, AppId, Nick, Uin, VULType, Port, Describe, AppName, References, AppVersion, VULURL, VULName, CVE, Fix, POCId, From, CWPVersion, IsSupportRepair, IsSupportDetect, InstanceUUID, Payload, EMGCVulType


### 第 22 次发布

发布时间：2023-11-15 01:23:10

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [ScanTaskInfo](https://cloud.tencent.com/document/api/664/90825#ScanTaskInfo)

	* <font color="#dd0000">**修改成员**：</font>AppId, UIN, UserName

* [VULViewVULRisk](https://cloud.tencent.com/document/api/664/90825#VULViewVULRisk)

	* <font color="#dd0000">**修改成员**：</font>Port, NoHandleCount, Level, Component, RecentTime, FirstTime, AffectAssetCount, Id, From, Index, VULType, VULName, CVE, Describe, Payload, AppName, References, AppVersion, VULURL, Nick, AppId, Uin, Fix, EMGCVulType


### 第 21 次发布

发布时间：2023-11-13 00:07:56

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [AssetViewPortRisk](https://cloud.tencent.com/document/api/664/90825#AssetViewPortRisk)

	* <font color="#dd0000">**修改成员**：</font>Port, AffectAsset, Level, InstanceType, Protocol, Component, Service, RecentTime, FirstTime, Suggestion, Status, Id, Index, InstanceId, InstanceName, AppId, Nick, Uin, From


### 第 20 次发布

发布时间：2023-11-03 01:10:39

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeTaskLogList](https://cloud.tencent.com/document/api/664/97682)

	* 新增出参：ReportTemplateNumber


修改数据结构：

* [TaskLogInfo](https://cloud.tencent.com/document/api/664/90825#TaskLogInfo)

	* 新增成员：ReportType, TemplateId

	* <font color="#dd0000">**修改成员**：</font>TaskLogName, TaskLogId, AssetsNumber, RiskNumber, Time, Status, TaskName, StartTime, TaskCenterTaskId, AppId, UIN, UserName


### 第 19 次发布

发布时间：2023-10-31 01:30:05

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [VULRiskAdvanceCFGList](https://cloud.tencent.com/document/api/664/90825#VULRiskAdvanceCFGList)

	* 新增成员：RiskId


### 第 18 次发布

发布时间：2023-10-30 00:24:02

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeVULRiskAdvanceCFGList](https://cloud.tencent.com/document/api/664/100951)

新增数据结构：

* [VULRiskAdvanceCFGList](https://cloud.tencent.com/document/api/664/90825#VULRiskAdvanceCFGList)

### 第 17 次发布

发布时间：2023-10-27 01:27:32

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateDomainAndIp](https://cloud.tencent.com/document/api/664/93274)

	* 新增入参：Tags

* [CreateRiskCenterScanTask](https://cloud.tencent.com/document/api/664/94177)

	* 新增入参：Tags

* [DeleteDomainAndIp](https://cloud.tencent.com/document/api/664/98743)

	* 新增入参：Tags, Type

	* <font color="#dd0000">**修改入参**：</font>Content

* [DescribeDomainAssets](https://cloud.tencent.com/document/api/664/93511)

	* 新增入参：Tags

* [DescribePublicIpAssets](https://cloud.tencent.com/document/api/664/93510)

	* 新增入参：Tags

* [DescribeRiskCenterAssetViewCFGRiskList](https://cloud.tencent.com/document/api/664/98822)

	* 新增入参：Tags

* [DescribeRiskCenterAssetViewPortRiskList](https://cloud.tencent.com/document/api/664/93509)

	* 新增入参：Tags

* [DescribeRiskCenterAssetViewVULRiskList](https://cloud.tencent.com/document/api/664/93508)

	* 新增入参：Tags

* [DescribeRiskCenterAssetViewWeakPasswordRiskList](https://cloud.tencent.com/document/api/664/98821)

	* 新增入参：Tags

* [DescribeRiskCenterPortViewPortRiskList](https://cloud.tencent.com/document/api/664/100198)

	* 新增入参：Tags

* [DescribeRiskCenterServerRiskList](https://cloud.tencent.com/document/api/664/98820)

	* 新增入参：Tags

* [DescribeRiskCenterVULViewVULRiskList](https://cloud.tencent.com/document/api/664/100197)

	* 新增入参：Tags

* [DescribeRiskCenterWebsiteRiskList](https://cloud.tencent.com/document/api/664/98819)

	* 新增入参：Tags

* [DescribeScanTaskList](https://cloud.tencent.com/document/api/664/97683)

	* 新增入参：Tags

* [DescribeTaskLogURL](https://cloud.tencent.com/document/api/664/97681)

	* 新增入参：ReportTaskIdList

	* <font color="#dd0000">**修改入参**：</font>ReportItemKeyList


新增数据结构：

* [AssetTag](https://cloud.tencent.com/document/api/664/90825#AssetTag)
* [ReportTaskIdList](https://cloud.tencent.com/document/api/664/90825#ReportTaskIdList)
* [Tags](https://cloud.tencent.com/document/api/664/90825#Tags)

### 第 16 次发布

发布时间：2023-10-16 01:11:35

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateRiskCenterScanTask](https://cloud.tencent.com/document/api/664/94177)

	* 新增入参：ScanFrom


### 第 15 次发布

发布时间：2023-10-13 01:12:24

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeRiskCenterPortViewPortRiskList](https://cloud.tencent.com/document/api/664/100198)
* [DescribeRiskCenterVULViewVULRiskList](https://cloud.tencent.com/document/api/664/100197)
* [ModifyRiskCenterRiskStatus](https://cloud.tencent.com/document/api/664/100196)

新增数据结构：

* [PortViewPortRisk](https://cloud.tencent.com/document/api/664/90825#PortViewPortRisk)
* [RiskCenterStatusKey](https://cloud.tencent.com/document/api/664/90825#RiskCenterStatusKey)
* [VULViewVULRisk](https://cloud.tencent.com/document/api/664/90825#VULViewVULRisk)

### 第 14 次发布

发布时间：2023-09-27 01:12:21

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeDbAssets](https://cloud.tencent.com/document/api/664/90819)

	* 新增入参：AssetTypes


修改数据结构：

* [AssetViewCFGRisk](https://cloud.tencent.com/document/api/664/90825#AssetViewCFGRisk)

	* <font color="#dd0000">**修改成员**：</font>Id, CFGName, CheckType, InstanceId, InstanceName, InstanceType, AffectAsset, Level, FirstTime, RecentTime, From, Status, CFGSTD, CFGDescribe, CFGFix, CFGHelpURL, Index, AppId, Nick, Uin

* [ScanTaskInfoList](https://cloud.tencent.com/document/api/664/90825#ScanTaskInfoList)

	* 新增成员：SourceType

* [TaskAssetObject](https://cloud.tencent.com/document/api/664/90825#TaskAssetObject)

	* 新增成员：Arn


### 第 13 次发布

发布时间：2023-09-25 01:10:56

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeRiskCenterAssetViewCFGRiskList](https://cloud.tencent.com/document/api/664/98822)
* [DescribeRiskCenterAssetViewWeakPasswordRiskList](https://cloud.tencent.com/document/api/664/98821)
* [DescribeRiskCenterServerRiskList](https://cloud.tencent.com/document/api/664/98820)
* [DescribeRiskCenterWebsiteRiskList](https://cloud.tencent.com/document/api/664/98819)

新增数据结构：

* [AssetViewCFGRisk](https://cloud.tencent.com/document/api/664/90825#AssetViewCFGRisk)
* [AssetViewWeakPassRisk](https://cloud.tencent.com/document/api/664/90825#AssetViewWeakPassRisk)
* [ServerRisk](https://cloud.tencent.com/document/api/664/90825#ServerRisk)
* [ServerRiskSuggestion](https://cloud.tencent.com/document/api/664/90825#ServerRiskSuggestion)
* [WebsiteRisk](https://cloud.tencent.com/document/api/664/90825#WebsiteRisk)

### 第 12 次发布

发布时间：2023-09-22 01:31:21

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DeleteDomainAndIp](https://cloud.tencent.com/document/api/664/98743)
* [DeleteRiskScanTask](https://cloud.tencent.com/document/api/664/98745)
* [StopRiskCenterTask](https://cloud.tencent.com/document/api/664/98744)

新增数据结构：

* [PublicIpDomainListKey](https://cloud.tencent.com/document/api/664/90825#PublicIpDomainListKey)
* [TaskIdListKey](https://cloud.tencent.com/document/api/664/90825#TaskIdListKey)

### 第 11 次发布

发布时间：2023-09-12 01:32:51

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [DomainAssetVO](https://cloud.tencent.com/document/api/664/90825#DomainAssetVO)

	* 新增成员：BotAccessCount


### 第 10 次发布

发布时间：2023-09-01 01:11:09

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeScanTaskList](https://cloud.tencent.com/document/api/664/97683)
* [DescribeSearchBugInfo](https://cloud.tencent.com/document/api/664/97679)
* [DescribeTaskLogList](https://cloud.tencent.com/document/api/664/97682)
* [DescribeTaskLogURL](https://cloud.tencent.com/document/api/664/97681)

新增数据结构：

* [AssetInfoDetail](https://cloud.tencent.com/document/api/664/90825#AssetInfoDetail)
* [BugInfoDetail](https://cloud.tencent.com/document/api/664/90825#BugInfoDetail)
* [DataSearchBug](https://cloud.tencent.com/document/api/664/90825#DataSearchBug)
* [ReportItemKey](https://cloud.tencent.com/document/api/664/90825#ReportItemKey)
* [ScanTaskInfoList](https://cloud.tencent.com/document/api/664/90825#ScanTaskInfoList)
* [TaskLogInfo](https://cloud.tencent.com/document/api/664/90825#TaskLogInfo)
* [TaskLogURL](https://cloud.tencent.com/document/api/664/90825#TaskLogURL)

### 第 9 次发布

发布时间：2023-08-31 01:11:48

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [ClbListenerListInfo](https://cloud.tencent.com/document/api/664/90825#ClbListenerListInfo)

	* 新增成员：LoadBalancerDomain

	* <font color="#dd0000">**修改成员**：</font>ListenerId, ListenerName, LoadBalancerId, LoadBalancerName, Protocol, Region, Vip, VPort, Zone, NumericalVpcId, LoadBalancerType, Domain


### 第 8 次发布

发布时间：2023-08-09 01:17:49

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeListenerList](https://cloud.tencent.com/document/api/664/96103)

新增数据结构：

* [ClbListenerListInfo](https://cloud.tencent.com/document/api/664/90825#ClbListenerListInfo)

### 第 7 次发布

发布时间：2023-08-08 01:12:25

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateRiskCenterScanTask](https://cloud.tencent.com/document/api/664/94177)

	* 新增出参：Status, UnAuthAsset


修改数据结构：

* [AssetClusterPod](https://cloud.tencent.com/document/api/664/90825#AssetClusterPod)

	* 新增成员：IsNewAsset

	* <font color="#dd0000">**修改成员**：</font>AppId, Uin, Nick, Region, AssetId, AssetName, InstanceCreateTime, Namespace, Status, ClusterId, ClusterName, MachineId, MachineName, PodIp, ServiceCount, ContainerCount, PublicIp, PrivateIp, IsCore

* [CVMAssetVO](https://cloud.tencent.com/document/api/664/90825#CVMAssetVO)

	* 新增成员：IsNewAsset

* [DBAssetVO](https://cloud.tencent.com/document/api/664/90825#DBAssetVO)

	* 新增成员：IsNewAsset

	* <font color="#dd0000">**修改成员**：</font>AssetId, AssetName, AssetType, VpcId, VpcName, Region, Domain, AssetCreateTime, LastScanTime, ConfigurationRisk, Attack, Access, ScanTask, AppId, Uin, NickName, Port, Tag, PrivateIp, PublicIp, Status, IsCore

* [DomainAssetVO](https://cloud.tencent.com/document/api/664/90825#DomainAssetVO)

	* 新增成员：IsNewAsset, VerifyDomain, VerifyTXTRecord, VerifyStatus

* [IpAssetListVO](https://cloud.tencent.com/document/api/664/90825#IpAssetListVO)

	* 新增成员：IsNewAsset, VerifyStatus

	* <font color="#dd0000">**修改成员**：</font>AssetId, AssetName, AssetType, Region, CFWStatus, AssetCreateTime, PublicIp, PublicIpType, VpcId, VpcName, AppId, Uin, NickName, IsCore, IsCloud, Attack, Access, Intercept, InBandwidth, OutBandwidth, InFlow, OutFlow, LastScanTime, PortRisk, VulnerabilityRisk, ConfigurationRisk, ScanTask, WeakPassword, WebContentRisk, Tag, AddressId, MemberId, RiskExposure

* [SubnetAsset](https://cloud.tencent.com/document/api/664/90825#SubnetAsset)

	* 新增成员：IsNewAsset

	* <font color="#dd0000">**修改成员**：</font>AppId, Uin, AssetId, AssetName, Region, VpcId, VpcName, Tag, Nick, CIDR, Zone, CVM, AvailableIp, CreateTime, ConfigureRisk, ScanTask, LastScanTime, IsCore

* [Vpc](https://cloud.tencent.com/document/api/664/90825#Vpc)

	* 新增成员：IsNewAsset, IsCore

	* <font color="#dd0000">**修改成员**：</font>Subnet, ConnectedVpc, AssetId, Region, CVM, Tag, DNS, AssetName, CIDR, CreateTime, AppId, Uin, Nick


### 第 6 次发布

发布时间：2023-07-18 01:21:16

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [DomainAssetVO](https://cloud.tencent.com/document/api/664/90825#DomainAssetVO)

	* 新增成员：ServiceRisk

	* <font color="#dd0000">**修改成员**：</font>AssetId, AssetName, AssetType, Region, WAFStatus, AssetCreateTime, AppId, Uin, NickName, IsCore, IsCloud, Attack, Access, Intercept, InBandwidth, OutBandwidth, InFlow, OutFlow, LastScanTime, PortRisk, VulnerabilityRisk, ConfigurationRisk, ScanTask, SubDomain, SeverIp, BotCount, WeakPassword, WebContentRisk, Tag, SourceType, MemberId, CCAttack, WebAttack


### 第 5 次发布

发布时间：2023-06-20 01:16:16

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateRiskCenterScanTask](https://cloud.tencent.com/document/api/664/94177)

新增数据结构：

* [TaskAdvanceCFG](https://cloud.tencent.com/document/api/664/90825#TaskAdvanceCFG)
* [TaskAssetObject](https://cloud.tencent.com/document/api/664/90825#TaskAssetObject)
* [TaskCenterCFGRiskInputParam](https://cloud.tencent.com/document/api/664/90825#TaskCenterCFGRiskInputParam)
* [TaskCenterVulRiskInputParam](https://cloud.tencent.com/document/api/664/90825#TaskCenterVulRiskInputParam)
* [TaskCenterWeakPwdRiskInputParam](https://cloud.tencent.com/document/api/664/90825#TaskCenterWeakPwdRiskInputParam)

### 第 4 次发布

发布时间：2023-06-15 01:11:27

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeClusterPodAssets](https://cloud.tencent.com/document/api/664/93512)
* [DescribeDomainAssets](https://cloud.tencent.com/document/api/664/93511)
* [DescribePublicIpAssets](https://cloud.tencent.com/document/api/664/93510)
* [DescribeRiskCenterAssetViewPortRiskList](https://cloud.tencent.com/document/api/664/93509)
* [DescribeRiskCenterAssetViewVULRiskList](https://cloud.tencent.com/document/api/664/93508)

新增数据结构：

* [AssetClusterPod](https://cloud.tencent.com/document/api/664/90825#AssetClusterPod)
* [AssetViewPortRisk](https://cloud.tencent.com/document/api/664/90825#AssetViewPortRisk)
* [AssetViewVULRisk](https://cloud.tencent.com/document/api/664/90825#AssetViewVULRisk)
* [DomainAssetVO](https://cloud.tencent.com/document/api/664/90825#DomainAssetVO)
* [IpAssetListVO](https://cloud.tencent.com/document/api/664/90825#IpAssetListVO)

修改数据结构：

* [CVMAssetVO](https://cloud.tencent.com/document/api/664/90825#CVMAssetVO)

	* 新增成员：BASAgentStatus


### 第 3 次发布

发布时间：2023-06-08 01:17:51

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateDomainAndIp](https://cloud.tencent.com/document/api/664/93274)

### 第 2 次发布

发布时间：2023-05-19 01:27:03

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeCVMAssets](https://cloud.tencent.com/document/api/664/90821)

	* 新增出参：OsList


修改数据结构：

* [CVMAssetVO](https://cloud.tencent.com/document/api/664/90825#CVMAssetVO)

	* 新增成员：RiskExposure


### 第 1 次发布

发布时间：2023-05-08 10:25:58

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [AddNewBindRoleUser](https://cloud.tencent.com/document/api/664/90824)
* [DescribeCVMAssetInfo](https://cloud.tencent.com/document/api/664/90822)
* [DescribeCVMAssets](https://cloud.tencent.com/document/api/664/90821)
* [DescribeDbAssetInfo](https://cloud.tencent.com/document/api/664/90820)
* [DescribeDbAssets](https://cloud.tencent.com/document/api/664/90819)
* [DescribeScanReportList](https://cloud.tencent.com/document/api/664/90815)
* [DescribeSubnetAssets](https://cloud.tencent.com/document/api/664/90818)
* [DescribeVpcAssets](https://cloud.tencent.com/document/api/664/90817)

新增数据结构：

* [AssetBaseInfoResponse](https://cloud.tencent.com/document/api/664/90825#AssetBaseInfoResponse)
* [CVMAssetVO](https://cloud.tencent.com/document/api/664/90825#CVMAssetVO)
* [DBAssetVO](https://cloud.tencent.com/document/api/664/90825#DBAssetVO)
* [DbAssetInfo](https://cloud.tencent.com/document/api/664/90825#DbAssetInfo)
* [Filter](https://cloud.tencent.com/document/api/664/90825#Filter)
* [FilterDataObject](https://cloud.tencent.com/document/api/664/90825#FilterDataObject)
* [ScanTaskInfo](https://cloud.tencent.com/document/api/664/90825#ScanTaskInfo)
* [SubnetAsset](https://cloud.tencent.com/document/api/664/90825#SubnetAsset)
* [Tag](https://cloud.tencent.com/document/api/664/90825#Tag)
* [Vpc](https://cloud.tencent.com/document/api/664/90825#Vpc)
* [WhereFilter](https://cloud.tencent.com/document/api/664/90825#WhereFilter)




## 5G入云服务(csxg) 版本：2023-03-03

### 第 1 次发布

发布时间：2023-05-19 11:26:14

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [Create5GInstance](https://cloud.tencent.com/document/api/1687/91680)
* [Delete5GInstance](https://cloud.tencent.com/document/api/1687/91679)
* [Describe5GAPNs](https://cloud.tencent.com/document/api/1687/91678)
* [Describe5GInstances](https://cloud.tencent.com/document/api/1687/91677)
* [Modify5GInstanceAttribute](https://cloud.tencent.com/document/api/1687/91676)




## 云服务器(cvm) 版本：2017-03-12

### 第 128 次发布

发布时间：2024-07-22 01:24:41

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [EnterRescueMode](https://cloud.tencent.com/document/api/213/109044)
* [ExitRescueMode](https://cloud.tencent.com/document/api/213/109043)

### 第 127 次发布

发布时间：2024-05-17 01:23:32

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [RunInstances](https://cloud.tencent.com/document/api/213/15730)

	* 新增入参：CpuTopology


新增数据结构：

* [CpuTopology](https://cloud.tencent.com/document/api/213/15753#CpuTopology)

### 第 126 次发布

发布时间：2024-05-07 01:13:09

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [InstanceStatus](https://cloud.tencent.com/document/api/213/15753#InstanceStatus)

	* <font color="#dd0000">**修改成员**：</font>InstanceId, InstanceState


### 第 125 次发布

发布时间：2024-03-08 01:12:05

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateKeyPair](https://cloud.tencent.com/document/api/213/15702)

	* <font color="#dd0000">**修改出参**：</font>KeyPair


修改数据结构：

* [KeyPair](https://cloud.tencent.com/document/api/213/15753#KeyPair)

	* <font color="#dd0000">**修改成员**：</font>KeyId, KeyName, ProjectId, Description, PublicKey, PrivateKey, AssociatedInstanceIds, CreatedTime, Tags


### 第 124 次发布

发布时间：2024-02-27 01:11:44

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DeleteInstancesActionTimer](https://cloud.tencent.com/document/api/213/103951)
* [DescribeInstancesActionTimer](https://cloud.tencent.com/document/api/213/103950)
* [ImportInstancesActionTimer](https://cloud.tencent.com/document/api/213/103949)

修改接口：

* [CreateHpcCluster](https://cloud.tencent.com/document/api/213/83222)

	* 新增入参：HpcClusterType, HpcClusterBusinessId

* [DescribeHpcClusters](https://cloud.tencent.com/document/api/213/83220)

	* 新增入参：HpcClusterType, HpcClusterBusinessId


修改数据结构：

* [HpcClusterInfo](https://cloud.tencent.com/document/api/213/15753#HpcClusterInfo)

	* 新增成员：HpcClusterType, HpcClusterBusinessId


### 第 123 次发布

发布时间：2023-12-22 01:11:31

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [InstanceRefund](https://cloud.tencent.com/document/api/213/15753#InstanceRefund)

	* <font color="#dd0000">**修改成员**：</font>InstanceId, Refunds, PriceDetail


### 第 122 次发布

发布时间：2023-12-01 01:12:05

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [ModifyInstancesAttribute](https://cloud.tencent.com/document/api/213/15739)

	* 新增入参：AutoReboot


修改数据结构：

* [DataDisk](https://cloud.tencent.com/document/api/213/15753#DataDisk)

	* 新增成员：BurstPerformance

* [Image](https://cloud.tencent.com/document/api/213/15753#Image)

	* <font color="#dd0000">**修改成员**：</font>ImageId, OsName, ImageType, Platform, ImageCreator, ImageSource, LicenseType


### 第 121 次发布

发布时间：2023-11-23 01:14:32

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [ModifyInstancesAttribute](https://cloud.tencent.com/document/api/213/15739)

	* 新增入参：UserData


### 第 120 次发布

发布时间：2023-11-20 00:06:15

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [InstanceTypeConfig](https://cloud.tencent.com/document/api/213/15753#InstanceTypeConfig)

	* <font color="#dd0000">**修改成员**：</font>Zone, InstanceType, InstanceFamily, GPU, CPU, Memory


### 第 119 次发布

发布时间：2023-10-30 00:24:37

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [ImportKeyPair](https://cloud.tencent.com/document/api/213/15703)

	* <font color="#dd0000">**修改出参**：</font>KeyId


### 第 118 次发布

发布时间：2023-10-27 01:28:27

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [InquiryPriceRunInstances](https://cloud.tencent.com/document/api/213/15726)

	* 新增入参：LaunchTemplate


修改数据结构：

* [Price](https://cloud.tencent.com/document/api/213/15753#Price)

	* <font color="#dd0000">**修改成员**：</font>InstancePrice, BandwidthPrice


### 第 117 次发布

发布时间：2023-10-09 01:11:19

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [InstanceTypeQuotaItem](https://cloud.tencent.com/document/api/213/15753#InstanceTypeQuotaItem)

	* 新增成员：StatusCategory


### 第 116 次发布

发布时间：2023-09-13 01:29:52

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [HostItem](https://cloud.tencent.com/document/api/213/15753#HostItem)

	* 新增成员：Tags

	* <font color="#dd0000">**修改成员**：</font>Placement, HostId, HostType, HostName, HostChargeType, RenewFlag, CreatedTime, ExpiredTime, InstanceIds, HostState, HostIp, HostResource


### 第 115 次发布

发布时间：2023-09-06 01:29:11

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [Placement](https://cloud.tencent.com/document/api/213/15753#Placement)

	* <font color="#dd0000">**删除成员**：</font>HostIps


### 第 114 次发布

发布时间：2023-08-30 01:11:15

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [HostResource](https://cloud.tencent.com/document/api/213/15753#HostResource)

	* 新增成员：ExclusiveOwner

	* <font color="#dd0000">**修改成员**：</font>CpuTotal, CpuAvailable, MemTotal, MemAvailable, DiskTotal, DiskAvailable, GpuTotal, GpuAvailable


### 第 113 次发布

发布时间：2023-08-10 01:11:31

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [SyncImages](https://cloud.tencent.com/document/api/213/15711)

	* <font color="#dd0000">**修改出参**：</font>ImageSet


### 第 112 次发布

发布时间：2023-07-19 01:16:55

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [StorageBlock](https://cloud.tencent.com/document/api/213/15753#StorageBlock)

	* <font color="#dd0000">**修改成员**：</font>Type, MinSize, MaxSize


### 第 111 次发布

发布时间：2023-07-18 01:21:28

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [ItemPrice](https://cloud.tencent.com/document/api/213/15753#ItemPrice)

	* <font color="#dd0000">**修改成员**：</font>UnitPrice, ChargeUnit, OriginalPrice, DiscountPrice, Discount, UnitPriceDiscount, UnitPriceSecondStep, UnitPriceDiscountSecondStep, UnitPriceThirdStep, UnitPriceDiscountThirdStep, OriginalPriceThreeYear, DiscountPriceThreeYear, DiscountThreeYear, OriginalPriceFiveYear, DiscountPriceFiveYear, DiscountFiveYear, OriginalPriceOneYear, DiscountPriceOneYear, DiscountOneYear


### 第 110 次发布

发布时间：2023-07-17 01:12:06

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [Instance](https://cloud.tencent.com/document/api/213/15753#Instance)

	* 新增成员：DedicatedClusterId


### 第 109 次发布

发布时间：2023-05-25 01:20:37

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [InstanceTypeConfig](https://cloud.tencent.com/document/api/213/15753#InstanceTypeConfig)

	* 新增成员：GpuCount


### 第 108 次发布

发布时间：2023-05-09 01:11:50

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [DisasterRecoverGroup](https://cloud.tencent.com/document/api/213/15753#DisasterRecoverGroup)

	* <font color="#dd0000">**修改成员**：</font>CreateTime


### 第 107 次发布

发布时间：2023-04-27 01:14:08

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeAccountQuota](https://cloud.tencent.com/document/api/213/55628)

	* <font color="#dd0000">**修改出参**：</font>AppId


### 第 106 次发布

发布时间：2023-03-24 01:28:57

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [LaunchTemplateVersionData](https://cloud.tencent.com/document/api/213/15753#LaunchTemplateVersionData)

	* 新增成员：DisableApiTermination


### 第 105 次发布

发布时间：2023-03-10 01:19:38

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [RepairTaskControl](https://cloud.tencent.com/document/api/213/88101)

修改接口：

* [InquiryPriceTerminateInstances](https://cloud.tencent.com/document/api/213/58193)

	* <font color="#dd0000">**修改出参**：</font>InstanceRefundsSet

* [TerminateInstances](https://cloud.tencent.com/document/api/213/15723)

	* 新增入参：ReleasePrepaidDataDisks


### 第 104 次发布

发布时间：2023-03-09 01:16:53

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeTaskInfo](https://cloud.tencent.com/document/api/213/87933)

修改接口：

* [ImportImage](https://cloud.tencent.com/document/api/213/15717)

	* 新增入参：BootMode


新增数据结构：

* [RepairTaskInfo](https://cloud.tencent.com/document/api/213/15753#RepairTaskInfo)

### 第 103 次发布

发布时间：2022-12-28 01:05:55

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [InquiryPriceRenewHosts](https://cloud.tencent.com/document/api/213/84595)

新增数据结构：

* [HostPriceInfo](https://cloud.tencent.com/document/api/213/15753#HostPriceInfo)

### 第 102 次发布

发布时间：2022-12-19 01:29:05

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [ExportImages](https://cloud.tencent.com/document/api/213/73474)

	* 新增出参：CosPaths


### 第 101 次发布

发布时间：2022-12-16 01:16:54

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [Instance](https://cloud.tencent.com/document/api/213/15753#Instance)

	* 新增成员：DefaultLoginUser, DefaultLoginPort, LatestOperationErrorMsg


### 第 100 次发布

发布时间：2022-12-07 06:29:50

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [InstanceTypeQuotaItem](https://cloud.tencent.com/document/api/213/15753#InstanceTypeQuotaItem)

	* 新增成员：GpuCount, Frequency


### 第 99 次发布

发布时间：2022-11-29 06:30:25

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [SyncImages](https://cloud.tencent.com/document/api/213/15711)

	* 新增入参：ImageSetRequired

	* 新增出参：ImageSet


新增数据结构：

* [SyncImage](https://cloud.tencent.com/document/api/213/15753#SyncImage)

### 第 98 次发布

发布时间：2022-11-23 06:18:34

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateHpcCluster](https://cloud.tencent.com/document/api/213/83222)
* [DeleteHpcClusters](https://cloud.tencent.com/document/api/213/83221)
* [DescribeHpcClusters](https://cloud.tencent.com/document/api/213/83220)
* [ModifyHpcClusterAttribute](https://cloud.tencent.com/document/api/213/83219)

新增数据结构：

* [HpcClusterInfo](https://cloud.tencent.com/document/api/213/15753#HpcClusterInfo)

### 第 97 次发布

发布时间：2022-11-15 06:17:11

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [ActionTimer](https://cloud.tencent.com/document/api/213/15753#ActionTimer)

	* <font color="#dd0000">**修改成员**：</font>Externals


### 第 96 次发布

发布时间：2022-11-02 06:16:11

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [ResetInstance](https://cloud.tencent.com/document/api/213/15724)

	* 新增入参：UserData


### 第 95 次发布

发布时间：2022-09-30 06:22:32

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [Instance](https://cloud.tencent.com/document/api/213/15753#Instance)

	* 新增成员：DisableApiTermination


### 第 94 次发布

发布时间：2022-09-16 06:17:50

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [ModifyInstancesAttribute](https://cloud.tencent.com/document/api/213/15739)

	* 新增入参：HostName


### 第 93 次发布

发布时间：2022-08-17 06:17:00

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [SyncImages](https://cloud.tencent.com/document/api/213/15711)

	* 新增入参：ImageName


### 第 92 次发布

发布时间：2022-08-08 06:14:02

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeChcDeniedActions](https://cloud.tencent.com/document/api/213/78724)

新增数据结构：

* [ChcHostDeniedActions](https://cloud.tencent.com/document/api/213/15753#ChcHostDeniedActions)

### 第 91 次发布

发布时间：2022-07-22 06:05:40

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [ImportImage](https://cloud.tencent.com/document/api/213/15717)

	* 新增入参：LicenseType


### 第 90 次发布

发布时间：2022-07-12 06:08:19

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateKeyPair](https://cloud.tencent.com/document/api/213/15702)

	* 新增入参：TagSpecification

* [ImportKeyPair](https://cloud.tencent.com/document/api/213/15703)

	* 新增入参：TagSpecification


### 第 89 次发布

发布时间：2022-07-05 06:10:41

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [ConfigureChcAssistVpc](https://cloud.tencent.com/document/api/213/76417)
* [ConfigureChcDeployVpc](https://cloud.tencent.com/document/api/213/76416)
* [ModifyChcAttribute](https://cloud.tencent.com/document/api/213/76415)
* [RemoveChcAssistVpc](https://cloud.tencent.com/document/api/213/76414)
* [RemoveChcDeployVpc](https://cloud.tencent.com/document/api/213/76413)

### 第 88 次发布

发布时间：2022-07-04 06:06:18

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeChcHosts](https://cloud.tencent.com/document/api/213/76366)

新增数据结构：

* [ChcDeployExtraConfig](https://cloud.tencent.com/document/api/213/15753#ChcDeployExtraConfig)
* [ChcHost](https://cloud.tencent.com/document/api/213/15753#ChcHost)

### 第 87 次发布

发布时间：2022-06-16 06:04:38

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateKeyPair](https://cloud.tencent.com/document/api/213/15702)

	* <font color="#dd0000">**修改出参**：</font>KeyPair

* [ImportKeyPair](https://cloud.tencent.com/document/api/213/15703)

	* <font color="#dd0000">**修改出参**：</font>KeyId


修改数据结构：

* [KeyPair](https://cloud.tencent.com/document/api/213/15753#KeyPair)

	* 新增成员：Tags


### 第 86 次发布

发布时间：2022-06-03 06:05:18

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [ModifyInstancesAttribute](https://cloud.tencent.com/document/api/213/15739)

	* 新增入参：CamRoleName, CamRoleType


### 第 85 次发布

发布时间：2022-06-02 06:05:44

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [Image](https://cloud.tencent.com/document/api/213/15753#Image)

	* 新增成员：LicenseType

* [Instance](https://cloud.tencent.com/document/api/213/15753#Instance)

	* 新增成员：LicenseType


### 第 84 次发布

发布时间：2022-05-25 06:06:32

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateLaunchTemplateVersion](https://cloud.tencent.com/document/api/213/66326)

	* 新增入参：DisableApiTermination


### 第 83 次发布

发布时间：2022-05-23 06:05:51

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [HostResource](https://cloud.tencent.com/document/api/213/15753#HostResource)

	* 新增成员：GpuTotal, GpuAvailable


### 第 82 次发布

发布时间：2022-05-20 06:04:47

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [RunInstances](https://cloud.tencent.com/document/api/213/15730)

	* 新增入参：DedicatedClusterId


### 第 81 次发布

发布时间：2022-05-09 06:05:50

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [ExportImages](https://cloud.tencent.com/document/api/213/73474)

### 第 80 次发布

发布时间：2022-04-21 06:09:51

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DeleteImages](https://cloud.tencent.com/document/api/213/15716)

	* 新增入参：DeleteBindedSnap, DryRun

* [SyncImages](https://cloud.tencent.com/document/api/213/15711)

	* 新增入参：DryRun


### 第 79 次发布

发布时间：2022-04-15 06:05:33

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [Image](https://cloud.tencent.com/document/api/213/15753#Image)

	* 新增成员：Tags


### 第 78 次发布

发布时间：2022-04-11 06:09:58

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [ReservedInstances](https://cloud.tencent.com/document/api/213/15753#ReservedInstances)

	* 新增成员：ReservedInstanceId, ReservedInstanceName


### 第 77 次发布

发布时间：2022-04-08 06:05:15

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [RunInstances](https://cloud.tencent.com/document/api/213/15730)

	* 新增入参：DisableApiTermination


### 第 76 次发布

发布时间：2022-03-28 08:06:12

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateLaunchTemplate](https://cloud.tencent.com/document/api/213/66327)

	* 新增入参：DisableApiTermination


### 第 75 次发布

发布时间：2022-03-16 08:07:01

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [InquiryPriceModifyInstancesChargeType](https://cloud.tencent.com/document/api/213/17965)

	* 新增入参：ModifyPortableDataDisk

* [ModifyInstancesChargeType](https://cloud.tencent.com/document/api/213/17964)

	* 新增入参：ModifyPortableDataDisk


### 第 74 次发布

发布时间：2022-02-22 08:04:45

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [ModifyInstancesAttribute](https://cloud.tencent.com/document/api/213/15739)

	* 新增入参：DisableApiTermination

* [RunInstances](https://cloud.tencent.com/document/api/213/15730)

	* 新增入参：ChcIds


### 第 73 次发布

发布时间：2022-02-18 08:07:21

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [ItemPrice](https://cloud.tencent.com/document/api/213/15753#ItemPrice)

	* <font color="#dd0000">**修改成员**：</font>Discount, UnitPriceDiscount, UnitPriceSecondStep, UnitPriceDiscountSecondStep, UnitPriceThirdStep, UnitPriceDiscountThirdStep, OriginalPriceThreeYear, DiscountPriceThreeYear, DiscountThreeYear, OriginalPriceFiveYear, DiscountPriceFiveYear, DiscountFiveYear, OriginalPriceOneYear, DiscountPriceOneYear, DiscountOneYear


### 第 72 次发布

发布时间：2022-01-24 08:07:40

本次发布包含了以下内容：

改善已有的文档。

新增数据结构：

* [GPUInfo](https://cloud.tencent.com/document/api/213/15753#GPUInfo)

修改数据结构：

* [Instance](https://cloud.tencent.com/document/api/213/15753#Instance)

	* 新增成员：GPUInfo


### 第 71 次发布

发布时间：2022-01-21 08:08:55

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateImage](https://cloud.tencent.com/document/api/213/16726)

	* 新增入参：TagSpecification

* [ImportImage](https://cloud.tencent.com/document/api/213/15717)

	* 新增入参：TagSpecification


### 第 70 次发布

发布时间：2022-01-18 08:07:22

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [ProgramFpgaImage](https://cloud.tencent.com/document/api/213/68353)

### 第 69 次发布

发布时间：2022-01-13 08:23:09

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [ResizeInstanceDisks](https://cloud.tencent.com/document/api/213/15731)

	* 新增入参：SystemDisk, ResizeOnline


### 第 68 次发布

发布时间：2021-12-22 08:09:40

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [LaunchTemplateVersionData](https://cloud.tencent.com/document/api/213/15753#LaunchTemplateVersionData)

	* 新增成员：Placement, InstanceType, InstanceName, InstanceChargeType, SystemDisk, DataDisks, InternetAccessible, VirtualPrivateCloud, ImageId, SecurityGroupIds, LoginSettings, CamRoleName, HpcClusterId, InstanceCount, EnhancedService, UserData, DisasterRecoverGroupIds, ActionTimer, InstanceMarketOptions, HostName, ClientToken, InstanceChargePrepaid, TagSpecification


### 第 67 次发布

发布时间：2021-12-21 08:03:40

本次发布包含了以下内容：

改善已有的文档。

新增数据结构：

* [LaunchTemplateVersionData](https://cloud.tencent.com/document/api/213/15753#LaunchTemplateVersionData)

修改数据结构：

* [LaunchTemplate](https://cloud.tencent.com/document/api/213/15753#LaunchTemplate)

	* 新增成员：LaunchTemplateId, LaunchTemplateVersion

* [LaunchTemplateInfo](https://cloud.tencent.com/document/api/213/15753#LaunchTemplateInfo)

	* 新增成员：LatestVersionNumber, LaunchTemplateId, LaunchTemplateName, DefaultVersionNumber, LaunchTemplateVersionCount, CreatedBy, CreationTime

* [LaunchTemplateVersionInfo](https://cloud.tencent.com/document/api/213/15753#LaunchTemplateVersionInfo)

	* 新增成员：LaunchTemplateVersion, LaunchTemplateVersionData, CreationTime, LaunchTemplateId, IsDefaultVersion, LaunchTemplateVersionDescription, CreatedBy


### 第 66 次发布

发布时间：2021-12-20 08:05:40

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateLaunchTemplate](https://cloud.tencent.com/document/api/213/66327)
* [CreateLaunchTemplateVersion](https://cloud.tencent.com/document/api/213/66326)
* [DeleteLaunchTemplate](https://cloud.tencent.com/document/api/213/66325)
* [DeleteLaunchTemplateVersions](https://cloud.tencent.com/document/api/213/66324)
* [DescribeLaunchTemplateVersions](https://cloud.tencent.com/document/api/213/66323)
* [DescribeLaunchTemplates](https://cloud.tencent.com/document/api/213/66322)
* [ModifyLaunchTemplateDefaultVersion](https://cloud.tencent.com/document/api/213/66321)

修改接口：

* [RunInstances](https://cloud.tencent.com/document/api/213/15730)

	* 新增入参：LaunchTemplate


新增数据结构：

* [LaunchTemplate](https://cloud.tencent.com/document/api/213/15753#LaunchTemplate)
* [LaunchTemplateInfo](https://cloud.tencent.com/document/api/213/15753#LaunchTemplateInfo)
* [LaunchTemplateVersionInfo](https://cloud.tencent.com/document/api/213/15753#LaunchTemplateVersionInfo)

### 第 65 次发布

发布时间：2021-12-13 08:07:20

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [ModifyInstanceDiskType](https://cloud.tencent.com/document/api/213/65850)

### 第 64 次发布

发布时间：2021-09-08 08:04:44

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [InquiryPriceTerminateInstances](https://cloud.tencent.com/document/api/213/58193)

	* 新增出参：InstanceRefundsSet


新增数据结构：

* [InstanceRefund](https://cloud.tencent.com/document/api/213/15753#InstanceRefund)

### 第 63 次发布

发布时间：2021-08-25 08:04:53

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [RunAutomationServiceEnabled](https://cloud.tencent.com/document/api/213/15753#RunAutomationServiceEnabled)

	* 新增成员：Enabled


### 第 62 次发布

发布时间：2021-08-18 08:04:46

本次发布包含了以下内容：

改善已有的文档。

新增数据结构：

* [RunAutomationServiceEnabled](https://cloud.tencent.com/document/api/213/15753#RunAutomationServiceEnabled)

修改数据结构：

* [EnhancedService](https://cloud.tencent.com/document/api/213/15753#EnhancedService)

	* 新增成员：AutomationService


### 第 61 次发布

发布时间：2021-08-16 08:04:43

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeInstancesModification](https://cloud.tencent.com/document/api/213/60294)

新增数据结构：

* [InstanceTypeConfigStatus](https://cloud.tencent.com/document/api/213/15753#InstanceTypeConfigStatus)

### 第 60 次发布

发布时间：2021-08-13 08:04:45

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [Instance](https://cloud.tencent.com/document/api/213/15753#Instance)

	* 新增成员：IsolatedSource


### 第 59 次发布

发布时间：2021-07-06 08:05:06

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [InquiryPriceTerminateInstances](https://cloud.tencent.com/document/api/213/58193)

### 第 58 次发布

发布时间：2021-05-11 08:04:20

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeAccountQuota](https://cloud.tencent.com/document/api/213/55628)

新增数据结构：

* [AccountQuota](https://cloud.tencent.com/document/api/213/15753#AccountQuota)
* [AccountQuotaOverview](https://cloud.tencent.com/document/api/213/15753#AccountQuotaOverview)
* [DisasterRecoverGroupQuota](https://cloud.tencent.com/document/api/213/15753#DisasterRecoverGroupQuota)
* [ImageQuota](https://cloud.tencent.com/document/api/213/15753#ImageQuota)
* [PostPaidQuota](https://cloud.tencent.com/document/api/213/15753#PostPaidQuota)
* [PrePaidQuota](https://cloud.tencent.com/document/api/213/15753#PrePaidQuota)
* [SpotPaidQuota](https://cloud.tencent.com/document/api/213/15753#SpotPaidQuota)

### 第 57 次发布

发布时间：2021-02-24 08:03:30

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [DataDisk](https://cloud.tencent.com/document/api/213/15753#DataDisk)

	* 新增成员：CdcId

* [SystemDisk](https://cloud.tencent.com/document/api/213/15753#SystemDisk)

	* 新增成员：CdcId


### 第 56 次发布

发布时间：2021-01-15 08:03:24

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [DataDisk](https://cloud.tencent.com/document/api/213/15753#DataDisk)

	* 新增成员：ThroughputPerformance


### 第 55 次发布

发布时间：2021-01-08 08:03:14

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [RunInstances](https://cloud.tencent.com/document/api/213/15730)

	* <font color="#dd0000">**修改入参**：</font>Placement, ImageId


### 第 54 次发布

发布时间：2020-11-26 22:19:36

本次发布包含了以下内容：

改善已有的文档。

<font color="#dd0000">**删除接口**：</font>

* DescribeSpotTypeConfig

### 第 53 次发布

发布时间：2020-11-05 08:03:10

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateImage](https://cloud.tencent.com/document/api/213/16726)

	* 新增出参：ImageId

* [DescribeZones](https://cloud.tencent.com/document/api/213/15707)

	* 新增出参：TotalCount, ZoneSet


新增数据结构：

* [ZoneInfo](https://cloud.tencent.com/document/api/213/15753#ZoneInfo)

### 第 52 次发布

发布时间：2020-10-29 08:03:13

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeZones](https://cloud.tencent.com/document/api/213/15707)

	* <font color="#dd0000">**删除出参**：</font>TotalCount, ZoneSet


<font color="#dd0000">**删除数据结构**：</font>

* ZoneInfo

### 第 51 次发布

发布时间：2020-10-28 08:02:49

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateImage](https://cloud.tencent.com/document/api/213/16726)

	* <font color="#dd0000">**删除出参**：</font>ImageId


### 第 50 次发布

发布时间：2020-10-27 08:03:29

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [ItemPrice](https://cloud.tencent.com/document/api/213/15753#ItemPrice)

	* 新增成员：OriginalPriceThreeYear, DiscountPriceThreeYear, DiscountThreeYear, OriginalPriceFiveYear, DiscountPriceFiveYear, DiscountFiveYear, OriginalPriceOneYear, DiscountPriceOneYear, DiscountOneYear


### 第 49 次发布

发布时间：2020-09-22 08:03:09

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [RunInstances](https://cloud.tencent.com/document/api/213/15730)

	* 新增入参：CamRoleName


### 第 48 次发布

发布时间：2020-09-07 08:03:47

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeReservedInstancesConfigInfos](https://cloud.tencent.com/document/api/213/48128)
* [InquirePricePurchaseReservedInstancesOffering](https://cloud.tencent.com/document/api/213/48127)

修改接口：

* [PurchaseReservedInstancesOffering](https://cloud.tencent.com/document/api/213/38093)

	* 新增入参：ReservedInstanceName


新增数据结构：

* [ReservedInstanceConfigInfoItem](https://cloud.tencent.com/document/api/213/15753#ReservedInstanceConfigInfoItem)
* [ReservedInstanceFamilyItem](https://cloud.tencent.com/document/api/213/15753#ReservedInstanceFamilyItem)
* [ReservedInstancePrice](https://cloud.tencent.com/document/api/213/15753#ReservedInstancePrice)
* [ReservedInstancePriceItem](https://cloud.tencent.com/document/api/213/15753#ReservedInstancePriceItem)
* [ReservedInstanceTypeItem](https://cloud.tencent.com/document/api/213/15753#ReservedInstanceTypeItem)

修改数据结构：

* [ReservedInstances](https://cloud.tencent.com/document/api/213/15753#ReservedInstances)

	* 新增成员：InstanceFamily


### 第 47 次发布

发布时间：2020-08-26 08:02:41

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeSpotTypeConfig](https://cloud.tencent.com/document/api/213/47817)

### 第 46 次发布

发布时间：2020-08-03 08:09:26

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [InquiryPriceRunInstances](https://cloud.tencent.com/document/api/213/15726)

	* 新增入参：HpcClusterId

* [RunInstances](https://cloud.tencent.com/document/api/213/15730)

	* 新增入参：HpcClusterId


修改数据结构：

* [Instance](https://cloud.tencent.com/document/api/213/15753#Instance)

	* 新增成员：HpcClusterId, RdmaIpAddresses


### 第 45 次发布

发布时间：2020-07-07 08:07:56

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [InstanceTypeQuotaItem](https://cloud.tencent.com/document/api/213/15753#InstanceTypeQuotaItem)

	* 新增成员：Gpu, Fpga, Remark


### 第 44 次发布

发布时间：2020-07-03 08:07:59

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [DataDisk](https://cloud.tencent.com/document/api/213/15753#DataDisk)

	* 新增成员：KmsKeyId


### 第 43 次发布

发布时间：2020-06-02 08:07:41

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [InstanceTypeQuotaItem](https://cloud.tencent.com/document/api/213/15753#InstanceTypeQuotaItem)

	* 新增成员：InstanceBandwidth, InstancePps, StorageBlockAmount, CpuType


### 第 42 次发布

发布时间：2020-05-20 08:08:24

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [InquiryPriceResizeInstanceDisks](https://cloud.tencent.com/document/api/213/15751)

	* <font color="#dd0000">**删除入参**：</font>SystemDisk

* [ResizeInstanceDisks](https://cloud.tencent.com/document/api/213/15731)

	* <font color="#dd0000">**删除入参**：</font>SystemDisk


### 第 41 次发布

发布时间：2020-05-19 08:07:40

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [InquiryPriceResizeInstanceDisks](https://cloud.tencent.com/document/api/213/15751)

	* 新增入参：SystemDisk

	* <font color="#dd0000">**修改入参**：</font>DataDisks

* [ResizeInstanceDisks](https://cloud.tencent.com/document/api/213/15731)

	* 新增入参：SystemDisk

	* <font color="#dd0000">**修改入参**：</font>DataDisks


### 第 40 次发布

发布时间：2020-04-29 08:07:53

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [ItemPrice](https://cloud.tencent.com/document/api/213/15753#ItemPrice)

	* <font color="#dd0000">**修改成员**：</font>Discount


### 第 39 次发布

发布时间：2020-04-03 08:06:18

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [ModifyHostsAttribute](https://cloud.tencent.com/document/api/213/16475)

	* 新增入参：ProjectId


### 第 38 次发布

发布时间：2020-04-02 08:06:49

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [Instance](https://cloud.tencent.com/document/api/213/15753#Instance)

	* <font color="#dd0000">**修改成员**：</font>IPv6Addresses


### 第 37 次发布

发布时间：2020-03-16 08:06:56

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [Instance](https://cloud.tencent.com/document/api/213/15753#Instance)

	* 新增成员：IPv6Addresses, CamRoleName

* [InstanceTypeConfig](https://cloud.tencent.com/document/api/213/15753#InstanceTypeConfig)

	* 新增成员：FPGA

* [ItemPrice](https://cloud.tencent.com/document/api/213/15753#ItemPrice)

	* 新增成员：Discount, UnitPriceDiscount, UnitPriceSecondStep, UnitPriceDiscountSecondStep, UnitPriceThirdStep, UnitPriceDiscountThirdStep


### 第 36 次发布

发布时间：2020-03-04 17:55:59

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [InstanceTypeQuotaItem](https://cloud.tencent.com/document/api/213/15753#InstanceTypeQuotaItem)

	* 新增成员：SoldOutReason


### 第 35 次发布

发布时间：2020-02-28 15:15:03

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [Instance](https://cloud.tencent.com/document/api/213/15753#Instance)

	* 新增成员：DisasterRecoverGroupId


### 第 34 次发布

发布时间：2020-01-16 18:11:12

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [DataDisk](https://cloud.tencent.com/document/api/213/15753#DataDisk)

	* 新增成员：Encrypt

* [Placement](https://cloud.tencent.com/document/api/213/15753#Placement)

	* 新增成员：HostId


### 第 33 次发布

发布时间：2020-01-02 16:49:23

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [HostResource](https://cloud.tencent.com/document/api/213/15753#HostResource)

	* 新增成员：DiskType


### 第 32 次发布

发布时间：2019-12-26 20:05:46

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [VirtualPrivateCloud](https://cloud.tencent.com/document/api/213/15753#VirtualPrivateCloud)

	* 新增成员：Ipv6AddressCount


### 第 31 次发布

发布时间：2019-11-21 22:04:15

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [LocalDiskType](https://cloud.tencent.com/document/api/213/15753#LocalDiskType)

	* 新增成员：Required


### 第 30 次发布

发布时间：2019-11-07 20:12:03

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateImage](https://cloud.tencent.com/document/api/213/16726)

	* 新增出参：ImageId


### 第 29 次发布

发布时间：2019-09-20 18:21:03

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeReservedInstances](https://cloud.tencent.com/document/api/213/38095)
* [DescribeReservedInstancesOfferings](https://cloud.tencent.com/document/api/213/38094)
* [PurchaseReservedInstancesOffering](https://cloud.tencent.com/document/api/213/38093)

新增数据结构：

* [ReservedInstances](https://cloud.tencent.com/document/api/213/15753#ReservedInstances)
* [ReservedInstancesOffering](https://cloud.tencent.com/document/api/213/15753#ReservedInstancesOffering)

修改数据结构：

* [Instance](https://cloud.tencent.com/document/api/213/15753#Instance)

	* 新增成员：LatestOperation, LatestOperationState, LatestOperationRequestId


### 第 28 次发布

发布时间：2019-09-05 21:46:48

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateImage](https://cloud.tencent.com/document/api/213/16726)

	* <font color="#dd0000">**删除入参**：</font>Reboot


修改数据结构：

* [Instance](https://cloud.tencent.com/document/api/213/15753#Instance)

	* 新增成员：Uuid


### 第 27 次发布

发布时间：2019-08-15 14:18:18

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [RunInstances](https://cloud.tencent.com/document/api/213/15730)

	* 新增入参：DryRun


### 第 26 次发布

发布时间：2019-07-13 01:45:58

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [RebootInstances](https://cloud.tencent.com/document/api/213/15742)

	* 新增入参：StopType


修改数据结构：

* [Placement](https://cloud.tencent.com/document/api/213/15753#Placement)

	* 新增成员：HostIps


### 第 25 次发布

发布时间：2019-05-16 16:00:51

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [DataDisk](https://cloud.tencent.com/document/api/213/15753#DataDisk)

	* 新增成员：SnapshotId


### 第 24 次发布

发布时间：2019-05-09 19:33:10

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [ModifyInstancesVpcAttribute](https://cloud.tencent.com/document/api/213/15750)

	* 新增入参：ReserveHostName

* [RenewInstances](https://cloud.tencent.com/document/api/213/15740)

	* <font color="#dd0000">**修改入参**：</font>InstanceChargePrepaid

* [ResetInstance](https://cloud.tencent.com/document/api/213/15724)

	* 新增入参：HostName


新增数据结构：

* [Snapshot](https://cloud.tencent.com/document/api/213/15753#Snapshot)

修改数据结构：

* [Image](https://cloud.tencent.com/document/api/213/15753#Image)

	* 新增成员：SnapshotSet


### 第 23 次发布

发布时间：2019-04-18 19:50:41

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeInstancesOperationLimit](https://cloud.tencent.com/document/api/213/34316)

修改接口：

* [AllocateHosts](https://cloud.tencent.com/document/api/213/16473)

	* 新增入参：TagSpecification


新增数据结构：

* [OperationCountLimit](https://cloud.tencent.com/document/api/213/15753#OperationCountLimit)

### 第 22 次发布

发布时间：2019-04-04 21:12:36

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [InquiryPriceResetInstancesType](https://cloud.tencent.com/document/api/213/15733)

	* <font color="#dd0000">**删除入参**：</font>ForceStop


修改数据结构：

* [HostItem](https://cloud.tencent.com/document/api/213/15753#HostItem)

	* 新增成员：CageId


### 第 21 次发布

发布时间：2019-03-21 19:59:14

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [InternetAccessible](https://cloud.tencent.com/document/api/213/15753#InternetAccessible)

	* 新增成员：BandwidthPackageId


### 第 20 次发布

发布时间：2018-12-27 19:22:31

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [InstanceMarketOptionsRequest](https://cloud.tencent.com/document/api/213/15753#InstanceMarketOptionsRequest)

	* <font color="#dd0000">**修改成员**：</font>SpotOptions


### 第 19 次发布

发布时间：2018-12-20 19:35:44

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [StopInstances](https://cloud.tencent.com/document/api/213/15743)

	* 新增入参：StoppedMode


### 第 18 次发布

发布时间：2018-12-06 20:38:08

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [AssociateSecurityGroups](https://cloud.tencent.com/document/api/213/31282)
* [DisassociateSecurityGroups](https://cloud.tencent.com/document/api/213/31281)

修改接口：

* [CreateImage](https://cloud.tencent.com/document/api/213/16726)

	* 新增入参：DataDiskIds, SnapshotIds

	* <font color="#dd0000">**修改入参**：</font>InstanceId


### 第 17 次发布

发布时间：2018-11-29 15:33:14

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [Instance](https://cloud.tencent.com/document/api/213/15753#Instance)

	* 新增成员：StopChargingMode


### 第 16 次发布

发布时间：2018-11-22 19:05:58

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateImage](https://cloud.tencent.com/document/api/213/16726)

	* 新增入参：DryRun


修改数据结构：

* [InstanceTypeConfig](https://cloud.tencent.com/document/api/213/15753#InstanceTypeConfig)

	* <font color="#dd0000">**删除成员**：</font>CbsSupport, InstanceTypeState


### 第 15 次发布

发布时间：2018-10-11 15:28:56

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [ModifyInstancesVpcAttribute](https://cloud.tencent.com/document/api/213/15750)

修改数据结构：

* [KeyPair](https://cloud.tencent.com/document/api/213/15753#KeyPair)

	* <font color="#dd0000">**修改成员**：</font>ProjectId


### 第 14 次发布

发布时间：2018-09-03 18:57:06

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [DataDisk](https://cloud.tencent.com/document/api/213/15753#DataDisk)

	* 新增成员：DeleteWithInstance


### 第 13 次发布

发布时间：2018-08-30 17:31:06

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [Image](https://cloud.tencent.com/document/api/213/15753#Image)

	* 新增成员：SyncPercent, IsSupportCloudinit

* [SharePermission](https://cloud.tencent.com/document/api/213/15753#SharePermission)

	* 新增成员：CreatedTime, AccountId

	* <font color="#dd0000">**删除成员**：</font>CreateTime, Account


### 第 12 次发布

发布时间：2018-08-17 13:09:59

本次发布包含了以下内容：

改善已有的文档。

### 第 11 次发布

发布时间：2018-07-23 15:35:41

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [StopInstances](https://cloud.tencent.com/document/api/213/15743)

	* <font color="#dd0000">**删除入参**：</font>StoppedMode


### 第 10 次发布

发布时间：2018-07-19 13:18:30

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateDisasterRecoverGroup](https://cloud.tencent.com/document/api/213/17813)

	* 新增入参：ClientToken


修改数据结构：

* [Instance](https://cloud.tencent.com/document/api/213/15753#Instance)

	* 新增成员：Tags


### 第 9 次发布

发布时间：2018-07-12 18:44:10

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [InquiryPriceRenewInstances](https://cloud.tencent.com/document/api/213/15725)

	* 新增入参：RenewPortableDataDisk

* [RenewInstances](https://cloud.tencent.com/document/api/213/15740)

	* 新增入参：RenewPortableDataDisk


修改数据结构：

* [OsVersion](https://cloud.tencent.com/document/api/213/15753#OsVersion)

	* 新增成员：Architecture


### 第 8 次发布

发布时间：2018-07-02 20:46:22

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeInstanceVncUrl](https://cloud.tencent.com/document/api/213/18150)

修改接口：

* [RunInstances](https://cloud.tencent.com/document/api/213/15730)

	* 新增入参：DisasterRecoverGroupIds


### 第 7 次发布

发布时间：2018-06-21 14:51:58

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [InquiryPriceModifyInstancesChargeType](https://cloud.tencent.com/document/api/213/17965)
* [ModifyInstancesChargeType](https://cloud.tencent.com/document/api/213/17964)

### 第 6 次发布

发布时间：2018-06-14 12:15:42

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateDisasterRecoverGroup](https://cloud.tencent.com/document/api/213/17813)
* [DeleteDisasterRecoverGroups](https://cloud.tencent.com/document/api/213/17812)
* [DescribeDisasterRecoverGroupQuota](https://cloud.tencent.com/document/api/213/17811)
* [DescribeDisasterRecoverGroups](https://cloud.tencent.com/document/api/213/17810)
* [ModifyDisasterRecoverGroupAttribute](https://cloud.tencent.com/document/api/213/17809)

修改接口：

* [DescribeImportImageOs](https://cloud.tencent.com/document/api/213/15718)

	* 新增出参：ImportImageOsVersionSet

	* <font color="#dd0000">**删除出参**：</font>ImportImageOsVersionSupported

	* <font color="#dd0000">**修改出参**：</font>ImportImageOsListSupported


新增数据结构：

* [DisasterRecoverGroup](https://cloud.tencent.com/document/api/213/15753#DisasterRecoverGroup)
* [ImageOsList](https://cloud.tencent.com/document/api/213/15753#ImageOsList)
* [OsVersion](https://cloud.tencent.com/document/api/213/15753#OsVersion)

修改数据结构：

* [HostItem](https://cloud.tencent.com/document/api/213/15753#HostItem)

	* <font color="#dd0000">**修改成员**：</font>InstanceIds


### 第 5 次发布

发布时间：2018-06-07 15:01:42

本次发布包含了以下内容：

改善已有的文档。

<font color="#dd0000">**删除接口**：</font>

* DescribeInstanceOperationLogs
* UpdateInstanceVpcConfig

修改接口：

* [ModifyInstancesAttribute](https://cloud.tencent.com/document/api/213/15739)

	* 新增入参：SecurityGroups

* [RunInstances](https://cloud.tencent.com/document/api/213/15730)

	* 新增入参：InstanceMarketOptions, UserData


修改数据结构：

* [Instance](https://cloud.tencent.com/document/api/213/15753#Instance)

	* 新增成员：InstanceState


### 第 4 次发布

发布时间：2018-05-31 14:45:35

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeZoneInstanceConfigInfos](https://cloud.tencent.com/document/api/213/17378)

新增数据结构：

* [InstanceTypeQuotaItem](https://cloud.tencent.com/document/api/213/15753#InstanceTypeQuotaItem)
* [LocalDiskType](https://cloud.tencent.com/document/api/213/15753#LocalDiskType)
* [StorageBlock](https://cloud.tencent.com/document/api/213/15753#StorageBlock)

修改数据结构：

* [Externals](https://cloud.tencent.com/document/api/213/15753#Externals)

	* 新增成员：UnsupportNetworks, StorageBlockAttr


### 第 3 次发布

发布时间：2018-05-24 17:08:50

本次发布包含了以下内容：

改善已有的文档。

<font color="#dd0000">**删除接口**：</font>

* QueryMigrateTask

### 第 2 次发布

发布时间：2018-05-17 16:17:11

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [InquiryPriceRunInstances](https://cloud.tencent.com/document/api/213/15726)

	* 新增入参：InstanceMarketOptions

* [TerminateInstances](https://cloud.tencent.com/document/api/213/15723)

	* <font color="#dd0000">**删除入参**：</font>DryRun


新增数据结构：

* [InstanceMarketOptionsRequest](https://cloud.tencent.com/document/api/213/15753#InstanceMarketOptionsRequest)
* [SpotMarketOptions](https://cloud.tencent.com/document/api/213/15753#SpotMarketOptions)

修改数据结构：

* [Image](https://cloud.tencent.com/document/api/213/15753#Image)

	* <font color="#dd0000">**修改成员**：</font>ImageSize, Platform, ImageCreator

* [Instance](https://cloud.tencent.com/document/api/213/15753#Instance)

	* 新增成员：OsName, SecurityGroupIds, LoginSettings


### 第 1 次发布

发布时间：2018-04-24

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [AllocateHosts](https://cloud.tencent.com/document/api/213/16473)
* [AssociateInstancesKeyPairs](https://cloud.tencent.com/document/api/213/15698)
* [CreateImage](https://cloud.tencent.com/document/api/213/16726)
* [CreateKeyPair](https://cloud.tencent.com/document/api/213/15702)
* [DeleteImages](https://cloud.tencent.com/document/api/213/15716)
* [DeleteKeyPairs](https://cloud.tencent.com/document/api/213/15700)
* [DescribeHosts](https://cloud.tencent.com/document/api/213/16474)
* [DescribeImageQuota](https://cloud.tencent.com/document/api/213/15719)
* [DescribeImageSharePermission](https://cloud.tencent.com/document/api/213/15712)
* [DescribeImages](https://cloud.tencent.com/document/api/213/15715)
* [DescribeImportImageOs](https://cloud.tencent.com/document/api/213/15718)
* [DescribeInstanceFamilyConfigs](https://cloud.tencent.com/document/api/213/15748)
* [DescribeInstanceInternetBandwidthConfigs](https://cloud.tencent.com/document/api/213/15734)
* [DescribeInstanceOperationLogs](https://cloud.tencent.com/document/api/213/15737)
* [DescribeInstanceTypeConfigs](https://cloud.tencent.com/document/api/213/15749)
* [DescribeInstances](https://cloud.tencent.com/document/api/213/15728)
* [DescribeInstancesStatus](https://cloud.tencent.com/document/api/213/15738)
* [DescribeInternetChargeTypeConfigs](https://cloud.tencent.com/document/api/213/15729)
* [DescribeKeyPairs](https://cloud.tencent.com/document/api/213/15699)
* [DescribeRegions](https://cloud.tencent.com/document/api/213/15708)
* [DescribeZones](https://cloud.tencent.com/document/api/213/15707)
* [DisassociateInstancesKeyPairs](https://cloud.tencent.com/document/api/213/15697)
* [ImportImage](https://cloud.tencent.com/document/api/213/15717)
* [ImportKeyPair](https://cloud.tencent.com/document/api/213/15703)
* [InquiryPriceRenewInstances](https://cloud.tencent.com/document/api/213/15725)
* [InquiryPriceResetInstance](https://cloud.tencent.com/document/api/213/15747)
* [InquiryPriceResetInstancesInternetMaxBandwidth](https://cloud.tencent.com/document/api/213/15732)
* [InquiryPriceResetInstancesType](https://cloud.tencent.com/document/api/213/15733)
* [InquiryPriceResizeInstanceDisks](https://cloud.tencent.com/document/api/213/15751)
* [InquiryPriceRunInstances](https://cloud.tencent.com/document/api/213/15726)
* [ModifyHostsAttribute](https://cloud.tencent.com/document/api/213/16475)
* [ModifyImageAttribute](https://cloud.tencent.com/document/api/213/15713)
* [ModifyImageSharePermission](https://cloud.tencent.com/document/api/213/15710)
* [ModifyInstancesAttribute](https://cloud.tencent.com/document/api/213/15739)
* [ModifyInstancesProject](https://cloud.tencent.com/document/api/213/15746)
* [ModifyInstancesRenewFlag](https://cloud.tencent.com/document/api/213/15752)
* [ModifyKeyPairAttribute](https://cloud.tencent.com/document/api/213/15701)
* [QueryMigrateTask](https://cloud.tencent.com/document/api/213/15722)
* [RebootInstances](https://cloud.tencent.com/document/api/213/15742)
* [RenewHosts](https://cloud.tencent.com/document/api/213/16476)
* [RenewInstances](https://cloud.tencent.com/document/api/213/15740)
* [ResetInstance](https://cloud.tencent.com/document/api/213/15724)
* [ResetInstancesInternetMaxBandwidth](https://cloud.tencent.com/document/api/213/15721)
* [ResetInstancesPassword](https://cloud.tencent.com/document/api/213/15736)
* [ResetInstancesType](https://cloud.tencent.com/document/api/213/15744)
* [ResizeInstanceDisks](https://cloud.tencent.com/document/api/213/15731)
* [RunInstances](https://cloud.tencent.com/document/api/213/15730)
* [StartInstances](https://cloud.tencent.com/document/api/213/15735)
* [StopInstances](https://cloud.tencent.com/document/api/213/15743)
* [SyncImages](https://cloud.tencent.com/document/api/213/15711)
* [TerminateInstances](https://cloud.tencent.com/document/api/213/15723)
* [UpdateInstanceVpcConfig](https://cloud.tencent.com/document/api/213/15750)

新增数据结构：

* [ActionTimer](https://cloud.tencent.com/document/api/213/15753#ActionTimer)
* [ChargePrepaid](https://cloud.tencent.com/document/api/213/15753#ChargePrepaid)
* [DataDisk](https://cloud.tencent.com/document/api/213/15753#DataDisk)
* [EnhancedService](https://cloud.tencent.com/document/api/213/15753#EnhancedService)
* [Externals](https://cloud.tencent.com/document/api/213/15753#Externals)
* [Filter](https://cloud.tencent.com/document/api/213/15753#Filter)
* [HostItem](https://cloud.tencent.com/document/api/213/15753#HostItem)
* [HostResource](https://cloud.tencent.com/document/api/213/15753#HostResource)
* [Image](https://cloud.tencent.com/document/api/213/15753#Image)
* [Instance](https://cloud.tencent.com/document/api/213/15753#Instance)
* [InstanceChargePrepaid](https://cloud.tencent.com/document/api/213/15753#InstanceChargePrepaid)
* [InstanceFamilyConfig](https://cloud.tencent.com/document/api/213/15753#InstanceFamilyConfig)
* [InstanceStatus](https://cloud.tencent.com/document/api/213/15753#InstanceStatus)
* [InstanceTypeConfig](https://cloud.tencent.com/document/api/213/15753#InstanceTypeConfig)
* [InternetAccessible](https://cloud.tencent.com/document/api/213/15753#InternetAccessible)
* [InternetBandwidthConfig](https://cloud.tencent.com/document/api/213/15753#InternetBandwidthConfig)
* [InternetChargeTypeConfig](https://cloud.tencent.com/document/api/213/15753#InternetChargeTypeConfig)
* [ItemPrice](https://cloud.tencent.com/document/api/213/15753#ItemPrice)
* [KeyPair](https://cloud.tencent.com/document/api/213/15753#KeyPair)
* [LoginSettings](https://cloud.tencent.com/document/api/213/15753#LoginSettings)
* [Placement](https://cloud.tencent.com/document/api/213/15753#Placement)
* [Price](https://cloud.tencent.com/document/api/213/15753#Price)
* [RegionInfo](https://cloud.tencent.com/document/api/213/15753#RegionInfo)
* [RunMonitorServiceEnabled](https://cloud.tencent.com/document/api/213/15753#RunMonitorServiceEnabled)
* [RunSecurityServiceEnabled](https://cloud.tencent.com/document/api/213/15753#RunSecurityServiceEnabled)
* [SharePermission](https://cloud.tencent.com/document/api/213/15753#SharePermission)
* [SystemDisk](https://cloud.tencent.com/document/api/213/15753#SystemDisk)
* [Tag](https://cloud.tencent.com/document/api/213/15753#Tag)
* [TagSpecification](https://cloud.tencent.com/document/api/213/15753#TagSpecification)
* [VirtualPrivateCloud](https://cloud.tencent.com/document/api/213/15753#VirtualPrivateCloud)
* [ZoneInfo](https://cloud.tencent.com/document/api/213/15753#ZoneInfo)




## 主机安全(cwp) 版本：2018-02-28

### 第 118 次发布

发布时间：2024-07-30 01:25:44

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [BashEvent](https://cloud.tencent.com/document/api/296/19867#BashEvent)

	* 新增成员：HostName

* [BashEventsInfo](https://cloud.tencent.com/document/api/296/19867#BashEventsInfo)

	* 新增成员：DetectBy


### 第 117 次发布

发布时间：2024-07-12 01:12:13

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeMalwareTimingScanSetting](https://cloud.tencent.com/document/api/296/58240)

	* 新增出参：ProtectMode, ProtectFileScope

* [ModifyMalwareTimingScanSettings](https://cloud.tencent.com/document/api/296/52509)

	* 新增入参：DoClean, ProtectMode, ProtectFileScope


### 第 116 次发布

发布时间：2024-07-05 01:06:53

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [ExportBaselineHostDetectList](https://cloud.tencent.com/document/api/296/87851)

	* 新增入参：IsExportDetail

* [ExportBaselineItemDetectList](https://cloud.tencent.com/document/api/296/87850)

	* 新增入参：IsExportDetail

* [ExportBaselineRuleDetectList](https://cloud.tencent.com/document/api/296/87848)

	* 新增入参：IsExportDetail


修改数据结构：

* [DeliverTypeDetails](https://cloud.tencent.com/document/api/296/19867#DeliverTypeDetails)

	* 新增成员：LogName, LogSetId, Region


### 第 115 次发布

发布时间：2024-06-28 01:08:04

本次发布包含了以下内容：

改善已有的文档。

<font color="#dd0000">**删除接口**：</font>

* ExportAttackLogs

### 第 114 次发布

发布时间：2024-06-26 01:12:49

本次发布包含了以下内容：

改善已有的文档。

<font color="#dd0000">**删除接口**：</font>

* DeleteAttackLogs

### 第 113 次发布

发布时间：2024-05-10 01:29:26

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [Item](https://cloud.tencent.com/document/api/296/19867#Item)

	* 新增成员：CategoryId


### 第 112 次发布

发布时间：2024-05-07 01:13:25

本次发布包含了以下内容：

改善已有的文档。

<font color="#dd0000">**删除接口**：</font>

* DescribeAttackLogInfo

### 第 111 次发布

发布时间：2024-03-29 01:13:05

本次发布包含了以下内容：

改善已有的文档。

<font color="#dd0000">**预下线接口**：</font>

* DeleteAttackLogs
* ExportAttackLogs

修改接口：

* [CreateSearchTemplate](https://cloud.tencent.com/document/api/296/55730)

	* 新增出参：Message

* [DescribeBaselineItemInfo](https://cloud.tencent.com/document/api/296/87860)

	* 新增出参：CategoryList

* [ModifyBaselineRule](https://cloud.tencent.com/document/api/296/87844)

	* 新增入参：IdType, ExcludeIds, CategoryIds


新增数据结构：

* [BaselineItemsCategory](https://cloud.tencent.com/document/api/296/19867#BaselineItemsCategory)

修改数据结构：

* [BaselineCategory](https://cloud.tencent.com/document/api/296/19867#BaselineCategory)

	* 新增成员：ItemCount

* [Item](https://cloud.tencent.com/document/api/296/19867#Item)

	* 新增成员：CustomItemValues


### 第 110 次发布

发布时间：2024-03-25 01:12:24

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [AssetMachineBaseInfo](https://cloud.tencent.com/document/api/296/19867#AssetMachineBaseInfo)

	* 新增成员：CpuLoadNum

	* <font color="#dd0000">**修改成员**：</font>Quuid, Uuid, MachineIp, MachineName, OsInfo, Cpu, MemSize, MemLoad, DiskSize, DiskLoad, PartitionCount, MachineWanIp, ProjectId, CpuSize, CpuLoad, Tag, UpdateTime, IsNew, FirstTime, MachineExtraInfo


### 第 109 次发布

发布时间：2024-03-22 01:11:57

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeBanStatus](https://cloud.tencent.com/document/api/296/60944)

	* 新增出参：OpenSmartMode

* [ModifyBanStatus](https://cloud.tencent.com/document/api/296/60942)

	* 新增入参：OpenSmartMode


修改数据结构：

* [BruteAttackInfo](https://cloud.tencent.com/document/api/296/19867#BruteAttackInfo)

	* 新增成员：AttackStatusDesc, BanExpiredTime


### 第 108 次发布

发布时间：2024-02-02 01:09:36

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeNetAttackSetting](https://cloud.tencent.com/document/api/296/99476)

	* 新增出参：Scope, InstanceIds, ExcludeInstanceIds, AutoInclude

* [DescribeVulDefenceSetting](https://cloud.tencent.com/document/api/296/99659)

	* 新增出参：InstanceIds, AutoInclude, ExcludeInstanceIds

* [ModifyNetAttackSetting](https://cloud.tencent.com/document/api/296/99456)

	* 新增入参：Scope, InstanceIds, ExcludeInstanceIds, AutoInclude

* [ModifyVulDefenceSetting](https://cloud.tencent.com/document/api/296/99545)

	* 新增入参：ExcludeInstanceIds, AutoInclude, InstanceIds


### 第 107 次发布

发布时间：2024-01-31 01:11:09

本次发布包含了以下内容：

改善已有的文档。

<font color="#dd0000">**预下线接口**：</font>

* DescribeAttackLogInfo

### 第 106 次发布

发布时间：2024-01-05 01:11:37

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [BruteAttackInfo](https://cloud.tencent.com/document/api/296/19867#BruteAttackInfo)

	* 新增成员：DataFrom


### 第 105 次发布

发布时间：2023-12-29 01:12:06

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [SyncBaselineDetectSummary](https://cloud.tencent.com/document/api/296/81348)

	* 新增入参：TaskIds


### 第 104 次发布

发布时间：2023-11-24 01:11:01

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeLicenseGeneral](https://cloud.tencent.com/document/api/296/80398)

	* 新增出参：RepurchaseRenewSwitch

* [ModifyAutoOpenProVersionConfig](https://cloud.tencent.com/document/api/296/19863)

	* 新增入参：RepurchaseRenewSwitch


### 第 103 次发布

发布时间：2023-10-27 01:29:35

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [BruteAttackInfo](https://cloud.tencent.com/document/api/296/19867#BruteAttackInfo)

	* 新增成员：RiskLevel

	* <font color="#dd0000">**修改成员**：</font>Id, Uuid, MachineIp, MachineName, UserName, SrcIp, Status, Country, City, Province, CreateTime, BanStatus, EventType, Count, Quuid, IsProVersion, Protocol, Port, ModifyTime, InstanceId, DataStatus, MachineExtraInfo, Location

* [ReverseShell](https://cloud.tencent.com/document/api/296/19867#ReverseShell)

	* 新增成员：RiskLevel

	* <font color="#dd0000">**修改成员**：</font>Id, Uuid, Quuid, Hostip, DstIp, DstPort, ProcessName, FullPath, CmdLine, UserName, UserGroup, ParentProcName, ParentProcUser, ParentProcGroup, ParentProcPath, Status, CreateTime, MachineName, ProcTree, DetectBy, MachineExtraInfo, Pid


### 第 102 次发布

发布时间：2023-10-26 01:11:16

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateScanMalwareSetting](https://cloud.tencent.com/document/api/296/58241)

	* 新增出参：TaskId

* [DescribeLicenseWhiteConfig](https://cloud.tencent.com/document/api/296/99627)

	* 新增出参：FlagShip, Professional, PrattWhitney


新增数据结构：

* [VersionWhiteConfig](https://cloud.tencent.com/document/api/296/19867#VersionWhiteConfig)

### 第 101 次发布

发布时间：2023-10-25 01:12:51

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateWhiteListOrder](https://cloud.tencent.com/document/api/296/99541)

	* 新增入参：SourceType


### 第 100 次发布

发布时间：2023-10-19 16:01:46

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateWhiteListOrder](https://cloud.tencent.com/document/api/296/99541)

	* 新增入参：LicenseType, LicenseNum, Deadline, RuleName, RegionId, ExtraParam

* [DescribeLicenseWhiteConfig](https://cloud.tencent.com/document/api/296/99627)

	* 新增入参：RuleName


### 第 99 次发布

发布时间：2023-10-18 01:38:58

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [AssetMachineDetail](https://cloud.tencent.com/document/api/296/19867#AssetMachineDetail)

	* 新增成员：CpuLoadVul, FirstTime

	* <font color="#dd0000">**修改成员**：</font>Quuid, Uuid, MachineIp, MachineName, OsInfo, Cpu, MemSize, MemLoad, DiskSize, DiskLoad, PartitionCount, MachineWanIp, CpuSize, CpuLoad, ProtectLevel, RiskStatus, ProtectDays, BuyTime, EndTime, CoreVersion, OsType, AgentVersion, InstallTime, BootTime, LastLiveTime, Producer, SerialNumber, NetCards, Disks, Status, ProjectId, DeviceVersion, OfflineTime, InstanceId, UpdateTime, MachineExtraInfo


### 第 98 次发布

发布时间：2023-10-10 01:12:51

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [AddLoginWhiteLists](https://cloud.tencent.com/document/api/296/99689)
* [ChangeStrategyEnableStatus](https://cloud.tencent.com/document/api/296/99571)
* [CheckBashPolicyParams](https://cloud.tencent.com/document/api/296/99650)
* [CheckFileTamperRule](https://cloud.tencent.com/document/api/296/99485)
* [CheckFirstScanBaseline](https://cloud.tencent.com/document/api/296/99570)
* [CheckLogKafkaConnectionState](https://cloud.tencent.com/document/api/296/99642)
* [ClearLocalStorage](https://cloud.tencent.com/document/api/296/99641)
* [CreateBanWhiteList](https://cloud.tencent.com/document/api/296/99692)
* [CreateBuyBindTask](https://cloud.tencent.com/document/api/296/99640)
* [CreateCloudProtectServiceOrderRecord](https://cloud.tencent.com/document/api/296/99542)
* [CreateIncidentBacktracking](https://cloud.tencent.com/document/api/296/99531)
* [CreateLogExport](https://cloud.tencent.com/document/api/296/99639)
* [CreateMaliciousRequestWhiteList](https://cloud.tencent.com/document/api/296/99685)
* [CreateMalwareWhiteList](https://cloud.tencent.com/document/api/296/99674)
* [CreateNetAttackWhiteList](https://cloud.tencent.com/document/api/296/99673)
* [CreateRansomDefenseStrategy](https://cloud.tencent.com/document/api/296/99638)
* [CreateVulFix](https://cloud.tencent.com/document/api/296/99563)
* [CreateWhiteListOrder](https://cloud.tencent.com/document/api/296/99541)
* [DeleteAllJavaMemShells](https://cloud.tencent.com/document/api/296/99672)
* [DeleteBanWhiteList](https://cloud.tencent.com/document/api/296/99691)
* [DeleteBashPolicies](https://cloud.tencent.com/document/api/296/99649)
* [DeleteLicenseRecordAll](https://cloud.tencent.com/document/api/296/99540)
* [DeleteLogExport](https://cloud.tencent.com/document/api/296/99637)
* [DeleteMachineClearHistory](https://cloud.tencent.com/document/api/296/99530)
* [DeleteMaliciousRequestWhiteList](https://cloud.tencent.com/document/api/296/99684)
* [DeleteMalwareWhiteList](https://cloud.tencent.com/document/api/296/99671)
* [DeleteNetAttackWhiteList](https://cloud.tencent.com/document/api/296/99670)
* [DeleteRiskDnsEvent](https://cloud.tencent.com/document/api/296/99683)
* [DeleteRiskDnsPolicy](https://cloud.tencent.com/document/api/296/99682)
* [DeleteWebHookPolicy](https://cloud.tencent.com/document/api/296/99636)
* [DeleteWebHookReceiver](https://cloud.tencent.com/document/api/296/99635)
* [DeleteWebHookRule](https://cloud.tencent.com/document/api/296/99539)
* [DescribeABTestConfig](https://cloud.tencent.com/document/api/296/99634)
* [DescribeAESKey](https://cloud.tencent.com/document/api/296/99633)
* [DescribeAgentInstallationToken](https://cloud.tencent.com/document/api/296/99529)
* [DescribeAssetAppCount](https://cloud.tencent.com/document/api/296/99528)
* [DescribeAssetDatabaseCount](https://cloud.tencent.com/document/api/296/99527)
* [DescribeAssetDiskList](https://cloud.tencent.com/document/api/296/99526)
* [DescribeAssetLoadInfo](https://cloud.tencent.com/document/api/296/99525)
* [DescribeAssetMachineTagTop](https://cloud.tencent.com/document/api/296/99524)
* [DescribeAssetPortCount](https://cloud.tencent.com/document/api/296/99523)
* [DescribeAssetProcessCount](https://cloud.tencent.com/document/api/296/99522)
* [DescribeAssetTotalCount](https://cloud.tencent.com/document/api/296/99521)
* [DescribeAssetTypeTop](https://cloud.tencent.com/document/api/296/99520)
* [DescribeAssetTypes](https://cloud.tencent.com/document/api/296/99632)
* [DescribeAssetUserCount](https://cloud.tencent.com/document/api/296/99519)
* [DescribeAssetUserKeyList](https://cloud.tencent.com/document/api/296/99518)
* [DescribeAssetWebAppCount](https://cloud.tencent.com/document/api/296/99517)
* [DescribeAssetWebFrameCount](https://cloud.tencent.com/document/api/296/99516)
* [DescribeAssetWebLocationCount](https://cloud.tencent.com/document/api/296/99515)
* [DescribeAssetWebLocationPathList](https://cloud.tencent.com/document/api/296/99514)
* [DescribeAssetWebServiceCount](https://cloud.tencent.com/document/api/296/99513)
* [DescribeAttackEventInfo](https://cloud.tencent.com/document/api/296/99484)
* [DescribeAttackSource](https://cloud.tencent.com/document/api/296/99631)
* [DescribeAttackSourceEvents](https://cloud.tencent.com/document/api/296/99630)
* [DescribeAttackStatistics](https://cloud.tencent.com/document/api/296/99483)
* [DescribeAttackTop](https://cloud.tencent.com/document/api/296/99482)
* [DescribeAttackTrends](https://cloud.tencent.com/document/api/296/99481)
* [DescribeBaselineDefaultStrategyList](https://cloud.tencent.com/document/api/296/99569)
* [DescribeBashEventsInfo](https://cloud.tencent.com/document/api/296/99648)
* [DescribeBashPolicies](https://cloud.tencent.com/document/api/296/99647)
* [DescribeCanFixVulMachine](https://cloud.tencent.com/document/api/296/99562)
* [DescribeCanNotSeparateMachine](https://cloud.tencent.com/document/api/296/99629)
* [DescribeCloudProtectServiceOrderList](https://cloud.tencent.com/document/api/296/99538)
* [DescribeDefenceEventDetail](https://cloud.tencent.com/document/api/296/99561)
* [DescribeDirectConnectInstallCommand](https://cloud.tencent.com/document/api/296/99512)
* [DescribeFastAnalysis](https://cloud.tencent.com/document/api/296/99628)
* [DescribeFileTamperEventRuleInfo](https://cloud.tencent.com/document/api/296/99480)
* [DescribeFileTamperRuleCount](https://cloud.tencent.com/document/api/296/99479)
* [DescribeFileTamperRuleInfo](https://cloud.tencent.com/document/api/296/99478)
* [DescribeFileTamperRules](https://cloud.tencent.com/document/api/296/99511)
* [DescribeHostInfo](https://cloud.tencent.com/document/api/296/99510)
* [DescribeHotVulTop](https://cloud.tencent.com/document/api/296/99565)
* [DescribeJavaMemShellInfo](https://cloud.tencent.com/document/api/296/99669)
* [DescribeJavaMemShellPluginInfo](https://cloud.tencent.com/document/api/296/99668)
* [DescribeJavaMemShellPluginList](https://cloud.tencent.com/document/api/296/99667)
* [DescribeLicense](https://cloud.tencent.com/document/api/296/99537)
* [DescribeLicenseWhiteConfig](https://cloud.tencent.com/document/api/296/99627)
* [DescribeLogDeliveryKafkaOptions](https://cloud.tencent.com/document/api/296/99626)
* [DescribeLogExports](https://cloud.tencent.com/document/api/296/99625)
* [DescribeLogHistogram](https://cloud.tencent.com/document/api/296/99624)
* [DescribeLogIndex](https://cloud.tencent.com/document/api/296/99623)
* [DescribeLogKafkaDeliverInfo](https://cloud.tencent.com/document/api/296/99622)
* [DescribeLogType](https://cloud.tencent.com/document/api/296/99566)
* [DescribeLoginWhiteHostList](https://cloud.tencent.com/document/api/296/99688)
* [DescribeMachineClearHistory](https://cloud.tencent.com/document/api/296/99509)
* [DescribeMachineDefenseCnt](https://cloud.tencent.com/document/api/296/99477)
* [DescribeMachineFileTamperRules](https://cloud.tencent.com/document/api/296/99508)
* [DescribeMachineGeneral](https://cloud.tencent.com/document/api/296/99507)
* [DescribeMachineLicenseDetail](https://cloud.tencent.com/document/api/296/99506)
* [DescribeMachineRegionList](https://cloud.tencent.com/document/api/296/99505)
* [DescribeMachineSnapshot](https://cloud.tencent.com/document/api/296/99560)
* [DescribeMachinesSimple](https://cloud.tencent.com/document/api/296/99504)
* [DescribeMalwareRiskOverview](https://cloud.tencent.com/document/api/296/99666)
* [DescribeMalwareWhiteList](https://cloud.tencent.com/document/api/296/99665)
* [DescribeMalwareWhiteListAffectList](https://cloud.tencent.com/document/api/296/99664)
* [DescribeNetAttackSetting](https://cloud.tencent.com/document/api/296/99476)
* [DescribeNetAttackWhiteList](https://cloud.tencent.com/document/api/296/99663)
* [DescribeProductStatus](https://cloud.tencent.com/document/api/296/99621)
* [DescribePublicProxyInstallCommand](https://cloud.tencent.com/document/api/296/99620)
* [DescribeRansomDefenseBackupList](https://cloud.tencent.com/document/api/296/99475)
* [DescribeRansomDefenseEventsList](https://cloud.tencent.com/document/api/296/99474)
* [DescribeRansomDefenseMachineList](https://cloud.tencent.com/document/api/296/99473)
* [DescribeRansomDefenseMachineStrategyInfo](https://cloud.tencent.com/document/api/296/99619)
* [DescribeRansomDefenseRollBackTaskList](https://cloud.tencent.com/document/api/296/99472)
* [DescribeRansomDefenseState](https://cloud.tencent.com/document/api/296/99618)
* [DescribeRansomDefenseStrategyDetail](https://cloud.tencent.com/document/api/296/99617)
* [DescribeRansomDefenseStrategyList](https://cloud.tencent.com/document/api/296/99471)
* [DescribeRansomDefenseStrategyMachines](https://cloud.tencent.com/document/api/296/99470)
* [DescribeRansomDefenseTrend](https://cloud.tencent.com/document/api/296/99616)
* [DescribeRecommendedProtectCpu](https://cloud.tencent.com/document/api/296/99615)
* [DescribeRiskBatchStatus](https://cloud.tencent.com/document/api/296/99614)
* [DescribeRiskDnsInfo](https://cloud.tencent.com/document/api/296/99681)
* [DescribeRiskDnsPolicyList](https://cloud.tencent.com/document/api/296/99680)
* [DescribeRiskProcessEvents](https://cloud.tencent.com/document/api/296/99662)
* [DescribeSafeInfo](https://cloud.tencent.com/document/api/296/99613)
* [DescribeScreenAttackHotspot](https://cloud.tencent.com/document/api/296/99612)
* [DescribeScreenBroadcasts](https://cloud.tencent.com/document/api/296/99611)
* [DescribeScreenDefenseTrends](https://cloud.tencent.com/document/api/296/99610)
* [DescribeScreenEmergentMsg](https://cloud.tencent.com/document/api/296/99609)
* [DescribeScreenEventsCnt](https://cloud.tencent.com/document/api/296/99608)
* [DescribeScreenGeneralStat](https://cloud.tencent.com/document/api/296/99607)
* [DescribeScreenHostInvasion](https://cloud.tencent.com/document/api/296/99606)
* [DescribeScreenMachineRegions](https://cloud.tencent.com/document/api/296/99605)
* [DescribeScreenMachines](https://cloud.tencent.com/document/api/296/99604)
* [DescribeScreenProtectionCnt](https://cloud.tencent.com/document/api/296/99603)
* [DescribeScreenProtectionStat](https://cloud.tencent.com/document/api/296/99602)
* [DescribeScreenRiskAssetsTop](https://cloud.tencent.com/document/api/296/99601)
* [DescribeSecurityBroadcastInfo](https://cloud.tencent.com/document/api/296/99568)
* [DescribeSecurityProtectionStat](https://cloud.tencent.com/document/api/296/99564)
* [DescribeTrialReport](https://cloud.tencent.com/document/api/296/99600)
* [DescribeUsersConfig](https://cloud.tencent.com/document/api/296/99599)
* [DescribeVdbAndPocInfo](https://cloud.tencent.com/document/api/296/99559)
* [DescribeVersionCompareChart](https://cloud.tencent.com/document/api/296/99598)
* [DescribeVulCveIdInfo](https://cloud.tencent.com/document/api/296/99558)
* [DescribeVulDefenceEvent](https://cloud.tencent.com/document/api/296/99557)
* [DescribeVulDefenceList](https://cloud.tencent.com/document/api/296/99556)
* [DescribeVulDefenceOverview](https://cloud.tencent.com/document/api/296/99661)
* [DescribeVulDefencePluginDetail](https://cloud.tencent.com/document/api/296/99555)
* [DescribeVulDefencePluginExceptionCount](https://cloud.tencent.com/document/api/296/99660)
* [DescribeVulDefencePluginStatus](https://cloud.tencent.com/document/api/296/99554)
* [DescribeVulDefenceSetting](https://cloud.tencent.com/document/api/296/99659)
* [DescribeVulEffectModules](https://cloud.tencent.com/document/api/296/99553)
* [DescribeVulEmergentMsg](https://cloud.tencent.com/document/api/296/99552)
* [DescribeVulFixStatus](https://cloud.tencent.com/document/api/296/99551)
* [DescribeVulLabels](https://cloud.tencent.com/document/api/296/99469)
* [DescribeVulOverview](https://cloud.tencent.com/document/api/296/99468)
* [DescribeVulTrend](https://cloud.tencent.com/document/api/296/99597)
* [DescribeWarningHostConfig](https://cloud.tencent.com/document/api/296/99596)
* [DescribeWebHookPolicy](https://cloud.tencent.com/document/api/296/99595)
* [DescribeWebHookReceiver](https://cloud.tencent.com/document/api/296/99594)
* [DescribeWebHookReceiverUsage](https://cloud.tencent.com/document/api/296/99593)
* [DescribeWebHookRule](https://cloud.tencent.com/document/api/296/99536)
* [DescribeWebHookRules](https://cloud.tencent.com/document/api/296/99535)
* [EditPrivilegeRules](https://cloud.tencent.com/document/api/296/99651)
* [EditReverseShellRules](https://cloud.tencent.com/document/api/296/99693)
* [ExportAssetAppList](https://cloud.tencent.com/document/api/296/99503)
* [ExportAssetDatabaseList](https://cloud.tencent.com/document/api/296/99502)
* [ExportAssetEnvList](https://cloud.tencent.com/document/api/296/99501)
* [ExportAssetInitServiceList](https://cloud.tencent.com/document/api/296/99500)
* [ExportAssetJarList](https://cloud.tencent.com/document/api/296/99499)
* [ExportAssetMachineDetail](https://cloud.tencent.com/document/api/296/99498)
* [ExportAssetMachineList](https://cloud.tencent.com/document/api/296/99497)
* [ExportAssetPlanTaskList](https://cloud.tencent.com/document/api/296/99496)
* [ExportAssetPortInfoList](https://cloud.tencent.com/document/api/296/99495)
* [ExportAssetProcessInfoList](https://cloud.tencent.com/document/api/296/99494)
* [ExportAssetRecentMachineInfo](https://cloud.tencent.com/document/api/296/99493)
* [ExportAssetSystemPackageList](https://cloud.tencent.com/document/api/296/99492)
* [ExportAssetUserList](https://cloud.tencent.com/document/api/296/99491)
* [ExportAssetWebAppList](https://cloud.tencent.com/document/api/296/99490)
* [ExportAssetWebFrameList](https://cloud.tencent.com/document/api/296/99489)
* [ExportAssetWebLocationList](https://cloud.tencent.com/document/api/296/99488)
* [ExportAttackEvents](https://cloud.tencent.com/document/api/296/99467)
* [ExportBashEventsNew](https://cloud.tencent.com/document/api/296/99646)
* [ExportBashPolicies](https://cloud.tencent.com/document/api/296/99645)
* [ExportFileTamperEvents](https://cloud.tencent.com/document/api/296/99466)
* [ExportFileTamperRules](https://cloud.tencent.com/document/api/296/99465)
* [ExportJavaMemShellPlugins](https://cloud.tencent.com/document/api/296/99658)
* [ExportJavaMemShells](https://cloud.tencent.com/document/api/296/99657)
* [ExportRansomDefenseBackupList](https://cloud.tencent.com/document/api/296/99464)
* [ExportRansomDefenseEventsList](https://cloud.tencent.com/document/api/296/99463)
* [ExportRansomDefenseMachineList](https://cloud.tencent.com/document/api/296/99462)
* [ExportRansomDefenseStrategyList](https://cloud.tencent.com/document/api/296/99461)
* [ExportRansomDefenseStrategyMachines](https://cloud.tencent.com/document/api/296/99460)
* [ExportRiskDnsEventList](https://cloud.tencent.com/document/api/296/99679)
* [ExportRiskDnsPolicyList](https://cloud.tencent.com/document/api/296/99678)
* [ExportRiskProcessEvents](https://cloud.tencent.com/document/api/296/99656)
* [ExportVulDefenceEvent](https://cloud.tencent.com/document/api/296/99550)
* [ExportVulDefenceList](https://cloud.tencent.com/document/api/296/99549)
* [ExportVulDefencePluginEvent](https://cloud.tencent.com/document/api/296/99548)
* [ExportVulInfo](https://cloud.tencent.com/document/api/296/99547)
* [GetLocalStorageItem](https://cloud.tencent.com/document/api/296/99592)
* [KeysLocalStorage](https://cloud.tencent.com/document/api/296/99591)
* [ModifyBanWhiteList](https://cloud.tencent.com/document/api/296/99690)
* [ModifyBashPolicy](https://cloud.tencent.com/document/api/296/99644)
* [ModifyBashPolicyStatus](https://cloud.tencent.com/document/api/296/99643)
* [ModifyEventAttackStatus](https://cloud.tencent.com/document/api/296/99590)
* [ModifyFileTamperEvents](https://cloud.tencent.com/document/api/296/99459)
* [ModifyFileTamperRule](https://cloud.tencent.com/document/api/296/99458)
* [ModifyFileTamperRuleStatus](https://cloud.tencent.com/document/api/296/99457)
* [ModifyJavaMemShellPluginSwitch](https://cloud.tencent.com/document/api/296/99655)
* [ModifyJavaMemShellsStatus](https://cloud.tencent.com/document/api/296/99654)
* [ModifyLogKafkaAccess](https://cloud.tencent.com/document/api/296/99589)
* [ModifyLogKafkaDeliverType](https://cloud.tencent.com/document/api/296/99588)
* [ModifyLogKafkaState](https://cloud.tencent.com/document/api/296/99587)
* [ModifyLoginWhiteInfo](https://cloud.tencent.com/document/api/296/99687)
* [ModifyLoginWhiteRecord](https://cloud.tencent.com/document/api/296/99686)
* [ModifyMachineAutoClearConfig](https://cloud.tencent.com/document/api/296/99487)
* [ModifyMaliciousRequestWhiteList](https://cloud.tencent.com/document/api/296/99677)
* [ModifyMalwareWhiteList](https://cloud.tencent.com/document/api/296/99653)
* [ModifyNetAttackSetting](https://cloud.tencent.com/document/api/296/99456)
* [ModifyNetAttackWhiteList](https://cloud.tencent.com/document/api/296/99652)
* [ModifyRansomDefenseEventsStatus](https://cloud.tencent.com/document/api/296/99455)
* [ModifyRansomDefenseStrategyStatus](https://cloud.tencent.com/document/api/296/99586)
* [ModifyRiskDnsPolicy](https://cloud.tencent.com/document/api/296/99676)
* [ModifyRiskDnsPolicyStatus](https://cloud.tencent.com/document/api/296/99675)
* [ModifyRiskEventsStatus](https://cloud.tencent.com/document/api/296/99585)
* [ModifyUsersConfig](https://cloud.tencent.com/document/api/296/99584)
* [ModifyVulDefenceEventStatus](https://cloud.tencent.com/document/api/296/99546)
* [ModifyVulDefenceSetting](https://cloud.tencent.com/document/api/296/99545)
* [ModifyWarningHostConfig](https://cloud.tencent.com/document/api/296/99583)
* [ModifyWebHookPolicy](https://cloud.tencent.com/document/api/296/99582)
* [ModifyWebHookPolicyStatus](https://cloud.tencent.com/document/api/296/99581)
* [ModifyWebHookReceiver](https://cloud.tencent.com/document/api/296/99580)
* [ModifyWebHookRule](https://cloud.tencent.com/document/api/296/99534)
* [ModifyWebHookRuleStatus](https://cloud.tencent.com/document/api/296/99533)
* [RansomDefenseRollback](https://cloud.tencent.com/document/api/296/99579)
* [RemoveLocalStorageItem](https://cloud.tencent.com/document/api/296/99578)
* [RemoveMachine](https://cloud.tencent.com/document/api/296/99486)
* [RetryCreateSnapshot](https://cloud.tencent.com/document/api/296/99544)
* [RetryVulFix](https://cloud.tencent.com/document/api/296/99543)
* [ScanBaseline](https://cloud.tencent.com/document/api/296/99567)
* [ScanTaskAgain](https://cloud.tencent.com/document/api/296/99577)
* [SearchLog](https://cloud.tencent.com/document/api/296/99576)
* [SetLocalStorageExpire](https://cloud.tencent.com/document/api/296/99575)
* [SetLocalStorageItem](https://cloud.tencent.com/document/api/296/99574)
* [StopAssetScan](https://cloud.tencent.com/document/api/296/99573)
* [SyncMachines](https://cloud.tencent.com/document/api/296/99572)
* [TestWebHookRule](https://cloud.tencent.com/document/api/296/99532)

新增数据结构：

* [ABTestConfig](https://cloud.tencent.com/document/api/296/19867#ABTestConfig)
* [AssetLoadDetail](https://cloud.tencent.com/document/api/296/19867#AssetLoadDetail)
* [AssetLoadSummary](https://cloud.tencent.com/document/api/296/19867#AssetLoadSummary)
* [AssetType](https://cloud.tencent.com/document/api/296/19867#AssetType)
* [AssetWebLocationPath](https://cloud.tencent.com/document/api/296/19867#AssetWebLocationPath)
* [AttackSource](https://cloud.tencent.com/document/api/296/19867#AttackSource)
* [AttackSourceEdge](https://cloud.tencent.com/document/api/296/19867#AttackSourceEdge)
* [AttackSourceEvent](https://cloud.tencent.com/document/api/296/19867#AttackSourceEvent)
* [AttackSourceNode](https://cloud.tencent.com/document/api/296/19867#AttackSourceNode)
* [BanWhiteList](https://cloud.tencent.com/document/api/296/19867#BanWhiteList)
* [BashEventsInfo](https://cloud.tencent.com/document/api/296/19867#BashEventsInfo)
* [BashPolicy](https://cloud.tencent.com/document/api/296/19867#BashPolicy)
* [BroadcastInfo](https://cloud.tencent.com/document/api/296/19867#BroadcastInfo)
* [CKafkaInstanceInfo](https://cloud.tencent.com/document/api/296/19867#CKafkaInstanceInfo)
* [CKafkaRouteInfo](https://cloud.tencent.com/document/api/296/19867#CKafkaRouteInfo)
* [CKafkaTopicInfo](https://cloud.tencent.com/document/api/296/19867#CKafkaTopicInfo)
* [CanFixVulInfo](https://cloud.tencent.com/document/api/296/19867#CanFixVulInfo)
* [CanNotSeparateInfo](https://cloud.tencent.com/document/api/296/19867#CanNotSeparateInfo)
* [CloudProtectService](https://cloud.tencent.com/document/api/296/19867#CloudProtectService)
* [CreateVulFixTaskQuuids](https://cloud.tencent.com/document/api/296/19867#CreateVulFixTaskQuuids)
* [DefaultStrategyInfo](https://cloud.tencent.com/document/api/296/19867#DefaultStrategyInfo)
* [DeliverTypeDetails](https://cloud.tencent.com/document/api/296/19867#DeliverTypeDetails)
* [DuplicateHosts](https://cloud.tencent.com/document/api/296/19867#DuplicateHosts)
* [ExportInfo](https://cloud.tencent.com/document/api/296/19867#ExportInfo)
* [FieldValueRatioInfo](https://cloud.tencent.com/document/api/296/19867#FieldValueRatioInfo)
* [FileTamperRule](https://cloud.tencent.com/document/api/296/19867#FileTamperRule)
* [FileTamperRuleCount](https://cloud.tencent.com/document/api/296/19867#FileTamperRuleCount)
* [FileTamperRuleDetail](https://cloud.tencent.com/document/api/296/19867#FileTamperRuleDetail)
* [FileTamperRuleInfo](https://cloud.tencent.com/document/api/296/19867#FileTamperRuleInfo)
* [FullTextInfo](https://cloud.tencent.com/document/api/296/19867#FullTextInfo)
* [HostDesc](https://cloud.tencent.com/document/api/296/19867#HostDesc)
* [HostInfo](https://cloud.tencent.com/document/api/296/19867#HostInfo)
* [HostLoginWhiteObj](https://cloud.tencent.com/document/api/296/19867#HostLoginWhiteObj)
* [HostTagInfo](https://cloud.tencent.com/document/api/296/19867#HostTagInfo)
* [JavaMemShellDetail](https://cloud.tencent.com/document/api/296/19867#JavaMemShellDetail)
* [JavaMemShellPluginInfo](https://cloud.tencent.com/document/api/296/19867#JavaMemShellPluginInfo)
* [JavaMemShellPluginSetting](https://cloud.tencent.com/document/api/296/19867#JavaMemShellPluginSetting)
* [KeyValueArrayInfo](https://cloud.tencent.com/document/api/296/19867#KeyValueArrayInfo)
* [KeyValueInfo](https://cloud.tencent.com/document/api/296/19867#KeyValueInfo)
* [LogHistogram](https://cloud.tencent.com/document/api/296/19867#LogHistogram)
* [LogInfo](https://cloud.tencent.com/document/api/296/19867#LogInfo)
* [MachineClearHistory](https://cloud.tencent.com/document/api/296/19867#MachineClearHistory)
* [MachineFileTamperRule](https://cloud.tencent.com/document/api/296/19867#MachineFileTamperRule)
* [MachineLicenseDetail](https://cloud.tencent.com/document/api/296/19867#MachineLicenseDetail)
* [MachineSimple](https://cloud.tencent.com/document/api/296/19867#MachineSimple)
* [MachineSnapshotInfo](https://cloud.tencent.com/document/api/296/19867#MachineSnapshotInfo)
* [MalwareRiskOverview](https://cloud.tencent.com/document/api/296/19867#MalwareRiskOverview)
* [MalwareWhiteListAffectEvent](https://cloud.tencent.com/document/api/296/19867#MalwareWhiteListAffectEvent)
* [MalwareWhiteListInfo](https://cloud.tencent.com/document/api/296/19867#MalwareWhiteListInfo)
* [NetAttackEventInfo](https://cloud.tencent.com/document/api/296/19867#NetAttackEventInfo)
* [NetAttackTopInfo](https://cloud.tencent.com/document/api/296/19867#NetAttackTopInfo)
* [NetAttackTrend](https://cloud.tencent.com/document/api/296/19867#NetAttackTrend)
* [NetAttackWhiteRule](https://cloud.tencent.com/document/api/296/19867#NetAttackWhiteRule)
* [OrderResource](https://cloud.tencent.com/document/api/296/19867#OrderResource)
* [ProductStatusInfo](https://cloud.tencent.com/document/api/296/19867#ProductStatusInfo)
* [RansomDefenseBackup](https://cloud.tencent.com/document/api/296/19867#RansomDefenseBackup)
* [RansomDefenseEvent](https://cloud.tencent.com/document/api/296/19867#RansomDefenseEvent)
* [RansomDefenseRollbackTask](https://cloud.tencent.com/document/api/296/19867#RansomDefenseRollbackTask)
* [RansomDefenseStrategy](https://cloud.tencent.com/document/api/296/19867#RansomDefenseStrategy)
* [RansomDefenseStrategyDetail](https://cloud.tencent.com/document/api/296/19867#RansomDefenseStrategyDetail)
* [RansomDefenseStrategyMachineBackupInfo](https://cloud.tencent.com/document/api/296/19867#RansomDefenseStrategyMachineBackupInfo)
* [RansomDefenseStrategyMachineDetail](https://cloud.tencent.com/document/api/296/19867#RansomDefenseStrategyMachineDetail)
* [RansomDefenseStrategyMachineInfo](https://cloud.tencent.com/document/api/296/19867#RansomDefenseStrategyMachineInfo)
* [RegionListDetail](https://cloud.tencent.com/document/api/296/19867#RegionListDetail)
* [RiskDnsPolicy](https://cloud.tencent.com/document/api/296/19867#RiskDnsPolicy)
* [RiskProcessEvent](https://cloud.tencent.com/document/api/296/19867#RiskProcessEvent)
* [RuleInfo](https://cloud.tencent.com/document/api/296/19867#RuleInfo)
* [ScreenAttackHotspot](https://cloud.tencent.com/document/api/296/19867#ScreenAttackHotspot)
* [ScreenBaselineInfo](https://cloud.tencent.com/document/api/296/19867#ScreenBaselineInfo)
* [ScreenBroadcasts](https://cloud.tencent.com/document/api/296/19867#ScreenBroadcasts)
* [ScreenDefendAttackLog](https://cloud.tencent.com/document/api/296/19867#ScreenDefendAttackLog)
* [ScreenEmergentMsg](https://cloud.tencent.com/document/api/296/19867#ScreenEmergentMsg)
* [ScreenEventsCnt](https://cloud.tencent.com/document/api/296/19867#ScreenEventsCnt)
* [ScreenInvasion](https://cloud.tencent.com/document/api/296/19867#ScreenInvasion)
* [ScreenMachine](https://cloud.tencent.com/document/api/296/19867#ScreenMachine)
* [ScreenNameValue](https://cloud.tencent.com/document/api/296/19867#ScreenNameValue)
* [ScreenProtection](https://cloud.tencent.com/document/api/296/19867#ScreenProtection)
* [ScreenProtectionCnt](https://cloud.tencent.com/document/api/296/19867#ScreenProtectionCnt)
* [ScreenRegionInfo](https://cloud.tencent.com/document/api/296/19867#ScreenRegionInfo)
* [ScreenRegionMachines](https://cloud.tencent.com/document/api/296/19867#ScreenRegionMachines)
* [ScreenTrendsChart](https://cloud.tencent.com/document/api/296/19867#ScreenTrendsChart)
* [ScreenVulInfo](https://cloud.tencent.com/document/api/296/19867#ScreenVulInfo)
* [TopInfo](https://cloud.tencent.com/document/api/296/19867#TopInfo)
* [UpdateHostLoginWhiteObj](https://cloud.tencent.com/document/api/296/19867#UpdateHostLoginWhiteObj)
* [ValueInfo](https://cloud.tencent.com/document/api/296/19867#ValueInfo)
* [VulDefenceEvent](https://cloud.tencent.com/document/api/296/19867#VulDefenceEvent)
* [VulDefenceEventDetail](https://cloud.tencent.com/document/api/296/19867#VulDefenceEventDetail)
* [VulDefenceOverview](https://cloud.tencent.com/document/api/296/19867#VulDefenceOverview)
* [VulDefencePluginDetail](https://cloud.tencent.com/document/api/296/19867#VulDefencePluginDetail)
* [VulDefencePluginStatus](https://cloud.tencent.com/document/api/296/19867#VulDefencePluginStatus)
* [VulDefenceRangeDetail](https://cloud.tencent.com/document/api/296/19867#VulDefenceRangeDetail)
* [VulEffectModuleInfo](https://cloud.tencent.com/document/api/296/19867#VulEffectModuleInfo)
* [VulEmergentMsgInfo](https://cloud.tencent.com/document/api/296/19867#VulEmergentMsgInfo)
* [VulFixStatusHostInfo](https://cloud.tencent.com/document/api/296/19867#VulFixStatusHostInfo)
* [VulFixStatusInfo](https://cloud.tencent.com/document/api/296/19867#VulFixStatusInfo)
* [VulFixStatusSnapshotInfo](https://cloud.tencent.com/document/api/296/19867#VulFixStatusSnapshotInfo)
* [VulInfoByCveId](https://cloud.tencent.com/document/api/296/19867#VulInfoByCveId)
* [VulInfoHostInfo](https://cloud.tencent.com/document/api/296/19867#VulInfoHostInfo)
* [VulOverview](https://cloud.tencent.com/document/api/296/19867#VulOverview)
* [WebHookCustomField](https://cloud.tencent.com/document/api/296/19867#WebHookCustomField)
* [WebHookEventKv](https://cloud.tencent.com/document/api/296/19867#WebHookEventKv)
* [WebHookHostLabel](https://cloud.tencent.com/document/api/296/19867#WebHookHostLabel)
* [WebHookPolicy](https://cloud.tencent.com/document/api/296/19867#WebHookPolicy)
* [WebHookReceiver](https://cloud.tencent.com/document/api/296/19867#WebHookReceiver)
* [WebHookReceiverUsage](https://cloud.tencent.com/document/api/296/19867#WebHookReceiverUsage)
* [WebHookRuleDetail](https://cloud.tencent.com/document/api/296/19867#WebHookRuleDetail)
* [WebHookRuleSummary](https://cloud.tencent.com/document/api/296/19867#WebHookRuleSummary)

修改数据结构：

* [RiskDnsEvent](https://cloud.tencent.com/document/api/296/19867#RiskDnsEvent)

	* 新增成员：OsType

	* <font color="#dd0000">**修改成员**：</font>Id, PolicyId, PolicyType, PolicyName, ProtectLevel, HostId, HostName, HostIp, WanIp, AgentId, Domain, Tags, AccessCount, ThreatDesc, SuggestSolution, ReferenceLink, HandleStatus, Pid, ProcessName, ProcessMd5, CmdLine, FirstTime, LastTime, HostStatus, MachineExtraInfo


### 第 97 次发布

发布时间：2023-09-26 01:16:14

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [AssetInitServiceBaseInfo](https://cloud.tencent.com/document/api/296/19867#AssetInitServiceBaseInfo)

	* 新增成员：IsAutoRun

	* <font color="#dd0000">**修改成员**：</font>Name, Type, Status, User, Path, MachineIp, MachineName, OsInfo, Quuid, Uuid, UpdateTime, FirstTime, IsNew, MachineWanIp, MachineExtraInfo


### 第 96 次发布

发布时间：2023-09-22 01:33:07

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeAgentInstallCommand](https://cloud.tencent.com/document/api/296/98746)

### 第 95 次发布

发布时间：2023-09-20 01:15:27

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeAttackEvents](https://cloud.tencent.com/document/api/296/98699)
* [DescribeMachineRiskCnt](https://cloud.tencent.com/document/api/296/98698)
* [DescribeSecurityBroadcasts](https://cloud.tencent.com/document/api/296/98701)
* [ModifyLicenseOrder](https://cloud.tencent.com/document/api/296/98700)

新增数据结构：

* [Broadcasts](https://cloud.tencent.com/document/api/296/19867#Broadcasts)
* [NetAttackEvent](https://cloud.tencent.com/document/api/296/19867#NetAttackEvent)

### 第 94 次发布

发布时间：2023-08-31 01:12:44

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeMaliciousRequestWhiteList](https://cloud.tencent.com/document/api/296/61720)

	* 新增入参：Order, By


### 第 93 次发布

发布时间：2023-08-30 01:11:34

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [BashRule](https://cloud.tencent.com/document/api/296/19867#BashRule)

	* 新增成员：Description


### 第 92 次发布

发布时间：2023-07-28 01:18:37

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [EffectiveMachineInfo](https://cloud.tencent.com/document/api/296/19867#EffectiveMachineInfo)

	* <font color="#dd0000">**修改成员**：</font>MachineName, MachinePublicIp, MachinePrivateIp, MachineTag, Quuid, Uuid, KernelVersion, MachineStatus, LicenseOrder, VulNum, CloudTags, InstanceID

* [LicenseDetail](https://cloud.tencent.com/document/api/296/19867#LicenseDetail)

	* 新增成员：FreezeNum

* [Machine](https://cloud.tencent.com/document/api/296/19867#Machine)

	* <font color="#dd0000">**修改成员**：</font>MachineName, MachineOs, MachineStatus, Uuid, Quuid, VulNum, MachineIp, IsProVersion, MachineWanIp, PayMode, MalwareNum, Tag, BaselineNum, CyberAttackNum, SecurityStatus, InvasionNum, RegionInfo, InstanceState, LicenseStatus, ProjectId, HasAssetScan, MachineType, KernelVersion, ProtectType, CloudTags, IsAddedOnTheFifteen, IpList, VpcId, MachineExtraInfo, InstanceId


### 第 91 次发布

发布时间：2023-07-18 01:22:32

本次发布包含了以下内容：

改善已有的文档。

<font color="#dd0000">**删除接口**：</font>

* DescribeSearchExportList

### 第 90 次发布

发布时间：2023-06-05 01:20:04

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeVulStoreList](https://cloud.tencent.com/document/api/296/93137)

<font color="#dd0000">**删除接口**：</font>

* DescribeSaveOrUpdateWarnings

新增数据结构：

* [VulStoreListInfo](https://cloud.tencent.com/document/api/296/19867#VulStoreListInfo)

### 第 89 次发布

发布时间：2023-06-02 01:19:01

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [AssetWebFrameBaseInfo](https://cloud.tencent.com/document/api/296/19867#AssetWebFrameBaseInfo)

	* 新增成员：Path


### 第 88 次发布

发布时间：2023-05-31 01:16:52

本次发布包含了以下内容：

改善已有的文档。

<font color="#dd0000">**预下线接口**：</font>

* DescribeSaveOrUpdateWarnings

修改接口：

* [DescribeAssetSystemPackageList](https://cloud.tencent.com/document/api/296/61933)

	* <font color="#dd0000">**修改入参**：</font>Uuid, Quuid


修改数据结构：

* [AssetSystemPackageInfo](https://cloud.tencent.com/document/api/296/19867#AssetSystemPackageInfo)

	* 新增成员：MachineExtraInfo, Quuid, Uuid


### 第 87 次发布

发布时间：2023-05-17 01:21:39

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeLogStorageConfig](https://cloud.tencent.com/document/api/296/91086)
* [DescribeLogStorageRecord](https://cloud.tencent.com/document/api/296/91085)
* [ModifyLogStorageConfig](https://cloud.tencent.com/document/api/296/91084)

新增数据结构：

* [LogStorageRecord](https://cloud.tencent.com/document/api/296/19867#LogStorageRecord)

### 第 86 次发布

发布时间：2023-05-16 01:22:17

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [LicenseBindTaskDetail](https://cloud.tencent.com/document/api/296/19867#LicenseBindTaskDetail)

	* 新增成员：FixMessage, MachineExtraInfo


### 第 85 次发布

发布时间：2023-05-15 01:28:20

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [VulInfoList](https://cloud.tencent.com/document/api/296/19867#VulInfoList)

	* 新增成员：AttackLevel, FixNoNeedRestart, Method


### 第 84 次发布

发布时间：2023-05-12 01:15:52

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeEmergencyVulList](https://cloud.tencent.com/document/api/296/60903)

	* 新增入参：HotspotAttack


修改数据结构：

* [EmergencyVul](https://cloud.tencent.com/document/api/296/19867#EmergencyVul)

	* 新增成员：Method, AttackLevel, DefenseState


### 第 83 次发布

发布时间：2023-05-09 01:12:29

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeAlarmIncidentNodes](https://cloud.tencent.com/document/api/296/89946)

	* 新增入参：TableId


### 第 82 次发布

发布时间：2023-05-08 01:17:35

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeLicenseGeneral](https://cloud.tencent.com/document/api/296/80398)

	* 新增出参：DestroyOrderNum


修改数据结构：

* [LoginWhiteCombinedInfo](https://cloud.tencent.com/document/api/296/19867#LoginWhiteCombinedInfo)

	* 新增成员：Locations

	* <font color="#dd0000">**修改成员**：</font>Places, UserName, SrcIp, Locale, Remark, StartTime, EndTime, IsGlobal, Name, Desc, Id, CreateTime, ModifyTime, Uuid

* [ProtectDirInfo](https://cloud.tencent.com/document/api/296/19867#ProtectDirInfo)

	* 新增成员：FirstProtectTime, LatestProtectTime, ProtectFileType, ProtectFilesCount

* [ProtectEventLists](https://cloud.tencent.com/document/api/296/19867#ProtectEventLists)

	* 新增成员：Quuid


### 第 81 次发布

发布时间：2023-04-19 01:23:40

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [FileTamperEvent](https://cloud.tencent.com/document/api/296/19867#FileTamperEvent)

	* 新增成员：FileAction


### 第 80 次发布

发布时间：2023-04-18 01:18:35

本次发布包含了以下内容：

改善已有的文档。

<font color="#dd0000">**预下线接口**：</font>

* DescribeSearchExportList

### 第 79 次发布

发布时间：2023-04-11 01:12:54

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [BashEventsInfoNew](https://cloud.tencent.com/document/api/296/19867#BashEventsInfoNew)

	* <font color="#dd0000">**修改成员**：</font>Id, Uuid, Quuid, HostIp, Platform, BashCmd, RuleId, RuleName, RuleLevel, Status, CreateTime, MachineName, Exe, ModifyTime, RuleCategory, RegexBashCmd, PsTree, SuggestScheme, HarmDescribe, Tags, References, MachineWanIp, MachineStatus, User, Pid, MachineType, DetectBy


### 第 78 次发布

发布时间：2023-04-10 01:18:59

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeFileTamperEvents](https://cloud.tencent.com/document/api/296/90008)

新增数据结构：

* [FileTamperEvent](https://cloud.tencent.com/document/api/296/19867#FileTamperEvent)

### 第 77 次发布

发布时间：2023-04-07 01:21:04

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeAlarmIncidentNodes](https://cloud.tencent.com/document/api/296/89946)
* [DescribeAlarmVertexId](https://cloud.tencent.com/document/api/296/89945)
* [DescribeEventByTable](https://cloud.tencent.com/document/api/296/89944)
* [DescribePrivilegeEventInfo](https://cloud.tencent.com/document/api/296/89947)
* [DescribeReverseShellEventInfo](https://cloud.tencent.com/document/api/296/89949)
* [DescribeRiskDnsEventInfo](https://cloud.tencent.com/document/api/296/89948)
* [DescribeVertexDetail](https://cloud.tencent.com/document/api/296/89943)

新增数据结构：

* [AlarmInfo](https://cloud.tencent.com/document/api/296/19867#AlarmInfo)
* [IncidentVertexInfo](https://cloud.tencent.com/document/api/296/19867#IncidentVertexInfo)
* [PrivilegeEventInfo](https://cloud.tencent.com/document/api/296/19867#PrivilegeEventInfo)
* [ReverseShellEventInfo](https://cloud.tencent.com/document/api/296/19867#ReverseShellEventInfo)
* [VertexDetail](https://cloud.tencent.com/document/api/296/19867#VertexDetail)
* [VertexInfo](https://cloud.tencent.com/document/api/296/19867#VertexInfo)

修改数据结构：

* [BruteAttackInfo](https://cloud.tencent.com/document/api/296/19867#BruteAttackInfo)

	* 新增成员：Location

* [HostLoginList](https://cloud.tencent.com/document/api/296/19867#HostLoginList)

	* 新增成员：Port

* [PrivilegeEscalationProcess](https://cloud.tencent.com/document/api/296/19867#PrivilegeEscalationProcess)

	* 新增成员：Pid

* [ReverseShell](https://cloud.tencent.com/document/api/296/19867#ReverseShell)

	* 新增成员：Pid


### 第 76 次发布

发布时间：2023-03-31 01:16:52

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeBashEventsInfoNew](https://cloud.tencent.com/document/api/296/89677)

新增数据结构：

* [BashEventsInfoNew](https://cloud.tencent.com/document/api/296/19867#BashEventsInfoNew)

### 第 75 次发布

发布时间：2023-03-30 01:13:34

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeRiskDnsEventList](https://cloud.tencent.com/document/api/296/89634)

新增数据结构：

* [RiskDnsEvent](https://cloud.tencent.com/document/api/296/19867#RiskDnsEvent)

### 第 74 次发布

发布时间：2023-03-29 11:10:50

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [UpdateMachineTags](https://cloud.tencent.com/document/api/296/60890)

	* <font color="#dd0000">**修改入参**：</font>MachineRegion, MachineArea


### 第 73 次发布

发布时间：2023-03-10 01:25:38

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [JavaMemShellInfo](https://cloud.tencent.com/document/api/296/19867#JavaMemShellInfo)

	* 新增成员：Uuid


### 第 72 次发布

发布时间：2023-03-09 01:17:51

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateEmergencyVulScan](https://cloud.tencent.com/document/api/296/60904)

	* 新增入参：TimeoutPeriod


### 第 71 次发布

发布时间：2023-03-07 01:13:54

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DeleteBaselineRule](https://cloud.tencent.com/document/api/296/87870)
* [DeleteBaselineRuleIgnore](https://cloud.tencent.com/document/api/296/87869)
* [DeleteBaselineWeakPassword](https://cloud.tencent.com/document/api/296/87868)
* [DescribeBaselineDetectList](https://cloud.tencent.com/document/api/296/87867)
* [DescribeBaselineDetectOverview](https://cloud.tencent.com/document/api/296/87866)
* [DescribeBaselineDownloadList](https://cloud.tencent.com/document/api/296/87865)
* [DescribeBaselineFixList](https://cloud.tencent.com/document/api/296/87864)
* [DescribeBaselineHostIgnoreList](https://cloud.tencent.com/document/api/296/87863)
* [DescribeBaselineHostRiskTop](https://cloud.tencent.com/document/api/296/87862)
* [DescribeBaselineItemIgnoreList](https://cloud.tencent.com/document/api/296/87861)
* [DescribeBaselineItemInfo](https://cloud.tencent.com/document/api/296/87860)
* [DescribeBaselineItemRiskTop](https://cloud.tencent.com/document/api/296/87859)
* [DescribeBaselineRuleCategoryList](https://cloud.tencent.com/document/api/296/87858)
* [DescribeBaselineRuleDetectList](https://cloud.tencent.com/document/api/296/87857)
* [DescribeBaselineRuleIgnoreList](https://cloud.tencent.com/document/api/296/87856)
* [DescribeBaselineRuleList](https://cloud.tencent.com/document/api/296/87855)
* [DescribeBaselineWeakPasswordList](https://cloud.tencent.com/document/api/296/87854)
* [DescribeIgnoreHostAndItemConfig](https://cloud.tencent.com/document/api/296/87853)
* [ExportBaselineFixList](https://cloud.tencent.com/document/api/296/87852)
* [ExportBaselineHostDetectList](https://cloud.tencent.com/document/api/296/87851)
* [ExportBaselineItemDetectList](https://cloud.tencent.com/document/api/296/87850)
* [ExportBaselineItemList](https://cloud.tencent.com/document/api/296/87849)
* [ExportBaselineRuleDetectList](https://cloud.tencent.com/document/api/296/87848)
* [ExportBaselineWeakPasswordList](https://cloud.tencent.com/document/api/296/87847)
* [FixBaselineDetect](https://cloud.tencent.com/document/api/296/87846)
* [ModifyBaselinePolicyState](https://cloud.tencent.com/document/api/296/87845)
* [ModifyBaselineRule](https://cloud.tencent.com/document/api/296/87844)
* [ModifyBaselineRuleIgnore](https://cloud.tencent.com/document/api/296/87843)
* [ModifyBaselineWeakPassword](https://cloud.tencent.com/document/api/296/87842)

修改接口：

* [DescribeScanVulSetting](https://cloud.tencent.com/document/api/296/58237)

	* 新增出参：Uuids

* [ScanVulSetting](https://cloud.tencent.com/document/api/296/58235)

	* 新增入参：Uuids


新增数据结构：

* [BaselineCategory](https://cloud.tencent.com/document/api/296/19867#BaselineCategory)
* [BaselineCustomRuleIdName](https://cloud.tencent.com/document/api/296/19867#BaselineCustomRuleIdName)
* [BaselineDownload](https://cloud.tencent.com/document/api/296/19867#BaselineDownload)
* [BaselineFix](https://cloud.tencent.com/document/api/296/19867#BaselineFix)
* [BaselineHost](https://cloud.tencent.com/document/api/296/19867#BaselineHost)
* [BaselineItemInfo](https://cloud.tencent.com/document/api/296/19867#BaselineItemInfo)
* [BaselinePolicyDetect](https://cloud.tencent.com/document/api/296/19867#BaselinePolicyDetect)
* [BaselineRiskItem](https://cloud.tencent.com/document/api/296/19867#BaselineRiskItem)
* [BaselineRule](https://cloud.tencent.com/document/api/296/19867#BaselineRule)
* [BaselineRuleDetect](https://cloud.tencent.com/document/api/296/19867#BaselineRuleDetect)
* [BaselineWeakPassword](https://cloud.tencent.com/document/api/296/19867#BaselineWeakPassword)
* [HostRiskLevelCount](https://cloud.tencent.com/document/api/296/19867#HostRiskLevelCount)
* [Item](https://cloud.tencent.com/document/api/296/19867#Item)

### 第 70 次发布

发布时间：2023-02-16 01:18:30

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [ModifyMachineRemark](https://cloud.tencent.com/document/api/296/86610)

修改数据结构：

* [Machine](https://cloud.tencent.com/document/api/296/19867#Machine)

	* 新增成员：Remark


### 第 69 次发布

发布时间：2023-02-15 01:21:32

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [WarningInfoObj](https://cloud.tencent.com/document/api/296/19867#WarningInfoObj)

	* 新增成员：HostRange, Count

* [WarningObject](https://cloud.tencent.com/document/api/296/19867#WarningObject)

	* 新增成员：HostRange


### 第 68 次发布

发布时间：2023-02-13 01:29:52

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DeleteAttackLogs](https://cloud.tencent.com/document/api/296/39575)

	* 新增入参：IsAll

	* <font color="#dd0000">**修改入参**：</font>Ids


### 第 67 次发布

发布时间：2023-01-12 01:12:53

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeBashEventsNew](https://cloud.tencent.com/document/api/296/85682)

新增数据结构：

* [BashEventNew](https://cloud.tencent.com/document/api/296/19867#BashEventNew)

### 第 66 次发布

发布时间：2023-01-10 01:16:24

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeVersionStatistics](https://cloud.tencent.com/document/api/296/60922)

	* 新增出参：GeneralVersionNum


### 第 65 次发布

发布时间：2023-01-04 01:15:09

本次发布包含了以下内容：

改善已有的文档。

新增数据结构：

* [MachineExtraInfo](https://cloud.tencent.com/document/api/296/19867#MachineExtraInfo)

修改数据结构：

* [AssetAppBaseInfo](https://cloud.tencent.com/document/api/296/19867#AssetAppBaseInfo)

	* 新增成员：MachineExtraInfo

	* <font color="#dd0000">**修改成员**：</font>MachineIp, MachineName, MachineWanIp, Uuid, Quuid, ProjectId, Tag, Name, Type, BinPath, OsInfo, ProcessCount, Desc, Version, ConfigPath, FirstTime, UpdateTime, IsNew

* [AssetCoreModuleBaseInfo](https://cloud.tencent.com/document/api/296/19867#AssetCoreModuleBaseInfo)

	* 新增成员：MachineExtraInfo

	* <font color="#dd0000">**修改成员**：</font>Name, Desc, Path, Version, MachineIp, MachineName, OsInfo, Size, ProcessCount, ModuleCount, Id, Quuid, Uuid, UpdateTime, FirstTime, IsNew, MachineWanIp

* [AssetDatabaseBaseInfo](https://cloud.tencent.com/document/api/296/19867#AssetDatabaseBaseInfo)

	* 新增成员：MachineExtraInfo

	* <font color="#dd0000">**修改成员**：</font>MachineIp, MachineWanIp, Quuid, Uuid, OsInfo, ProjectId, Tag, Name, Version, Port, Proto, User, Ip, ConfigPath, LogPath, DataPath, Permission, ErrorLogPath, PlugInPath, BinPath, Param, Id, UpdateTime, FirstTime, IsNew, MachineName

* [AssetEnvBaseInfo](https://cloud.tencent.com/document/api/296/19867#AssetEnvBaseInfo)

	* 新增成员：MachineExtraInfo

	* <font color="#dd0000">**修改成员**：</font>Name, Type, User, Value, MachineIp, MachineName, OsInfo, Quuid, Uuid, UpdateTime, FirstTime, IsNew, MachineWanIp

* [AssetInitServiceBaseInfo](https://cloud.tencent.com/document/api/296/19867#AssetInitServiceBaseInfo)

	* 新增成员：MachineExtraInfo

	* <font color="#dd0000">**修改成员**：</font>Name, Type, Status, User, Path, MachineIp, MachineName, OsInfo, Quuid, Uuid, UpdateTime, FirstTime, IsNew, MachineWanIp

* [AssetJarBaseInfo](https://cloud.tencent.com/document/api/296/19867#AssetJarBaseInfo)

	* 新增成员：MachineExtraInfo

	* <font color="#dd0000">**修改成员**：</font>Name, Type, Status, Version, Path, MachineIp, MachineName, OsInfo, Id, Md5, Quuid, Uuid, UpdateTime, FirstTime, IsNew, MachineWanIp

* [AssetMachineBaseInfo](https://cloud.tencent.com/document/api/296/19867#AssetMachineBaseInfo)

	* 新增成员：MachineExtraInfo

	* <font color="#dd0000">**修改成员**：</font>Quuid, Uuid, MachineIp, MachineName, OsInfo, Cpu, MemSize, MemLoad, DiskSize, DiskLoad, PartitionCount, MachineWanIp, ProjectId, CpuSize, CpuLoad, Tag, UpdateTime, IsNew, FirstTime

* [AssetMachineDetail](https://cloud.tencent.com/document/api/296/19867#AssetMachineDetail)

	* 新增成员：MachineExtraInfo

	* <font color="#dd0000">**修改成员**：</font>Quuid, Uuid, MachineIp, MachineName, OsInfo, Cpu, MemSize, MemLoad, DiskSize, DiskLoad, PartitionCount, MachineWanIp, CpuSize, CpuLoad, ProtectLevel, RiskStatus, ProtectDays, BuyTime, EndTime, CoreVersion, OsType, AgentVersion, InstallTime, BootTime, LastLiveTime, Producer, SerialNumber, NetCards, Disks, Status, ProjectId, DeviceVersion, OfflineTime, InstanceId, UpdateTime

* [AssetPlanTask](https://cloud.tencent.com/document/api/296/19867#AssetPlanTask)

	* 新增成员：MachineExtraInfo

	* <font color="#dd0000">**修改成员**：</font>Status, Cycle, Command, User, ConfigPath, MachineIp, MachineName, OsInfo, Quuid, Uuid, UpdateTime, FirstTime, IsNew, MachineWanIp

* [AssetPortBaseInfo](https://cloud.tencent.com/document/api/296/19867#AssetPortBaseInfo)

	* 新增成员：MachineExtraInfo

	* <font color="#dd0000">**修改成员**：</font>MachineIp, MachineWanIp, Quuid, Uuid, OsInfo, ProjectId, Tag, ProcessName, ProcessVersion, ProcessPath, Pid, User, StartTime, Param, Teletype, Port, GroupName, Md5, Ppid, ParentProcessName, Proto, BindIp, MachineName, UpdateTime, FirstTime, IsNew

* [AssetProcessBaseInfo](https://cloud.tencent.com/document/api/296/19867#AssetProcessBaseInfo)

	* 新增成员：MachineExtraInfo

	* <font color="#dd0000">**修改成员**：</font>MachineIp, MachineWanIp, Quuid, Uuid, OsInfo, ProjectId, Tag, Name, Desc, Path, Pid, User, StartTime, Param, Tty, Version, GroupName, Md5, Ppid, ParentProcessName, Status, HasSign, InstallByPackage, PackageName, MachineName, UpdateTime, FirstTime, IsNew

* [AssetUserBaseInfo](https://cloud.tencent.com/document/api/296/19867#AssetUserBaseInfo)

	* 新增成员：MachineExtraInfo

	* <font color="#dd0000">**修改成员**：</font>MachineIp, MachineWanIp, MachineName, OsInfo, Uuid, Quuid, Uid, Gid, Status, IsRoot, LoginType, LastLoginTime, Name, ProjectId, UserType, IsDomain, IsSudo, IsSshLogin, HomePath, Shell, ShellLoginStatus, PasswordChangeTime, PasswordDueTime, PasswordLockDays, PasswordStatus, UpdateTime, FirstTime, IsNew

* [AssetWebAppBaseInfo](https://cloud.tencent.com/document/api/296/19867#AssetWebAppBaseInfo)

	* 新增成员：MachineExtraInfo

	* <font color="#dd0000">**修改成员**：</font>MachineIp, MachineWanIp, Quuid, Uuid, OsInfo, ProjectId, Tag, Name, Version, RootPath, ServiceType, Domain, VirtualPath, PluginCount, Id, Desc, MachineName, UpdateTime, FirstTime, IsNew

* [AssetWebFrameBaseInfo](https://cloud.tencent.com/document/api/296/19867#AssetWebFrameBaseInfo)

	* 新增成员：MachineExtraInfo

	* <font color="#dd0000">**修改成员**：</font>MachineIp, MachineWanIp, Quuid, Uuid, OsInfo, ProjectId, Tag, Name, Version, Lang, ServiceType, MachineName, UpdateTime, FirstTime, IsNew

* [AssetWebLocationBaseInfo](https://cloud.tencent.com/document/api/296/19867#AssetWebLocationBaseInfo)

	* 新增成员：MachineExtraInfo

	* <font color="#dd0000">**修改成员**：</font>Uuid, Quuid, MachineIp, MachineWanIp, MachineName, OsInfo, Name, Port, Proto, ServiceType, PathCount, User, MainPath, MainPathOwner, Permission, ProjectId, Tag, Id, UpdateTime, FirstTime, IsNew

* [AssetWebServiceBaseInfo](https://cloud.tencent.com/document/api/296/19867#AssetWebServiceBaseInfo)

	* 新增成员：MachineExtraInfo

	* <font color="#dd0000">**修改成员**：</font>MachineIp, MachineWanIp, Quuid, Uuid, OsInfo, ProjectId, Tag, Name, Version, BinPath, User, InstallPath, ConfigPath, ProcessCount, Id, MachineName, Desc, UpdateTime, FirstTime, IsNew

* [BaselineHostDetect](https://cloud.tencent.com/document/api/296/19867#BaselineHostDetect)

	* 新增成员：MachineExtraInfo

	* <font color="#dd0000">**修改成员**：</font>HostId, HostIp, HostName, WanIp, DetectStatus, PassedItemCount, ItemCount, NotPassedItemCount, FirstTime, LastTime, Uuid

* [BaselineItem](https://cloud.tencent.com/document/api/296/19867#BaselineItem)

	* 新增成员：MachineExtraInfo

	* <font color="#dd0000">**修改成员**：</font>ItemId, ItemName, CategoryId, ItemDesc, FixMethod, RuleName, DetectResultDesc, Level, DetectStatus, HostId, HostName, HostIp, WanIp, FirstTime, LastTime, CanBeFixed, Uuid

* [BruteAttackInfo](https://cloud.tencent.com/document/api/296/19867#BruteAttackInfo)

	* 新增成员：MachineExtraInfo

	* <font color="#dd0000">**修改成员**：</font>Id, Uuid, MachineIp, MachineName, UserName, SrcIp, Status, Country, City, Province, CreateTime, BanStatus, EventType, Count, Quuid, IsProVersion, Protocol, Port, ModifyTime, InstanceId, DataStatus

* [DefendAttackLog](https://cloud.tencent.com/document/api/296/19867#DefendAttackLog)

	* 新增成员：MachineExtraInfo

	* <font color="#dd0000">**修改成员**：</font>Id, Uuid, SrcIp, SrcPort, HttpMethod, HttpCgi, HttpParam, VulType, CreatedAt, MachineIp, MachineName, DstIp, DstPort, HttpContent

* [EffectiveMachineInfo](https://cloud.tencent.com/document/api/296/19867#EffectiveMachineInfo)

	* 新增成员：CloudTags, InstanceID

	* <font color="#dd0000">**修改成员**：</font>MachineName, MachinePublicIp, MachinePrivateIp, MachineTag, Quuid, Uuid, KernelVersion, MachineStatus, LicenseOrder, VulNum

* [HostLoginList](https://cloud.tencent.com/document/api/296/19867#HostLoginList)

	* 新增成员：MachineExtraInfo

	* <font color="#dd0000">**修改成员**：</font>Id, Uuid, MachineIp, MachineName, UserName, SrcIp, Status, Country, City, Province, LoginTime, ModifyTime, IsRiskArea, IsRiskUser, IsRiskTime, IsRiskSrcIp, RiskLevel, Location, Quuid, Desc

* [JavaMemShellInfo](https://cloud.tencent.com/document/api/296/19867#JavaMemShellInfo)

	* 新增成员：MachineExtraInfo

	* <font color="#dd0000">**修改成员**：</font>Id, Alias, HostIp, Type, Description, CreateTime, RecentFoundTime, Status, Quuid

* [LicenseBindDetail](https://cloud.tencent.com/document/api/296/19867#LicenseBindDetail)

	* 新增成员：MachineExtraInfo

	* <font color="#dd0000">**修改成员**：</font>MachineName, MachineWanIp, MachineIp, Quuid, Uuid, Tags, AgentStatus, IsUnBind, IsSwitchBind

* [Machine](https://cloud.tencent.com/document/api/296/19867#Machine)

	* 新增成员：VpcId, MachineExtraInfo, InstanceId

	* <font color="#dd0000">**修改成员**：</font>MachineName, MachineOs, MachineStatus, Uuid, Quuid, VulNum, MachineIp, IsProVersion, MachineWanIp, PayMode, MalwareNum, Tag, BaselineNum, CyberAttackNum, SecurityStatus, InvasionNum, RegionInfo, InstanceState, LicenseStatus, ProjectId, HasAssetScan, MachineType, KernelVersion, ProtectType, CloudTags, IsAddedOnTheFifteen, IpList

* [MalWareList](https://cloud.tencent.com/document/api/296/19867#MalWareList)

	* 新增成员：MachineExtraInfo

	* <font color="#dd0000">**修改成员**：</font>HostIp, Uuid, FilePath, VirusName, Status, Id, Alias, Tags, FileCreateTime, FileModifierTime, CreateTime, LatestScanTime, Level, CheckPlatform, ProcessExists, FileExists, Quuid, MD5

* [MalwareInfo](https://cloud.tencent.com/document/api/296/19867#MalwareInfo)

	* 新增成员：MachineExtraInfo

	* <font color="#dd0000">**修改成员**：</font>VirusName, FileSize, MD5, FilePath, FileCreateTime, FileModifierTime, HarmDescribe, SuggestScheme, ServersName, HostIp, ProcessName, ProcessID, Tags, Breadth, Heat, Id, FileName, CreateTime, LatestScanTime, Reference, MachineWanIp, PsTree, MachineStatus, Status, Level, CheckPlatform, Uuid, ModifyTime, StrFileAccessTime

* [PrivilegeEscalationProcess](https://cloud.tencent.com/document/api/296/19867#PrivilegeEscalationProcess)

	* 新增成员：MachineExtraInfo

	* <font color="#dd0000">**修改成员**：</font>Id, Uuid, Quuid, Hostip, ProcessName, FullPath, CmdLine, UserName, UserGroup, ProcFilePrivilege, ParentProcName, ParentProcUser, ParentProcGroup, ParentProcPath, ProcTree, Status, CreateTime, MachineName

* [ProtectDirRelatedServer](https://cloud.tencent.com/document/api/296/19867#ProtectDirRelatedServer)

	* 新增成员：MachineExtraInfo

	* <font color="#dd0000">**修改成员**：</font>Id, HostName, HostIp, MachineOs, RelateDirNum, ProtectStatus, ProtectSwitch, AutoRestoreSwitchStatus, Quuid, Authorization, Exception, Progress, ExceptionMessage

* [ProtectEventLists](https://cloud.tencent.com/document/api/296/19867#ProtectEventLists)

	* 新增成员：MachineExtraInfo

	* <font color="#dd0000">**修改成员**：</font>HostName, HostIp, EventDir, EventType, EventStatus, CreateTime, RestoreTime, Id, FileType

* [ReverseShell](https://cloud.tencent.com/document/api/296/19867#ReverseShell)

	* 新增成员：MachineExtraInfo

	* <font color="#dd0000">**修改成员**：</font>Id, Uuid, Quuid, Hostip, DstIp, DstPort, ProcessName, FullPath, CmdLine, UserName, UserGroup, ParentProcName, ParentProcUser, ParentProcGroup, ParentProcPath, Status, CreateTime, MachineName, ProcTree, DetectBy

* [ScanTaskDetails](https://cloud.tencent.com/document/api/296/19867#ScanTaskDetails)

	* 新增成员：MachineExtraInfo

	* <font color="#dd0000">**修改成员**：</font>HostIp, HostName, OsName, RiskNum, ScanBeginTime, ScanEndTime, Uuid, Quuid, Status, Description, Id, FailType, MachineWanIp

* [VulEffectHostList](https://cloud.tencent.com/document/api/296/19867#VulEffectHostList)

	* 新增成员：CloudTags, MachineExtraInfo

	* <font color="#dd0000">**修改成员**：</font>EventId, Status, LastTime, Level, Quuid, Uuid, HostIp, AliasName, Tags, Description, HostVersion, IsSupportAutoFix, FixStatusMsg, FirstDiscoveryTime, InstanceState, PublicIpAddresses


### 第 64 次发布

发布时间：2022-12-13 10:22:29

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateLicenseOrder](https://cloud.tencent.com/document/api/296/80402)

	* 新增入参：ModifyConfig

* [DescribeLicenseGeneral](https://cloud.tencent.com/document/api/296/80398)

	* 新增出参：AutoRepurchaseSwitch, AutoRepurchaseRenewSwitch

* [ModifyAutoOpenProVersionConfig](https://cloud.tencent.com/document/api/296/19863)

	* 新增入参：AutoRepurchaseSwitch, AutoRepurchaseRenewSwitch


新增数据结构：

* [OrderModifyObject](https://cloud.tencent.com/document/api/296/19867#OrderModifyObject)

### 第 63 次发布

发布时间：2022-11-17 06:19:07

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeClientException](https://cloud.tencent.com/document/api/296/82997)

新增数据结构：

* [RecordInfo](https://cloud.tencent.com/document/api/296/19867#RecordInfo)

### 第 62 次发布

发布时间：2022-11-09 06:23:04

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [Machine](https://cloud.tencent.com/document/api/296/19867#Machine)

	* 新增成员：IpList


### 第 61 次发布

发布时间：2022-11-04 06:17:24

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateScanMalwareSetting](https://cloud.tencent.com/document/api/296/58241)

	* 新增入参：EnableMemShellScan

* [DescribeMalwareRiskWarning](https://cloud.tencent.com/document/api/296/60929)

	* 新增出参：ProcessList

* [DescribeMalwareTimingScanSetting](https://cloud.tencent.com/document/api/296/58240)

	* 新增出参：EnableMemShellScan

* [ModifyMalwareTimingScanSettings](https://cloud.tencent.com/document/api/296/52509)

	* 新增入参：EnableMemShellScan


### 第 60 次发布

发布时间：2022-10-26 06:25:43

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeMalwareTimingScanSetting](https://cloud.tencent.com/document/api/296/58240)

	* 新增出参：EnableInspiredEngine

* [ModifyMalwareTimingScanSettings](https://cloud.tencent.com/document/api/296/52509)

	* 新增入参：EnableInspiredEngine


### 第 59 次发布

发布时间：2022-10-25 06:25:41

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [HostLoginList](https://cloud.tencent.com/document/api/296/19867#HostLoginList)

	* 新增成员：Desc


### 第 58 次发布

发布时间：2022-10-24 06:23:41

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeBaselinePolicyList](https://cloud.tencent.com/document/api/296/81834)

### 第 57 次发布

发布时间：2022-10-21 06:19:41

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DeleteBaselinePolicy](https://cloud.tencent.com/document/api/296/81788)
* [DeleteScanTask](https://cloud.tencent.com/document/api/296/81789)
* [DescribeBaselineHostDetectList](https://cloud.tencent.com/document/api/296/81787)
* [DescribeJavaMemShellList](https://cloud.tencent.com/document/api/296/81790)
* [ModifyBaselinePolicy](https://cloud.tencent.com/document/api/296/81786)
* [StopBaselineDetect](https://cloud.tencent.com/document/api/296/81785)

新增数据结构：

* [BaselineHostDetect](https://cloud.tencent.com/document/api/296/19867#BaselineHostDetect)
* [BaselinePolicy](https://cloud.tencent.com/document/api/296/19867#BaselinePolicy)
* [JavaMemShellInfo](https://cloud.tencent.com/document/api/296/19867#JavaMemShellInfo)

### 第 56 次发布

发布时间：2022-10-12 06:24:06

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeBaselineItemDetectList](https://cloud.tencent.com/document/api/296/81351)
* [DescribeBaselineItemList](https://cloud.tencent.com/document/api/296/81350)
* [StartBaselineDetect](https://cloud.tencent.com/document/api/296/81349)
* [SyncBaselineDetectSummary](https://cloud.tencent.com/document/api/296/81348)

新增数据结构：

* [BaselineDetectParam](https://cloud.tencent.com/document/api/296/19867#BaselineDetectParam)
* [BaselineItem](https://cloud.tencent.com/document/api/296/19867#BaselineItem)
* [BaselineItemDetect](https://cloud.tencent.com/document/api/296/19867#BaselineItemDetect)

### 第 55 次发布

发布时间：2022-10-10 06:18:10

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeAssetHostTotalCount](https://cloud.tencent.com/document/api/296/81238)

### 第 54 次发布

发布时间：2022-09-28 06:22:44

本次发布包含了以下内容：

改善已有的文档。

<font color="#dd0000">**删除接口**：</font>

* DescribeESHits

### 第 53 次发布

发布时间：2022-09-12 06:18:20

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateLicenseOrder](https://cloud.tencent.com/document/api/296/80402)
* [DeleteLicenseRecord](https://cloud.tencent.com/document/api/296/80401)
* [DescribeLicenseBindList](https://cloud.tencent.com/document/api/296/80400)
* [DescribeLicenseBindSchedule](https://cloud.tencent.com/document/api/296/80399)
* [DescribeLicenseGeneral](https://cloud.tencent.com/document/api/296/80398)
* [DescribeLicenseList](https://cloud.tencent.com/document/api/296/80397)
* [DestroyOrder](https://cloud.tencent.com/document/api/296/80396)
* [ExportLicenseDetail](https://cloud.tencent.com/document/api/296/80395)
* [ModifyLicenseBinds](https://cloud.tencent.com/document/api/296/80394)
* [ModifyLicenseUnBinds](https://cloud.tencent.com/document/api/296/80393)
* [ModifyOrderAttribute](https://cloud.tencent.com/document/api/296/80392)

新增数据结构：

* [LicenseBindDetail](https://cloud.tencent.com/document/api/296/19867#LicenseBindDetail)
* [LicenseBindTaskDetail](https://cloud.tencent.com/document/api/296/19867#LicenseBindTaskDetail)
* [LicenseDetail](https://cloud.tencent.com/document/api/296/19867#LicenseDetail)
* [LicenseUnBindRsp](https://cloud.tencent.com/document/api/296/19867#LicenseUnBindRsp)

### 第 52 次发布

发布时间：2022-09-09 06:18:24

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeAssetDatabaseList](https://cloud.tencent.com/document/api/296/61942)

	* 新增入参：Order, By

* [DescribeAssetEnvList](https://cloud.tencent.com/document/api/296/61948)

	* 新增入参：Order, By

* [DescribeAssetInfo](https://cloud.tencent.com/document/api/296/57282)

	* 新增出参：AccountNewCount, PortNewCount, ProcessNewCount, SoftwareNewCount, DatabaseNewCount, WebAppNewCount, WebFrameNewCount, WebServiceNewCount, WebLocationNewCount, MachineNewCount

* [DescribeAssetInitServiceList](https://cloud.tencent.com/document/api/296/61941)

	* 新增入参：Order, By

* [DescribeAssetJarList](https://cloud.tencent.com/document/api/296/61939)

	* 新增入参：Order, By

* [DescribeAssetPlanTaskList](https://cloud.tencent.com/document/api/296/61936)

	* 新增入参：Order, By


修改数据结构：

* [AssetAppBaseInfo](https://cloud.tencent.com/document/api/296/19867#AssetAppBaseInfo)

	* 新增成员：MachineName, FirstTime, IsNew

* [AssetCoreModuleBaseInfo](https://cloud.tencent.com/document/api/296/19867#AssetCoreModuleBaseInfo)

	* 新增成员：FirstTime, IsNew, MachineWanIp

* [AssetDatabaseBaseInfo](https://cloud.tencent.com/document/api/296/19867#AssetDatabaseBaseInfo)

	* 新增成员：FirstTime, IsNew, MachineName

* [AssetEnvBaseInfo](https://cloud.tencent.com/document/api/296/19867#AssetEnvBaseInfo)

	* 新增成员：FirstTime, IsNew, MachineWanIp

* [AssetInitServiceBaseInfo](https://cloud.tencent.com/document/api/296/19867#AssetInitServiceBaseInfo)

	* 新增成员：FirstTime, IsNew, MachineWanIp

* [AssetJarBaseInfo](https://cloud.tencent.com/document/api/296/19867#AssetJarBaseInfo)

	* 新增成员：FirstTime, IsNew, MachineWanIp

* [AssetKeyVal](https://cloud.tencent.com/document/api/296/19867#AssetKeyVal)

	* 新增成员：NewCount

* [AssetMachineBaseInfo](https://cloud.tencent.com/document/api/296/19867#AssetMachineBaseInfo)

	* 新增成员：IsNew, FirstTime

* [AssetPlanTask](https://cloud.tencent.com/document/api/296/19867#AssetPlanTask)

	* 新增成员：FirstTime, IsNew, MachineWanIp

* [AssetPortBaseInfo](https://cloud.tencent.com/document/api/296/19867#AssetPortBaseInfo)

	* 新增成员：FirstTime, IsNew

* [AssetProcessBaseInfo](https://cloud.tencent.com/document/api/296/19867#AssetProcessBaseInfo)

	* 新增成员：FirstTime, IsNew

* [AssetSystemPackageInfo](https://cloud.tencent.com/document/api/296/19867#AssetSystemPackageInfo)

	* 新增成员：FirstTime, IsNew

* [AssetUserBaseInfo](https://cloud.tencent.com/document/api/296/19867#AssetUserBaseInfo)

	* 新增成员：FirstTime, IsNew

* [AssetWebAppBaseInfo](https://cloud.tencent.com/document/api/296/19867#AssetWebAppBaseInfo)

	* 新增成员：FirstTime, IsNew

* [AssetWebFrameBaseInfo](https://cloud.tencent.com/document/api/296/19867#AssetWebFrameBaseInfo)

	* 新增成员：FirstTime, IsNew

* [AssetWebLocationBaseInfo](https://cloud.tencent.com/document/api/296/19867#AssetWebLocationBaseInfo)

	* 新增成员：FirstTime, IsNew

* [AssetWebServiceBaseInfo](https://cloud.tencent.com/document/api/296/19867#AssetWebServiceBaseInfo)

	* 新增成员：FirstTime, IsNew


### 第 51 次发布

发布时间：2022-09-07 06:21:27

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeGeneralStat](https://cloud.tencent.com/document/api/296/53132)

	* 新增出参：AddedOnTheFifteen


修改数据结构：

* [Machine](https://cloud.tencent.com/document/api/296/19867#Machine)

	* 新增成员：IsAddedOnTheFifteen

* [MalWareList](https://cloud.tencent.com/document/api/296/19867#MalWareList)

	* 新增成员：Quuid, MD5


### 第 50 次发布

发布时间：2022-08-19 06:16:28

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeVulHostCountScanTime](https://cloud.tencent.com/document/api/296/60899)

	* 新增出参：LastFixTime, hadAutoFixVul

* [DescribeVulInfoCvss](https://cloud.tencent.com/document/api/296/60898)

	* 新增出参：SuccessFixCount, FixSwitch


新增数据结构：

* [Tags](https://cloud.tencent.com/document/api/296/19867#Tags)

修改数据结构：

* [Machine](https://cloud.tencent.com/document/api/296/19867#Machine)

	* 新增成员：CloudTags


### 第 49 次发布

发布时间：2022-07-15 06:07:13

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [MalwareInfo](https://cloud.tencent.com/document/api/296/19867#MalwareInfo)

	* 新增成员：ModifyTime, StrFileAccessTime


### 第 48 次发布

发布时间：2022-07-06 06:10:33

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [EffectiveMachineInfo](https://cloud.tencent.com/document/api/296/19867#EffectiveMachineInfo)

	* 新增成员：VulNum


### 第 47 次发布

发布时间：2022-07-01 06:09:29

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeScanTaskDetails](https://cloud.tencent.com/document/api/296/58238)

	* 新增出参：VulCount

* [DescribeVulHostTop](https://cloud.tencent.com/document/api/296/61709)

	* 新增入参：IsFollowVul

* [DescribeVulInfoCvss](https://cloud.tencent.com/document/api/296/60898)

	* 新增出参：DefenseAttackCount

* [DescribeVulLevelCount](https://cloud.tencent.com/document/api/296/60897)

	* 新增入参：IsFollowVul

* [DescribeVulTop](https://cloud.tencent.com/document/api/296/60896)

	* 新增入参：IsFollowVul


修改数据结构：

* [EmergencyVul](https://cloud.tencent.com/document/api/296/19867#EmergencyVul)

	* 新增成员：IsSupportDefense, DefenseAttackCount

* [ScanTaskDetails](https://cloud.tencent.com/document/api/296/19867#ScanTaskDetails)

	* 新增成员：MachineWanIp

* [VulEffectHostList](https://cloud.tencent.com/document/api/296/19867#VulEffectHostList)

	* 新增成员：PublicIpAddresses

* [VulInfoList](https://cloud.tencent.com/document/api/296/19867#VulInfoList)

	* 新增成员：IsSupportDefense, DefenseAttackCount, FirstAppearTime, VulCategory


### 第 46 次发布

发布时间：2022-06-29 06:05:43

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [HostLoginList](https://cloud.tencent.com/document/api/296/19867#HostLoginList)

	* 新增成员：Quuid


### 第 45 次发布

发布时间：2022-06-23 06:10:09

本次发布包含了以下内容：

改善已有的文档。

新增数据结构：

* [LicenseOrder](https://cloud.tencent.com/document/api/296/19867#LicenseOrder)

修改数据结构：

* [EffectiveMachineInfo](https://cloud.tencent.com/document/api/296/19867#EffectiveMachineInfo)

	* 新增成员：LicenseOrder


### 第 44 次发布

发布时间：2022-06-20 06:06:12

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [VulEffectHostList](https://cloud.tencent.com/document/api/296/19867#VulEffectHostList)

	* 新增成员：FirstDiscoveryTime, InstanceState


### 第 43 次发布

发布时间：2022-06-10 06:05:46

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeBashEvents](https://cloud.tencent.com/document/api/296/39594)

	* 新增入参：Order, By

* [DescribeBruteAttackList](https://cloud.tencent.com/document/api/296/56373)

	* 新增入参：Order, By

* [DescribeHostLoginList](https://cloud.tencent.com/document/api/296/60938)

	* 新增入参：Order, By

* [DescribePrivilegeEvents](https://cloud.tencent.com/document/api/296/39591)

	* 新增入参：Order, By

* [DescribeReverseShellEvents](https://cloud.tencent.com/document/api/296/39589)

	* 新增入参：Order, By


### 第 42 次发布

发布时间：2022-05-31 06:08:47

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [MalWareList](https://cloud.tencent.com/document/api/296/19867#MalWareList)

	* 新增成员：CheckPlatform, ProcessExists, FileExists


### 第 41 次发布

发布时间：2022-05-17 06:07:58

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeHistoryService](https://cloud.tencent.com/document/api/296/55727)

	* 新增出参：StartTime


### 第 40 次发布

发布时间：2022-04-27 06:08:17

本次发布包含了以下内容：

改善已有的文档。

<font color="#dd0000">**删除接口**：</font>

* CloseProVersion
* InquiryPriceOpenProVersionPrepaid
* ModifyProVersionRenewFlag
* OpenProVersion
* OpenProVersionPrepaid
* RenewProVersion

<font color="#dd0000">**删除数据结构**：</font>

* ChargePrepaid
* ProVersionMachine

### 第 39 次发布

发布时间：2022-04-04 06:27:42

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [BruteAttackInfo](https://cloud.tencent.com/document/api/296/19867#BruteAttackInfo)

	* 新增成员：DataStatus


### 第 38 次发布

发布时间：2022-03-24 20:38:18

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeSecurityEventStat](https://cloud.tencent.com/document/api/296/71661)

新增数据结构：

* [EventStat](https://cloud.tencent.com/document/api/296/19867#EventStat)

### 第 37 次发布

发布时间：2022-01-10 08:08:49

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeGeneralStat](https://cloud.tencent.com/document/api/296/53132)

	* 新增出参：FlagshipMachineCnt, ProtectDays

* [DescribeImportMachineInfo](https://cloud.tencent.com/document/api/296/55203)

	* 新增入参：Filters

* [DescribeMachineInfo](https://cloud.tencent.com/document/api/296/19851)

	* 新增出参：ProtectType


修改数据结构：

* [Machine](https://cloud.tencent.com/document/api/296/19867#Machine)

	* 新增成员：ProtectType

* [MalwareInfo](https://cloud.tencent.com/document/api/296/19867#MalwareInfo)

	* 新增成员：CheckPlatform, Uuid


### 第 36 次发布

发布时间：2021-12-10 08:04:29

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateScanMalwareSetting](https://cloud.tencent.com/document/api/296/58241)

	* 新增入参：EngineType

* [DescribeMalwareTimingScanSetting](https://cloud.tencent.com/document/api/296/58240)

	* 新增出参：EngineType

* [ModifyMalwareTimingScanSettings](https://cloud.tencent.com/document/api/296/52509)

	* 新增入参：EngineType


修改数据结构：

* [MalWareList](https://cloud.tencent.com/document/api/296/19867#MalWareList)

	* 新增成员：Level

* [MalwareInfo](https://cloud.tencent.com/document/api/296/19867#MalwareInfo)

	* 新增成员：Level


### 第 35 次发布

发布时间：2021-11-18 08:05:46

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeScanState](https://cloud.tencent.com/document/api/296/60923)

	* 新增出参：ScanBeginTime, RiskEventCount, ScanEndTime

* [DescribeSecurityEventsCnt](https://cloud.tencent.com/document/api/296/50427)

	* 新增出参：WindowVul, LinuxVul

* [DescribeVulInfoCvss](https://cloud.tencent.com/document/api/296/60898)

	* 新增出参：Labels

* [DescribeVulLevelCount](https://cloud.tencent.com/document/api/296/60897)

	* 新增入参：VulCategory

* [DescribeVulList](https://cloud.tencent.com/document/api/296/63340)

	* 新增入参：By, Order

* [ScanVul](https://cloud.tencent.com/document/api/296/57375)

	* <font color="#dd0000">**修改入参**：</font>VulCategories


修改数据结构：

* [EmergencyVul](https://cloud.tencent.com/document/api/296/19867#EmergencyVul)

	* 新增成员：CveId, CvssScore, Labels, HostCount

* [VulEffectHostList](https://cloud.tencent.com/document/api/296/19867#VulEffectHostList)

	* 新增成员：HostVersion, IsSupportAutoFix, FixStatusMsg

* [VulInfoList](https://cloud.tencent.com/document/api/296/19867#VulInfoList)

	* 新增成员：CveId, CvssScore, Labels, FixSwitch, TaskId


### 第 34 次发布

发布时间：2021-11-02 08:05:13

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeVersionStatistics](https://cloud.tencent.com/document/api/296/60922)

	* 新增出参：UltimateVersionNum


修改数据结构：

* [EffectiveMachineInfo](https://cloud.tencent.com/document/api/296/19867#EffectiveMachineInfo)

	* 新增成员：KernelVersion, MachineStatus

* [Machine](https://cloud.tencent.com/document/api/296/19867#Machine)

	* 新增成员：KernelVersion


### 第 33 次发布

发布时间：2021-10-27 08:05:40

本次发布包含了以下内容：

改善已有的文档。

<font color="#dd0000">**删除接口**：</font>

* RescanImpactedHost

### 第 32 次发布

发布时间：2021-10-26 08:07:04

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeVulEffectHostList](https://cloud.tencent.com/document/api/296/63341)
* [DescribeVulList](https://cloud.tencent.com/document/api/296/63340)

新增数据结构：

* [VulEffectHostList](https://cloud.tencent.com/document/api/296/19867#VulEffectHostList)
* [VulInfoList](https://cloud.tencent.com/document/api/296/19867#VulInfoList)

### 第 31 次发布

发布时间：2021-10-21 11:24:07

本次发布包含了以下内容：

改善已有的文档。

<font color="#dd0000">**删除接口**：</font>

* DescribeAccounts

<font color="#dd0000">**删除数据结构**：</font>

* Account

### 第 30 次发布

发布时间：2021-09-30 08:03:28

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [EditBashRules](https://cloud.tencent.com/document/api/296/58239)

	* <font color="#dd0000">**修改入参**：</font>Name, Rule


修改数据结构：

* [MalwareInfo](https://cloud.tencent.com/document/api/296/19867#MalwareInfo)

	* 新增成员：MachineWanIp, PsTree, MachineStatus, Status

* [RiskDnsList](https://cloud.tencent.com/document/api/296/19867#RiskDnsList)

	* 新增成员：MachineWanIp, MachineStatus


### 第 29 次发布

发布时间：2021-09-28 08:03:47

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeMalwareTimingScanSetting](https://cloud.tencent.com/document/api/296/58240)

	* 新增出参：KillProcess

* [ModifyMalwareTimingScanSettings](https://cloud.tencent.com/document/api/296/52509)

	* 新增入参：KillProcess

* [SeparateMalwares](https://cloud.tencent.com/document/api/296/30320)

	* 新增入参：KillProcess


### 第 28 次发布

发布时间：2021-09-27 08:09:25

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeAssetAppList](https://cloud.tencent.com/document/api/296/61947)
* [DescribeAssetAppProcessList](https://cloud.tencent.com/document/api/296/61946)
* [DescribeAssetCoreModuleInfo](https://cloud.tencent.com/document/api/296/61945)
* [DescribeAssetCoreModuleList](https://cloud.tencent.com/document/api/296/61944)
* [DescribeAssetDatabaseInfo](https://cloud.tencent.com/document/api/296/61943)
* [DescribeAssetDatabaseList](https://cloud.tencent.com/document/api/296/61942)
* [DescribeAssetEnvList](https://cloud.tencent.com/document/api/296/61948)
* [DescribeAssetInitServiceList](https://cloud.tencent.com/document/api/296/61941)
* [DescribeAssetJarInfo](https://cloud.tencent.com/document/api/296/61940)
* [DescribeAssetJarList](https://cloud.tencent.com/document/api/296/61939)
* [DescribeAssetMachineDetail](https://cloud.tencent.com/document/api/296/61938)
* [DescribeAssetMachineList](https://cloud.tencent.com/document/api/296/61937)
* [DescribeAssetPlanTaskList](https://cloud.tencent.com/document/api/296/61936)
* [DescribeAssetPortInfoList](https://cloud.tencent.com/document/api/296/61935)
* [DescribeAssetProcessInfoList](https://cloud.tencent.com/document/api/296/61934)
* [DescribeAssetSystemPackageList](https://cloud.tencent.com/document/api/296/61933)
* [DescribeAssetUserInfo](https://cloud.tencent.com/document/api/296/61932)
* [DescribeAssetUserList](https://cloud.tencent.com/document/api/296/61931)
* [DescribeAssetWebAppList](https://cloud.tencent.com/document/api/296/61930)
* [DescribeAssetWebAppPluginList](https://cloud.tencent.com/document/api/296/61929)
* [DescribeAssetWebFrameList](https://cloud.tencent.com/document/api/296/61928)
* [DescribeAssetWebLocationInfo](https://cloud.tencent.com/document/api/296/61927)
* [DescribeAssetWebLocationList](https://cloud.tencent.com/document/api/296/61926)
* [DescribeAssetWebServiceInfoList](https://cloud.tencent.com/document/api/296/61925)
* [DescribeAssetWebServiceProcessList](https://cloud.tencent.com/document/api/296/61924)

修改接口：

* [DescribeVersionStatistics](https://cloud.tencent.com/document/api/296/60922)

	* 新增出参：BasicVersionNum, ProVersionNum


新增数据结构：

* [AssetAppBaseInfo](https://cloud.tencent.com/document/api/296/19867#AssetAppBaseInfo)
* [AssetAppProcessInfo](https://cloud.tencent.com/document/api/296/19867#AssetAppProcessInfo)
* [AssetCoreModuleBaseInfo](https://cloud.tencent.com/document/api/296/19867#AssetCoreModuleBaseInfo)
* [AssetCoreModuleDetail](https://cloud.tencent.com/document/api/296/19867#AssetCoreModuleDetail)
* [AssetCoreModuleParam](https://cloud.tencent.com/document/api/296/19867#AssetCoreModuleParam)
* [AssetDatabaseBaseInfo](https://cloud.tencent.com/document/api/296/19867#AssetDatabaseBaseInfo)
* [AssetDatabaseDetail](https://cloud.tencent.com/document/api/296/19867#AssetDatabaseDetail)
* [AssetDiskPartitionInfo](https://cloud.tencent.com/document/api/296/19867#AssetDiskPartitionInfo)
* [AssetEnvBaseInfo](https://cloud.tencent.com/document/api/296/19867#AssetEnvBaseInfo)
* [AssetInitServiceBaseInfo](https://cloud.tencent.com/document/api/296/19867#AssetInitServiceBaseInfo)
* [AssetJarBaseInfo](https://cloud.tencent.com/document/api/296/19867#AssetJarBaseInfo)
* [AssetJarDetail](https://cloud.tencent.com/document/api/296/19867#AssetJarDetail)
* [AssetMachineBaseInfo](https://cloud.tencent.com/document/api/296/19867#AssetMachineBaseInfo)
* [AssetMachineDetail](https://cloud.tencent.com/document/api/296/19867#AssetMachineDetail)
* [AssetNetworkCardInfo](https://cloud.tencent.com/document/api/296/19867#AssetNetworkCardInfo)
* [AssetPlanTask](https://cloud.tencent.com/document/api/296/19867#AssetPlanTask)
* [AssetPortBaseInfo](https://cloud.tencent.com/document/api/296/19867#AssetPortBaseInfo)
* [AssetProcessBaseInfo](https://cloud.tencent.com/document/api/296/19867#AssetProcessBaseInfo)
* [AssetSystemPackageInfo](https://cloud.tencent.com/document/api/296/19867#AssetSystemPackageInfo)
* [AssetUserBaseInfo](https://cloud.tencent.com/document/api/296/19867#AssetUserBaseInfo)
* [AssetUserDetail](https://cloud.tencent.com/document/api/296/19867#AssetUserDetail)
* [AssetUserKeyInfo](https://cloud.tencent.com/document/api/296/19867#AssetUserKeyInfo)
* [AssetWebAppBaseInfo](https://cloud.tencent.com/document/api/296/19867#AssetWebAppBaseInfo)
* [AssetWebAppPluginInfo](https://cloud.tencent.com/document/api/296/19867#AssetWebAppPluginInfo)
* [AssetWebFrameBaseInfo](https://cloud.tencent.com/document/api/296/19867#AssetWebFrameBaseInfo)
* [AssetWebLocationBaseInfo](https://cloud.tencent.com/document/api/296/19867#AssetWebLocationBaseInfo)
* [AssetWebLocationInfo](https://cloud.tencent.com/document/api/296/19867#AssetWebLocationInfo)
* [AssetWebServiceBaseInfo](https://cloud.tencent.com/document/api/296/19867#AssetWebServiceBaseInfo)

### 第 27 次发布

发布时间：2021-09-22 08:06:00

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeAvailableExpertServiceDetail](https://cloud.tencent.com/document/api/296/61727)
* [DescribeBanWhiteList](https://cloud.tencent.com/document/api/296/61722)
* [DescribeBaselineAnalysisData](https://cloud.tencent.com/document/api/296/61717)
* [DescribeBaselineEffectHostList](https://cloud.tencent.com/document/api/296/61716)
* [DescribeBaselineHostTop](https://cloud.tencent.com/document/api/296/61715)
* [DescribeBaselineList](https://cloud.tencent.com/document/api/296/61714)
* [DescribeBaselineStrategyDetail](https://cloud.tencent.com/document/api/296/61713)
* [DescribeBaselineStrategyList](https://cloud.tencent.com/document/api/296/61712)
* [DescribeBaselineTop](https://cloud.tencent.com/document/api/296/61711)
* [DescribeBruteAttackRules](https://cloud.tencent.com/document/api/296/61721)
* [DescribeEmergencyResponseList](https://cloud.tencent.com/document/api/296/61726)
* [DescribeExpertServiceList](https://cloud.tencent.com/document/api/296/61725)
* [DescribeExpertServiceOrderList](https://cloud.tencent.com/document/api/296/61724)
* [DescribeIgnoreRuleEffectHostList](https://cloud.tencent.com/document/api/296/61710)
* [DescribeMaliciousRequestWhiteList](https://cloud.tencent.com/document/api/296/61720)
* [DescribeProtectNetList](https://cloud.tencent.com/document/api/296/61723)
* [DescribeScanTaskStatus](https://cloud.tencent.com/document/api/296/61719)
* [DescribeVulHostTop](https://cloud.tencent.com/document/api/296/61709)
* [ExportSecurityTrends](https://cloud.tencent.com/document/api/296/61718)

新增数据结构：

* [BanWhiteListDetail](https://cloud.tencent.com/document/api/296/19867#BanWhiteListDetail)
* [BaselineEffectHost](https://cloud.tencent.com/document/api/296/19867#BaselineEffectHost)
* [BaselineEventLevelInfo](https://cloud.tencent.com/document/api/296/19867#BaselineEventLevelInfo)
* [BaselineHostTopList](https://cloud.tencent.com/document/api/296/19867#BaselineHostTopList)
* [BaselineInfo](https://cloud.tencent.com/document/api/296/19867#BaselineInfo)
* [BaselineRuleTopInfo](https://cloud.tencent.com/document/api/296/19867#BaselineRuleTopInfo)
* [BruteAttackRuleList](https://cloud.tencent.com/document/api/296/19867#BruteAttackRuleList)
* [EmergencyResponseInfo](https://cloud.tencent.com/document/api/296/19867#EmergencyResponseInfo)
* [ExpertServiceOrderInfo](https://cloud.tencent.com/document/api/296/19867#ExpertServiceOrderInfo)
* [IgnoreRuleEffectHostInfo](https://cloud.tencent.com/document/api/296/19867#IgnoreRuleEffectHostInfo)
* [MaliciousRequestWhiteListInfo](https://cloud.tencent.com/document/api/296/19867#MaliciousRequestWhiteListInfo)
* [ProtectNetInfo](https://cloud.tencent.com/document/api/296/19867#ProtectNetInfo)
* [SecurityButlerInfo](https://cloud.tencent.com/document/api/296/19867#SecurityButlerInfo)
* [Strategy](https://cloud.tencent.com/document/api/296/19867#Strategy)
* [TaskStatus](https://cloud.tencent.com/document/api/296/19867#TaskStatus)
* [VulHostTopInfo](https://cloud.tencent.com/document/api/296/19867#VulHostTopInfo)
* [VulLevelCountInfo](https://cloud.tencent.com/document/api/296/19867#VulLevelCountInfo)

### 第 26 次发布

发布时间：2021-08-31 08:12:20

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CancelIgnoreVul](https://cloud.tencent.com/document/api/296/60905)
* [ChangeRuleEventsIgnoreStatus](https://cloud.tencent.com/document/api/296/60921)
* [CheckBashRuleParams](https://cloud.tencent.com/document/api/296/60925)
* [CreateEmergencyVulScan](https://cloud.tencent.com/document/api/296/60904)
* [DeleteBaselineStrategy](https://cloud.tencent.com/document/api/296/60920)
* [DeleteMalwareScanTask](https://cloud.tencent.com/document/api/296/60932)
* [DeleteProtectDir](https://cloud.tencent.com/document/api/296/60889)
* [DescribeBanMode](https://cloud.tencent.com/document/api/296/60946)
* [DescribeBanRegions](https://cloud.tencent.com/document/api/296/60945)
* [DescribeBanStatus](https://cloud.tencent.com/document/api/296/60944)
* [DescribeBaselineBasicInfo](https://cloud.tencent.com/document/api/296/60919)
* [DescribeBaselineDetail](https://cloud.tencent.com/document/api/296/60918)
* [DescribeBaselineRule](https://cloud.tencent.com/document/api/296/60917)
* [DescribeBaselineScanSchedule](https://cloud.tencent.com/document/api/296/60916)
* [DescribeEmergencyVulList](https://cloud.tencent.com/document/api/296/60903)
* [DescribeHostLoginList](https://cloud.tencent.com/document/api/296/60938)
* [DescribeIgnoreBaselineRule](https://cloud.tencent.com/document/api/296/60915)
* [DescribeLoginWhiteCombinedList](https://cloud.tencent.com/document/api/296/60937)
* [DescribeMalWareList](https://cloud.tencent.com/document/api/296/60931)
* [DescribeMalwareFile](https://cloud.tencent.com/document/api/296/60930)
* [DescribeMalwareRiskWarning](https://cloud.tencent.com/document/api/296/60929)
* [DescribeMonthInspectionReport](https://cloud.tencent.com/document/api/296/60950)
* [DescribeProVersionStatus](https://cloud.tencent.com/document/api/296/60924)
* [DescribeProtectDirList](https://cloud.tencent.com/document/api/296/60888)
* [DescribeProtectDirRelatedServer](https://cloud.tencent.com/document/api/296/60887)
* [DescribeSaveOrUpdateWarnings](https://cloud.tencent.com/document/api/296/60893)
* [DescribeScanSchedule](https://cloud.tencent.com/document/api/296/60902)
* [DescribeScanState](https://cloud.tencent.com/document/api/296/60923)
* [DescribeServerRelatedDirInfo](https://cloud.tencent.com/document/api/296/60886)
* [DescribeServersAndRiskAndFirstInfo](https://cloud.tencent.com/document/api/296/60928)
* [DescribeStrategyExist](https://cloud.tencent.com/document/api/296/60914)
* [DescribeUndoVulCounts](https://cloud.tencent.com/document/api/296/60901)
* [DescribeVersionStatistics](https://cloud.tencent.com/document/api/296/60922)
* [DescribeVulCountByDates](https://cloud.tencent.com/document/api/296/60900)
* [DescribeVulHostCountScanTime](https://cloud.tencent.com/document/api/296/60899)
* [DescribeVulInfoCvss](https://cloud.tencent.com/document/api/296/60898)
* [DescribeVulLevelCount](https://cloud.tencent.com/document/api/296/60897)
* [DescribeVulTop](https://cloud.tencent.com/document/api/296/60896)
* [DescribeWarningList](https://cloud.tencent.com/document/api/296/60892)
* [DescribeWebPageEventList](https://cloud.tencent.com/document/api/296/60885)
* [DescribeWebPageProtectStat](https://cloud.tencent.com/document/api/296/60884)
* [DescribeWebPageServiceInfo](https://cloud.tencent.com/document/api/296/60883)
* [ExportAssetWebServiceInfoList](https://cloud.tencent.com/document/api/296/60891)
* [ExportBaselineEffectHostList](https://cloud.tencent.com/document/api/296/60913)
* [ExportBaselineList](https://cloud.tencent.com/document/api/296/60912)
* [ExportIgnoreBaselineRule](https://cloud.tencent.com/document/api/296/60911)
* [ExportIgnoreRuleEffectHostList](https://cloud.tencent.com/document/api/296/60910)
* [ExportProtectDirList](https://cloud.tencent.com/document/api/296/60882)
* [ExportVulEffectHostList](https://cloud.tencent.com/document/api/296/60895)
* [ExportVulList](https://cloud.tencent.com/document/api/296/60894)
* [ExportWebPageEventList](https://cloud.tencent.com/document/api/296/60881)
* [ModifyBanMode](https://cloud.tencent.com/document/api/296/60943)
* [ModifyBanStatus](https://cloud.tencent.com/document/api/296/60942)
* [ModifyBruteAttackRules](https://cloud.tencent.com/document/api/296/60941)
* [ModifyWebPageProtectDir](https://cloud.tencent.com/document/api/296/60880)
* [ModifyWebPageProtectSwitch](https://cloud.tencent.com/document/api/296/60879)
* [StopNoticeBanTips](https://cloud.tencent.com/document/api/296/60940)
* [UpdateMachineTags](https://cloud.tencent.com/document/api/296/60890)

修改接口：

* [DescribeGeneralStat](https://cloud.tencent.com/document/api/296/53132)

	* 新增出参：Shutdown, Offline

* [DescribeMachineRegions](https://cloud.tencent.com/document/api/296/55137)

	* 新增出参：ALL

* [ExportMaliciousRequests](https://cloud.tencent.com/document/api/296/31287)

	* 新增出参：TaskId

* [ExportMalwares](https://cloud.tencent.com/document/api/296/39582)

	* 新增入参：By, Order

* [SyncAssetScan](https://cloud.tencent.com/document/api/296/57280)

	* 新增出参：State, LatestStartTime, LatestEndTime, TaskId


新增数据结构：

* [BaselineBasicInfo](https://cloud.tencent.com/document/api/296/19867#BaselineBasicInfo)
* [BaselineDetail](https://cloud.tencent.com/document/api/296/19867#BaselineDetail)
* [BaselineRuleInfo](https://cloud.tencent.com/document/api/296/19867#BaselineRuleInfo)
* [BruteAttackRule](https://cloud.tencent.com/document/api/296/19867#BruteAttackRule)
* [EmergencyVul](https://cloud.tencent.com/document/api/296/19867#EmergencyVul)
* [HostLoginList](https://cloud.tencent.com/document/api/296/19867#HostLoginList)
* [IgnoreBaselineRule](https://cloud.tencent.com/document/api/296/19867#IgnoreBaselineRule)
* [LoginWhiteCombinedInfo](https://cloud.tencent.com/document/api/296/19867#LoginWhiteCombinedInfo)
* [MalWareList](https://cloud.tencent.com/document/api/296/19867#MalWareList)
* [MalwareRisk](https://cloud.tencent.com/document/api/296/19867#MalwareRisk)
* [MonthInspectionReport](https://cloud.tencent.com/document/api/296/19867#MonthInspectionReport)
* [ProtectDirInfo](https://cloud.tencent.com/document/api/296/19867#ProtectDirInfo)
* [ProtectDirRelatedServer](https://cloud.tencent.com/document/api/296/19867#ProtectDirRelatedServer)
* [ProtectEventLists](https://cloud.tencent.com/document/api/296/19867#ProtectEventLists)
* [ProtectMachine](https://cloud.tencent.com/document/api/296/19867#ProtectMachine)
* [ProtectMachineInfo](https://cloud.tencent.com/document/api/296/19867#ProtectMachineInfo)
* [ProtectStat](https://cloud.tencent.com/document/api/296/19867#ProtectStat)
* [RegionSet](https://cloud.tencent.com/document/api/296/19867#RegionSet)
* [StandardModeConfig](https://cloud.tencent.com/document/api/296/19867#StandardModeConfig)
* [VulLevelInfo](https://cloud.tencent.com/document/api/296/19867#VulLevelInfo)
* [VulTopInfo](https://cloud.tencent.com/document/api/296/19867#VulTopInfo)
* [WarningInfoObj](https://cloud.tencent.com/document/api/296/19867#WarningInfoObj)
* [ZoneInfo](https://cloud.tencent.com/document/api/296/19867#ZoneInfo)

### 第 25 次发布

发布时间：2021-08-25 08:11:32

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [ExportScanTaskDetails](https://cloud.tencent.com/document/api/296/60691)

### 第 24 次发布

发布时间：2021-08-18 08:11:40

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [ModifyWarningSetting](https://cloud.tencent.com/document/api/296/19864)

新增数据结构：

* [WarningObject](https://cloud.tencent.com/document/api/296/19867#WarningObject)

### 第 23 次发布

发布时间：2021-08-17 08:12:05

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [BruteAttackInfo](https://cloud.tencent.com/document/api/296/19867#BruteAttackInfo)

	* 新增成员：InstanceId

* [Machine](https://cloud.tencent.com/document/api/296/19867#Machine)

	* 新增成员：MachineType

* [MalwareInfo](https://cloud.tencent.com/document/api/296/19867#MalwareInfo)

	* 新增成员：Reference

* [ReverseShell](https://cloud.tencent.com/document/api/296/19867#ReverseShell)

	* 新增成员：DetectBy


### 第 22 次发布

发布时间：2021-07-29 08:12:24

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [Place](https://cloud.tencent.com/document/api/296/19867#Place)

	* 新增成员：Location


### 第 21 次发布

发布时间：2021-07-23 11:15:23

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [ScanAsset](https://cloud.tencent.com/document/api/296/59114)

<font color="#dd0000">**删除接口**：</font>

* AddLoginWhiteList
* AddMachineTag
* CreateOpenPortTask
* CreateProcessTask
* CreateUsualLoginPlaces
* DeleteUsualLoginPlaces
* DescribeAgentVuls
* DescribeAlarmAttribute
* DescribeBruteAttacks
* DescribeComponentInfo
* DescribeComponents
* DescribeImpactedHosts
* DescribeMaliciousRequests
* DescribeMalwares
* DescribeNonlocalLoginPlaces
* DescribeOpenPortTaskStatus
* DescribeOpenPorts
* DescribeProcessTaskStatus
* DescribeProcesses
* DescribeVulInfo
* DescribeVulScanResult
* DescribeVuls
* DescribeWeeklyReportBruteAttacks
* DescribeWeeklyReportInfo
* DescribeWeeklyReportMalwares
* DescribeWeeklyReportNonlocalLoginPlaces
* DescribeWeeklyReportVuls
* DescribeWeeklyReports
* EditBashRule
* EditPrivilegeRule
* EditReverseShellRule
* MisAlarmNonlocalLoginPlaces
* ModifyAlarmAttribute
* ModifyLoginWhiteList
* TrustMaliciousRequest
* UntrustMaliciousRequest

修改接口：

* [DescribeSecurityEventsCnt](https://cloud.tencent.com/document/api/296/50427)

	* 新增出参：EffectMachineCount, EventsCount


<font color="#dd0000">**删除数据结构**：</font>

* AgentVul
* BruteAttack
* Component
* ImpactedHost
* LoginWhiteListsRule
* MaliciousRequest
* Malware
* NonLocalLoginPlace
* OpenPort
* Process
* Vul
* WeeklyReport
* WeeklyReportBruteAttack
* WeeklyReportMalware
* WeeklyReportNonlocalLoginPlace
* WeeklyReportVul

### 第 20 次发布

发布时间：2021-07-07 10:06:12

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateScanMalwareSetting](https://cloud.tencent.com/document/api/296/58241)
* [DescribeMalwareTimingScanSetting](https://cloud.tencent.com/document/api/296/58240)
* [DescribeScanTaskDetails](https://cloud.tencent.com/document/api/296/58238)
* [DescribeScanVulSetting](https://cloud.tencent.com/document/api/296/58237)
* [EditBashRules](https://cloud.tencent.com/document/api/296/58239)
* [ScanVulAgain](https://cloud.tencent.com/document/api/296/58236)
* [ScanVulSetting](https://cloud.tencent.com/document/api/296/58235)

修改接口：

* [DescribeMachineRegions](https://cloud.tencent.com/document/api/296/55137)

	* 新增出参：CVM, BM, LH, ECM, Other

* [ModifyMalwareTimingScanSettings](https://cloud.tencent.com/document/api/296/52509)

	* 新增入参：AutoIsolation

* [ScanVul](https://cloud.tencent.com/document/api/296/57375)

	* 新增入参：TimeoutPeriod, VulIds


新增数据结构：

* [ScanTaskDetails](https://cloud.tencent.com/document/api/296/19867#ScanTaskDetails)
* [VulDetailInfo](https://cloud.tencent.com/document/api/296/19867#VulDetailInfo)

修改数据结构：

* [BashEvent](https://cloud.tencent.com/document/api/296/19867#BashEvent)

	* 新增成员：DetectBy, Pid, Exe, ModifyTime, RuleCategory, RegexBashCmd

* [BashRule](https://cloud.tencent.com/document/api/296/19867#BashRule)

	* 新增成员：Uuids, White, DealOldEvents


### 第 19 次发布

发布时间：2021-06-28 08:11:03

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeRiskDnsList](https://cloud.tencent.com/document/api/296/53644)

	* 新增出参：RiskDnsList, TotalCount


新增数据结构：

* [RiskDnsList](https://cloud.tencent.com/document/api/296/19867#RiskDnsList)

### 第 18 次发布

发布时间：2021-06-16 08:11:12

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateProtectServer](https://cloud.tencent.com/document/api/296/57379)
* [DeleteWebPageEventLog](https://cloud.tencent.com/document/api/296/57378)
* [DescribeWebPageGeneralize](https://cloud.tencent.com/document/api/296/57377)
* [ModifyWebPageProtectSetting](https://cloud.tencent.com/document/api/296/57376)
* [ScanVul](https://cloud.tencent.com/document/api/296/57375)

新增数据结构：

* [ProtectHostConfig](https://cloud.tencent.com/document/api/296/19867#ProtectHostConfig)

### 第 17 次发布

发布时间：2021-06-14 08:10:35

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeAssetInfo](https://cloud.tencent.com/document/api/296/57282)
* [DescribeAssetRecentMachineInfo](https://cloud.tencent.com/document/api/296/57281)
* [SyncAssetScan](https://cloud.tencent.com/document/api/296/57280)

新增数据结构：

* [AssetKeyVal](https://cloud.tencent.com/document/api/296/19867#AssetKeyVal)

### 第 16 次发布

发布时间：2021-06-04 08:10:58

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeImportMachineInfo](https://cloud.tencent.com/document/api/296/55203)

	* 新增入参：IsQueryProMachine


修改数据结构：

* [EffectiveMachineInfo](https://cloud.tencent.com/document/api/296/19867#EffectiveMachineInfo)

	* 新增成员：Uuid


### 第 15 次发布

发布时间：2021-06-01 08:12:13

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [ExportAssetCoreModuleList](https://cloud.tencent.com/document/api/296/56488)

修改接口：

* [DescribeMachineInfo](https://cloud.tencent.com/document/api/296/19851)

	* 新增入参：Quuid

	* 新增出参：HasAssetScan


### 第 14 次发布

发布时间：2021-05-28 08:10:41

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeBruteAttackList](https://cloud.tencent.com/document/api/296/56373)

新增数据结构：

* [BruteAttackInfo](https://cloud.tencent.com/document/api/296/19867#BruteAttackInfo)

### 第 13 次发布

发布时间：2021-05-20 08:10:42

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DeleteNonlocalLoginPlaces](https://cloud.tencent.com/document/api/296/19843)

	* 新增入参：Uuid


### 第 12 次发布

发布时间：2021-05-13 08:10:09

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateSearchLog](https://cloud.tencent.com/document/api/296/55731)
* [CreateSearchTemplate](https://cloud.tencent.com/document/api/296/55730)
* [DeleteSearchTemplate](https://cloud.tencent.com/document/api/296/55729)
* [DescribeESAggregations](https://cloud.tencent.com/document/api/296/55728)
* [DescribeHistoryService](https://cloud.tencent.com/document/api/296/55727)
* [DescribeIndexList](https://cloud.tencent.com/document/api/296/55726)
* [DescribeLogStorageStatistic](https://cloud.tencent.com/document/api/296/55725)
* [DescribeSearchExportList](https://cloud.tencent.com/document/api/296/55724)
* [DescribeSearchLogs](https://cloud.tencent.com/document/api/296/55723)
* [DescribeSearchTemplates](https://cloud.tencent.com/document/api/296/55722)

新增数据结构：

* [SearchTemplate](https://cloud.tencent.com/document/api/296/19867#SearchTemplate)

### 第 11 次发布

发布时间：2021-05-11 08:11:40

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeESHits](https://cloud.tencent.com/document/api/296/55637)

### 第 10 次发布

发布时间：2021-04-27 08:12:06

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeImportMachineInfo](https://cloud.tencent.com/document/api/296/55203)
* [ExportVulDetectionExcel](https://cloud.tencent.com/document/api/296/55202)
* [ExportVulDetectionReport](https://cloud.tencent.com/document/api/296/55201)

新增数据结构：

* [EffectiveMachineInfo](https://cloud.tencent.com/document/api/296/19867#EffectiveMachineInfo)

### 第 9 次发布

发布时间：2021-04-26 08:10:41

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeMachineRegions](https://cloud.tencent.com/document/api/296/55137)

修改数据结构：

* [RegionInfo](https://cloud.tencent.com/document/api/296/19867#RegionInfo)

	* 新增成员：RegionNameEn


### 第 8 次发布

发布时间：2021-03-19 08:10:11

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeMachineOsList](https://cloud.tencent.com/document/api/296/53876)

新增数据结构：

* [OsName](https://cloud.tencent.com/document/api/296/19867#OsName)

修改数据结构：

* [Machine](https://cloud.tencent.com/document/api/296/19867#Machine)

	* 新增成员：HasAssetScan


### 第 7 次发布

发布时间：2021-03-16 08:11:59

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeRiskDnsList](https://cloud.tencent.com/document/api/296/53644)
* [UpdateBaselineStrategy](https://cloud.tencent.com/document/api/296/53643)

修改接口：

* [DescribeTags](https://cloud.tencent.com/document/api/296/39565)

	* 新增入参：Filters


### 第 6 次发布

发布时间：2021-03-03 08:09:44

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeAttackVulTypeList](https://cloud.tencent.com/document/api/296/53358)

修改接口：

* [ExportAttackLogs](https://cloud.tencent.com/document/api/296/39572)

	* 新增入参：Uuid, Quuid


### 第 5 次发布

发布时间：2021-02-25 08:09:56

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeGeneralStat](https://cloud.tencent.com/document/api/296/53132)

### 第 4 次发布

发布时间：2021-01-26 08:11:34

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeExportMachines](https://cloud.tencent.com/document/api/296/52507)
* [DescribeMachineList](https://cloud.tencent.com/document/api/296/52506)
* [DescribeMalwareInfo](https://cloud.tencent.com/document/api/296/52511)
* [DescribeScanMalwareSchedule](https://cloud.tencent.com/document/api/296/52510)
* [ExportTasks](https://cloud.tencent.com/document/api/296/52508)
* [ModifyMalwareTimingScanSettings](https://cloud.tencent.com/document/api/296/52509)

修改接口：

* [DeleteNonlocalLoginPlaces](https://cloud.tencent.com/document/api/296/19843)

	* 新增入参：DelType, Ip

	* <font color="#dd0000">**修改入参**：</font>Ids

* [DescribeMachines](https://cloud.tencent.com/document/api/296/19850)

	* 新增入参：ProjectIds

* [ExportAttackLogs](https://cloud.tencent.com/document/api/296/39572)

	* 新增入参：Filters

* [ExportMaliciousRequests](https://cloud.tencent.com/document/api/296/31287)

	* 新增入参：Filters

* [ExportMalwares](https://cloud.tencent.com/document/api/296/39582)

	* 新增出参：TaskId

* [ExportPrivilegeEvents](https://cloud.tencent.com/document/api/296/39580)

	* 新增入参：Filters

	* 新增出参：TaskId


新增数据结构：

* [AssetFilters](https://cloud.tencent.com/document/api/296/19867#AssetFilters)
* [MalwareInfo](https://cloud.tencent.com/document/api/296/19867#MalwareInfo)

修改数据结构：

* [Filters](https://cloud.tencent.com/document/api/296/19867#Filters)

	* 新增成员：ExactMatch

* [Machine](https://cloud.tencent.com/document/api/296/19867#Machine)

	* 新增成员：ProjectId


### 第 3 次发布

发布时间：2020-12-09 08:09:21

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [Filter](https://cloud.tencent.com/document/api/296/19867#Filter)

	* 新增成员：ExactMatch


### 第 2 次发布

发布时间：2020-11-30 08:43:46

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeSecurityEventsCnt](https://cloud.tencent.com/document/api/296/50427)

修改接口：

* [DescribeMachineInfo](https://cloud.tencent.com/document/api/296/19851)

	* 新增出参：AgentVersion, ProVersionDeadline

* [ExportBashEvents](https://cloud.tencent.com/document/api/296/39584)

	* 新增入参：Filters

	* 新增出参：TaskId

* [ExportBruteAttacks](https://cloud.tencent.com/document/api/296/39583)

	* 新增入参：Filters

	* 新增出参：TaskId

* [ExportMalwares](https://cloud.tencent.com/document/api/296/39582)

	* 新增入参：Limit, Offset, Filters

* [ExportNonlocalLoginPlaces](https://cloud.tencent.com/document/api/296/39581)

	* 新增入参：Filters

* [ExportReverseShellEvents](https://cloud.tencent.com/document/api/296/39579)

	* 新增入参：Filters

	* 新增出参：TaskId


新增数据结构：

* [Filters](https://cloud.tencent.com/document/api/296/19867#Filters)
* [SecurityEventInfo](https://cloud.tencent.com/document/api/296/19867#SecurityEventInfo)

修改数据结构：

* [Machine](https://cloud.tencent.com/document/api/296/19867#Machine)

	* 新增成员：InstanceState, LicenseStatus


### 第 1 次发布

发布时间：2020-09-28 08:11:13

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [AddLoginWhiteList](https://cloud.tencent.com/document/api/296/39602)
* [AddMachineTag](https://cloud.tencent.com/document/api/296/39571)
* [CloseProVersion](https://cloud.tencent.com/document/api/296/19847)
* [CreateBaselineStrategy](https://cloud.tencent.com/document/api/296/46372)
* [CreateOpenPortTask](https://cloud.tencent.com/document/api/296/39570)
* [CreateProcessTask](https://cloud.tencent.com/document/api/296/30341)
* [CreateUsualLoginPlaces](https://cloud.tencent.com/document/api/296/19846)
* [DeleteAttackLogs](https://cloud.tencent.com/document/api/296/39575)
* [DeleteBashEvents](https://cloud.tencent.com/document/api/296/39601)
* [DeleteBashRules](https://cloud.tencent.com/document/api/296/39600)
* [DeleteBruteAttacks](https://cloud.tencent.com/document/api/296/19845)
* [DeleteLoginWhiteList](https://cloud.tencent.com/document/api/296/39599)
* [DeleteMachine](https://cloud.tencent.com/document/api/296/19844)
* [DeleteMachineTag](https://cloud.tencent.com/document/api/296/39569)
* [DeleteMaliciousRequests](https://cloud.tencent.com/document/api/296/31289)
* [DeleteMalwares](https://cloud.tencent.com/document/api/296/19839)
* [DeleteNonlocalLoginPlaces](https://cloud.tencent.com/document/api/296/19843)
* [DeletePrivilegeEvents](https://cloud.tencent.com/document/api/296/39598)
* [DeletePrivilegeRules](https://cloud.tencent.com/document/api/296/39597)
* [DeleteReverseShellEvents](https://cloud.tencent.com/document/api/296/39596)
* [DeleteReverseShellRules](https://cloud.tencent.com/document/api/296/39595)
* [DeleteTags](https://cloud.tencent.com/document/api/296/39568)
* [DeleteUsualLoginPlaces](https://cloud.tencent.com/document/api/296/19842)
* [DescribeAccountStatistics](https://cloud.tencent.com/document/api/296/30340)
* [DescribeAccounts](https://cloud.tencent.com/document/api/296/30339)
* [DescribeAgentVuls](https://cloud.tencent.com/document/api/296/19861)
* [DescribeAlarmAttribute](https://cloud.tencent.com/document/api/296/19866)
* [DescribeAttackLogInfo](https://cloud.tencent.com/document/api/296/39574)
* [DescribeAttackLogs](https://cloud.tencent.com/document/api/296/39573)
* [DescribeBashEvents](https://cloud.tencent.com/document/api/296/39594)
* [DescribeBashRules](https://cloud.tencent.com/document/api/296/39593)
* [DescribeBruteAttacks](https://cloud.tencent.com/document/api/296/19838)
* [DescribeComponentInfo](https://cloud.tencent.com/document/api/296/30338)
* [DescribeComponentStatistics](https://cloud.tencent.com/document/api/296/30337)
* [DescribeComponents](https://cloud.tencent.com/document/api/296/30336)
* [DescribeHistoryAccounts](https://cloud.tencent.com/document/api/296/30335)
* [DescribeImpactedHosts](https://cloud.tencent.com/document/api/296/19860)
* [DescribeLoginWhiteList](https://cloud.tencent.com/document/api/296/39592)
* [DescribeMachineInfo](https://cloud.tencent.com/document/api/296/19851)
* [DescribeMachines](https://cloud.tencent.com/document/api/296/19850)
* [DescribeMaliciousRequests](https://cloud.tencent.com/document/api/296/31288)
* [DescribeMalwares](https://cloud.tencent.com/document/api/296/19837)
* [DescribeNonlocalLoginPlaces](https://cloud.tencent.com/document/api/296/19836)
* [DescribeOpenPortStatistics](https://cloud.tencent.com/document/api/296/30328)
* [DescribeOpenPortTaskStatus](https://cloud.tencent.com/document/api/296/39567)
* [DescribeOpenPorts](https://cloud.tencent.com/document/api/296/30327)
* [DescribeOverviewStatistics](https://cloud.tencent.com/document/api/296/19849)
* [DescribePrivilegeEvents](https://cloud.tencent.com/document/api/296/39591)
* [DescribePrivilegeRules](https://cloud.tencent.com/document/api/296/39590)
* [DescribeProVersionInfo](https://cloud.tencent.com/document/api/296/19865)
* [DescribeProcessStatistics](https://cloud.tencent.com/document/api/296/30334)
* [DescribeProcessTaskStatus](https://cloud.tencent.com/document/api/296/30333)
* [DescribeProcesses](https://cloud.tencent.com/document/api/296/30332)
* [DescribeReverseShellEvents](https://cloud.tencent.com/document/api/296/39589)
* [DescribeReverseShellRules](https://cloud.tencent.com/document/api/296/39588)
* [DescribeSecurityDynamics](https://cloud.tencent.com/document/api/296/30330)
* [DescribeSecurityTrends](https://cloud.tencent.com/document/api/296/30329)
* [DescribeTagMachines](https://cloud.tencent.com/document/api/296/39566)
* [DescribeTags](https://cloud.tencent.com/document/api/296/39565)
* [DescribeUsualLoginPlaces](https://cloud.tencent.com/document/api/296/19841)
* [DescribeVulInfo](https://cloud.tencent.com/document/api/296/19859)
* [DescribeVulScanResult](https://cloud.tencent.com/document/api/296/19858)
* [DescribeVuls](https://cloud.tencent.com/document/api/296/19857)
* [DescribeWeeklyReportBruteAttacks](https://cloud.tencent.com/document/api/296/30326)
* [DescribeWeeklyReportInfo](https://cloud.tencent.com/document/api/296/30325)
* [DescribeWeeklyReportMalwares](https://cloud.tencent.com/document/api/296/30324)
* [DescribeWeeklyReportNonlocalLoginPlaces](https://cloud.tencent.com/document/api/296/30323)
* [DescribeWeeklyReportVuls](https://cloud.tencent.com/document/api/296/30322)
* [DescribeWeeklyReports](https://cloud.tencent.com/document/api/296/30321)
* [EditBashRule](https://cloud.tencent.com/document/api/296/39587)
* [EditPrivilegeRule](https://cloud.tencent.com/document/api/296/39586)
* [EditReverseShellRule](https://cloud.tencent.com/document/api/296/39585)
* [EditTags](https://cloud.tencent.com/document/api/296/39564)
* [ExportAttackLogs](https://cloud.tencent.com/document/api/296/39572)
* [ExportBashEvents](https://cloud.tencent.com/document/api/296/39584)
* [ExportBruteAttacks](https://cloud.tencent.com/document/api/296/39583)
* [ExportMaliciousRequests](https://cloud.tencent.com/document/api/296/31287)
* [ExportMalwares](https://cloud.tencent.com/document/api/296/39582)
* [ExportNonlocalLoginPlaces](https://cloud.tencent.com/document/api/296/39581)
* [ExportPrivilegeEvents](https://cloud.tencent.com/document/api/296/39580)
* [ExportReverseShellEvents](https://cloud.tencent.com/document/api/296/39579)
* [IgnoreImpactedHosts](https://cloud.tencent.com/document/api/296/19856)
* [InquiryPriceOpenProVersionPrepaid](https://cloud.tencent.com/document/api/296/31293)
* [MisAlarmNonlocalLoginPlaces](https://cloud.tencent.com/document/api/296/19835)
* [ModifyAlarmAttribute](https://cloud.tencent.com/document/api/296/19864)
* [ModifyAutoOpenProVersionConfig](https://cloud.tencent.com/document/api/296/19863)
* [ModifyLoginWhiteList](https://cloud.tencent.com/document/api/296/39578)
* [ModifyProVersionRenewFlag](https://cloud.tencent.com/document/api/296/31292)
* [OpenProVersion](https://cloud.tencent.com/document/api/296/41154)
* [OpenProVersionPrepaid](https://cloud.tencent.com/document/api/296/31291)
* [RecoverMalwares](https://cloud.tencent.com/document/api/296/19834)
* [RenewProVersion](https://cloud.tencent.com/document/api/296/31290)
* [RescanImpactedHost](https://cloud.tencent.com/document/api/296/19855)
* [SeparateMalwares](https://cloud.tencent.com/document/api/296/30320)
* [SetBashEventsStatus](https://cloud.tencent.com/document/api/296/39577)
* [SwitchBashRules](https://cloud.tencent.com/document/api/296/39576)
* [TrustMaliciousRequest](https://cloud.tencent.com/document/api/296/31286)
* [TrustMalwares](https://cloud.tencent.com/document/api/296/19833)
* [UntrustMaliciousRequest](https://cloud.tencent.com/document/api/296/31285)
* [UntrustMalwares](https://cloud.tencent.com/document/api/296/30319)

新增数据结构：

* [Account](https://cloud.tencent.com/document/api/296/19867#Account)
* [AccountStatistics](https://cloud.tencent.com/document/api/296/19867#AccountStatistics)
* [AgentVul](https://cloud.tencent.com/document/api/296/19867#AgentVul)
* [BashEvent](https://cloud.tencent.com/document/api/296/19867#BashEvent)
* [BashRule](https://cloud.tencent.com/document/api/296/19867#BashRule)
* [BruteAttack](https://cloud.tencent.com/document/api/296/19867#BruteAttack)
* [ChargePrepaid](https://cloud.tencent.com/document/api/296/19867#ChargePrepaid)
* [Component](https://cloud.tencent.com/document/api/296/19867#Component)
* [ComponentStatistics](https://cloud.tencent.com/document/api/296/19867#ComponentStatistics)
* [DefendAttackLog](https://cloud.tencent.com/document/api/296/19867#DefendAttackLog)
* [Filter](https://cloud.tencent.com/document/api/296/19867#Filter)
* [HistoryAccount](https://cloud.tencent.com/document/api/296/19867#HistoryAccount)
* [ImpactedHost](https://cloud.tencent.com/document/api/296/19867#ImpactedHost)
* [LoginWhiteLists](https://cloud.tencent.com/document/api/296/19867#LoginWhiteLists)
* [LoginWhiteListsRule](https://cloud.tencent.com/document/api/296/19867#LoginWhiteListsRule)
* [Machine](https://cloud.tencent.com/document/api/296/19867#Machine)
* [MachineTag](https://cloud.tencent.com/document/api/296/19867#MachineTag)
* [MaliciousRequest](https://cloud.tencent.com/document/api/296/19867#MaliciousRequest)
* [Malware](https://cloud.tencent.com/document/api/296/19867#Malware)
* [NonLocalLoginPlace](https://cloud.tencent.com/document/api/296/19867#NonLocalLoginPlace)
* [OpenPort](https://cloud.tencent.com/document/api/296/19867#OpenPort)
* [OpenPortStatistics](https://cloud.tencent.com/document/api/296/19867#OpenPortStatistics)
* [Place](https://cloud.tencent.com/document/api/296/19867#Place)
* [PrivilegeEscalationProcess](https://cloud.tencent.com/document/api/296/19867#PrivilegeEscalationProcess)
* [PrivilegeRule](https://cloud.tencent.com/document/api/296/19867#PrivilegeRule)
* [ProVersionMachine](https://cloud.tencent.com/document/api/296/19867#ProVersionMachine)
* [Process](https://cloud.tencent.com/document/api/296/19867#Process)
* [ProcessStatistics](https://cloud.tencent.com/document/api/296/19867#ProcessStatistics)
* [RegionInfo](https://cloud.tencent.com/document/api/296/19867#RegionInfo)
* [ReverseShell](https://cloud.tencent.com/document/api/296/19867#ReverseShell)
* [ReverseShellRule](https://cloud.tencent.com/document/api/296/19867#ReverseShellRule)
* [SecurityDynamic](https://cloud.tencent.com/document/api/296/19867#SecurityDynamic)
* [SecurityTrend](https://cloud.tencent.com/document/api/296/19867#SecurityTrend)
* [Tag](https://cloud.tencent.com/document/api/296/19867#Tag)
* [TagMachine](https://cloud.tencent.com/document/api/296/19867#TagMachine)
* [UsualPlace](https://cloud.tencent.com/document/api/296/19867#UsualPlace)
* [Vul](https://cloud.tencent.com/document/api/296/19867#Vul)
* [WeeklyReport](https://cloud.tencent.com/document/api/296/19867#WeeklyReport)
* [WeeklyReportBruteAttack](https://cloud.tencent.com/document/api/296/19867#WeeklyReportBruteAttack)
* [WeeklyReportMalware](https://cloud.tencent.com/document/api/296/19867#WeeklyReportMalware)
* [WeeklyReportNonlocalLoginPlace](https://cloud.tencent.com/document/api/296/19867#WeeklyReportNonlocalLoginPlace)
* [WeeklyReportVul](https://cloud.tencent.com/document/api/296/19867#WeeklyReportVul)




## (cws) 版本：2018-03-12

### 第 5 次发布

发布时间：2019-11-22 12:16:15

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateSites](https://cloud.tencent.com/document/api/#/#)

	* 新增出参：Sites

* [DescribeConfig](https://cloud.tencent.com/document/api/#/#)

	* 新增出参：ContentLevel


新增数据结构：

* [MiniSite](https://cloud.tencent.com/document/api/#/##MiniSite)

修改数据结构：

* [Monitor](https://cloud.tencent.com/document/api/#/##Monitor)

	* 新增成员：ContentScanStatus

* [MonitorsDetail](https://cloud.tencent.com/document/api/#/##MonitorsDetail)

	* 新增成员：ContentNumber

* [Site](https://cloud.tencent.com/document/api/#/##Site)

	* 新增成员：ContentStatus, LastScanContentNum


### 第 4 次发布

发布时间：2018-06-28 15:15:08

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateVulsReport](https://cloud.tencent.com/document/api/#/#)
* [DescribeVulsNumber](https://cloud.tencent.com/document/api/#/#)
* [DescribeVulsNumberTimeline](https://cloud.tencent.com/document/api/#/#)

新增数据结构：

* [VulsTimeline](https://cloud.tencent.com/document/api/#/##VulsTimeline)

### 第 3 次发布

发布时间：2018-06-14 12:15:42

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateSites](https://cloud.tencent.com/document/api/#/#)

	* 新增入参：UserAgent

* [DescribeConfig](https://cloud.tencent.com/document/api/#/#)

	* 新增出参：Appid

* [DescribeSitesVerification](https://cloud.tencent.com/document/api/#/#)

	* <font color="#dd0000">**修改出参**：</font>SitesVerification

* [ModifySiteAttribute](https://cloud.tencent.com/document/api/#/#)

	* 新增入参：NeedLogin, LoginCookie, LoginCheckUrl, LoginCheckKw, ScanDisallow


修改数据结构：

* [Site](https://cloud.tencent.com/document/api/#/##Site)

	* 新增成员：NeedLogin, LoginCookie, LoginCookieValid, LoginCheckUrl, LoginCheckKw, ScanDisallow, UserAgent

	* <font color="#dd0000">**删除成员**：</font>LastScanExtsCount

* [SitesVerification](https://cloud.tencent.com/document/api/#/##SitesVerification)

	* 新增成员：VerifyUrl, VerifyFileUrl

* [Vul](https://cloud.tencent.com/document/api/#/##Vul)

	* 新增成员：Appid, Uin


### 第 2 次发布

发布时间：2018-05-24 17:08:50

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [Monitor](https://cloud.tencent.com/document/api/#/##Monitor)

	* 新增成员：Id, Appid

	* <font color="#dd0000">**删除成员**：</font>ID

* [Site](https://cloud.tencent.com/document/api/#/##Site)

	* 新增成员：LastScanExtsCount, Appid, Uin

* [SitesVerification](https://cloud.tencent.com/document/api/#/##SitesVerification)

	* 新增成员：Id, Appid


### 第 1 次发布

发布时间：2018-04-24

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateMonitors](https://cloud.tencent.com/document/api/#/#)
* [CreateSites](https://cloud.tencent.com/document/api/#/#)
* [CreateSitesScans](https://cloud.tencent.com/document/api/#/#)
* [CreateVulsMisinformation](https://cloud.tencent.com/document/api/#/#)
* [DeleteMonitors](https://cloud.tencent.com/document/api/#/#)
* [DeleteSites](https://cloud.tencent.com/document/api/#/#)
* [DescribeConfig](https://cloud.tencent.com/document/api/#/#)
* [DescribeMonitors](https://cloud.tencent.com/document/api/#/#)
* [DescribeSiteQuota](https://cloud.tencent.com/document/api/#/#)
* [DescribeSites](https://cloud.tencent.com/document/api/#/#)
* [DescribeSitesVerification](https://cloud.tencent.com/document/api/#/#)
* [DescribeVuls](https://cloud.tencent.com/document/api/#/#)
* [ModifyConfigAttribute](https://cloud.tencent.com/document/api/#/#)
* [ModifyMonitorAttribute](https://cloud.tencent.com/document/api/#/#)
* [ModifySiteAttribute](https://cloud.tencent.com/document/api/#/#)
* [VerifySites](https://cloud.tencent.com/document/api/#/#)

新增数据结构：

* [Filter](https://cloud.tencent.com/document/api/#/##Filter)
* [Monitor](https://cloud.tencent.com/document/api/#/##Monitor)
* [MonitorMiniSite](https://cloud.tencent.com/document/api/#/##MonitorMiniSite)
* [MonitorsDetail](https://cloud.tencent.com/document/api/#/##MonitorsDetail)
* [Site](https://cloud.tencent.com/document/api/#/##Site)
* [SitesVerification](https://cloud.tencent.com/document/api/#/##SitesVerification)
* [Vul](https://cloud.tencent.com/document/api/#/##Vul)




## TDSQL-C MySQL 版(cynosdb) 版本：2019-01-07

### 第 98 次发布

发布时间：2024-07-26 01:29:47

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateCLSDelivery](https://cloud.tencent.com/document/api/1003/106079)

	* 新增入参：LogType, IsInMaintainPeriod

* [DeleteCLSDelivery](https://cloud.tencent.com/document/api/1003/106078)

	* 新增入参：LogType, IsInMaintainPeriod

* [DescribeInstanceCLSLogDelivery](https://cloud.tencent.com/document/api/1003/106077)

	* 新增入参：LogType

* [StartCLSDelivery](https://cloud.tencent.com/document/api/1003/106076)

	* 新增入参：LogType, IsInMaintainPeriod

* [StopCLSDelivery](https://cloud.tencent.com/document/api/1003/106075)

	* 新增入参：LogType, IsInMaintainPeriod


修改数据结构：

* [InstanceCLSDeliveryInfo](https://cloud.tencent.com/document/api/1003/48097#InstanceCLSDeliveryInfo)

	* 新增成员：LogType


### 第 97 次发布

发布时间：2024-07-22 01:29:16

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [ExportResourcePackageDeductDetails](https://cloud.tencent.com/document/api/1003/109046)
* [ModifyResourcePackagesDeductionPriority](https://cloud.tencent.com/document/api/1003/109045)

新增数据结构：

* [PackagePriority](https://cloud.tencent.com/document/api/1003/48097#PackagePriority)

### 第 96 次发布

发布时间：2024-07-02 01:13:35

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [Ability](https://cloud.tencent.com/document/api/1003/48097#Ability)

	* 新增成员：IsSupportTransparentDataEncryption, NoSupportTransparentDataEncryptionReason

* [NetAddr](https://cloud.tencent.com/document/api/1003/48097#NetAddr)

	* <font color="#dd0000">**修改成员**：</font>InstanceGroupId

* [ParamInfo](https://cloud.tencent.com/document/api/1003/48097#ParamInfo)

	* 新增成员：FuncPattern


### 第 95 次发布

发布时间：2024-06-26 01:13:42

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [AuditLog](https://cloud.tencent.com/document/api/1003/48097#AuditLog)

	* 新增成员：TrxId


### 第 94 次发布

发布时间：2024-06-21 01:30:05

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [RenewClusters](https://cloud.tencent.com/document/api/1003/107548)

### 第 93 次发布

发布时间：2024-06-20 01:30:19

本次发布包含了以下内容：

改善已有的文档。

新增数据结构：

* [ExchangeInstanceInfo](https://cloud.tencent.com/document/api/1003/48097#ExchangeInstanceInfo)
* [ExchangeRoGroupInfo](https://cloud.tencent.com/document/api/1003/48097#ExchangeRoGroupInfo)
* [RollbackInstanceInfo](https://cloud.tencent.com/document/api/1003/48097#RollbackInstanceInfo)
* [RollbackProcessInfo](https://cloud.tencent.com/document/api/1003/48097#RollbackProcessInfo)
* [RollbackRoGroupInfo](https://cloud.tencent.com/document/api/1003/48097#RollbackRoGroupInfo)

修改数据结构：

* [BizTaskInfo](https://cloud.tencent.com/document/api/1003/48097#BizTaskInfo)

	* 新增成员：Region, InstanceCLSDeliveryInfos

* [RollbackData](https://cloud.tencent.com/document/api/1003/48097#RollbackData)

	* 新增成员：RollbackProcess


### 第 92 次发布

发布时间：2024-06-18 01:30:07

本次发布包含了以下内容：

改善已有的文档。

<font color="#dd0000">**预下线接口**：</font>

* DescribeRollbackTimeValidity

修改接口：

* [RollbackToNewCluster](https://cloud.tencent.com/document/api/1003/104727)

	* 新增入参：TimeSpan, TimeUnit, RollbackDatabases, RollbackTables, OriginalROInstanceList


### 第 91 次发布

发布时间：2024-06-06 01:35:01

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [ParamDetail](https://cloud.tencent.com/document/api/1003/48097#ParamDetail)

	* 新增成员：FuncPattern

* [ParamItemDetail](https://cloud.tencent.com/document/api/1003/48097#ParamItemDetail)

	* 新增成员：FuncPattern


### 第 90 次发布

发布时间：2024-05-27 01:28:43

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [AddInstances](https://cloud.tencent.com/document/api/1003/48088)

	* 新增入参：DeviceType

* [DescribeInstanceSpecs](https://cloud.tencent.com/document/api/1003/48084)

	* 新增入参：DeviceType

* [InquirePriceCreate](https://cloud.tencent.com/document/api/1003/77738)

	* 新增入参：DeviceType

* [RollbackToNewCluster](https://cloud.tencent.com/document/api/1003/104727)

	* 新增入参：PayMode

* [UpgradeInstance](https://cloud.tencent.com/document/api/1003/48077)

	* 新增入参：DeviceType


修改数据结构：

* [ClusterInstanceDetail](https://cloud.tencent.com/document/api/1003/48097#ClusterInstanceDetail)

	* 新增成员：InstanceTasks, InstanceDeviceType

* [CynosdbInstance](https://cloud.tencent.com/document/api/1003/48097#CynosdbInstance)

	* 新增成员：DeviceType

* [InstanceInitInfo](https://cloud.tencent.com/document/api/1003/48097#InstanceInitInfo)

	* 新增成员：DeviceType

* [ModifyInstanceData](https://cloud.tencent.com/document/api/1003/48097#ModifyInstanceData)

	* 新增成员：OldDeviceType, DeviceType


### 第 89 次发布

发布时间：2024-05-14 01:39:01

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateCLSDelivery](https://cloud.tencent.com/document/api/1003/106079)

	* 新增入参：InstanceId, CLSInfoList

	* 新增出参：TaskId

* [DeleteCLSDelivery](https://cloud.tencent.com/document/api/1003/106078)

	* 新增入参：InstanceId, CLSTopicIds

	* 新增出参：TaskId

* [DescribeInstanceCLSLogDelivery](https://cloud.tencent.com/document/api/1003/106077)

	* 新增入参：InstanceId

	* 新增出参：TotalCount, InstanceCLSDeliveryInfos

* [StartCLSDelivery](https://cloud.tencent.com/document/api/1003/106076)

	* 新增入参：InstanceId, CLSTopicIds

	* 新增出参：TaskId

* [StopCLSDelivery](https://cloud.tencent.com/document/api/1003/106075)

	* 新增入参：InstanceId, CLSTopicIds

	* 新增出参：TaskId


新增数据结构：

* [CLSInfo](https://cloud.tencent.com/document/api/1003/48097#CLSInfo)
* [InstanceCLSDeliveryInfo](https://cloud.tencent.com/document/api/1003/48097#InstanceCLSDeliveryInfo)

### 第 88 次发布

发布时间：2024-05-13 01:14:47

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateCLSDelivery](https://cloud.tencent.com/document/api/1003/106079)
* [DeleteCLSDelivery](https://cloud.tencent.com/document/api/1003/106078)
* [DescribeInstanceCLSLogDelivery](https://cloud.tencent.com/document/api/1003/106077)
* [StartCLSDelivery](https://cloud.tencent.com/document/api/1003/106076)
* [StopCLSDelivery](https://cloud.tencent.com/document/api/1003/106075)

### 第 87 次发布

发布时间：2024-05-10 01:33:56

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [ResourcePackage](https://cloud.tencent.com/document/api/1003/48097#ResourcePackage)

	* 新增成员：DeductionPriority


### 第 86 次发布

发布时间：2024-04-26 01:13:19

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeChangedParamsAfterUpgrade](https://cloud.tencent.com/document/api/1003/105702)

新增数据结构：

* [ParamItemInfo](https://cloud.tencent.com/document/api/1003/48097#ParamItemInfo)

### 第 85 次发布

发布时间：2024-04-23 01:13:35

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [ModifyInstanceUpgradeLimitDays](https://cloud.tencent.com/document/api/1003/105564)

### 第 84 次发布

发布时间：2024-04-22 01:13:46

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [AddClusterSlaveZone](https://cloud.tencent.com/document/api/1003/79555)

	* 新增入参：BinlogSyncWay

* [ModifyClusterSlaveZone](https://cloud.tencent.com/document/api/1003/79554)

	* 新增入参：BinlogSyncWay


新增数据结构：

* [SlaveZoneAttrItem](https://cloud.tencent.com/document/api/1003/48097#SlaveZoneAttrItem)

修改数据结构：

* [ClusterSlaveData](https://cloud.tencent.com/document/api/1003/48097#ClusterSlaveData)

	* 新增成员：NewSlaveZoneAttr, OldSlaveZoneAttr

* [CynosdbClusterDetail](https://cloud.tencent.com/document/api/1003/48097#CynosdbClusterDetail)

	* 新增成员：SlaveZoneAttr


### 第 83 次发布

发布时间：2024-04-17 01:10:53

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [SlowQueriesItem](https://cloud.tencent.com/document/api/1003/48097#SlowQueriesItem)

	* 新增成员：SyncReadCountRemote, SyncReadBytesRemote, SyncReadTimeRemote, SyncWriteCountRemote, SyncWriteBytesRemote, SyncWriteTimeRemote, TrxCommitDelay


### 第 82 次发布

发布时间：2024-03-29 01:14:11

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [RollbackToNewCluster](https://cloud.tencent.com/document/api/1003/104727)

### 第 81 次发布

发布时间：2024-03-15 01:12:26

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [AddInstances](https://cloud.tencent.com/document/api/1003/48088)

	* 新增入参：UpgradeProxy

* [UpgradeInstance](https://cloud.tencent.com/document/api/1003/48077)

	* 新增入参：UpgradeProxy


新增数据结构：

* [UpgradeProxy](https://cloud.tencent.com/document/api/1003/48097#UpgradeProxy)

### 第 80 次发布

发布时间：2024-02-26 01:12:56

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeClusterInstanceGroups](https://cloud.tencent.com/document/api/1003/103934)

### 第 79 次发布

发布时间：2024-02-21 01:12:48

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeTasks](https://cloud.tencent.com/document/api/1003/103866)

新增数据结构：

* [BizTaskInfo](https://cloud.tencent.com/document/api/1003/48097#BizTaskInfo)
* [BizTaskModifyInstanceParam](https://cloud.tencent.com/document/api/1003/48097#BizTaskModifyInstanceParam)
* [BizTaskModifyParamsData](https://cloud.tencent.com/document/api/1003/48097#BizTaskModifyParamsData)
* [ClusterSlaveData](https://cloud.tencent.com/document/api/1003/48097#ClusterSlaveData)
* [CreateClustersData](https://cloud.tencent.com/document/api/1003/48097#CreateClustersData)
* [ManualBackupData](https://cloud.tencent.com/document/api/1003/48097#ManualBackupData)
* [ModifyDbVersionData](https://cloud.tencent.com/document/api/1003/48097#ModifyDbVersionData)
* [ModifyInstanceData](https://cloud.tencent.com/document/api/1003/48097#ModifyInstanceData)
* [ModifyParamsData](https://cloud.tencent.com/document/api/1003/48097#ModifyParamsData)
* [RollbackData](https://cloud.tencent.com/document/api/1003/48097#RollbackData)
* [SwitchClusterLogBin](https://cloud.tencent.com/document/api/1003/48097#SwitchClusterLogBin)
* [TaskMaintainInfo](https://cloud.tencent.com/document/api/1003/48097#TaskMaintainInfo)

### 第 78 次发布

发布时间：2024-01-25 01:10:23

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeAuditInstanceList](https://cloud.tencent.com/document/api/1003/103372)

新增数据结构：

* [AuditInstanceFilters](https://cloud.tencent.com/document/api/1003/48097#AuditInstanceFilters)
* [AuditInstanceInfo](https://cloud.tencent.com/document/api/1003/48097#AuditInstanceInfo)
* [InstanceAuditStatus](https://cloud.tencent.com/document/api/1003/48097#InstanceAuditStatus)

### 第 77 次发布

发布时间：2024-01-19 01:11:18

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [AddInstances](https://cloud.tencent.com/document/api/1003/48088)

* [CloseWan](https://cloud.tencent.com/document/api/1003/92737)

	* 新增入参：InstanceGroupId, InstanceId

	* <font color="#dd0000">**修改入参**：</font>InstanceGrpId

* [DescribeClusterInstanceGrps](https://cloud.tencent.com/document/api/1003/48303)

	* 新增出参：InstanceGroupInfoList

* [DescribeClusterParams](https://cloud.tencent.com/document/api/1003/79556)

	* 新增入参：IsGlobal

* [DescribeDBSecurityGroups](https://cloud.tencent.com/document/api/1003/48305)

	* 新增入参：InstanceGroupId

	* <font color="#dd0000">**修改入参**：</font>InstanceId

* [DescribeInstanceParams](https://cloud.tencent.com/document/api/1003/92729)

	* 新增入参：IsGlobal

* [ModifyVipVport](https://cloud.tencent.com/document/api/1003/86720)

	* 新增入参：InstanceGroupId

	* <font color="#dd0000">**修改入参**：</font>InstanceGrpId

* [OpenWan](https://cloud.tencent.com/document/api/1003/92732)

	* 新增入参：InstanceId, InstanceGroupId

	* <font color="#dd0000">**修改入参**：</font>InstanceGrpId


新增数据结构：

* [CynosdbInstanceGroup](https://cloud.tencent.com/document/api/1003/48097#CynosdbInstanceGroup)

修改数据结构：

* [Ability](https://cloud.tencent.com/document/api/1003/48097#Ability)

	* 新增成员：IsSupportManualSnapshot

* [ModifiableInfo](https://cloud.tencent.com/document/api/1003/48097#ModifiableInfo)

	* 新增成员：IsModifiable


### 第 76 次发布

发布时间：2024-01-10 01:11:56

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [IsolateCluster](https://cloud.tencent.com/document/api/1003/48082)

	* 新增入参：IsolateReasonTypes, IsolateReason

* [IsolateInstance](https://cloud.tencent.com/document/api/1003/48081)

	* 新增入参：IsolateReasonTypes, IsolateReason


新增数据结构：

* [InstanceAbility](https://cloud.tencent.com/document/api/1003/48097#InstanceAbility)
* [SlaveZoneStockInfo](https://cloud.tencent.com/document/api/1003/48097#SlaveZoneStockInfo)

修改数据结构：

* [CynosdbInstance](https://cloud.tencent.com/document/api/1003/48097#CynosdbInstance)

	* 新增成员：InstanceAbility

* [ZoneStockInfo](https://cloud.tencent.com/document/api/1003/48097#ZoneStockInfo)

	* 新增成员：SlaveZoneStockInfos


### 第 75 次发布

发布时间：2023-12-06 01:34:06

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [Package](https://cloud.tencent.com/document/api/1003/48097#Package)

	* 新增成员：HistoryBindResourceInfos


### 第 74 次发布

发布时间：2023-11-14 01:12:41

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeClusterDatabases](https://cloud.tencent.com/document/api/1003/101559)

### 第 73 次发布

发布时间：2023-10-23 00:08:10

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [CynosdbInstance](https://cloud.tencent.com/document/api/1003/48097#CynosdbInstance)

	* 新增成员：InstanceIndexMode

	* <font color="#dd0000">**修改成员**：</font>DbMode, MasterZone, SlaveZones, InstanceNetInfo, ResourcePackages


### 第 72 次发布

发布时间：2023-10-13 01:13:55

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [InstanceNetInfo](https://cloud.tencent.com/document/api/1003/48097#InstanceNetInfo)

	* <font color="#dd0000">**修改成员**：</font>InstanceGroupType, InstanceGroupId, VpcId, SubnetId, NetType, Vip, Vport, WanDomain, WanIP, WanPort, WanStatus


### 第 71 次发布

发布时间：2023-09-20 01:32:40

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeBackupConfig](https://cloud.tencent.com/document/api/1003/48094)

	* 新增出参：LogicCrossRegionsConfigUpdateTime

* [DescribeBackupList](https://cloud.tencent.com/document/api/1003/48093)

	* 新增入参：BackupRegion, IsCrossRegionsBackup

* [ModifyBackupConfig](https://cloud.tencent.com/document/api/1003/48090)

	* 新增入参：LogicBackupConfig, DeleteAutoLogicBackup

	* <font color="#dd0000">**修改入参**：</font>ReserveDuration


新增数据结构：

* [LogicBackupConfigInfo](https://cloud.tencent.com/document/api/1003/48097#LogicBackupConfigInfo)

### 第 70 次发布

发布时间：2023-09-15 01:35:18

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateAuditRuleTemplate](https://cloud.tencent.com/document/api/1003/84702)

	* 新增入参：AlarmLevel, AlarmPolicy

* [DescribeAuditRuleTemplates](https://cloud.tencent.com/document/api/1003/84700)

	* 新增入参：AlarmLevel, AlarmPolicy

* [ModifyAuditRuleTemplates](https://cloud.tencent.com/document/api/1003/84698)

	* 新增入参：AlarmLevel, AlarmPolicy

* [OpenAuditService](https://cloud.tencent.com/document/api/1003/84696)

	* 新增入参：AuditAll


新增数据结构：

* [LogRuleTemplateInfo](https://cloud.tencent.com/document/api/1003/48097#LogRuleTemplateInfo)
* [RuleTemplateInfo](https://cloud.tencent.com/document/api/1003/48097#RuleTemplateInfo)

修改数据结构：

* [AuditLog](https://cloud.tencent.com/document/api/1003/48097#AuditLog)

	* 新增成员：TemplateInfo

* [AuditRuleTemplateInfo](https://cloud.tencent.com/document/api/1003/48097#AuditRuleTemplateInfo)

	* 新增成员：UpdateAt, AlarmLevel, AlarmPolicy, Status, AffectedInstances

* [InstanceAuditRule](https://cloud.tencent.com/document/api/1003/48097#InstanceAuditRule)

	* 新增成员：OldRule, RuleTemplates


### 第 69 次发布

发布时间：2023-09-14 01:33:33

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [CynosdbClusterDetail](https://cloud.tencent.com/document/api/1003/48097#CynosdbClusterDetail)

	* 新增成员：NetworkType


### 第 68 次发布

发布时间：2023-08-25 01:28:19

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [Package](https://cloud.tencent.com/document/api/1003/48097#Package)

	* <font color="#dd0000">**修改成员**：</font>AppId, PackageId, PackageName, PackageType, PackageRegion, Status, PackageTotalSpec, PackageUsedSpec, HasQuota, BindInstanceInfos, StartTime, ExpireTime


### 第 67 次发布

发布时间：2023-08-21 01:09:59

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [ProxyNodeInfo](https://cloud.tencent.com/document/api/1003/48097#ProxyNodeInfo)

	* 新增成员：OssProxyNodeName


### 第 66 次发布

发布时间：2023-08-16 01:18:52

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeResourcePackageDetail](https://cloud.tencent.com/document/api/1003/93012)

	* 新增入参：InstanceIds


修改数据结构：

* [BindInstanceInfo](https://cloud.tencent.com/document/api/1003/48097#BindInstanceInfo)

	* 新增成员：ExtendIds

	* <font color="#dd0000">**修改成员**：</font>InstanceId, InstanceRegion, InstanceType

* [ClusterInstanceDetail](https://cloud.tencent.com/document/api/1003/48097#ClusterInstanceDetail)

	* 新增成员：ServerlessStatus

* [InstanceInitInfo](https://cloud.tencent.com/document/api/1003/48097#InstanceInitInfo)

	* 新增成员：MinRoCount, MaxRoCount, MinRoCpu, MaxRoCpu


### 第 65 次发布

发布时间：2023-08-08 01:14:23

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [CynosdbClusterDetail](https://cloud.tencent.com/document/api/1003/48097#CynosdbClusterDetail)

	* <font color="#dd0000">**修改成员**：</font>ResourcePackages, RenewFlag


### 第 64 次发布

发布时间：2023-08-02 01:13:37

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [OpenClusterReadOnlyInstanceGroupAccess](https://cloud.tencent.com/document/api/1003/95782)

### 第 63 次发布

发布时间：2023-08-01 01:15:19

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeAccounts](https://cloud.tencent.com/document/api/1003/48075)

	* 新增入参：AccountRegular


修改数据结构：

* [ClusterInstanceDetail](https://cloud.tencent.com/document/api/1003/48097#ClusterInstanceDetail)

	* 新增成员：MaintainStartTime, MaintainDuration, MaintainWeekDays


### 第 62 次发布

发布时间：2023-07-27 01:11:21

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [ExportInstanceSlowQueries](https://cloud.tencent.com/document/api/1003/76368)

	* 新增入参：OrderBy, OrderByType


### 第 61 次发布

发布时间：2023-07-13 01:13:53

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateAuditLogFile](https://cloud.tencent.com/document/api/1003/81440)

	* 新增入参：LogFilter

* [DescribeAuditLogs](https://cloud.tencent.com/document/api/1003/81437)

	* 新增入参：LogFilter


新增数据结构：

* [InstanceAuditLogFilter](https://cloud.tencent.com/document/api/1003/48097#InstanceAuditLogFilter)

修改数据结构：

* [AuditLog](https://cloud.tencent.com/document/api/1003/48097#AuditLog)

	* 新增成员：CheckRows, CpuTime, IoWaitTime, LockWaitTime, TrxLivingTime, NsTime


### 第 60 次发布

发布时间：2023-06-29 14:25:48

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateProxyEndPoint](https://cloud.tencent.com/document/api/1003/94133)

	* 新增出参：ProxyGroupId


### 第 59 次发布

发布时间：2023-06-29 11:34:47

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateProxy](https://cloud.tencent.com/document/api/1003/94134)

	* 新增出参：ProxyGroupId


### 第 58 次发布

发布时间：2023-06-26 01:22:36

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeSupportProxyVersion](https://cloud.tencent.com/document/api/1003/94260)

### 第 57 次发布

发布时间：2023-06-22 01:22:32

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeProxySpecs](https://cloud.tencent.com/document/api/1003/94241)

新增数据结构：

* [ProxySpec](https://cloud.tencent.com/document/api/1003/48097#ProxySpec)

### 第 56 次发布

发布时间：2023-06-19 01:14:27

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CloseProxy](https://cloud.tencent.com/document/api/1003/94135)
* [CreateProxy](https://cloud.tencent.com/document/api/1003/94134)
* [CreateProxyEndPoint](https://cloud.tencent.com/document/api/1003/94133)
* [DescribeProxies](https://cloud.tencent.com/document/api/1003/94132)
* [DescribeProxyNodes](https://cloud.tencent.com/document/api/1003/94131)
* [ModifyProxyDesc](https://cloud.tencent.com/document/api/1003/94130)
* [ModifyProxyRwSplit](https://cloud.tencent.com/document/api/1003/94129)
* [ReloadBalanceProxyNode](https://cloud.tencent.com/document/api/1003/94128)
* [UpgradeProxy](https://cloud.tencent.com/document/api/1003/94127)
* [UpgradeProxyVersion](https://cloud.tencent.com/document/api/1003/94126)

新增数据结构：

* [ProxyConnectionPoolInfo](https://cloud.tencent.com/document/api/1003/48097#ProxyConnectionPoolInfo)
* [ProxyGroup](https://cloud.tencent.com/document/api/1003/48097#ProxyGroup)
* [ProxyGroupInfo](https://cloud.tencent.com/document/api/1003/48097#ProxyGroupInfo)
* [ProxyGroupRwInfo](https://cloud.tencent.com/document/api/1003/48097#ProxyGroupRwInfo)
* [ProxyInstanceWeight](https://cloud.tencent.com/document/api/1003/48097#ProxyInstanceWeight)
* [ProxyNodeInfo](https://cloud.tencent.com/document/api/1003/48097#ProxyNodeInfo)
* [ProxyZone](https://cloud.tencent.com/document/api/1003/48097#ProxyZone)
* [QueryParamFilter](https://cloud.tencent.com/document/api/1003/48097#QueryParamFilter)

### 第 55 次发布

发布时间：2023-06-09 01:14:30

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [CynosdbClusterDetail](https://cloud.tencent.com/document/api/1003/48097#CynosdbClusterDetail)

	* 新增成员：RenewFlag


### 第 54 次发布

发布时间：2023-05-31 01:18:15

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [BindClusterResourcePackages](https://cloud.tencent.com/document/api/1003/93014)
* [CreateResourcePackage](https://cloud.tencent.com/document/api/1003/93013)
* [DescribeResourcePackageDetail](https://cloud.tencent.com/document/api/1003/93012)
* [DescribeResourcePackageList](https://cloud.tencent.com/document/api/1003/93011)
* [DescribeResourcePackageSaleSpec](https://cloud.tencent.com/document/api/1003/93010)
* [ModifyResourcePackageClusters](https://cloud.tencent.com/document/api/1003/93009)
* [ModifyResourcePackageName](https://cloud.tencent.com/document/api/1003/93008)
* [RefundResourcePackage](https://cloud.tencent.com/document/api/1003/93007)
* [UnbindClusterResourcePackages](https://cloud.tencent.com/document/api/1003/93006)

新增数据结构：

* [BindInstanceInfo](https://cloud.tencent.com/document/api/1003/48097#BindInstanceInfo)
* [Package](https://cloud.tencent.com/document/api/1003/48097#Package)
* [PackageDetail](https://cloud.tencent.com/document/api/1003/48097#PackageDetail)
* [ResourcePackage](https://cloud.tencent.com/document/api/1003/48097#ResourcePackage)
* [SalePackageSpec](https://cloud.tencent.com/document/api/1003/48097#SalePackageSpec)

修改数据结构：

* [CynosdbCluster](https://cloud.tencent.com/document/api/1003/48097#CynosdbCluster)

	* 新增成员：ResourcePackages

* [CynosdbClusterDetail](https://cloud.tencent.com/document/api/1003/48097#CynosdbClusterDetail)

	* 新增成员：ResourcePackages

* [CynosdbInstance](https://cloud.tencent.com/document/api/1003/48097#CynosdbInstance)

	* 新增成员：DbMode, ResourcePackages


### 第 53 次发布

发布时间：2023-05-25 01:27:43

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CloseClusterPasswordComplexity](https://cloud.tencent.com/document/api/1003/92724)
* [CloseWan](https://cloud.tencent.com/document/api/1003/92737)
* [CopyClusterPasswordComplexity](https://cloud.tencent.com/document/api/1003/92723)
* [CreateClusterDatabase](https://cloud.tencent.com/document/api/1003/92736)
* [CreateParamTemplate](https://cloud.tencent.com/document/api/1003/92731)
* [DeleteAccounts](https://cloud.tencent.com/document/api/1003/92718)
* [DeleteClusterDatabase](https://cloud.tencent.com/document/api/1003/92735)
* [DeleteParamTemplate](https://cloud.tencent.com/document/api/1003/92730)
* [DescribeAccountPrivileges](https://cloud.tencent.com/document/api/1003/92717)
* [DescribeClusterDetailDatabases](https://cloud.tencent.com/document/api/1003/92734)
* [DescribeClusterPasswordComplexity](https://cloud.tencent.com/document/api/1003/92722)
* [DescribeInstanceParams](https://cloud.tencent.com/document/api/1003/92729)
* [DescribeParamTemplateDetail](https://cloud.tencent.com/document/api/1003/92728)
* [ModifyAccountDescription](https://cloud.tencent.com/document/api/1003/92716)
* [ModifyAccountHost](https://cloud.tencent.com/document/api/1003/92715)
* [ModifyAccountPrivileges](https://cloud.tencent.com/document/api/1003/92714)
* [ModifyBinlogSaveDays](https://cloud.tencent.com/document/api/1003/92725)
* [ModifyClusterDatabase](https://cloud.tencent.com/document/api/1003/92733)
* [ModifyClusterPasswordComplexity](https://cloud.tencent.com/document/api/1003/92721)
* [ModifyInstanceParam](https://cloud.tencent.com/document/api/1003/92727)
* [ModifyParamTemplate](https://cloud.tencent.com/document/api/1003/92726)
* [OpenClusterPasswordComplexity](https://cloud.tencent.com/document/api/1003/92720)
* [OpenWan](https://cloud.tencent.com/document/api/1003/92732)
* [UpgradeClusterVersion](https://cloud.tencent.com/document/api/1003/92719)

新增数据结构：

* [DbInfo](https://cloud.tencent.com/document/api/1003/48097#DbInfo)
* [InstanceParamItem](https://cloud.tencent.com/document/api/1003/48097#InstanceParamItem)
* [ParamDetail](https://cloud.tencent.com/document/api/1003/48097#ParamDetail)
* [ParamItemDetail](https://cloud.tencent.com/document/api/1003/48097#ParamItemDetail)
* [UserHostPrivilege](https://cloud.tencent.com/document/api/1003/48097#UserHostPrivilege)

### 第 52 次发布

发布时间：2023-05-11 01:17:45

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeInstanceErrorLogs](https://cloud.tencent.com/document/api/1003/90936)
* [ExportInstanceErrorLogs](https://cloud.tencent.com/document/api/1003/90935)

新增数据结构：

* [CynosdbErrorLogItem](https://cloud.tencent.com/document/api/1003/48097#CynosdbErrorLogItem)
* [ErrorLogItemExport](https://cloud.tencent.com/document/api/1003/48097#ErrorLogItemExport)

### 第 51 次发布

发布时间：2023-05-10 01:18:08

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [OpenReadOnlyInstanceExclusiveAccess](https://cloud.tencent.com/document/api/1003/90902)

### 第 50 次发布

发布时间：2023-05-09 01:13:44

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [NetAddr](https://cloud.tencent.com/document/api/1003/48097#NetAddr)

	* 新增成员：InstanceGroupId


### 第 49 次发布

发布时间：2023-03-20 01:19:56

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [AddInstances](https://cloud.tencent.com/document/api/1003/48088)

	* 新增入参：SecurityGroupIds


### 第 48 次发布

发布时间：2023-03-15 01:22:02

本次发布包含了以下内容：

改善已有的文档。

新增数据结构：

* [InstanceNetInfo](https://cloud.tencent.com/document/api/1003/48097#InstanceNetInfo)

修改数据结构：

* [CynosdbInstance](https://cloud.tencent.com/document/api/1003/48097#CynosdbInstance)

	* 新增成员：InstanceNetInfo


### 第 47 次发布

发布时间：2023-03-03 01:13:15

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [CynosdbInstance](https://cloud.tencent.com/document/api/1003/48097#CynosdbInstance)

	* 新增成员：MasterZone, SlaveZones


### 第 46 次发布

发布时间：2023-02-22 01:19:31

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [ModifyBackupConfig](https://cloud.tencent.com/document/api/1003/48090)

	* <font color="#dd0000">**修改入参**：</font>BackupTimeBeg, BackupTimeEnd


### 第 45 次发布

发布时间：2023-02-20 20:15:53

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [ModifyVipVport](https://cloud.tencent.com/document/api/1003/86720)

### 第 44 次发布

发布时间：2023-02-17 02:45:25

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [SwitchClusterVpc](https://cloud.tencent.com/document/api/1003/86634)

### 第 43 次发布

发布时间：2023-02-15 01:22:55

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeZones](https://cloud.tencent.com/document/api/1003/86547)

新增数据结构：

* [Module](https://cloud.tencent.com/document/api/1003/48097#Module)
* [SaleRegion](https://cloud.tencent.com/document/api/1003/48097#SaleRegion)
* [SaleZone](https://cloud.tencent.com/document/api/1003/48097#SaleZone)

### 第 42 次发布

发布时间：2023-02-07 01:22:36

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeFlow](https://cloud.tencent.com/document/api/1003/86162)

### 第 41 次发布

发布时间：2023-02-02 01:16:40

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [RestartInstance](https://cloud.tencent.com/document/api/1003/86028)

### 第 40 次发布

发布时间：2023-01-02 01:17:01

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CloseAuditService](https://cloud.tencent.com/document/api/1003/84703)
* [CreateAuditRuleTemplate](https://cloud.tencent.com/document/api/1003/84702)
* [DeleteAuditRuleTemplates](https://cloud.tencent.com/document/api/1003/84701)
* [DescribeAuditRuleTemplates](https://cloud.tencent.com/document/api/1003/84700)
* [DescribeAuditRuleWithInstanceIds](https://cloud.tencent.com/document/api/1003/84699)
* [ModifyAuditRuleTemplates](https://cloud.tencent.com/document/api/1003/84698)
* [ModifyAuditService](https://cloud.tencent.com/document/api/1003/84697)
* [OpenAuditService](https://cloud.tencent.com/document/api/1003/84696)

新增数据结构：

* [AuditRuleFilters](https://cloud.tencent.com/document/api/1003/48097#AuditRuleFilters)
* [AuditRuleTemplateInfo](https://cloud.tencent.com/document/api/1003/48097#AuditRuleTemplateInfo)
* [InstanceAuditRule](https://cloud.tencent.com/document/api/1003/48097#InstanceAuditRule)
* [OldAddrInfo](https://cloud.tencent.com/document/api/1003/48097#OldAddrInfo)
* [RuleFilters](https://cloud.tencent.com/document/api/1003/48097#RuleFilters)

修改数据结构：

* [CynosdbInstanceGrp](https://cloud.tencent.com/document/api/1003/48097#CynosdbInstanceGrp)

	* 新增成员：UniqVpcId, UniqSubnetId, OldAddrInfo, ProcessingTasks, Tasks, NetServiceId

	* <font color="#dd0000">**修改成员**：</font>AppId, ClusterId, CreatedTime, DeletedTime, InstanceGrpId, Status, Type, UpdatedTime, Vip, Vport, WanDomain, WanIP, WanPort, WanStatus, InstanceSet

* [InstanceSpec](https://cloud.tencent.com/document/api/1003/48097#InstanceSpec)

	* 新增成员：StockCount

* [ZoneStockInfo](https://cloud.tencent.com/document/api/1003/48097#ZoneStockInfo)

	* 新增成员：StockCount


### 第 39 次发布

发布时间：2022-12-30 01:18:47

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [AddInstances](https://cloud.tencent.com/document/api/1003/48088)

	* 新增入参：ParamTemplateId, InstanceParams

* [DeleteBackup](https://cloud.tencent.com/document/api/1003/82201)

	* 新增入参：BackupIds

	* <font color="#dd0000">**修改入参**：</font>SnapshotIdList

* [RollBackCluster](https://cloud.tencent.com/document/api/1003/70115)

	* 新增入参：RollbackMode


新增数据结构：

* [ModifyParamItem](https://cloud.tencent.com/document/api/1003/48097#ModifyParamItem)

### 第 38 次发布

发布时间：2022-12-29 10:16:58

本次发布包含了以下内容：

改善已有的文档。

新增数据结构：

* [Ability](https://cloud.tencent.com/document/api/1003/48097#Ability)

修改数据结构：

* [ClusterInstanceDetail](https://cloud.tencent.com/document/api/1003/48097#ClusterInstanceDetail)

	* 新增成员：InstanceRole

* [CynosdbCluster](https://cloud.tencent.com/document/api/1003/48097#CynosdbCluster)

	* 新增成员：PhysicalZone, MasterZone, HasSlaveZone, SlaveZones, BusinessType, IsFreeze, OrderSource, Ability

* [CynosdbClusterDetail](https://cloud.tencent.com/document/api/1003/48097#CynosdbClusterDetail)

	* 新增成员：LogBin, PitrType, PhysicalZone, StorageId, Storage, MaxStorageSize, MinStorageSize, StoragePayMode, DbMode, StorageLimit, Ability, CynosVersion, BusinessType, HasSlaveZone, IsFreeze, Tasks, MasterZone, SlaveZones, ProxyStatus, IsSkipTrade, IsOpenPasswordComplexity, NetworkStatus

* [NetAddr](https://cloud.tencent.com/document/api/1003/48097#NetAddr)

	* 新增成员：WanIP, WanStatus

* [NewAccount](https://cloud.tencent.com/document/api/1003/48097#NewAccount)

	* 新增成员：MaxUserConnections


### 第 37 次发布

发布时间：2022-12-23 01:24:17

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateClusters](https://cloud.tencent.com/document/api/1003/48087)

	* 新增入参：InstanceInitInfos


新增数据结构：

* [InstanceInitInfo](https://cloud.tencent.com/document/api/1003/48097#InstanceInitInfo)

### 第 36 次发布

发布时间：2022-12-15 01:20:30

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeAccounts](https://cloud.tencent.com/document/api/1003/48075)

	* 新增入参：Hosts, Limit, Offset

	* 新增出参：TotalCount

* [DescribeBackupList](https://cloud.tencent.com/document/api/1003/48093)

	* 新增入参：SnapshotIdList

* [DescribeClusterParams](https://cloud.tencent.com/document/api/1003/79556)

	* 新增入参：ParamName

* [DescribeProjectSecurityGroups](https://cloud.tencent.com/document/api/1003/48304)

	* 新增入参：Limit, Offset, SearchKey

	* <font color="#dd0000">**修改入参**：</font>ProjectId

	* 新增出参：Total


### 第 35 次发布

发布时间：2022-12-08 01:24:51

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeClusterParamLogs](https://cloud.tencent.com/document/api/1003/70118)

	* 新增入参：InstanceIds, OrderBy, OrderByType


### 第 34 次发布

发布时间：2022-12-07 06:32:17

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [UpgradeInstance](https://cloud.tencent.com/document/api/1003/48077)

	* 新增入参：UpgradeMode


修改数据结构：

* [AuditLogFilter](https://cloud.tencent.com/document/api/1003/48097#AuditLogFilter)

	* 新增成员：SentRows, ThreadId

* [ClusterParamModifyLog](https://cloud.tencent.com/document/api/1003/48097#ClusterParamModifyLog)

	* 新增成员：ClusterId, InstanceId


### 第 33 次发布

发布时间：2022-12-06 06:33:40

本次发布包含了以下内容：

改善已有的文档。

新增数据结构：

* [ModifiableInfo](https://cloud.tencent.com/document/api/1003/48097#ModifiableInfo)

修改数据结构：

* [Account](https://cloud.tencent.com/document/api/1003/48097#Account)

	* 新增成员：MaxUserConnections

* [CynosdbInstance](https://cloud.tencent.com/document/api/1003/48097#CynosdbInstance)

	* 新增成员：PhysicalZone, BusinessType, Tasks, IsFreeze, ResourceTags

* [ParamInfo](https://cloud.tencent.com/document/api/1003/48097#ParamInfo)

	* 新增成员：IsGlobal, ModifiableInfo, IsFunc, Func


### 第 32 次发布

发布时间：2022-12-05 06:38:55

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [ResetAccountPassword](https://cloud.tencent.com/document/api/1003/83592)
* [SearchClusterDatabases](https://cloud.tencent.com/document/api/1003/83594)
* [SearchClusterTables](https://cloud.tencent.com/document/api/1003/83593)
* [SwitchProxyVpc](https://cloud.tencent.com/document/api/1003/83595)

### 第 31 次发布

发布时间：2022-11-23 06:21:08

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeParamTemplates](https://cloud.tencent.com/document/api/1003/77805)

	* 新增入参：EngineVersions, TemplateNames, TemplateIds, DbModes, Offset, Limit, Products, TemplateTypes, EngineTypes, OrderBy, OrderDirection


新增数据结构：

* [TemplateParamInfo](https://cloud.tencent.com/document/api/1003/48097#TemplateParamInfo)

修改数据结构：

* [ParamTemplateListInfo](https://cloud.tencent.com/document/api/1003/48097#ParamTemplateListInfo)

	* 新增成员：DbMode, ParamInfoSet


### 第 30 次发布

发布时间：2022-11-01 06:21:27

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DeleteBackup](https://cloud.tencent.com/document/api/1003/82201)

### 第 29 次发布

发布时间：2022-10-14 14:46:49

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateAuditLogFile](https://cloud.tencent.com/document/api/1003/81440)
* [DeleteAuditLogFile](https://cloud.tencent.com/document/api/1003/81439)
* [DescribeAuditLogFiles](https://cloud.tencent.com/document/api/1003/81438)
* [DescribeAuditLogs](https://cloud.tencent.com/document/api/1003/81437)

新增数据结构：

* [AuditLog](https://cloud.tencent.com/document/api/1003/48097#AuditLog)
* [AuditLogFile](https://cloud.tencent.com/document/api/1003/48097#AuditLogFile)
* [AuditLogFilter](https://cloud.tencent.com/document/api/1003/48097#AuditLogFilter)

### 第 28 次发布

发布时间：2022-10-14 06:23:27

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [QueryFilter](https://cloud.tencent.com/document/api/1003/48097#QueryFilter)

	* 新增成员：Operator


### 第 27 次发布

发布时间：2022-09-14 06:18:19

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeBackupList](https://cloud.tencent.com/document/api/1003/48093)

	* 新增入参：BackupIds, BackupType, BackupMethod, SnapShotType, StartTime, EndTime, FileNames, BackupNames

	* <font color="#dd0000">**修改入参**：</font>Limit, Offset


修改数据结构：

* [BackupFileInfo](https://cloud.tencent.com/document/api/1003/48097#BackupFileInfo)

	* 新增成员：BackupId, SnapShotType, BackupName


### 第 26 次发布

发布时间：2022-09-08 06:19:30

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [ModifyClusterStorage](https://cloud.tencent.com/document/api/1003/80282)

### 第 25 次发布

发布时间：2022-09-07 06:23:00

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateBackup](https://cloud.tencent.com/document/api/1003/80212)

新增数据结构：

* [DatabaseTables](https://cloud.tencent.com/document/api/1003/48097#DatabaseTables)

### 第 24 次发布

发布时间：2022-08-30 06:23:54

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeInstanceSpecs](https://cloud.tencent.com/document/api/1003/48084)

	* 新增入参：IncludeZoneStocks


新增数据结构：

* [ZoneStockInfo](https://cloud.tencent.com/document/api/1003/48097#ZoneStockInfo)

修改数据结构：

* [InstanceSpec](https://cloud.tencent.com/document/api/1003/48097#InstanceSpec)

	* 新增成员：HasStock, MachineType, MaxIops, MaxIoBandWidth, ZoneStockInfos


### 第 23 次发布

发布时间：2022-08-25 06:22:53

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [AddClusterSlaveZone](https://cloud.tencent.com/document/api/1003/79555)
* [DescribeClusterParams](https://cloud.tencent.com/document/api/1003/79556)
* [ModifyClusterSlaveZone](https://cloud.tencent.com/document/api/1003/79554)
* [RemoveClusterSlaveZone](https://cloud.tencent.com/document/api/1003/79553)
* [SwitchClusterZone](https://cloud.tencent.com/document/api/1003/79552)

修改接口：

* [DescribeRollbackTimeRange](https://cloud.tencent.com/document/api/1003/48092)

	* 新增出参：RollbackTimeRanges


新增数据结构：

* [ParamInfo](https://cloud.tencent.com/document/api/1003/48097#ParamInfo)
* [RollbackTimeRange](https://cloud.tencent.com/document/api/1003/48097#RollbackTimeRange)

### 第 22 次发布

发布时间：2022-08-16 06:18:39

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [NetAddr](https://cloud.tencent.com/document/api/1003/48097#NetAddr)

	* 新增成员：UniqSubnetId, UniqVpcId, Description


### 第 21 次发布

发布时间：2022-07-26 06:12:54

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeParamTemplates](https://cloud.tencent.com/document/api/1003/77805)
* [InquirePriceRenew](https://cloud.tencent.com/document/api/1003/77804)

新增数据结构：

* [ParamTemplateListInfo](https://cloud.tencent.com/document/api/1003/48097#ParamTemplateListInfo)

### 第 20 次发布

发布时间：2022-07-25 06:06:31

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [InquirePriceCreate](https://cloud.tencent.com/document/api/1003/77738)

新增数据结构：

* [TradePrice](https://cloud.tencent.com/document/api/1003/48097#TradePrice)

### 第 19 次发布

发布时间：2022-07-12 06:09:05

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateClusters](https://cloud.tencent.com/document/api/1003/48087)

	* 新增入参：SlaveZone

* [DescribeResourcesByDealName](https://cloud.tencent.com/document/api/1003/52131)

	* 新增入参：DealNames

	* <font color="#dd0000">**修改入参**：</font>DealName


### 第 18 次发布

发布时间：2022-07-11 06:10:21

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [BillingResourceInfo](https://cloud.tencent.com/document/api/1003/48097#BillingResourceInfo)

	* 新增成员：DealName


### 第 17 次发布

发布时间：2022-07-04 06:07:00

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeBackupDownloadUrl](https://cloud.tencent.com/document/api/1003/76374)
* [DescribeBinlogDownloadUrl](https://cloud.tencent.com/document/api/1003/76373)
* [DescribeBinlogSaveDays](https://cloud.tencent.com/document/api/1003/76372)
* [DescribeBinlogs](https://cloud.tencent.com/document/api/1003/76371)
* [DescribeInstanceSlowQueries](https://cloud.tencent.com/document/api/1003/76369)
* [ExportInstanceSlowQueries](https://cloud.tencent.com/document/api/1003/76368)
* [ModifyBackupName](https://cloud.tencent.com/document/api/1003/76370)

新增数据结构：

* [BinlogItem](https://cloud.tencent.com/document/api/1003/48097#BinlogItem)
* [SlowQueriesItem](https://cloud.tencent.com/document/api/1003/48097#SlowQueriesItem)

### 第 16 次发布

发布时间：2022-03-29 08:08:26

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [ModifyClusterName](https://cloud.tencent.com/document/api/1003/71729)
* [ModifyInstanceName](https://cloud.tencent.com/document/api/1003/71728)

### 第 15 次发布

发布时间：2022-03-24 17:50:45

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateAccounts](https://cloud.tencent.com/document/api/1003/71660)

新增数据结构：

* [NewAccount](https://cloud.tencent.com/document/api/1003/48097#NewAccount)

### 第 14 次发布

发布时间：2022-02-18 08:07:59

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [ActivateInstance](https://cloud.tencent.com/document/api/1003/70116)
* [AssociateSecurityGroups](https://cloud.tencent.com/document/api/1003/70119)
* [DescribeAccountAllGrantPrivileges](https://cloud.tencent.com/document/api/1003/70114)
* [DescribeClusterParamLogs](https://cloud.tencent.com/document/api/1003/70118)
* [DisassociateSecurityGroups](https://cloud.tencent.com/document/api/1003/70117)
* [GrantAccountPrivileges](https://cloud.tencent.com/document/api/1003/70113)
* [ModifyAccountParams](https://cloud.tencent.com/document/api/1003/70112)
* [PauseServerless](https://cloud.tencent.com/document/api/1003/70122)
* [ResumeServerless](https://cloud.tencent.com/document/api/1003/70121)
* [RevokeAccountPrivileges](https://cloud.tencent.com/document/api/1003/70111)
* [RollBackCluster](https://cloud.tencent.com/document/api/1003/70115)

修改接口：

* [ModifyClusterParam](https://cloud.tencent.com/document/api/1003/63365)

	* 新增入参：IsInMaintainPeriod


新增数据结构：

* [AccountParam](https://cloud.tencent.com/document/api/1003/48097#AccountParam)
* [ClusterParamModifyLog](https://cloud.tencent.com/document/api/1003/48097#ClusterParamModifyLog)
* [DatabasePrivileges](https://cloud.tencent.com/document/api/1003/48097#DatabasePrivileges)
* [DbTable](https://cloud.tencent.com/document/api/1003/48097#DbTable)
* [InputAccount](https://cloud.tencent.com/document/api/1003/48097#InputAccount)
* [RollbackDatabase](https://cloud.tencent.com/document/api/1003/48097#RollbackDatabase)
* [RollbackTable](https://cloud.tencent.com/document/api/1003/48097#RollbackTable)
* [RollbackTableInfo](https://cloud.tencent.com/document/api/1003/48097#RollbackTableInfo)
* [TablePrivileges](https://cloud.tencent.com/document/api/1003/48097#TablePrivileges)

### 第 13 次发布

发布时间：2021-10-27 08:06:08

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [ModifyClusterParam](https://cloud.tencent.com/document/api/1003/63365)

### 第 12 次发布

发布时间：2021-10-26 11:55:38

本次发布包含了以下内容：

改善已有的文档。

新增数据结构：

* [NetAddr](https://cloud.tencent.com/document/api/1003/48097#NetAddr)

修改数据结构：

* [CynosdbCluster](https://cloud.tencent.com/document/api/1003/48097#CynosdbCluster)

	* 新增成员：NetAddrs


### 第 11 次发布

发布时间：2021-10-12 08:04:56

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [AddInstances](https://cloud.tencent.com/document/api/1003/48088)

	* 新增入参：DealMode

* [CreateClusters](https://cloud.tencent.com/document/api/1003/48087)

	* 新增入参：SecurityGroupIds, AlarmPolicyIds, ClusterParams, DealMode, ParamTemplateId

* [UpgradeInstance](https://cloud.tencent.com/document/api/1003/48077)

	* 新增入参：DealMode


新增数据结构：

* [ParamItem](https://cloud.tencent.com/document/api/1003/48097#ParamItem)

### 第 10 次发布

发布时间：2021-07-12 08:01:28

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateClusters](https://cloud.tencent.com/document/api/1003/48087)

	* 新增入参：StoragePayMode

* [DescribeBackupList](https://cloud.tencent.com/document/api/1003/48093)

	* 新增入参：DbType


修改数据结构：

* [CynosdbCluster](https://cloud.tencent.com/document/api/1003/48097#CynosdbCluster)

	* 新增成员：Storage, StorageId, StoragePayMode, MinStorageSize, MaxStorageSize

* [CynosdbInstance](https://cloud.tencent.com/document/api/1003/48097#CynosdbInstance)

	* 新增成员：StoragePayMode, StorageId

* [CynosdbInstanceDetail](https://cloud.tencent.com/document/api/1003/48097#CynosdbInstanceDetail)

	* 新增成员：MinCpu, MaxCpu, ServerlessStatus


### 第 9 次发布

发布时间：2021-05-31 08:01:04

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [CynosdbClusterDetail](https://cloud.tencent.com/document/api/1003/48097#CynosdbClusterDetail)

	* 新增成员：ServerlessStatus


### 第 8 次发布

发布时间：2021-01-18 08:00:35

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeResourcesByDealName](https://cloud.tencent.com/document/api/1003/52131)

新增数据结构：

* [BillingResourceInfo](https://cloud.tencent.com/document/api/1003/48097#BillingResourceInfo)

### 第 7 次发布

发布时间：2020-12-25 08:00:23

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateClusters](https://cloud.tencent.com/document/api/1003/48087)

	* <font color="#dd0000">**修改入参**：</font>Cpu, Memory, StorageLimit


### 第 6 次发布

发布时间：2020-12-10 08:00:20

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateClusters](https://cloud.tencent.com/document/api/1003/48087)

	* 新增入参：DbMode, MinCpu, MaxCpu, AutoPause, AutoPauseDelay


修改数据结构：

* [CynosdbCluster](https://cloud.tencent.com/document/api/1003/48097#CynosdbCluster)

	* 新增成员：DbMode, ServerlessStatus

* [CynosdbInstance](https://cloud.tencent.com/document/api/1003/48097#CynosdbInstance)

	* 新增成员：MinCpu, MaxCpu, ServerlessStatus


### 第 5 次发布

发布时间：2020-09-23 08:00:10

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateClusters](https://cloud.tencent.com/document/api/1003/48087)

	* 新增入参：ResourceTags


新增数据结构：

* [Tag](https://cloud.tencent.com/document/api/1003/48097#Tag)

修改数据结构：

* [CynosdbCluster](https://cloud.tencent.com/document/api/1003/48097#CynosdbCluster)

	* 新增成员：ResourceTags

* [CynosdbClusterDetail](https://cloud.tencent.com/document/api/1003/48097#CynosdbClusterDetail)

	* 新增成员：ResourceTags


### 第 4 次发布

发布时间：2020-09-15 08:00:04

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeInstances](https://cloud.tencent.com/document/api/1003/48334)

### 第 3 次发布

发布时间：2020-09-11 08:00:04

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeClusterInstanceGrps](https://cloud.tencent.com/document/api/1003/48303)
* [DescribeDBSecurityGroups](https://cloud.tencent.com/document/api/1003/48305)
* [DescribeProjectSecurityGroups](https://cloud.tencent.com/document/api/1003/48304)

新增数据结构：

* [CynosdbInstance](https://cloud.tencent.com/document/api/1003/48097#CynosdbInstance)
* [CynosdbInstanceGrp](https://cloud.tencent.com/document/api/1003/48097#CynosdbInstanceGrp)
* [PolicyRule](https://cloud.tencent.com/document/api/1003/48097#PolicyRule)
* [SecurityGroup](https://cloud.tencent.com/document/api/1003/48097#SecurityGroup)

### 第 2 次发布

发布时间：2020-09-10 08:00:12

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeInstanceDetail](https://cloud.tencent.com/document/api/1003/48250)
* [OfflineInstance](https://cloud.tencent.com/document/api/1003/48249)

新增数据结构：

* [CynosdbInstanceDetail](https://cloud.tencent.com/document/api/1003/48097#CynosdbInstanceDetail)

### 第 1 次发布

发布时间：2020-09-03 20:28:44

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [AddInstances](https://cloud.tencent.com/document/api/1003/48088)
* [CreateClusters](https://cloud.tencent.com/document/api/1003/48087)
* [DescribeAccounts](https://cloud.tencent.com/document/api/1003/48075)
* [DescribeBackupConfig](https://cloud.tencent.com/document/api/1003/48094)
* [DescribeBackupList](https://cloud.tencent.com/document/api/1003/48093)
* [DescribeClusterDetail](https://cloud.tencent.com/document/api/1003/48086)
* [DescribeClusters](https://cloud.tencent.com/document/api/1003/48085)
* [DescribeInstanceSpecs](https://cloud.tencent.com/document/api/1003/48084)
* [DescribeMaintainPeriod](https://cloud.tencent.com/document/api/1003/48083)
* [DescribeRollbackTimeRange](https://cloud.tencent.com/document/api/1003/48092)
* [DescribeRollbackTimeValidity](https://cloud.tencent.com/document/api/1003/48091)
* [IsolateCluster](https://cloud.tencent.com/document/api/1003/48082)
* [IsolateInstance](https://cloud.tencent.com/document/api/1003/48081)
* [ModifyBackupConfig](https://cloud.tencent.com/document/api/1003/48090)
* [ModifyDBInstanceSecurityGroups](https://cloud.tencent.com/document/api/1003/48096)
* [ModifyMaintainPeriodConfig](https://cloud.tencent.com/document/api/1003/48080)
* [OfflineCluster](https://cloud.tencent.com/document/api/1003/48079)
* [SetRenewFlag](https://cloud.tencent.com/document/api/1003/48078)
* [UpgradeInstance](https://cloud.tencent.com/document/api/1003/48077)

新增数据结构：

* [Account](https://cloud.tencent.com/document/api/1003/48097#Account)
* [Addr](https://cloud.tencent.com/document/api/1003/48097#Addr)
* [BackupFileInfo](https://cloud.tencent.com/document/api/1003/48097#BackupFileInfo)
* [ClusterInstanceDetail](https://cloud.tencent.com/document/api/1003/48097#ClusterInstanceDetail)
* [CynosdbCluster](https://cloud.tencent.com/document/api/1003/48097#CynosdbCluster)
* [CynosdbClusterDetail](https://cloud.tencent.com/document/api/1003/48097#CynosdbClusterDetail)
* [InstanceSpec](https://cloud.tencent.com/document/api/1003/48097#InstanceSpec)
* [ObjectTask](https://cloud.tencent.com/document/api/1003/48097#ObjectTask)
* [QueryFilter](https://cloud.tencent.com/document/api/1003/48097#QueryFilter)




## 运维安全中心（堡垒机）(dasb) 版本：2019-10-18

### 第 27 次发布

发布时间：2024-05-31 01:30:02

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [BindDeviceResource](https://cloud.tencent.com/document/api/1025/74792)

	* 新增入参：DomainId

* [ModifyDevice](https://cloud.tencent.com/document/api/1025/86951)

	* 新增入参：DomainId


修改数据结构：

* [Department](https://cloud.tencent.com/document/api/1025/74416#Department)

	* <font color="#dd0000">**修改成员**：</font>Id, Name, Managers, ManagerUsers

* [Device](https://cloud.tencent.com/document/api/1025/74416#Device)

	* 新增成员：DomainId, DomainName

* [Group](https://cloud.tencent.com/document/api/1025/74416#Group)

	* <font color="#dd0000">**修改成员**：</font>Id, Name, Department, Count

* [Resource](https://cloud.tencent.com/document/api/1025/74416#Resource)

	* 新增成员：DomainCount, UsedDomainCount


### 第 26 次发布

发布时间：2024-05-29 01:29:52

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeResources](https://cloud.tencent.com/document/api/1025/74801)

	* 新增入参：Limit, Offset

	* 新增出参：TotalCount


新增数据结构：

* [Clb](https://cloud.tencent.com/document/api/1025/74416#Clb)

修改数据结构：

* [Resource](https://cloud.tencent.com/document/api/1025/74416#Resource)

	* 新增成员：ClbSet


### 第 25 次发布

发布时间：2024-05-27 01:29:56

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateChangePwdTask](https://cloud.tencent.com/document/api/1025/106579)
* [DeleteChangePwdTask](https://cloud.tencent.com/document/api/1025/106578)
* [DescribeChangePwdTask](https://cloud.tencent.com/document/api/1025/106577)
* [DescribeChangePwdTaskDetail](https://cloud.tencent.com/document/api/1025/106576)
* [ModifyChangePwdTask](https://cloud.tencent.com/document/api/1025/106575)
* [RunChangePwdTask](https://cloud.tencent.com/document/api/1025/106574)

新增数据结构：

* [ChangePwdTaskDetail](https://cloud.tencent.com/document/api/1025/74416#ChangePwdTaskDetail)
* [ChangePwdTaskInfo](https://cloud.tencent.com/document/api/1025/74416#ChangePwdTaskInfo)
* [RunChangePwdTaskDetail](https://cloud.tencent.com/document/api/1025/74416#RunChangePwdTaskDetail)

### 第 24 次发布

发布时间：2024-03-07 01:13:28

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [ModifyOAuthSetting](https://cloud.tencent.com/document/api/1025/104132)

### 第 23 次发布

发布时间：2024-01-24 01:26:26

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [Acl](https://cloud.tencent.com/document/api/1025/74416#Acl)

	* 新增成员：WhiteCmds

* [User](https://cloud.tencent.com/document/api/1025/74416#User)

	* 新增成员：AclVersion


### 第 22 次发布

发布时间：2024-01-17 01:12:30

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DeployResource](https://cloud.tencent.com/document/api/1025/86961)

	* 新增入参：CdcClusterId


### 第 21 次发布

发布时间：2024-01-05 01:13:10

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [Command](https://cloud.tencent.com/document/api/1025/74416#Command)

	* 新增成员：Size

* [SearchCommandResult](https://cloud.tencent.com/document/api/1025/74416#SearchCommandResult)

	* 新增成员：Size


### 第 20 次发布

发布时间：2023-11-16 01:14:38

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [ModifyUserGroup](https://cloud.tencent.com/document/api/1025/101605)

### 第 19 次发布

发布时间：2023-11-09 01:11:47

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateResource](https://cloud.tencent.com/document/api/1025/100130)

	* 新增出参：ResourceId

* [ImportExternalDevice](https://cloud.tencent.com/document/api/1025/86967)

	* 新增出参：DeviceIdSet


修改数据结构：

* [Command](https://cloud.tencent.com/document/api/1025/74416#Command)

	* 新增成员：SessionTime

	* <font color="#dd0000">**修改成员**：</font>Sid, UserName, Account, InstanceId, FromIp, SessTime, ConfirmTime, UserDepartmentId, UserDepartmentName, DeviceDepartmentId, DeviceDepartmentName

* [SearchCommandResult](https://cloud.tencent.com/document/api/1025/74416#SearchCommandResult)

	* 新增成员：SessionTime

	* <font color="#dd0000">**修改成员**：</font>Account, FromIp, SessTime, ConfirmTime, UserDepartmentId, UserDepartmentName, DeviceDepartmentId, DeviceDepartmentName


### 第 18 次发布

发布时间：2023-10-12 01:46:01

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateResource](https://cloud.tencent.com/document/api/1025/100130)

	* 新增入参：DeployRegion, ResourceEdition, ResourceNode, TimeUnit, TimeSpan, PayMode, AutoRenewFlag, DeployZone


### 第 17 次发布

发布时间：2023-10-11 01:37:08

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateResource](https://cloud.tencent.com/document/api/1025/100130)
* [ModifyResource](https://cloud.tencent.com/document/api/1025/100129)

### 第 16 次发布

发布时间：2023-09-20 01:33:17

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [ModifyCmdTemplate](https://cloud.tencent.com/document/api/1025/98702)

### 第 15 次发布

发布时间：2023-08-16 01:19:34

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateAcl](https://cloud.tencent.com/document/api/1025/74411)

	* 新增入参：AllowAccessCredential

* [DescribeUsers](https://cloud.tencent.com/document/api/1025/74404)

	* 新增入参：Filters

* [ModifyAcl](https://cloud.tencent.com/document/api/1025/74408)

	* 新增入参：AllowAccessCredential


新增数据结构：

* [ACTemplate](https://cloud.tencent.com/document/api/1025/74416#ACTemplate)
* [DepartmentManagerUser](https://cloud.tencent.com/document/api/1025/74416#DepartmentManagerUser)

修改数据结构：

* [Acl](https://cloud.tencent.com/document/api/1025/74416#Acl)

	* 新增成员：AllowAccessCredential, ACTemplateSet

* [Department](https://cloud.tencent.com/document/api/1025/74416#Department)

	* 新增成员：ManagerUsers

* [User](https://cloud.tencent.com/document/api/1025/74416#User)

	* 新增成员：ActiveStatus, LockStatus, Status


### 第 14 次发布

发布时间：2023-08-08 01:15:01

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeDevices](https://cloud.tencent.com/document/api/1025/74415)

	* 新增入参：ManagedAccount


### 第 13 次发布

发布时间：2023-08-02 01:13:55

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [Device](https://cloud.tencent.com/document/api/1025/74416#Device)

	* 新增成员：IpPortSet

* [ExternalDevice](https://cloud.tencent.com/document/api/1025/74416#ExternalDevice)

	* 新增成员：IpPortSet

* [Resource](https://cloud.tencent.com/document/api/1025/74416#Resource)

	* <font color="#dd0000">**修改成员**：</font>LogDeliveryArgs


### 第 12 次发布

发布时间：2023-07-07 01:21:45

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateUser](https://cloud.tencent.com/document/api/1025/74406)

	* <font color="#dd0000">**修改入参**：</font>Phone

* [DescribeUsers](https://cloud.tencent.com/document/api/1025/74404)

	* 新增入参：Email

* [ModifyUser](https://cloud.tencent.com/document/api/1025/74403)

	* <font color="#dd0000">**修改入参**：</font>Phone, Email


修改数据结构：

* [User](https://cloud.tencent.com/document/api/1025/74416#User)

	* <font color="#dd0000">**修改成员**：</font>Phone


### 第 11 次发布

发布时间：2023-05-12 01:18:05

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateAcl](https://cloud.tencent.com/document/api/1025/74411)

	* 新增入参：ACTemplateIdSet

* [ModifyAcl](https://cloud.tencent.com/document/api/1025/74408)

	* 新增入参：ACTemplateIdSet


### 第 10 次发布

发布时间：2023-04-28 01:18:09

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateCmdTemplate](https://cloud.tencent.com/document/api/1025/86964)

	* 新增入参：Encoding

* [SearchCommand](https://cloud.tencent.com/document/api/1025/90045)

	* 新增入参：Encoding

* [SearchCommandBySid](https://cloud.tencent.com/document/api/1025/90044)

	* 新增入参：Encoding

* [SearchSessionCommand](https://cloud.tencent.com/document/api/1025/90040)

	* 新增入参：Encoding


修改数据结构：

* [Command](https://cloud.tencent.com/document/api/1025/74416#Command)

	* 新增成员：Sid, UserName, Account, InstanceId, FromIp, SessTime, ConfirmTime, UserDepartmentId, UserDepartmentName, DeviceDepartmentId, DeviceDepartmentName

* [SearchCommandResult](https://cloud.tencent.com/document/api/1025/74416#SearchCommandResult)

	* 新增成员：Account, FromIp, SessTime, ConfirmTime, UserDepartmentId, UserDepartmentName, DeviceDepartmentId, DeviceDepartmentName


### 第 9 次发布

发布时间：2023-04-11 01:14:47

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeLoginEvent](https://cloud.tencent.com/document/api/1025/90039)
* [DescribeOperationEvent](https://cloud.tencent.com/document/api/1025/90038)
* [SearchAuditLog](https://cloud.tencent.com/document/api/1025/90046)
* [SearchCommand](https://cloud.tencent.com/document/api/1025/90045)
* [SearchCommandBySid](https://cloud.tencent.com/document/api/1025/90044)
* [SearchFile](https://cloud.tencent.com/document/api/1025/90043)
* [SearchFileBySid](https://cloud.tencent.com/document/api/1025/90042)
* [SearchSession](https://cloud.tencent.com/document/api/1025/90041)
* [SearchSessionCommand](https://cloud.tencent.com/document/api/1025/90040)

新增数据结构：

* [AuditLogResult](https://cloud.tencent.com/document/api/1025/74416#AuditLogResult)
* [Command](https://cloud.tencent.com/document/api/1025/74416#Command)
* [LoginEvent](https://cloud.tencent.com/document/api/1025/74416#LoginEvent)
* [OperationEvent](https://cloud.tencent.com/document/api/1025/74416#OperationEvent)
* [SearchCommandResult](https://cloud.tencent.com/document/api/1025/74416#SearchCommandResult)
* [SearchFileBySidResult](https://cloud.tencent.com/document/api/1025/74416#SearchFileBySidResult)
* [SearchFileResult](https://cloud.tencent.com/document/api/1025/74416#SearchFileResult)
* [SearchFileTypeFilter](https://cloud.tencent.com/document/api/1025/74416#SearchFileTypeFilter)
* [SessionCommand](https://cloud.tencent.com/document/api/1025/74416#SessionCommand)
* [SessionResult](https://cloud.tencent.com/document/api/1025/74416#SessionResult)

### 第 8 次发布

发布时间：2023-03-20 01:20:40

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [Resource](https://cloud.tencent.com/document/api/1025/74416#Resource)

	* 新增成员：LogDeliveryArgs


### 第 7 次发布

发布时间：2023-02-27 17:21:05

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [ImportExternalDevice](https://cloud.tencent.com/document/api/1025/86967)

新增数据结构：

* [ExternalDevice](https://cloud.tencent.com/document/api/1025/74416#ExternalDevice)

### 第 6 次发布

发布时间：2023-02-27 16:50:43

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [BindDeviceAccountPassword](https://cloud.tencent.com/document/api/1025/86959)
* [BindDeviceAccountPrivateKey](https://cloud.tencent.com/document/api/1025/86958)
* [CreateAssetSyncJob](https://cloud.tencent.com/document/api/1025/86957)
* [CreateCmdTemplate](https://cloud.tencent.com/document/api/1025/86964)
* [CreateDeviceAccount](https://cloud.tencent.com/document/api/1025/86956)
* [DeleteCmdTemplates](https://cloud.tencent.com/document/api/1025/86963)
* [DeleteDeviceAccounts](https://cloud.tencent.com/document/api/1025/86955)
* [DeleteDevices](https://cloud.tencent.com/document/api/1025/86954)
* [DeployResource](https://cloud.tencent.com/document/api/1025/86961)
* [DescribeAssetSyncStatus](https://cloud.tencent.com/document/api/1025/86953)
* [DescribeCmdTemplates](https://cloud.tencent.com/document/api/1025/86962)
* [DescribeDeviceAccounts](https://cloud.tencent.com/document/api/1025/86952)
* [ModifyDevice](https://cloud.tencent.com/document/api/1025/86951)
* [ModifyDeviceGroup](https://cloud.tencent.com/document/api/1025/86966)
* [ResetDeviceAccountPassword](https://cloud.tencent.com/document/api/1025/86950)
* [ResetDeviceAccountPrivateKey](https://cloud.tencent.com/document/api/1025/86949)
* [ResetUser](https://cloud.tencent.com/document/api/1025/86960)

新增数据结构：

* [AssetSyncStatus](https://cloud.tencent.com/document/api/1025/74416#AssetSyncStatus)
* [DeviceAccount](https://cloud.tencent.com/document/api/1025/74416#DeviceAccount)

### 第 5 次发布

发布时间：2023-02-07 01:23:16

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeDevices](https://cloud.tencent.com/document/api/1025/74415)

	* 新增入参：Filters


新增数据结构：

* [Filter](https://cloud.tencent.com/document/api/1025/74416#Filter)

修改数据结构：

* [Group](https://cloud.tencent.com/document/api/1025/74416#Group)

	* 新增成员：Count


### 第 4 次发布

发布时间：2022-11-03 06:19:23

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeDeviceGroupMembers](https://cloud.tencent.com/document/api/1025/74787)

	* 新增入参：TagFilters

* [DescribeDevices](https://cloud.tencent.com/document/api/1025/74415)

	* 新增入参：TagFilters


新增数据结构：

* [TagFilter](https://cloud.tencent.com/document/api/1025/74416#TagFilter)

### 第 3 次发布

发布时间：2022-08-16 06:19:02

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateAcl](https://cloud.tencent.com/document/api/1025/74411)

	* 新增入参：DepartmentId

* [CreateDeviceGroup](https://cloud.tencent.com/document/api/1025/74790)

	* 新增入参：DepartmentId

* [CreateUser](https://cloud.tencent.com/document/api/1025/74406)

	* 新增入参：DepartmentId

* [CreateUserGroup](https://cloud.tencent.com/document/api/1025/74798)

	* 新增入参：DepartmentId

* [DescribeAcls](https://cloud.tencent.com/document/api/1025/74409)

	* 新增入参：DepartmentId

* [DescribeDeviceGroupMembers](https://cloud.tencent.com/document/api/1025/74787)

	* 新增入参：DepartmentId

* [DescribeDeviceGroups](https://cloud.tencent.com/document/api/1025/74786)

	* 新增入参：DepartmentId

* [DescribeDevices](https://cloud.tencent.com/document/api/1025/74415)

	* 新增入参：DepartmentId

* [DescribeUserGroupMembers](https://cloud.tencent.com/document/api/1025/74795)

	* 新增入参：DepartmentId

* [DescribeUserGroups](https://cloud.tencent.com/document/api/1025/74794)

	* 新增入参：DepartmentId

* [DescribeUsers](https://cloud.tencent.com/document/api/1025/74404)

	* 新增入参：DepartmentId

* [ModifyAcl](https://cloud.tencent.com/document/api/1025/74408)

	* 新增入参：DepartmentId

* [ModifyUser](https://cloud.tencent.com/document/api/1025/74403)

	* 新增入参：DepartmentId


新增数据结构：

* [Department](https://cloud.tencent.com/document/api/1025/74416#Department)

修改数据结构：

* [Acl](https://cloud.tencent.com/document/api/1025/74416#Acl)

	* 新增成员：Department

* [Device](https://cloud.tencent.com/document/api/1025/74416#Device)

	* 新增成员：Department

* [Group](https://cloud.tencent.com/document/api/1025/74416#Group)

	* 新增成员：Department

* [User](https://cloud.tencent.com/document/api/1025/74416#User)

	* 新增成员：Department, DepartmentId


### 第 2 次发布

发布时间：2022-06-01 20:56:43

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [AddDeviceGroupMembers](https://cloud.tencent.com/document/api/1025/74791)
* [AddUserGroupMembers](https://cloud.tencent.com/document/api/1025/74799)
* [BindDeviceResource](https://cloud.tencent.com/document/api/1025/74792)
* [CreateDeviceGroup](https://cloud.tencent.com/document/api/1025/74790)
* [CreateUserGroup](https://cloud.tencent.com/document/api/1025/74798)
* [DeleteDeviceGroupMembers](https://cloud.tencent.com/document/api/1025/74789)
* [DeleteDeviceGroups](https://cloud.tencent.com/document/api/1025/74788)
* [DeleteUserGroupMembers](https://cloud.tencent.com/document/api/1025/74797)
* [DeleteUserGroups](https://cloud.tencent.com/document/api/1025/74796)
* [DescribeDeviceGroupMembers](https://cloud.tencent.com/document/api/1025/74787)
* [DescribeDeviceGroups](https://cloud.tencent.com/document/api/1025/74786)
* [DescribeResources](https://cloud.tencent.com/document/api/1025/74801)
* [DescribeUserGroupMembers](https://cloud.tencent.com/document/api/1025/74795)
* [DescribeUserGroups](https://cloud.tencent.com/document/api/1025/74794)

### 第 1 次发布

发布时间：2022-05-25 11:33:45

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateAcl](https://cloud.tencent.com/document/api/1025/74411)
* [CreateUser](https://cloud.tencent.com/document/api/1025/74406)
* [DeleteAcls](https://cloud.tencent.com/document/api/1025/74410)
* [DeleteUsers](https://cloud.tencent.com/document/api/1025/74405)
* [DescribeAcls](https://cloud.tencent.com/document/api/1025/74409)
* [DescribeDasbImageIds](https://cloud.tencent.com/document/api/1025/74413)
* [DescribeDevices](https://cloud.tencent.com/document/api/1025/74415)
* [DescribeUsers](https://cloud.tencent.com/document/api/1025/74404)
* [ModifyAcl](https://cloud.tencent.com/document/api/1025/74408)
* [ModifyUser](https://cloud.tencent.com/document/api/1025/74403)

新增数据结构：

* [Acl](https://cloud.tencent.com/document/api/1025/74416#Acl)
* [CmdTemplate](https://cloud.tencent.com/document/api/1025/74416#CmdTemplate)
* [Device](https://cloud.tencent.com/document/api/1025/74416#Device)
* [Group](https://cloud.tencent.com/document/api/1025/74416#Group)
* [Resource](https://cloud.tencent.com/document/api/1025/74416#Resource)
* [User](https://cloud.tencent.com/document/api/1025/74416#User)




## 数据接入平台(dataintegration) 版本：2022-06-13

### 第 1 次发布

发布时间：2022-07-26 15:32:15

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [SendMessage](https://cloud.tencent.com/document/api/1591/77844)

新增数据结构：

* [BatchContent](https://cloud.tencent.com/document/api/1591/77845#BatchContent)




## DDoS 高防包(dayu) 版本：2018-07-09

### 第 22 次发布

发布时间：2023-01-13 01:19:41

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [IpBlockData](https://cloud.tencent.com/document/api/1021/39225#IpBlockData)

	* 新增成员：ProtectFlag


### 第 21 次发布

发布时间：2021-04-26 08:04:08

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [BoundIpInfo](https://cloud.tencent.com/document/api/1021/39225#BoundIpInfo)

	* 新增成员：IspCode


### 第 20 次发布

发布时间：2021-04-02 08:03:57

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeBizHttpStatus](https://cloud.tencent.com/document/api/1021/54301)

新增数据结构：

* [HttpStatusMap](https://cloud.tencent.com/document/api/1021/39225#HttpStatusMap)

### 第 19 次发布

发布时间：2020-10-19 08:02:57

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeBizTrend](https://cloud.tencent.com/document/api/1021/49205)

### 第 18 次发布

发布时间：2020-08-25 08:03:42

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeCCTrend](https://cloud.tencent.com/document/api/1021/39475)

	* 新增入参：Domain


### 第 17 次发布

发布时间：2020-07-17 08:08:18

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateNewL7RulesUpload](https://cloud.tencent.com/document/api/1021/46423)

### 第 16 次发布

发布时间：2020-07-01 08:08:22

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [ModifyNewDomainRules](https://cloud.tencent.com/document/api/1021/45890)
* [ModifyNewL4Rule](https://cloud.tencent.com/document/api/1021/45889)

修改数据结构：

* [L7RuleEntry](https://cloud.tencent.com/document/api/1021/39225#L7RuleEntry)

	* 新增成员：VirtualPort

* [NewL7RuleEntry](https://cloud.tencent.com/document/api/1021/39225#NewL7RuleEntry)

	* 新增成员：VirtualPort


### 第 15 次发布

发布时间：2020-05-21 08:07:56

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [ModifyCCThreshold](https://cloud.tencent.com/document/api/1021/39518)

	* 新增入参：Domain


### 第 14 次发布

发布时间：2020-04-27 08:07:22

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateNewL4Rules](https://cloud.tencent.com/document/api/1021/52792)
* [CreateNewL7Rules](https://cloud.tencent.com/document/api/1021/43847)
* [DeleteNewL4Rules](https://cloud.tencent.com/document/api/1021/52787)
* [DeleteNewL7Rules](https://cloud.tencent.com/document/api/1021/52785)
* [DescribeNewL4Rules](https://cloud.tencent.com/document/api/1021/52752)
* [DescribeNewL4RulesErrHealth](https://cloud.tencent.com/document/api/1021/39488)
* [DescribeNewL7RulesErrHealth](https://cloud.tencent.com/document/api/1021/43846)
* [DescribleNewL7Rules](https://cloud.tencent.com/document/api/1021/43845)

新增数据结构：

* [L4DelRule](https://cloud.tencent.com/document/api/1021/39225#L4DelRule)
* [NewL4RuleEntry](https://cloud.tencent.com/document/api/1021/39225#NewL4RuleEntry)
* [NewL7RuleEntry](https://cloud.tencent.com/document/api/1021/39225#NewL7RuleEntry)

### 第 13 次发布

发布时间：2020-04-13 08:07:17

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeSchedulingDomainList](https://cloud.tencent.com/document/api/1021/43369)

新增数据结构：

* [SchedulingDomain](https://cloud.tencent.com/document/api/1021/39225#SchedulingDomain)

### 第 12 次发布

发布时间：2020-04-02 08:07:12

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [L7RuleEntry](https://cloud.tencent.com/document/api/1021/39225#L7RuleEntry)

	* 新增成员：HttpsToHttpEnable


### 第 11 次发布

发布时间：2020-03-27 08:05:57

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [DDoSEventRecord](https://cloud.tencent.com/document/api/1021/39225#DDoSEventRecord)

	* 新增成员：EventId


### 第 10 次发布

发布时间：2020-03-24 08:05:50

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeBGPIPL7RuleMaxCnt](https://cloud.tencent.com/document/api/1021/42835)

### 第 9 次发布

发布时间：2020-03-19 08:06:43

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateL7CCRule](https://cloud.tencent.com/document/api/1021/39527)

新增数据结构：

* [CCRuleConfig](https://cloud.tencent.com/document/api/1021/39225#CCRuleConfig)

### 第 8 次发布

发布时间：2020-03-16 08:07:28

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateNetReturn](https://cloud.tencent.com/document/api/1021/42280)
* [ModifyNetReturnSwitch](https://cloud.tencent.com/document/api/1021/42279)

### 第 7 次发布

发布时间：2020-03-06 12:07:02

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateBoundIP](https://cloud.tencent.com/document/api/1021/41997)

新增数据结构：

* [BoundIpInfo](https://cloud.tencent.com/document/api/1021/39225#BoundIpInfo)

### 第 6 次发布

发布时间：2020-02-13 18:00:42

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateCCFrequencyRules](https://cloud.tencent.com/document/api/1021/41273)
* [DeleteCCFrequencyRules](https://cloud.tencent.com/document/api/1021/41272)
* [DescribeBasicCCThreshold](https://cloud.tencent.com/document/api/1021/41271)
* [DescribeCCFrequencyRules](https://cloud.tencent.com/document/api/1021/41270)
* [DescribeDDoSAttackIPRegionMap](https://cloud.tencent.com/document/api/1021/41267)
* [ModifyCCFrequencyRules](https://cloud.tencent.com/document/api/1021/41269)
* [ModifyCCFrequencyRulesStatus](https://cloud.tencent.com/document/api/1021/41268)

<font color="#dd0000">**删除接口**：</font>

* CreateL7CCRule

修改接口：

* [CreateDDoSPolicyCase](https://cloud.tencent.com/document/api/1021/39514)

	* 新增入参：TcpPortList, UdpPortList

* [ModifyCCThreshold](https://cloud.tencent.com/document/api/1021/39518)

	* 新增入参：BasicIp, BasicRegion, BasicBizType, BasicDeviceType, BasicIpInstance, BasicIspCode

	* <font color="#dd0000">**修改入参**：</font>Id

* [ModifyDDoSPolicyCase](https://cloud.tencent.com/document/api/1021/39504)

	* 新增入参：TcpPortList, UdpPortList


新增数据结构：

* [CCFrequencyRule](https://cloud.tencent.com/document/api/1021/39225#CCFrequencyRule)

<font color="#dd0000">**删除数据结构**：</font>

* CCRuleConfig

### 第 5 次发布

发布时间：2019-12-20 10:35:06

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeCCAlarmThreshold](https://cloud.tencent.com/document/api/1021/40383)
* [DescribeCCSelfDefinePolicy](https://cloud.tencent.com/document/api/1021/40382)
* [DescribeDDoSAlarmThreshold](https://cloud.tencent.com/document/api/1021/40380)
* [DescribeDDoSAttackSource](https://cloud.tencent.com/document/api/1021/40378)
* [ModifyCCAlarmThreshold](https://cloud.tencent.com/document/api/1021/40381)
* [ModifyDDoSAlarmThreshold](https://cloud.tencent.com/document/api/1021/40379)

新增数据结构：

* [CCAlarmThreshold](https://cloud.tencent.com/document/api/1021/39225#CCAlarmThreshold)
* [DDoSAlarmThreshold](https://cloud.tencent.com/document/api/1021/39225#DDoSAlarmThreshold)
* [DDoSAttackSourceRecord](https://cloud.tencent.com/document/api/1021/39225#DDoSAttackSourceRecord)

### 第 4 次发布

发布时间：2019-12-05 16:26:22

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateBasicDDoSAlarmThreshold](https://cloud.tencent.com/document/api/1021/40041)
* [DescribeBasicDeviceThreshold](https://cloud.tencent.com/document/api/1021/40038)
* [DescribeIPProductInfo](https://cloud.tencent.com/document/api/1021/40040)
* [ModifyResourceRenewFlag](https://cloud.tencent.com/document/api/1021/40039)

### 第 3 次发布

发布时间：2019-11-28 22:04:36

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeIpUnBlockList](https://cloud.tencent.com/document/api/1021/39772)

新增数据结构：

* [IpUnBlockData](https://cloud.tencent.com/document/api/1021/39225#IpUnBlockData)
* [Paging](https://cloud.tencent.com/document/api/1021/39225#Paging)

### 第 2 次发布

发布时间：2019-11-22 11:01:03

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateCCSelfDefinePolicy](https://cloud.tencent.com/document/api/1021/39528)
* [CreateDDoSPolicy](https://cloud.tencent.com/document/api/1021/39515)
* [CreateDDoSPolicyCase](https://cloud.tencent.com/document/api/1021/39514)
* [CreateInstanceName](https://cloud.tencent.com/document/api/1021/39459)
* [CreateL4HealthConfig](https://cloud.tencent.com/document/api/1021/39497)
* [CreateL4Rules](https://cloud.tencent.com/document/api/1021/39496)
* [CreateL7CCRule](https://cloud.tencent.com/document/api/1021/39527)
* [CreateL7HealthConfig](https://cloud.tencent.com/document/api/1021/39495)
* [CreateL7RuleCert](https://cloud.tencent.com/document/api/1021/39494)
* [CreateL7Rules](https://cloud.tencent.com/document/api/1021/39493)
* [CreateL7RulesUpload](https://cloud.tencent.com/document/api/1021/39492)
* [CreateUnblockIp](https://cloud.tencent.com/document/api/1021/39452)
* [DeleteCCSelfDefinePolicy](https://cloud.tencent.com/document/api/1021/39526)
* [DeleteDDoSPolicy](https://cloud.tencent.com/document/api/1021/39513)
* [DeleteDDoSPolicyCase](https://cloud.tencent.com/document/api/1021/39512)
* [DeleteL4Rules](https://cloud.tencent.com/document/api/1021/39491)
* [DeleteL7Rules](https://cloud.tencent.com/document/api/1021/39490)
* [DescribeActionLog](https://cloud.tencent.com/document/api/1021/39458)
* [DescribeBaradData](https://cloud.tencent.com/document/api/1021/39477)
* [DescribeCCEvList](https://cloud.tencent.com/document/api/1021/39476)
* [DescribeCCIpAllowDeny](https://cloud.tencent.com/document/api/1021/39525)
* [DescribeCCTrend](https://cloud.tencent.com/document/api/1021/39475)
* [DescribeCCUrlAllow](https://cloud.tencent.com/document/api/1021/39524)
* [DescribeDDoSCount](https://cloud.tencent.com/document/api/1021/39474)
* [DescribeDDoSDefendStatus](https://cloud.tencent.com/document/api/1021/39511)
* [DescribeDDoSEvInfo](https://cloud.tencent.com/document/api/1021/39473)
* [DescribeDDoSEvList](https://cloud.tencent.com/document/api/1021/39472)
* [DescribeDDoSIpLog](https://cloud.tencent.com/document/api/1021/39471)
* [DescribeDDoSNetCount](https://cloud.tencent.com/document/api/1021/39470)
* [DescribeDDoSNetEvInfo](https://cloud.tencent.com/document/api/1021/39469)
* [DescribeDDoSNetEvList](https://cloud.tencent.com/document/api/1021/39468)
* [DescribeDDoSNetIpLog](https://cloud.tencent.com/document/api/1021/39467)
* [DescribeDDoSNetTrend](https://cloud.tencent.com/document/api/1021/39466)
* [DescribeDDoSPolicy](https://cloud.tencent.com/document/api/1021/39510)
* [DescribeDDoSTrend](https://cloud.tencent.com/document/api/1021/39465)
* [DescribeDDoSUsedStatis](https://cloud.tencent.com/document/api/1021/39464)
* [DescribeInsurePacks](https://cloud.tencent.com/document/api/1021/39457)
* [DescribeIpBlockList](https://cloud.tencent.com/document/api/1021/39451)
* [DescribeL4HealthConfig](https://cloud.tencent.com/document/api/1021/39489)
* [DescribeL4RulesErrHealth](https://cloud.tencent.com/document/api/1021/50713)
* [DescribeL7HealthConfig](https://cloud.tencent.com/document/api/1021/39487)
* [DescribePackIndex](https://cloud.tencent.com/document/api/1021/39456)
* [DescribePcap](https://cloud.tencent.com/document/api/1021/39463)
* [DescribePolicyCase](https://cloud.tencent.com/document/api/1021/39509)
* [DescribeResIpList](https://cloud.tencent.com/document/api/1021/39455)
* [DescribeRuleSets](https://cloud.tencent.com/document/api/1021/39486)
* [DescribeSecIndex](https://cloud.tencent.com/document/api/1021/39462)
* [DescribeSourceIpSegment](https://cloud.tencent.com/document/api/1021/39485)
* [DescribeTransmitStatis](https://cloud.tencent.com/document/api/1021/39461)
* [DescribeUnBlockStatis](https://cloud.tencent.com/document/api/1021/39450)
* [DescribleL4Rules](https://cloud.tencent.com/document/api/1021/39484)
* [DescribleL7Rules](https://cloud.tencent.com/document/api/1021/39483)
* [DescribleRegionCount](https://cloud.tencent.com/document/api/1021/39454)
* [ModifyCCHostProtection](https://cloud.tencent.com/document/api/1021/39523)
* [ModifyCCIpAllowDeny](https://cloud.tencent.com/document/api/1021/39522)
* [ModifyCCLevel](https://cloud.tencent.com/document/api/1021/39521)
* [ModifyCCPolicySwitch](https://cloud.tencent.com/document/api/1021/39520)
* [ModifyCCSelfDefinePolicy](https://cloud.tencent.com/document/api/1021/39519)
* [ModifyCCThreshold](https://cloud.tencent.com/document/api/1021/39518)
* [ModifyCCUrlAllow](https://cloud.tencent.com/document/api/1021/39517)
* [ModifyDDoSAIStatus](https://cloud.tencent.com/document/api/1021/39508)
* [ModifyDDoSDefendStatus](https://cloud.tencent.com/document/api/1021/39507)
* [ModifyDDoSLevel](https://cloud.tencent.com/document/api/1021/39506)
* [ModifyDDoSPolicy](https://cloud.tencent.com/document/api/1021/39505)
* [ModifyDDoSPolicyCase](https://cloud.tencent.com/document/api/1021/39504)
* [ModifyDDoSPolicyName](https://cloud.tencent.com/document/api/1021/39503)
* [ModifyDDoSSwitch](https://cloud.tencent.com/document/api/1021/39502)
* [ModifyDDoSThreshold](https://cloud.tencent.com/document/api/1021/39501)
* [ModifyDDoSWaterKey](https://cloud.tencent.com/document/api/1021/39500)
* [ModifyElasticLimit](https://cloud.tencent.com/document/api/1021/39453)
* [ModifyL4Health](https://cloud.tencent.com/document/api/1021/39482)
* [ModifyL4KeepTime](https://cloud.tencent.com/document/api/1021/39481)
* [ModifyL4Rules](https://cloud.tencent.com/document/api/1021/39480)
* [ModifyL7Rules](https://cloud.tencent.com/document/api/1021/39479)
* [ModifyResBindDDoSPolicy](https://cloud.tencent.com/document/api/1021/39499)

新增数据结构：

* [BaradData](https://cloud.tencent.com/document/api/1021/39225#BaradData)
* [CCEventRecord](https://cloud.tencent.com/document/api/1021/39225#CCEventRecord)
* [CCPolicy](https://cloud.tencent.com/document/api/1021/39225#CCPolicy)
* [CCRule](https://cloud.tencent.com/document/api/1021/39225#CCRule)
* [CCRuleConfig](https://cloud.tencent.com/document/api/1021/39225#CCRuleConfig)
* [DDoSEventRecord](https://cloud.tencent.com/document/api/1021/39225#DDoSEventRecord)
* [DDoSPolicyDropOption](https://cloud.tencent.com/document/api/1021/39225#DDoSPolicyDropOption)
* [DDoSPolicyPacketFilter](https://cloud.tencent.com/document/api/1021/39225#DDoSPolicyPacketFilter)
* [DDoSPolicyPortLimit](https://cloud.tencent.com/document/api/1021/39225#DDoSPolicyPortLimit)
* [DDosPolicy](https://cloud.tencent.com/document/api/1021/39225#DDosPolicy)
* [IpBlackWhite](https://cloud.tencent.com/document/api/1021/39225#IpBlackWhite)
* [IpBlockData](https://cloud.tencent.com/document/api/1021/39225#IpBlockData)
* [L4HealthConfig](https://cloud.tencent.com/document/api/1021/39225#L4HealthConfig)
* [L4RuleEntry](https://cloud.tencent.com/document/api/1021/39225#L4RuleEntry)
* [L4RuleHealth](https://cloud.tencent.com/document/api/1021/39225#L4RuleHealth)
* [L4RuleSource](https://cloud.tencent.com/document/api/1021/39225#L4RuleSource)
* [L7HealthConfig](https://cloud.tencent.com/document/api/1021/39225#L7HealthConfig)
* [L7RuleEntry](https://cloud.tencent.com/document/api/1021/39225#L7RuleEntry)
* [L7RuleHealth](https://cloud.tencent.com/document/api/1021/39225#L7RuleHealth)
* [ProtocolPort](https://cloud.tencent.com/document/api/1021/39225#ProtocolPort)
* [RegionInstanceCount](https://cloud.tencent.com/document/api/1021/39225#RegionInstanceCount)
* [ResourceIp](https://cloud.tencent.com/document/api/1021/39225#ResourceIp)
* [SuccessCode](https://cloud.tencent.com/document/api/1021/39225#SuccessCode)
* [WaterPrintKey](https://cloud.tencent.com/document/api/1021/39225#WaterPrintKey)
* [WaterPrintPolicy](https://cloud.tencent.com/document/api/1021/39225#WaterPrintPolicy)

### 第 1 次发布

发布时间：2019-11-14 17:09:13

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeResourceList](https://cloud.tencent.com/document/api/1021/39224)

新增数据结构：

* [KeyValue](https://cloud.tencent.com/document/api/1021/39225#KeyValue)
* [KeyValueRecord](https://cloud.tencent.com/document/api/1021/39225#KeyValueRecord)
* [OrderBy](https://cloud.tencent.com/document/api/1021/39225#OrderBy)




## 数据库智能管家 DBbrain(dbbrain) 版本：2019-10-16

### 第 15 次发布

发布时间：2024-03-12 19:50:52

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [SlowLogTopSqlItem](https://cloud.tencent.com/document/api/1130/39561#SlowLogTopSqlItem)

	* <font color="#dd0000">**修改成员**：</font>Md5


### 第 14 次发布

发布时间：2023-06-12 01:14:59

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeSlowLogUserHostStats](https://cloud.tencent.com/document/api/1130/54870)

	* 新增出参：UserNameItems, UserTotalCount


新增数据结构：

* [SlowLogUser](https://cloud.tencent.com/document/api/1130/39561#SlowLogUser)

修改数据结构：

* [InstanceConfs](https://cloud.tencent.com/document/api/1130/39561#InstanceConfs)

	* 新增成员：KeyDelimiters

* [InstanceInfo](https://cloud.tencent.com/document/api/1130/39561#InstanceInfo)

	* 新增成员：InternalVip, InternalVport, CreateTime, ClusterId, ClusterName


### 第 13 次发布

发布时间：2023-06-09 01:15:59

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [SlowLogTopSqlItem](https://cloud.tencent.com/document/api/1130/39561#SlowLogTopSqlItem)

	* 新增成员：Md5


### 第 12 次发布

发布时间：2021-04-23 08:04:16

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeUserSqlAdvice](https://cloud.tencent.com/document/api/1130/54999)

### 第 11 次发布

发布时间：2021-04-21 08:04:17

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateDBDiagReportUrl](https://cloud.tencent.com/document/api/1130/54874)
* [DescribeDBDiagReportTasks](https://cloud.tencent.com/document/api/1130/54873)
* [DescribeSlowLogUserHostStats](https://cloud.tencent.com/document/api/1130/54870)
* [DescribeTopSpaceSchemaTimeSeries](https://cloud.tencent.com/document/api/1130/54872)
* [DescribeTopSpaceSchemas](https://cloud.tencent.com/document/api/1130/54871)

新增数据结构：

* [HealthReportTask](https://cloud.tencent.com/document/api/1130/39561#HealthReportTask)
* [HealthStatus](https://cloud.tencent.com/document/api/1130/39561#HealthStatus)
* [InstanceBasicInfo](https://cloud.tencent.com/document/api/1130/39561#InstanceBasicInfo)
* [SchemaSpaceData](https://cloud.tencent.com/document/api/1130/39561#SchemaSpaceData)
* [SchemaSpaceTimeSeries](https://cloud.tencent.com/document/api/1130/39561#SchemaSpaceTimeSeries)
* [ScoreDetail](https://cloud.tencent.com/document/api/1130/39561#ScoreDetail)
* [ScoreItem](https://cloud.tencent.com/document/api/1130/39561#ScoreItem)
* [SlowLogHost](https://cloud.tencent.com/document/api/1130/39561#SlowLogHost)

修改数据结构：

* [SlowLogTopSqlItem](https://cloud.tencent.com/document/api/1130/39561#SlowLogTopSqlItem)

	* 新增成员：QueryTimeAvg, RowsSentAvg, LockTimeAvg, RowsExaminedAvg


### 第 10 次发布

发布时间：2021-02-03 08:04:05

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [AddUserContact](https://cloud.tencent.com/document/api/1130/52723)
* [CreateSchedulerMailProfile](https://cloud.tencent.com/document/api/1130/52722)
* [DescribeDiagDBInstances](https://cloud.tencent.com/document/api/1130/52719)
* [DescribeHealthScore](https://cloud.tencent.com/document/api/1130/52718)
* [DescribeMailProfile](https://cloud.tencent.com/document/api/1130/52721)

新增数据结构：

* [EventInfo](https://cloud.tencent.com/document/api/1130/39561#EventInfo)
* [HealthScoreInfo](https://cloud.tencent.com/document/api/1130/39561#HealthScoreInfo)
* [InstanceInfo](https://cloud.tencent.com/document/api/1130/39561#InstanceInfo)
* [IssueTypeInfo](https://cloud.tencent.com/document/api/1130/39561#IssueTypeInfo)
* [UserProfile](https://cloud.tencent.com/document/api/1130/39561#UserProfile)

修改数据结构：

* [InstanceConfs](https://cloud.tencent.com/document/api/1130/39561#InstanceConfs)

	* 新增成员：OverviewDisplay


### 第 9 次发布

发布时间：2021-02-01 08:03:55

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateSecurityAuditLogExportTask](https://cloud.tencent.com/document/api/1130/52657)
* [DeleteSecurityAuditLogExportTasks](https://cloud.tencent.com/document/api/1130/52656)
* [DescribeSecurityAuditLogDownloadUrls](https://cloud.tencent.com/document/api/1130/52655)
* [DescribeSecurityAuditLogExportTasks](https://cloud.tencent.com/document/api/1130/52654)

新增数据结构：

* [SecLogExportTaskInfo](https://cloud.tencent.com/document/api/1130/39561#SecLogExportTaskInfo)

### 第 8 次发布

发布时间：2020-12-02 08:03:01

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateDBDiagReportTask](https://cloud.tencent.com/document/api/1130/50518)
* [CreateMailProfile](https://cloud.tencent.com/document/api/1130/50517)
* [DescribeAllUserContact](https://cloud.tencent.com/document/api/1130/50516)
* [DescribeAllUserGroup](https://cloud.tencent.com/document/api/1130/50515)
* [ModifyDiagDBInstanceConf](https://cloud.tencent.com/document/api/1130/50514)

新增数据结构：

* [ContactItem](https://cloud.tencent.com/document/api/1130/39561#ContactItem)
* [GroupItem](https://cloud.tencent.com/document/api/1130/39561#GroupItem)
* [InstanceConfs](https://cloud.tencent.com/document/api/1130/39561#InstanceConfs)
* [MailConfiguration](https://cloud.tencent.com/document/api/1130/39561#MailConfiguration)
* [ProfileInfo](https://cloud.tencent.com/document/api/1130/39561#ProfileInfo)

### 第 7 次发布

发布时间：2020-11-17 08:03:56

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeDBDiagEvent](https://cloud.tencent.com/document/api/1130/39560)

	* 新增入参：Product

* [DescribeDBDiagHistory](https://cloud.tencent.com/document/api/1130/39559)

	* 新增入参：Product

* [DescribeDBSpaceStatus](https://cloud.tencent.com/document/api/1130/46047)

	* 新增入参：Product

* [DescribeSlowLogTimeSeriesStats](https://cloud.tencent.com/document/api/1130/39557)

	* 新增入参：Product

* [DescribeSlowLogTopSqls](https://cloud.tencent.com/document/api/1130/39556)

	* 新增入参：Product

* [DescribeTopSpaceTableTimeSeries](https://cloud.tencent.com/document/api/1130/46279)

	* 新增入参：Product

* [DescribeTopSpaceTables](https://cloud.tencent.com/document/api/1130/46046)

	* 新增入参：Product


### 第 6 次发布

发布时间：2020-11-09 08:03:16

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeSlowLogTopSqls](https://cloud.tencent.com/document/api/1130/39556)

	* 新增入参：SchemaList


新增数据结构：

* [SchemaItem](https://cloud.tencent.com/document/api/1130/39561#SchemaItem)

### 第 5 次发布

发布时间：2020-11-03 08:04:06

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeDBDiagHistory](https://cloud.tencent.com/document/api/1130/39559)

	* 新增出参：Events

* [DescribeSlowLogTimeSeriesStats](https://cloud.tencent.com/document/api/1130/39557)

	* 新增出参：Period, TimeSeries, SeriesData

* [DescribeSlowLogTopSqls](https://cloud.tencent.com/document/api/1130/39556)

	* 新增出参：TotalCount, Rows

* [DescribeTopSpaceTableTimeSeries](https://cloud.tencent.com/document/api/1130/46279)

	* 新增出参：TopSpaceTableTimeSeries

* [DescribeTopSpaceTables](https://cloud.tencent.com/document/api/1130/46046)

	* 新增出参：TopSpaceTables, Timestamp


新增数据结构：

* [DiagHistoryEventItem](https://cloud.tencent.com/document/api/1130/39561#DiagHistoryEventItem)
* [MonitorFloatMetric](https://cloud.tencent.com/document/api/1130/39561#MonitorFloatMetric)
* [MonitorFloatMetricSeriesData](https://cloud.tencent.com/document/api/1130/39561#MonitorFloatMetricSeriesData)
* [MonitorMetric](https://cloud.tencent.com/document/api/1130/39561#MonitorMetric)
* [MonitorMetricSeriesData](https://cloud.tencent.com/document/api/1130/39561#MonitorMetricSeriesData)
* [SlowLogTopSqlItem](https://cloud.tencent.com/document/api/1130/39561#SlowLogTopSqlItem)
* [TableSpaceData](https://cloud.tencent.com/document/api/1130/39561#TableSpaceData)
* [TableSpaceTimeSeries](https://cloud.tencent.com/document/api/1130/39561#TableSpaceTimeSeries)
* [TimeSlice](https://cloud.tencent.com/document/api/1130/39561#TimeSlice)

### 第 4 次发布

发布时间：2020-10-29 08:03:38

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeDBDiagHistory](https://cloud.tencent.com/document/api/1130/39559)

	* <font color="#dd0000">**删除出参**：</font>Events

* [DescribeSlowLogTimeSeriesStats](https://cloud.tencent.com/document/api/1130/39557)

	* <font color="#dd0000">**删除出参**：</font>Period, TimeSeries, SeriesData

* [DescribeSlowLogTopSqls](https://cloud.tencent.com/document/api/1130/39556)

	* <font color="#dd0000">**删除出参**：</font>TotalCount, Rows

* [DescribeTopSpaceTableTimeSeries](https://cloud.tencent.com/document/api/1130/46279)

	* <font color="#dd0000">**删除出参**：</font>TopSpaceTableTimeSeries

* [DescribeTopSpaceTables](https://cloud.tencent.com/document/api/1130/46046)

	* <font color="#dd0000">**删除出参**：</font>TopSpaceTables


<font color="#dd0000">**删除数据结构**：</font>

* DiagHistoryEventItem
* MonitorFloatMetric
* MonitorFloatMetricSeriesData
* MonitorMetric
* MonitorMetricSeriesData
* SlowLogTopSqlItem
* TableSpaceData
* TableSpaceTimeSeries
* TimeSlice

### 第 3 次发布

发布时间：2020-07-14 08:08:56

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeTopSpaceTableTimeSeries](https://cloud.tencent.com/document/api/1130/46279)

新增数据结构：

* [MonitorFloatMetric](https://cloud.tencent.com/document/api/1130/39561#MonitorFloatMetric)
* [MonitorFloatMetricSeriesData](https://cloud.tencent.com/document/api/1130/39561#MonitorFloatMetricSeriesData)
* [TableSpaceTimeSeries](https://cloud.tencent.com/document/api/1130/39561#TableSpaceTimeSeries)

### 第 2 次发布

发布时间：2020-07-08 08:09:29

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeDBSpaceStatus](https://cloud.tencent.com/document/api/1130/46047)
* [DescribeTopSpaceTables](https://cloud.tencent.com/document/api/1130/46046)

新增数据结构：

* [TableSpaceData](https://cloud.tencent.com/document/api/1130/39561#TableSpaceData)

### 第 1 次发布

发布时间：2019-11-22 19:34:18

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeDBDiagEvent](https://cloud.tencent.com/document/api/1130/39560)
* [DescribeDBDiagHistory](https://cloud.tencent.com/document/api/1130/39559)
* [DescribeSlowLogTimeSeriesStats](https://cloud.tencent.com/document/api/1130/39557)
* [DescribeSlowLogTopSqls](https://cloud.tencent.com/document/api/1130/39556)

新增数据结构：

* [DiagHistoryEventItem](https://cloud.tencent.com/document/api/1130/39561#DiagHistoryEventItem)
* [MonitorMetric](https://cloud.tencent.com/document/api/1130/39561#MonitorMetric)
* [MonitorMetricSeriesData](https://cloud.tencent.com/document/api/1130/39561#MonitorMetricSeriesData)
* [SlowLogTopSqlItem](https://cloud.tencent.com/document/api/1130/39561#SlowLogTopSqlItem)
* [TimeSlice](https://cloud.tencent.com/document/api/1130/39561#TimeSlice)



## 数据库智能管家 DBbrain(dbbrain) 版本：2021-05-27

### 第 30 次发布

发布时间：2024-07-25 01:31:31

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateKillTask](https://cloud.tencent.com/document/api/1130/67783)

	* 新增入参：Infos


### 第 29 次发布

发布时间：2024-05-27 01:30:50

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DeleteRedisBigKeyAnalysisTasks](https://cloud.tencent.com/document/api/1130/106580)

### 第 28 次发布

发布时间：2024-05-24 01:30:51

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeRedisBigKeyAnalysisTasks](https://cloud.tencent.com/document/api/1130/106545)

新增数据结构：

* [RedisBigKeyTask](https://cloud.tencent.com/document/api/1130/57812#RedisBigKeyTask)

修改数据结构：

* [InstanceConfs](https://cloud.tencent.com/document/api/1130/57812#InstanceConfs)

	* 新增成员：AnalysisTopKey


### 第 27 次发布

发布时间：2024-01-16 01:12:56

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeRedisTopBigKeys](https://cloud.tencent.com/document/api/1130/72832)

	* 新增入参：AsyncRequestId, ShardIds


修改数据结构：

* [InstanceConfs](https://cloud.tencent.com/document/api/1130/57812#InstanceConfs)

	* 新增成员：ShardNum


### 第 26 次发布

发布时间：2023-09-27 12:20:53

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeIndexRecommendAggregationSlowLogs](https://cloud.tencent.com/document/api/1130/98912)
* [DescribeIndexRecommendInfo](https://cloud.tencent.com/document/api/1130/98911)
* [DescribeRedisProcessList](https://cloud.tencent.com/document/api/1130/98909)

新增数据结构：

* [Aggregation](https://cloud.tencent.com/document/api/1130/57812#Aggregation)
* [IndexesToBuild](https://cloud.tencent.com/document/api/1130/57812#IndexesToBuild)
* [IndexesToDrop](https://cloud.tencent.com/document/api/1130/57812#IndexesToDrop)
* [MongoDBIndex](https://cloud.tencent.com/document/api/1130/57812#MongoDBIndex)
* [Process](https://cloud.tencent.com/document/api/1130/57812#Process)

### 第 25 次发布

发布时间：2023-09-04 01:41:27

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeAlarmTemplate](https://cloud.tencent.com/document/api/1130/97726)
* [ModifyAlarmPolicy](https://cloud.tencent.com/document/api/1130/97725)

新增数据结构：

* [AlarmProfileList](https://cloud.tencent.com/document/api/1130/57812#AlarmProfileList)
* [AlarmsRules](https://cloud.tencent.com/document/api/1130/57812#AlarmsRules)
* [InstanceID](https://cloud.tencent.com/document/api/1130/57812#InstanceID)
* [ReceiveInfo](https://cloud.tencent.com/document/api/1130/57812#ReceiveInfo)
* [ReceiveUin](https://cloud.tencent.com/document/api/1130/57812#ReceiveUin)
* [TemplateInfo](https://cloud.tencent.com/document/api/1130/57812#TemplateInfo)

### 第 24 次发布

发布时间：2023-09-01 01:12:36

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [UpdateAgentSwitch](https://cloud.tencent.com/document/api/1130/97686)
* [UpdateMonitorSwitch](https://cloud.tencent.com/document/api/1130/97685)

### 第 23 次发布

发布时间：2023-08-31 01:13:53

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [InstanceInfo](https://cloud.tencent.com/document/api/1130/57812#InstanceInfo)

	* 新增成员：AgentStatus, InstanceStatus

	* <font color="#dd0000">**修改成员**：</font>InternalVip, InternalVport, CreateTime, ClusterId, ClusterName


### 第 22 次发布

发布时间：2023-07-13 01:15:30

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CloseAuditService](https://cloud.tencent.com/document/api/1130/95014)
* [DescribeAuditInstanceList](https://cloud.tencent.com/document/api/1130/95013)
* [ModifyAuditService](https://cloud.tencent.com/document/api/1130/95012)
* [OpenAuditService](https://cloud.tencent.com/document/api/1130/95011)

新增数据结构：

* [AuditInstance](https://cloud.tencent.com/document/api/1130/57812#AuditInstance)
* [AuditInstanceFilter](https://cloud.tencent.com/document/api/1130/57812#AuditInstanceFilter)
* [AuditInstanceInfo](https://cloud.tencent.com/document/api/1130/57812#AuditInstanceInfo)

### 第 21 次发布

发布时间：2023-07-07 01:22:44

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateRedisBigKeyAnalysisTask](https://cloud.tencent.com/document/api/1130/94604)

### 第 20 次发布

发布时间：2023-06-13 01:16:02

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateSqlFilter](https://cloud.tencent.com/document/api/1130/72835)

	* <font color="#dd0000">**修改入参**：</font>SessionToken

* [DeleteSqlFilters](https://cloud.tencent.com/document/api/1130/72834)

	* <font color="#dd0000">**修改入参**：</font>SessionToken

* [ModifySqlFilters](https://cloud.tencent.com/document/api/1130/72829)

	* <font color="#dd0000">**修改入参**：</font>SessionToken


### 第 19 次发布

发布时间：2023-06-12 01:16:06

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeSlowLogUserHostStats](https://cloud.tencent.com/document/api/1130/57783)

	* 新增出参：UserNameItems, UserTotalCount


新增数据结构：

* [SlowLogUser](https://cloud.tencent.com/document/api/1130/57812#SlowLogUser)

修改数据结构：

* [InstanceInfo](https://cloud.tencent.com/document/api/1130/57812#InstanceInfo)

	* 新增成员：ClusterId, ClusterName

* [RedisKeySpaceData](https://cloud.tencent.com/document/api/1130/57812#RedisKeySpaceData)

	* 新增成员：AveElementSize, ShardId


### 第 18 次发布

发布时间：2023-05-08 01:20:12

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DeleteSqlFilters](https://cloud.tencent.com/document/api/1130/72834)

	* 新增入参：Product

* [DescribeSqlFilters](https://cloud.tencent.com/document/api/1130/72831)

	* 新增入参：Product

* [KillMySqlThreads](https://cloud.tencent.com/document/api/1130/61129)

	* 新增入参：RecordHistory


### 第 17 次发布

发布时间：2023-04-27 01:17:03

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DeleteDBDiagReportTasks](https://cloud.tencent.com/document/api/1130/90009)

	* <font color="#dd0000">**修改入参**：</font>Product


### 第 16 次发布

发布时间：2023-04-21 01:20:02

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateAuditLogFile](https://cloud.tencent.com/document/api/1130/90373)
* [DeleteAuditLogFile](https://cloud.tencent.com/document/api/1130/90372)
* [DescribeAuditLogFiles](https://cloud.tencent.com/document/api/1130/90371)

新增数据结构：

* [AuditLogFile](https://cloud.tencent.com/document/api/1130/57812#AuditLogFile)
* [AuditLogFilter](https://cloud.tencent.com/document/api/1130/57812#AuditLogFilter)

### 第 15 次发布

发布时间：2023-04-11 01:16:00

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeSlowLogs](https://cloud.tencent.com/document/api/1130/90047)

新增数据结构：

* [SlowLogInfoItem](https://cloud.tencent.com/document/api/1130/57812#SlowLogInfoItem)

### 第 14 次发布

发布时间：2023-04-10 01:23:09

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DeleteDBDiagReportTasks](https://cloud.tencent.com/document/api/1130/90009)

### 第 13 次发布

发布时间：2023-03-27 01:41:31

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [InstanceConfs](https://cloud.tencent.com/document/api/1130/57812#InstanceConfs)

	* 新增成员：KeyDelimiters

* [InstanceInfo](https://cloud.tencent.com/document/api/1130/57812#InstanceInfo)

	* 新增成员：InternalVip, InternalVport, CreateTime


### 第 12 次发布

发布时间：2023-01-09 01:18:23

本次发布包含了以下内容：

改善已有的文档。

新增数据结构：

* [SessionItem](https://cloud.tencent.com/document/api/1130/57812#SessionItem)

修改数据结构：

* [ProcessStatistic](https://cloud.tencent.com/document/api/1130/57812#ProcessStatistic)

	* 新增成员：Items, AllConnSum, ActiveConnSum


### 第 11 次发布

发布时间：2022-12-27 01:33:02

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeProxyProcessStatistics](https://cloud.tencent.com/document/api/1130/84544)

新增数据结构：

* [ProcessStatistic](https://cloud.tencent.com/document/api/1130/57812#ProcessStatistic)

### 第 10 次发布

发布时间：2022-09-07 06:24:27

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeRedisTopKeyPrefixList](https://cloud.tencent.com/document/api/1130/80213)

新增数据结构：

* [RedisPreKeySpaceData](https://cloud.tencent.com/document/api/1130/57812#RedisPreKeySpaceData)

### 第 9 次发布

发布时间：2022-04-21 06:10:54

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CancelKillTask](https://cloud.tencent.com/document/api/1130/72836)
* [CreateSqlFilter](https://cloud.tencent.com/document/api/1130/72835)
* [DeleteSqlFilters](https://cloud.tencent.com/document/api/1130/72834)
* [DescribeNoPrimaryKeyTables](https://cloud.tencent.com/document/api/1130/72833)
* [DescribeRedisTopBigKeys](https://cloud.tencent.com/document/api/1130/72832)
* [DescribeSqlFilters](https://cloud.tencent.com/document/api/1130/72831)
* [DescribeSqlTemplate](https://cloud.tencent.com/document/api/1130/72830)
* [ModifySqlFilters](https://cloud.tencent.com/document/api/1130/72829)
* [VerifyUserAccount](https://cloud.tencent.com/document/api/1130/72828)

新增数据结构：

* [RedisKeySpaceData](https://cloud.tencent.com/document/api/1130/57812#RedisKeySpaceData)
* [SQLFilter](https://cloud.tencent.com/document/api/1130/57812#SQLFilter)
* [Table](https://cloud.tencent.com/document/api/1130/57812#Table)

### 第 8 次发布

发布时间：2022-03-03 08:04:55

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeUserSqlAdvice](https://cloud.tencent.com/document/api/1130/57782)

	* 新增入参：Product


### 第 7 次发布

发布时间：2022-02-14 08:09:51

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeProxySessionKillTasks](https://cloud.tencent.com/document/api/1130/69205)

新增数据结构：

* [TaskInfo](https://cloud.tencent.com/document/api/1130/57812#TaskInfo)

### 第 6 次发布

发布时间：2022-01-10 08:09:43

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateKillTask](https://cloud.tencent.com/document/api/1130/67783)
* [CreateProxySessionKillTask](https://cloud.tencent.com/document/api/1130/67782)

### 第 5 次发布

发布时间：2021-12-15 08:06:44

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeDBDiagEvents](https://cloud.tencent.com/document/api/1130/65947)

### 第 4 次发布

发布时间：2021-09-03 08:05:46

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [KillMySqlThreads](https://cloud.tencent.com/document/api/1130/61129)

### 第 3 次发布

发布时间：2021-07-23 08:05:15

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeSlowLogUserHostStats](https://cloud.tencent.com/document/api/1130/57783)

	* 新增入参：Md5


修改数据结构：

* [SlowLogTopSqlItem](https://cloud.tencent.com/document/api/1130/57812#SlowLogTopSqlItem)

	* 新增成员：Md5


### 第 2 次发布

发布时间：2021-06-24 14:42:17

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeMySqlProcessList](https://cloud.tencent.com/document/api/1130/57824)

新增数据结构：

* [MySqlProcess](https://cloud.tencent.com/document/api/1130/57812#MySqlProcess)

### 第 1 次发布

发布时间：2021-05-28 08:04:39

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [AddUserContact](https://cloud.tencent.com/document/api/1130/57811)
* [CreateDBDiagReportTask](https://cloud.tencent.com/document/api/1130/57802)
* [CreateDBDiagReportUrl](https://cloud.tencent.com/document/api/1130/57810)
* [CreateMailProfile](https://cloud.tencent.com/document/api/1130/57809)
* [CreateSchedulerMailProfile](https://cloud.tencent.com/document/api/1130/57808)
* [CreateSecurityAuditLogExportTask](https://cloud.tencent.com/document/api/1130/57801)
* [DeleteSecurityAuditLogExportTasks](https://cloud.tencent.com/document/api/1130/57800)
* [DescribeAllUserContact](https://cloud.tencent.com/document/api/1130/57807)
* [DescribeAllUserGroup](https://cloud.tencent.com/document/api/1130/57806)
* [DescribeDBDiagEvent](https://cloud.tencent.com/document/api/1130/57788)
* [DescribeDBDiagHistory](https://cloud.tencent.com/document/api/1130/57787)
* [DescribeDBDiagReportTasks](https://cloud.tencent.com/document/api/1130/57805)
* [DescribeDBSpaceStatus](https://cloud.tencent.com/document/api/1130/57799)
* [DescribeDiagDBInstances](https://cloud.tencent.com/document/api/1130/57798)
* [DescribeHealthScore](https://cloud.tencent.com/document/api/1130/57797)
* [DescribeMailProfile](https://cloud.tencent.com/document/api/1130/57804)
* [DescribeSecurityAuditLogDownloadUrls](https://cloud.tencent.com/document/api/1130/57796)
* [DescribeSecurityAuditLogExportTasks](https://cloud.tencent.com/document/api/1130/57795)
* [DescribeSlowLogTimeSeriesStats](https://cloud.tencent.com/document/api/1130/57785)
* [DescribeSlowLogTopSqls](https://cloud.tencent.com/document/api/1130/57784)
* [DescribeSlowLogUserHostStats](https://cloud.tencent.com/document/api/1130/57783)
* [DescribeTopSpaceSchemaTimeSeries](https://cloud.tencent.com/document/api/1130/57794)
* [DescribeTopSpaceSchemas](https://cloud.tencent.com/document/api/1130/57793)
* [DescribeTopSpaceTableTimeSeries](https://cloud.tencent.com/document/api/1130/57792)
* [DescribeTopSpaceTables](https://cloud.tencent.com/document/api/1130/57791)
* [DescribeUserSqlAdvice](https://cloud.tencent.com/document/api/1130/57782)
* [ModifyDiagDBInstanceConf](https://cloud.tencent.com/document/api/1130/57790)

新增数据结构：

* [ContactItem](https://cloud.tencent.com/document/api/1130/57812#ContactItem)
* [DiagHistoryEventItem](https://cloud.tencent.com/document/api/1130/57812#DiagHistoryEventItem)
* [EventInfo](https://cloud.tencent.com/document/api/1130/57812#EventInfo)
* [GroupItem](https://cloud.tencent.com/document/api/1130/57812#GroupItem)
* [HealthReportTask](https://cloud.tencent.com/document/api/1130/57812#HealthReportTask)
* [HealthScoreInfo](https://cloud.tencent.com/document/api/1130/57812#HealthScoreInfo)
* [HealthStatus](https://cloud.tencent.com/document/api/1130/57812#HealthStatus)
* [InstanceBasicInfo](https://cloud.tencent.com/document/api/1130/57812#InstanceBasicInfo)
* [InstanceConfs](https://cloud.tencent.com/document/api/1130/57812#InstanceConfs)
* [InstanceInfo](https://cloud.tencent.com/document/api/1130/57812#InstanceInfo)
* [IssueTypeInfo](https://cloud.tencent.com/document/api/1130/57812#IssueTypeInfo)
* [MailConfiguration](https://cloud.tencent.com/document/api/1130/57812#MailConfiguration)
* [MonitorFloatMetric](https://cloud.tencent.com/document/api/1130/57812#MonitorFloatMetric)
* [MonitorFloatMetricSeriesData](https://cloud.tencent.com/document/api/1130/57812#MonitorFloatMetricSeriesData)
* [MonitorMetric](https://cloud.tencent.com/document/api/1130/57812#MonitorMetric)
* [MonitorMetricSeriesData](https://cloud.tencent.com/document/api/1130/57812#MonitorMetricSeriesData)
* [ProfileInfo](https://cloud.tencent.com/document/api/1130/57812#ProfileInfo)
* [SchemaItem](https://cloud.tencent.com/document/api/1130/57812#SchemaItem)
* [SchemaSpaceData](https://cloud.tencent.com/document/api/1130/57812#SchemaSpaceData)
* [SchemaSpaceTimeSeries](https://cloud.tencent.com/document/api/1130/57812#SchemaSpaceTimeSeries)
* [ScoreDetail](https://cloud.tencent.com/document/api/1130/57812#ScoreDetail)
* [ScoreItem](https://cloud.tencent.com/document/api/1130/57812#ScoreItem)
* [SecLogExportTaskInfo](https://cloud.tencent.com/document/api/1130/57812#SecLogExportTaskInfo)
* [SlowLogHost](https://cloud.tencent.com/document/api/1130/57812#SlowLogHost)
* [SlowLogTopSqlItem](https://cloud.tencent.com/document/api/1130/57812#SlowLogTopSqlItem)
* [TableSpaceData](https://cloud.tencent.com/document/api/1130/57812#TableSpaceData)
* [TableSpaceTimeSeries](https://cloud.tencent.com/document/api/1130/57812#TableSpaceTimeSeries)
* [TimeSlice](https://cloud.tencent.com/document/api/1130/57812#TimeSlice)
* [UserProfile](https://cloud.tencent.com/document/api/1130/57812#UserProfile)




## 云数据库独享集群(dbdc) 版本：2020-10-29

### 第 4 次发布

发布时间：2022-11-23 06:23:05

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [HostDetail](https://cloud.tencent.com/document/api/1322/74754#HostDetail)

	* 新增成员：InstanceId


### 第 3 次发布

发布时间：2022-07-27 06:08:38

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeInstanceDetail](https://cloud.tencent.com/document/api/1322/74752)

	* 新增出参：ClusterId

* [DescribeInstanceList](https://cloud.tencent.com/document/api/1322/74751)

	* 新增入参：ClusterId


修改数据结构：

* [DBInstanceDetail](https://cloud.tencent.com/document/api/1322/74754#DBInstanceDetail)

	* 新增成员：Region, CreateTime

* [DescribeInstanceDetail](https://cloud.tencent.com/document/api/1322/74754#DescribeInstanceDetail)

	* 新增成员：ClusterId


### 第 2 次发布

发布时间：2022-07-01 11:26:52

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeHostList](https://cloud.tencent.com/document/api/1322/76350)

新增数据结构：

* [HostDetail](https://cloud.tencent.com/document/api/1322/74754#HostDetail)

### 第 1 次发布

发布时间：2022-05-31 17:05:07

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeDBInstances](https://cloud.tencent.com/document/api/1322/74753)
* [DescribeInstanceDetail](https://cloud.tencent.com/document/api/1322/74752)
* [DescribeInstanceList](https://cloud.tencent.com/document/api/1322/74751)
* [DescribeInstances](https://cloud.tencent.com/document/api/1322/74750)
* [ModifyInstanceName](https://cloud.tencent.com/document/api/1322/74749)

新增数据结构：

* [DBInstanceDetail](https://cloud.tencent.com/document/api/1322/74754#DBInstanceDetail)
* [DescribeInstanceDetail](https://cloud.tencent.com/document/api/1322/74754#DescribeInstanceDetail)
* [DeviceInfo](https://cloud.tencent.com/document/api/1322/74754#DeviceInfo)
* [InstanceDetail](https://cloud.tencent.com/document/api/1322/74754#InstanceDetail)
* [InstanceDeviceInfo](https://cloud.tencent.com/document/api/1322/74754#InstanceDeviceInfo)
* [InstanceExpand](https://cloud.tencent.com/document/api/1322/74754#InstanceExpand)




## 专线接入(dc) 版本：2018-04-10

### 第 26 次发布

发布时间：2024-06-14 01:40:38

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [DirectConnectTunnel](https://cloud.tencent.com/document/api/216/18418#DirectConnectTunnel)

	* 新增成员：ShareOrNot


### 第 25 次发布

发布时间：2024-03-06 01:13:45

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [ModifyDirectConnectTunnelExtra](https://cloud.tencent.com/document/api/216/49100)

	* 新增入参：TencentIPv6Address, TencentBackupIPv6Address, CustomerIPv6Address


### 第 24 次发布

发布时间：2022-10-14 06:25:18

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [DirectConnectTunnelExtra](https://cloud.tencent.com/document/api/216/18418#DirectConnectTunnelExtra)

	* 新增成员：HighPrecisionBFDEnable


### 第 23 次发布

发布时间：2022-04-13 06:36:47

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateDirectConnectTunnel](https://cloud.tencent.com/document/api/216/19821)

	* 新增入参：BfdEnable, NqaEnable, BfdInfo, NqaInfo


### 第 22 次发布

发布时间：2021-08-17 08:05:38

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [AccessPoint](https://cloud.tencent.com/document/api/216/18418#AccessPoint)

	* 新增成员：AccessPointType


### 第 21 次发布

发布时间：2021-05-24 08:04:38

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [DirectConnectTunnelExtra](https://cloud.tencent.com/document/api/216/18418#DirectConnectTunnelExtra)

	* 新增成员：JumboEnable


### 第 20 次发布

发布时间：2021-04-21 08:04:26

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [ModifyDirectConnectTunnelExtra](https://cloud.tencent.com/document/api/216/49100)

	* 新增入参：JumboEnable


### 第 19 次发布

发布时间：2021-04-20 08:04:47

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [DirectConnect](https://cloud.tencent.com/document/api/216/18418#DirectConnect)

	* 新增成员：LocalZone, VlanZeroDirectConnectTunnelCount, OtherVlanDirectConnectTunnelCount, MinBandwidth


### 第 18 次发布

发布时间：2021-04-07 08:04:13

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [ModifyDirectConnectAttribute](https://cloud.tencent.com/document/api/216/34825)

	* 新增入参：Bandwidth


### 第 17 次发布

发布时间：2021-02-23 08:04:16

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [AccessPoint](https://cloud.tencent.com/document/api/216/18418#AccessPoint)

	* 新增成员：Area


### 第 16 次发布

发布时间：2021-01-28 08:04:02

本次发布包含了以下内容：

改善已有的文档。

新增数据结构：

* [Coordinate](https://cloud.tencent.com/document/api/216/18418#Coordinate)

修改数据结构：

* [AccessPoint](https://cloud.tencent.com/document/api/216/18418#AccessPoint)

	* 新增成员：Coordinate, City


### 第 15 次发布

发布时间：2021-01-19 08:04:38

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [ModifyDirectConnectTunnelExtra](https://cloud.tencent.com/document/api/216/49100)

	* 新增入参：CustomerIDCRoutes


### 第 14 次发布

发布时间：2020-12-25 08:03:57

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [ApplyInternetAddress](https://cloud.tencent.com/document/api/216/51491)
* [DescribeInternetAddress](https://cloud.tencent.com/document/api/216/51490)
* [DescribeInternetAddressQuota](https://cloud.tencent.com/document/api/216/51489)
* [DescribeInternetAddressStatistics](https://cloud.tencent.com/document/api/216/51488)
* [DisableInternetAddress](https://cloud.tencent.com/document/api/216/51487)
* [EnableInternetAddress](https://cloud.tencent.com/document/api/216/51486)
* [ReleaseInternetAddress](https://cloud.tencent.com/document/api/216/51485)

修改接口：

* [ModifyDirectConnectTunnelExtra](https://cloud.tencent.com/document/api/216/49100)

	* 新增入参：IPv6Enable


新增数据结构：

* [InternetAddressDetail](https://cloud.tencent.com/document/api/216/18418#InternetAddressDetail)
* [InternetAddressStatistics](https://cloud.tencent.com/document/api/216/18418#InternetAddressStatistics)

修改数据结构：

* [DirectConnectTunnelExtra](https://cloud.tencent.com/document/api/216/18418#DirectConnectTunnelExtra)

	* 新增成员：IPv6Enable, TencentIPv6Address, TencentBackupIPv6Address, BgpIPv6Status, CustomerIPv6Address


### 第 13 次发布

发布时间：2020-12-18 08:04:11

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateDirectConnectTunnel](https://cloud.tencent.com/document/api/216/19821)

	* 新增入参：CloudAttachId


修改数据结构：

* [DirectConnectTunnel](https://cloud.tencent.com/document/api/216/18418#DirectConnectTunnel)

	* 新增成员：CloudAttachId


### 第 12 次发布

发布时间：2020-10-14 08:03:21

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeDirectConnectTunnelExtra](https://cloud.tencent.com/document/api/216/49102)
* [DescribePublicDirectConnectTunnelRoutes](https://cloud.tencent.com/document/api/216/49101)
* [ModifyDirectConnectTunnelExtra](https://cloud.tencent.com/document/api/216/49100)

新增数据结构：

* [BFDInfo](https://cloud.tencent.com/document/api/216/18418#BFDInfo)
* [BGPStatus](https://cloud.tencent.com/document/api/216/18418#BGPStatus)
* [DirectConnectTunnelExtra](https://cloud.tencent.com/document/api/216/18418#DirectConnectTunnelExtra)
* [DirectConnectTunnelRoute](https://cloud.tencent.com/document/api/216/18418#DirectConnectTunnelRoute)
* [NQAInfo](https://cloud.tencent.com/document/api/216/18418#NQAInfo)

### 第 11 次发布

发布时间：2020-08-04 08:10:19

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateDirectConnect](https://cloud.tencent.com/document/api/216/34829)

	* 新增入参：SignLaw

	* <font color="#dd0000">**修改入参**：</font>Location

* [DescribeDirectConnects](https://cloud.tencent.com/document/api/216/34826)

	* 新增出参：AllSignLaw

* [ModifyDirectConnectAttribute](https://cloud.tencent.com/document/api/216/34825)

	* 新增入参：SignLaw


### 第 10 次发布

发布时间：2020-08-03 08:10:29

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [AccessPoint](https://cloud.tencent.com/document/api/216/18418#AccessPoint)

	* 新增成员：AvailablePortType

* [DirectConnect](https://cloud.tencent.com/document/api/216/18418#DirectConnect)

	* 新增成员：SignLaw

* [DirectConnectTunnel](https://cloud.tencent.com/document/api/216/18418#DirectConnectTunnel)

	* 新增成员：SignLaw


### 第 9 次发布

发布时间：2020-06-10 08:08:58

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [DirectConnect](https://cloud.tencent.com/document/api/216/18418#DirectConnect)

	* 新增成员：StartTime


### 第 8 次发布

发布时间：2020-04-21 08:08:32

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [ModifyDirectConnectTunnelAttribute](https://cloud.tencent.com/document/api/216/19818)

	* 新增入参：TencentBackupAddress


### 第 7 次发布

发布时间：2020-04-17 08:07:36

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateDirectConnectTunnel](https://cloud.tencent.com/document/api/216/19821)

	* 新增入参：TencentBackupAddress


### 第 6 次发布

发布时间：2020-04-15 08:08:41

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [DirectConnectTunnel](https://cloud.tencent.com/document/api/216/18418#DirectConnectTunnel)

	* 新增成员：TencentBackupAddress


### 第 5 次发布

发布时间：2020-03-20 08:06:49

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [DirectConnect](https://cloud.tencent.com/document/api/216/18418#DirectConnect)

	* 新增成员：IdcCity, ChargeState

* [DirectConnectTunnel](https://cloud.tencent.com/document/api/216/18418#DirectConnectTunnel)

	* 新增成员：DirectConnectGatewayName, VpcName


### 第 4 次发布

发布时间：2020-03-16 08:08:04

本次发布包含了以下内容：

改善已有的文档。

新增数据结构：

* [Tag](https://cloud.tencent.com/document/api/216/18418#Tag)

修改数据结构：

* [DirectConnect](https://cloud.tencent.com/document/api/216/18418#DirectConnect)

	* 新增成员：TagSet, AccessPointType

* [DirectConnectTunnel](https://cloud.tencent.com/document/api/216/18418#DirectConnectTunnel)

	* 新增成员：TagSet, NetDetectId, EnableBGPCommunity, NatType, VpcRegion, BfdEnable, AccessPointType


### 第 3 次发布

发布时间：2019-05-09 22:03:57

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateDirectConnect](https://cloud.tencent.com/document/api/216/34829)
* [DeleteDirectConnect](https://cloud.tencent.com/document/api/216/34828)
* [DescribeAccessPoints](https://cloud.tencent.com/document/api/216/34827)
* [DescribeDirectConnects](https://cloud.tencent.com/document/api/216/34826)
* [ModifyDirectConnectAttribute](https://cloud.tencent.com/document/api/216/34825)

新增数据结构：

* [AccessPoint](https://cloud.tencent.com/document/api/216/18418#AccessPoint)
* [DirectConnect](https://cloud.tencent.com/document/api/216/18418#DirectConnect)

### 第 2 次发布

发布时间：2018-08-17 13:00:45

本次发布包含了以下内容：

改善已有的文档。

### 第 1 次发布

发布时间：2018-07-19 16:17:35

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [AcceptDirectConnectTunnel](https://cloud.tencent.com/document/api/216/19822)
* [CreateDirectConnectTunnel](https://cloud.tencent.com/document/api/216/19821)
* [DeleteDirectConnectTunnel](https://cloud.tencent.com/document/api/216/19820)
* [DescribeDirectConnectTunnels](https://cloud.tencent.com/document/api/216/19819)
* [ModifyDirectConnectTunnelAttribute](https://cloud.tencent.com/document/api/216/19818)
* [RejectDirectConnectTunnel](https://cloud.tencent.com/document/api/216/19817)

新增数据结构：

* [BgpPeer](https://cloud.tencent.com/document/api/216/18418#BgpPeer)
* [DirectConnectTunnel](https://cloud.tencent.com/document/api/216/18418#DirectConnectTunnel)
* [Filter](https://cloud.tencent.com/document/api/216/18418#Filter)
* [RouteFilterPrefix](https://cloud.tencent.com/document/api/216/18418#RouteFilterPrefix)




## TDSQL MySQL 版(dcdb) 版本：2018-04-11

### 第 69 次发布

发布时间：2024-07-03 01:14:20

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [InstanceBackupFileItem](https://cloud.tencent.com/document/api/557/16142#InstanceBackupFileItem)

	* 新增成员：StorageClass


### 第 68 次发布

发布时间：2024-04-24 01:10:19

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeDCDBInstances](https://cloud.tencent.com/document/api/557/16140)

	* 新增入参：Tags

* [SwitchDBInstanceHA](https://cloud.tencent.com/document/api/557/68111)

	* 新增入参：ShardInstanceIds


新增数据结构：

* [Tag](https://cloud.tencent.com/document/api/557/16142#Tag)

### 第 67 次发布

发布时间：2023-10-30 00:33:47

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateDCDBInstance](https://cloud.tencent.com/document/api/557/16135)

	* 新增入参：DcnSyncMode

* [CreateDedicatedClusterDCDBInstance](https://cloud.tencent.com/document/api/557/61369)

	* 新增入参：DcnSyncMode

* [DescribeDCDBInstanceDetail](https://cloud.tencent.com/document/api/557/89385)

	* 新增出参：IsDcnStrongSyncSupported, IsDcnSwitchSupported


修改数据结构：

* [DcnDetailItem](https://cloud.tencent.com/document/api/557/16142#DcnDetailItem)

	* 新增成员：DcnStatusDesc, PolarisInstanceId, PolarisInstanceName, PolarisNamespace, PolarisService, PolarisServiceStatus, PolarisServiceStatusDesc, PolarisRegion, IsDcnSwitchSupported


### 第 66 次发布

发布时间：2023-08-29 01:12:46

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateHourDCDBInstance](https://cloud.tencent.com/document/api/557/70249)

	* 新增入参：DcnSyncMode


### 第 65 次发布

发布时间：2023-08-23 01:20:18

本次发布包含了以下内容：

改善已有的文档。

<font color="#dd0000">**删除接口**：</font>

* DescribeSqlLogs

<font color="#dd0000">**删除数据结构**：</font>

* SqlLogItem

### 第 64 次发布

发布时间：2023-08-14 01:19:27

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeLogFileRetentionPeriod](https://cloud.tencent.com/document/api/557/96159)

### 第 63 次发布

发布时间：2023-06-28 01:18:44

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateDedicatedClusterDCDBInstance](https://cloud.tencent.com/document/api/557/61369)

	* 新增入参：SecurityGroupIds


### 第 62 次发布

发布时间：2023-06-21 01:15:23

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeDBTmpInstances](https://cloud.tencent.com/document/api/557/94218)

新增数据结构：

* [TmpInstance](https://cloud.tencent.com/document/api/557/16142#TmpInstance)

### 第 61 次发布

发布时间：2023-06-13 01:16:36

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeDCDBInstanceDetail](https://cloud.tencent.com/document/api/557/89385)

	* 新增出参：IsPhysicalReplicationSupported


### 第 60 次发布

发布时间：2023-06-08 01:23:27

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [IsolateDCDBInstance](https://cloud.tencent.com/document/api/557/93275)

### 第 59 次发布

发布时间：2023-06-05 01:24:19

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateDedicatedClusterDCDBInstance](https://cloud.tencent.com/document/api/557/61369)

	* 新增出参：InstanceIds, FlowId


### 第 58 次发布

发布时间：2023-06-01 09:49:03

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [ModifyAccountConfig](https://cloud.tencent.com/document/api/557/93041)

新增数据结构：

* [ConfigValue](https://cloud.tencent.com/document/api/557/16142#ConfigValue)

### 第 57 次发布

发布时间：2023-05-29 01:20:37

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateTmpDCDBInstance](https://cloud.tencent.com/document/api/557/92836)

修改接口：

* [DescribeDCDBInstanceDetail](https://cloud.tencent.com/document/api/557/89385)

	* 新增出参：ReservedNetResources


新增数据结构：

* [ReservedNetResource](https://cloud.tencent.com/document/api/557/16142#ReservedNetResource)

修改数据结构：

* [DBAccount](https://cloud.tencent.com/document/api/557/16142#DBAccount)

	* 新增成员：MaxUserConnections


### 第 56 次发布

发布时间：2023-05-23 01:16:58

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateDedicatedClusterDCDBInstance](https://cloud.tencent.com/document/api/557/61369)
* [DescribeDBEncryptAttributes](https://cloud.tencent.com/document/api/557/92617)
* [UpgradeDedicatedDCDBInstance](https://cloud.tencent.com/document/api/557/92616)

<font color="#dd0000">**预下线接口**：</font>

* DescribeSqlLogs

### 第 55 次发布

发布时间：2023-04-04 01:14:38

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeBackupFiles](https://cloud.tencent.com/document/api/557/89799)

新增数据结构：

* [InstanceBackupFileItem](https://cloud.tencent.com/document/api/557/16142#InstanceBackupFileItem)

### 第 54 次发布

发布时间：2023-03-29 03:25:14

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeDCDBInstanceDetail](https://cloud.tencent.com/document/api/557/89385)

	* 新增出参：RsAccessStrategy


### 第 53 次发布

发布时间：2023-03-27 01:42:17

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeDCDBInstanceDetail](https://cloud.tencent.com/document/api/557/89385)

新增数据结构：

* [NodeInfo](https://cloud.tencent.com/document/api/557/16142#NodeInfo)
* [ShardBriefInfo](https://cloud.tencent.com/document/api/557/16142#ShardBriefInfo)

### 第 52 次发布

发布时间：2023-02-27 01:19:52

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [ModifyDBEncryptAttributes](https://cloud.tencent.com/document/api/557/86907)

### 第 51 次发布

发布时间：2023-01-30 01:20:38

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [UpgradeHourDCDBInstance](https://cloud.tencent.com/document/api/557/85926)

### 第 50 次发布

发布时间：2022-11-29 06:37:37

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [ModifyAccountPrivileges](https://cloud.tencent.com/document/api/557/83475)

新增数据结构：

* [Account](https://cloud.tencent.com/document/api/557/16142#Account)
* [ColumnPrivilege](https://cloud.tencent.com/document/api/557/16142#ColumnPrivilege)
* [DatabasePrivilege](https://cloud.tencent.com/document/api/557/16142#DatabasePrivilege)
* [TablePrivilege](https://cloud.tencent.com/document/api/557/16142#TablePrivilege)
* [ViewPrivileges](https://cloud.tencent.com/document/api/557/16142#ViewPrivileges)

### 第 49 次发布

发布时间：2022-11-23 06:23:24

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [DcnDetailItem](https://cloud.tencent.com/document/api/557/16142#DcnDetailItem)

	* 新增成员：EncryptStatus


### 第 48 次发布

发布时间：2022-11-16 06:19:54

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeDCDBPrice](https://cloud.tencent.com/document/api/557/16131)

	* 新增入参：AmountUnit

* [DescribeDCDBRenewalPrice](https://cloud.tencent.com/document/api/557/16138)

	* 新增入参：AmountUnit

* [DescribeDCDBUpgradePrice](https://cloud.tencent.com/document/api/557/16132)

	* 新增入参：AmountUnit


修改数据结构：

* [ExpandShardConfig](https://cloud.tencent.com/document/api/557/16142#ExpandShardConfig)

	* 新增成员：ShardNodeCount


### 第 47 次发布

发布时间：2022-11-04 06:20:23

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [IsolateDedicatedDBInstance](https://cloud.tencent.com/document/api/557/82371)

修改数据结构：

* [ZonesInfo](https://cloud.tencent.com/document/api/557/16142#ZonesInfo)

	* 新增成员：OnSale


### 第 46 次发布

发布时间：2022-10-28 06:24:03

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [ModifyInstanceNetwork](https://cloud.tencent.com/document/api/557/82021)
* [ModifyInstanceVip](https://cloud.tencent.com/document/api/557/82020)
* [ModifyInstanceVport](https://cloud.tencent.com/document/api/557/82019)

### 第 45 次发布

发布时间：2022-08-31 06:24:58

本次发布包含了以下内容：

改善已有的文档。

<font color="#dd0000">**删除接口**：</font>

* CreateDedicatedClusterDCDBInstance

### 第 44 次发布

发布时间：2022-08-25 06:25:03

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateDedicatedClusterDCDBInstance](https://cloud.tencent.com/document/api/557/61369)

	* 新增入参：RollbackInstanceId, RollbackTime


### 第 43 次发布

发布时间：2022-07-22 06:06:56

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [DCDBInstanceInfo](https://cloud.tencent.com/document/api/557/16142#DCDBInstanceInfo)

	* 新增成员：DbVersionId


### 第 42 次发布

发布时间：2022-07-05 06:12:03

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateAccount](https://cloud.tencent.com/document/api/557/19996)

	* 新增入参：SlaveConst, MaxUserConnections


修改数据结构：

* [DBAccount](https://cloud.tencent.com/document/api/557/16142#DBAccount)

	* 新增成员：SlaveConst


### 第 41 次发布

发布时间：2022-05-31 06:09:47

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [TerminateDedicatedDBInstance](https://cloud.tencent.com/document/api/557/74711)

### 第 40 次发布

发布时间：2022-05-25 06:07:44

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeDBSecurityGroups](https://cloud.tencent.com/document/api/557/51781)
* [DescribeOrders](https://cloud.tencent.com/document/api/557/16139)

新增数据结构：

* [Deal](https://cloud.tencent.com/document/api/557/16142#Deal)

### 第 39 次发布

发布时间：2022-04-26 06:09:14

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [ModifyDBInstanceName](https://cloud.tencent.com/document/api/557/73095)

### 第 38 次发布

发布时间：2022-04-13 06:37:02

本次发布包含了以下内容：

改善已有的文档。

<font color="#dd0000">**删除接口**：</font>

* DescribeDBSecurityGroups
* DescribeOrders

修改接口：

* [CreateHourDCDBInstance](https://cloud.tencent.com/document/api/557/70249)

	* 新增出参：DealName


<font color="#dd0000">**删除数据结构**：</font>

* Deal

### 第 37 次发布

发布时间：2022-03-24 23:20:33

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [ParamDesc](https://cloud.tencent.com/document/api/557/16142#ParamDesc)

	* 新增成员：NeedRestart


### 第 36 次发布

发布时间：2022-03-01 08:05:34

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [ActiveHourDCDBInstance](https://cloud.tencent.com/document/api/557/70421)
* [IsolateHourDCDBInstance](https://cloud.tencent.com/document/api/557/70420)

### 第 35 次发布

发布时间：2022-02-23 08:06:28

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateHourDCDBInstance](https://cloud.tencent.com/document/api/557/70249)

### 第 34 次发布

发布时间：2022-02-17 08:09:34

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeDBSlowLogs](https://cloud.tencent.com/document/api/557/70099)

新增数据结构：

* [SlowLogData](https://cloud.tencent.com/document/api/557/16142#SlowLogData)

### 第 33 次发布

发布时间：2022-01-13 08:32:29

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [SwitchDBInstanceHA](https://cloud.tencent.com/document/api/557/68111)

### 第 32 次发布

发布时间：2022-01-11 08:07:36

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateDCDBInstance](https://cloud.tencent.com/document/api/557/16135)

	* 新增入参：SecurityGroupIds

* [DescribeProjectSecurityGroups](https://cloud.tencent.com/document/api/557/51780)

	* 新增出参：Total


修改数据结构：

* [DCDBInstanceInfo](https://cloud.tencent.com/document/api/557/16142#DCDBInstanceInfo)

	* 新增成员：ResourceTags


### 第 31 次发布

发布时间：2021-12-17 08:10:31

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeFileDownloadUrl](https://cloud.tencent.com/document/api/557/66229)

### 第 30 次发布

发布时间：2021-11-26 08:08:12

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [UpgradeDCDBInstance](https://cloud.tencent.com/document/api/557/16136)

	* 新增入参：Zones


### 第 29 次发布

发布时间：2021-11-17 08:10:41

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateDCDBInstance](https://cloud.tencent.com/document/api/557/16135)

	* 新增入参：AutoRenewFlag


### 第 28 次发布

发布时间：2021-09-10 08:05:13

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateDedicatedClusterDCDBInstance](https://cloud.tencent.com/document/api/557/61369)

### 第 27 次发布

发布时间：2021-08-11 08:05:20

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [ModifyRealServerAccessStrategy](https://cloud.tencent.com/document/api/557/60074)

### 第 26 次发布

发布时间：2021-08-05 08:05:14

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateDCDBInstance](https://cloud.tencent.com/document/api/557/16135)

	* 新增入参：DcnRegion, DcnInstanceId


### 第 25 次发布

发布时间：2021-07-20 08:07:55

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CancelDcnJob](https://cloud.tencent.com/document/api/557/58910)

### 第 24 次发布

发布时间：2021-07-14 08:05:11

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeDCDBUpgradePrice](https://cloud.tencent.com/document/api/557/16132)

	* 新增出参：Formula


修改数据结构：

* [DcnDetailItem](https://cloud.tencent.com/document/api/557/16142#DcnDetailItem)

	* 新增成员：Cpu, Memory, Storage, PayMode, CreateTime, PeriodEndTime, InstanceType


### 第 23 次发布

发布时间：2021-06-01 08:05:28

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeFlow](https://cloud.tencent.com/document/api/557/56485)
* [DestroyDCDBInstance](https://cloud.tencent.com/document/api/557/56484)
* [DestroyHourDCDBInstance](https://cloud.tencent.com/document/api/557/56483)

修改接口：

* [CreateDCDBInstance](https://cloud.tencent.com/document/api/557/16135)

	* 新增入参：InitParams

* [DescribeDCDBInstances](https://cloud.tencent.com/document/api/557/16140)

	* 新增入参：Status, ExcludeStatus


### 第 22 次发布

发布时间：2021-05-27 08:04:44

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeDcnDetail](https://cloud.tencent.com/document/api/557/56346)

新增数据结构：

* [DcnDetailItem](https://cloud.tencent.com/document/api/557/16142#DcnDetailItem)

### 第 21 次发布

发布时间：2021-04-22 08:04:38

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeDCDBInstanceNodeInfo](https://cloud.tencent.com/document/api/557/54943)

新增数据结构：

* [BriefNodeInfo](https://cloud.tencent.com/document/api/557/16142#BriefNodeInfo)

### 第 20 次发布

发布时间：2021-04-08 08:04:19

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [KillSession](https://cloud.tencent.com/document/api/557/53595)

	* 新增入参：ShardSerialId


### 第 19 次发布

发布时间：2021-03-24 08:04:31

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeDBSecurityGroups](https://cloud.tencent.com/document/api/557/51781)

	* 新增出参：VIP, VPort

* [DescribeDBSyncMode](https://cloud.tencent.com/document/api/557/19991)

	* 新增出参：CurrentSyncMode


### 第 18 次发布

发布时间：2021-03-15 08:03:59

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [KillSession](https://cloud.tencent.com/document/api/557/53595)

### 第 17 次发布

发布时间：2021-01-21 08:03:45

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [DCDBShardInfo](https://cloud.tencent.com/document/api/557/16142#DCDBShardInfo)

	* 新增成员：Range


### 第 16 次发布

发布时间：2021-01-07 08:04:18

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [AssociateSecurityGroups](https://cloud.tencent.com/document/api/557/51782)
* [DescribeDBSecurityGroups](https://cloud.tencent.com/document/api/557/51781)
* [DescribeProjectSecurityGroups](https://cloud.tencent.com/document/api/557/51780)
* [DisassociateSecurityGroups](https://cloud.tencent.com/document/api/557/51779)
* [ModifyDBInstanceSecurityGroups](https://cloud.tencent.com/document/api/557/51778)

新增数据结构：

* [SecurityGroup](https://cloud.tencent.com/document/api/557/16142#SecurityGroup)
* [SecurityGroupBound](https://cloud.tencent.com/document/api/557/16142#SecurityGroupBound)

### 第 15 次发布

发布时间：2020-12-23 08:03:37

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeUserTasks](https://cloud.tencent.com/document/api/557/51327)

新增数据结构：

* [UserTaskInfo](https://cloud.tencent.com/document/api/557/16142#UserTaskInfo)

### 第 14 次发布

发布时间：2020-12-16 08:04:12

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [DCDBInstanceInfo](https://cloud.tencent.com/document/api/557/16142#DCDBInstanceInfo)

	* 新增成员：InstanceType


### 第 13 次发布

发布时间：2020-09-28 08:04:27

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeDCDBInstances](https://cloud.tencent.com/document/api/557/16140)

	* 新增入参：FilterInstanceType

* [DescribeDCDBShards](https://cloud.tencent.com/document/api/557/19990)

	* 新增出参：DcnFlag


修改数据结构：

* [DCDBInstanceInfo](https://cloud.tencent.com/document/api/557/16142#DCDBInstanceInfo)

	* 新增成员：DcnFlag, DcnStatus, DcnDstNum


### 第 12 次发布

发布时间：2020-08-18 08:11:06

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [FlushBinlog](https://cloud.tencent.com/document/api/557/47582)

修改接口：

* [CreateDCDBInstance](https://cloud.tencent.com/document/api/557/16135)

	* 新增入参：ResourceTags

* [DescribeDCDBInstances](https://cloud.tencent.com/document/api/557/16140)

	* 新增入参：TagKeys


新增数据结构：

* [ResourceTag](https://cloud.tencent.com/document/api/557/16142#ResourceTag)

修改数据结构：

* [DCDBInstanceInfo](https://cloud.tencent.com/document/api/557/16142#DCDBInstanceInfo)

	* 新增成员：Ipv6Flag, Vipv6, WanVipv6, WanPortIpv6, WanStatusIpv6


### 第 11 次发布

发布时间：2020-07-02 08:09:04

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CloseDBExtranetAccess](https://cloud.tencent.com/document/api/557/19998)

	* 新增入参：Ipv6Flag

* [CreateDCDBInstance](https://cloud.tencent.com/document/api/557/16135)

	* 新增入参：Ipv6Flag

* [OpenDBExtranetAccess](https://cloud.tencent.com/document/api/557/19980)

	* 新增入参：Ipv6Flag


### 第 10 次发布

发布时间：2020-04-16 08:07:40

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeProjects](https://cloud.tencent.com/document/api/557/43471)

新增数据结构：

* [Project](https://cloud.tencent.com/document/api/557/16142#Project)

### 第 9 次发布

发布时间：2020-03-19 08:07:20

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [DCDBShardInfo](https://cloud.tencent.com/document/api/557/16142#DCDBShardInfo)

	* 新增成员：Cpu

* [SpecConfigInfo](https://cloud.tencent.com/document/api/557/16142#SpecConfigInfo)

	* 新增成员：Cpu


### 第 8 次发布

发布时间：2020-03-16 08:08:20

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [DCDBInstanceInfo](https://cloud.tencent.com/document/api/557/16142#DCDBInstanceInfo)

	* 新增成员：Cpu

* [ParamDesc](https://cloud.tencent.com/document/api/557/16142#ParamDesc)

	* 新增成员：HaveSetValue

* [ShardInfo](https://cloud.tencent.com/document/api/557/16142#ShardInfo)

	* 新增成员：Cpu


### 第 7 次发布

发布时间：2020-02-13 17:00:33

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateDCDBInstance](https://cloud.tencent.com/document/api/557/16135)

	* 新增入参：SecurityGroupId, InstanceName

* [DescribeDCDBPrice](https://cloud.tencent.com/document/api/557/16131)

	* 新增入参：Paymode


修改数据结构：

* [DCDBShardInfo](https://cloud.tencent.com/document/api/557/16142#DCDBShardInfo)

	* 新增成员：Paymode, ShardMasterZone, ShardSlaveZones


### 第 6 次发布

发布时间：2019-08-26 15:13:13

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeDCDBInstances](https://cloud.tencent.com/document/api/557/16140)

	* 新增入参：ExclusterIds


修改数据结构：

* [DCDBShardInfo](https://cloud.tencent.com/document/api/557/16142#DCDBShardInfo)

	* 新增成员：Pid, ProxyVersion


### 第 5 次发布

发布时间：2019-05-09 19:17:08

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [DCDBInstanceInfo](https://cloud.tencent.com/document/api/557/16142#DCDBInstanceInfo)

	* 新增成员：IsAuditSupported

* [LogFileInfo](https://cloud.tencent.com/document/api/557/16142#LogFileInfo)

	* 新增成员：FileName


### 第 4 次发布

发布时间：2018-11-22 21:00:11

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [DCDBInstanceInfo](https://cloud.tencent.com/document/api/557/16142#DCDBInstanceInfo)

	* 新增成员：WanStatus


### 第 3 次发布

发布时间：2018-09-27 17:03:43

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CloneAccount](https://cloud.tencent.com/document/api/557/20255)
* [DescribeSqlLogs](https://cloud.tencent.com/document/api/557/20254)

新增数据结构：

* [SqlLogItem](https://cloud.tencent.com/document/api/557/16142#SqlLogItem)

### 第 2 次发布

发布时间：2018-09-20 12:25:48

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CloseDBExtranetAccess](https://cloud.tencent.com/document/api/557/19998)
* [CopyAccountPrivileges](https://cloud.tencent.com/document/api/557/19997)
* [CreateAccount](https://cloud.tencent.com/document/api/557/19996)
* [DeleteAccount](https://cloud.tencent.com/document/api/557/19995)
* [DescribeAccountPrivileges](https://cloud.tencent.com/document/api/557/19994)
* [DescribeAccounts](https://cloud.tencent.com/document/api/557/19993)
* [DescribeDBParameters](https://cloud.tencent.com/document/api/557/19992)
* [DescribeDBSyncMode](https://cloud.tencent.com/document/api/557/19991)
* [DescribeDCDBShards](https://cloud.tencent.com/document/api/557/19990)
* [DescribeDatabaseObjects](https://cloud.tencent.com/document/api/557/19989)
* [DescribeDatabaseTable](https://cloud.tencent.com/document/api/557/19988)
* [DescribeDatabases](https://cloud.tencent.com/document/api/557/19987)
* [GrantAccountPrivileges](https://cloud.tencent.com/document/api/557/19986)
* [InitDCDBInstances](https://cloud.tencent.com/document/api/557/19985)
* [ModifyAccountDescription](https://cloud.tencent.com/document/api/557/19984)
* [ModifyDBInstancesProject](https://cloud.tencent.com/document/api/557/19983)
* [ModifyDBParameters](https://cloud.tencent.com/document/api/557/19982)
* [ModifyDBSyncMode](https://cloud.tencent.com/document/api/557/19981)
* [OpenDBExtranetAccess](https://cloud.tencent.com/document/api/557/19980)
* [ResetAccountPassword](https://cloud.tencent.com/document/api/557/19979)

修改接口：

* [DescribeDBLogFiles](https://cloud.tencent.com/document/api/557/16133)

	* 新增出参：InstanceId, Type, Total, Files, VpcPrefix, NormalPrefix, ShardId

* [DescribeDCDBInstances](https://cloud.tencent.com/document/api/557/16140)

	* 新增入参：ExclusterType, IsFilterExcluster

	* <font color="#dd0000">**修改入参**：</font>IsFilterVpc


新增数据结构：

* [ConstraintRange](https://cloud.tencent.com/document/api/557/16142#ConstraintRange)
* [DBAccount](https://cloud.tencent.com/document/api/557/16142#DBAccount)
* [DBParamValue](https://cloud.tencent.com/document/api/557/16142#DBParamValue)
* [DCDBShardInfo](https://cloud.tencent.com/document/api/557/16142#DCDBShardInfo)
* [Database](https://cloud.tencent.com/document/api/557/16142#Database)
* [DatabaseFunction](https://cloud.tencent.com/document/api/557/16142#DatabaseFunction)
* [DatabaseProcedure](https://cloud.tencent.com/document/api/557/16142#DatabaseProcedure)
* [DatabaseTable](https://cloud.tencent.com/document/api/557/16142#DatabaseTable)
* [DatabaseView](https://cloud.tencent.com/document/api/557/16142#DatabaseView)
* [LogFileInfo](https://cloud.tencent.com/document/api/557/16142#LogFileInfo)
* [ParamConstraint](https://cloud.tencent.com/document/api/557/16142#ParamConstraint)
* [ParamDesc](https://cloud.tencent.com/document/api/557/16142#ParamDesc)
* [ParamModifyResult](https://cloud.tencent.com/document/api/557/16142#ParamModifyResult)
* [TableColumn](https://cloud.tencent.com/document/api/557/16142#TableColumn)

修改数据结构：

* [DCDBInstanceInfo](https://cloud.tencent.com/document/api/557/16142#DCDBInstanceInfo)

	* 新增成员：NodeCount, IsTmp, ExclusterId, UniqueVpcId, UniqueSubnetId, Id, WanDomain, WanVip, WanPort, Pid, UpdateTime, DbEngine, DbVersion, Paymode, Locker

* [Deal](https://cloud.tencent.com/document/api/557/16142#Deal)

	* 新增成员：PayMode

* [ShardInfo](https://cloud.tencent.com/document/api/557/16142#ShardInfo)

	* 新增成员：NodeCount, Pid


### 第 1 次发布

发布时间：2018-04-24

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateDCDBInstance](https://cloud.tencent.com/document/api/557/16135)
* [DescribeDBLogFiles](https://cloud.tencent.com/document/api/557/16133)
* [DescribeDCDBInstances](https://cloud.tencent.com/document/api/557/16140)
* [DescribeDCDBPrice](https://cloud.tencent.com/document/api/557/16131)
* [DescribeDCDBRenewalPrice](https://cloud.tencent.com/document/api/557/16138)
* [DescribeDCDBSaleInfo](https://cloud.tencent.com/document/api/557/16141)
* [DescribeDCDBUpgradePrice](https://cloud.tencent.com/document/api/557/16132)
* [DescribeOrders](https://cloud.tencent.com/document/api/557/16139)
* [DescribeShardSpec](https://cloud.tencent.com/document/api/557/16134)
* [RenewDCDBInstance](https://cloud.tencent.com/document/api/557/16137)
* [UpgradeDCDBInstance](https://cloud.tencent.com/document/api/557/16136)

新增数据结构：

* [AddShardConfig](https://cloud.tencent.com/document/api/557/16142#AddShardConfig)
* [DCDBInstanceInfo](https://cloud.tencent.com/document/api/557/16142#DCDBInstanceInfo)
* [Deal](https://cloud.tencent.com/document/api/557/16142#Deal)
* [ExpandShardConfig](https://cloud.tencent.com/document/api/557/16142#ExpandShardConfig)
* [RegionInfo](https://cloud.tencent.com/document/api/557/16142#RegionInfo)
* [ShardInfo](https://cloud.tencent.com/document/api/557/16142#ShardInfo)
* [ShardZoneChooseInfo](https://cloud.tencent.com/document/api/557/16142#ShardZoneChooseInfo)
* [SpecConfig](https://cloud.tencent.com/document/api/557/16142#SpecConfig)
* [SpecConfigInfo](https://cloud.tencent.com/document/api/557/16142#SpecConfigInfo)
* [SplitShardConfig](https://cloud.tencent.com/document/api/557/16142#SplitShardConfig)
* [ZonesInfo](https://cloud.tencent.com/document/api/557/16142#ZonesInfo)




## 数据湖计算 DLC(dlc) 版本：2021-01-25

### 第 98 次发布

发布时间：2024-07-31 01:28:29

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeNotebookSessions](https://cloud.tencent.com/document/api/1342/86309)

	* 新增入参：Filters

* [DescribeUpdatableDataEngines](https://cloud.tencent.com/document/api/1342/101606)

	* 新增入参：UseLakeFs, CustomResultPath


### 第 97 次发布

发布时间：2024-07-17 01:14:09

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeDataEngineImageVersions](https://cloud.tencent.com/document/api/1342/99270)

	* 新增入参：Sort, Asc


### 第 96 次发布

发布时间：2024-07-08 01:13:07

本次发布包含了以下内容：

改善已有的文档。

新增数据结构：

* [AccessInfo](https://cloud.tencent.com/document/api/1342/53778#AccessInfo)

修改数据结构：

* [DataEngineInfo](https://cloud.tencent.com/document/api/1342/53778#DataEngineInfo)

	* 新增成员：AccessInfos, EngineNetworkName


### 第 95 次发布

发布时间：2024-06-25 01:13:07

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeDataEnginesScaleDetail](https://cloud.tencent.com/document/api/1342/107670)

新增数据结构：

* [DataEngineScaleInfo](https://cloud.tencent.com/document/api/1342/53778#DataEngineScaleInfo)
* [DataEngineScaleInfoDetail](https://cloud.tencent.com/document/api/1342/53778#DataEngineScaleInfoDetail)

### 第 94 次发布

发布时间：2024-06-21 01:33:48

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeSparkSessionBatchSQLCost](https://cloud.tencent.com/document/api/1342/107549)

修改接口：

* [DescribeTasksOverview](https://cloud.tencent.com/document/api/1342/107503)

	* 新增入参：StartTime, EndTime, Filters, DataEngineName


新增数据结构：

* [BatchSQLCostInfo](https://cloud.tencent.com/document/api/1342/53778#BatchSQLCostInfo)

### 第 93 次发布

发布时间：2024-06-20 01:34:00

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeTasksOverview](https://cloud.tencent.com/document/api/1342/107503)

### 第 92 次发布

发布时间：2024-06-07 01:39:09

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateCHDFSBindingProduct](https://cloud.tencent.com/document/api/1342/107096)
* [DeleteCHDFSBindingProduct](https://cloud.tencent.com/document/api/1342/107095)
* [DeleteThirdPartyAccessUser](https://cloud.tencent.com/document/api/1342/107094)
* [DescribeDLCCatalogAccess](https://cloud.tencent.com/document/api/1342/107099)
* [DescribeOtherCHDFSBindingList](https://cloud.tencent.com/document/api/1342/107093)
* [DescribeSubUserAccessPolicy](https://cloud.tencent.com/document/api/1342/107092)
* [DescribeThirdPartyAccessUser](https://cloud.tencent.com/document/api/1342/107091)
* [GrantDLCCatalogAccess](https://cloud.tencent.com/document/api/1342/107098)
* [RegisterThirdPartyAccessUser](https://cloud.tencent.com/document/api/1342/107090)
* [RevokeDLCCatalogAccess](https://cloud.tencent.com/document/api/1342/107097)

新增数据结构：

* [CHDFSProductVpcInfo](https://cloud.tencent.com/document/api/1342/53778#CHDFSProductVpcInfo)
* [DLCCatalogAccess](https://cloud.tencent.com/document/api/1342/53778#DLCCatalogAccess)
* [MountPointAssociates](https://cloud.tencent.com/document/api/1342/53778#MountPointAssociates)
* [OpendThirdAccessUserInfo](https://cloud.tencent.com/document/api/1342/53778#OpendThirdAccessUserInfo)
* [OtherCHDFSBinding](https://cloud.tencent.com/document/api/1342/53778#OtherCHDFSBinding)
* [VpcCidrBlock](https://cloud.tencent.com/document/api/1342/53778#VpcCidrBlock)
* [VpcInfo](https://cloud.tencent.com/document/api/1342/53778#VpcInfo)

### 第 91 次发布

发布时间：2024-05-31 01:32:25

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeLakeFsInfo](https://cloud.tencent.com/document/api/1342/87873)

	* 新增出参：LakeFsInfos


新增数据结构：

* [LakeFsInfo](https://cloud.tencent.com/document/api/1342/53778#LakeFsInfo)

### 第 90 次发布

发布时间：2024-05-27 01:32:23

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [ListTaskJobLogName](https://cloud.tencent.com/document/api/1342/106581)

### 第 89 次发布

发布时间：2024-05-24 01:32:25

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [AddOptimizerEngines](https://cloud.tencent.com/document/api/1342/106546)
* [DescribeTasksCostInfo](https://cloud.tencent.com/document/api/1342/106547)

### 第 88 次发布

发布时间：2024-05-22 01:32:04

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeTaskLog](https://cloud.tencent.com/document/api/1342/106509)

### 第 87 次发布

发布时间：2024-05-09 01:13:34

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateTask](https://cloud.tencent.com/document/api/1342/53775)

	* 新增入参：ResourceGroupName

* [CreateTasks](https://cloud.tencent.com/document/api/1342/59274)

	* 新增入参：ResourceGroupName

* [DescribeTasks](https://cloud.tencent.com/document/api/1342/53771)

	* 新增入参：ResourceGroupName


修改数据结构：

* [DataEngineInfo](https://cloud.tencent.com/document/api/1342/53778#DataEngineInfo)

	* 新增成员：EngineResourceGroupCount, EngineResourceUsedCU

* [TaskResponseInfo](https://cloud.tencent.com/document/api/1342/53778#TaskResponseInfo)

	* 新增成员：EngineTypeDetail, ResourceGroupName


### 第 86 次发布

发布时间：2024-04-29 01:14:26

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [SparkJobInfo](https://cloud.tencent.com/document/api/1342/53778#SparkJobInfo)

	* 新增成员：EngineTypeDetail


### 第 85 次发布

发布时间：2024-04-23 01:14:24

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeNotebookSessionStatementSqlResult](https://cloud.tencent.com/document/api/1342/86307)

	* 新增出参：UseTime, AffectRows, DataAmount


### 第 84 次发布

发布时间：2024-03-28 01:14:58

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [TableBaseInfo](https://cloud.tencent.com/document/api/1342/53778#TableBaseInfo)


### 第 83 次发布

发布时间：2024-03-27 01:14:55

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [QueryTaskCostDetail](https://cloud.tencent.com/document/api/1342/104596)

### 第 82 次发布

发布时间：2024-03-21 01:14:28

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [DataEngineInfo](https://cloud.tencent.com/document/api/1342/53778#DataEngineInfo)

	* 新增成员：EngineNetworkId


### 第 81 次发布

发布时间：2024-02-23 01:13:43

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeTaskResult](https://cloud.tencent.com/document/api/1342/66644)

	* 新增入参：IsTransformDataType


### 第 80 次发布

发布时间：2024-02-21 01:13:43

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [TaskResultInfo](https://cloud.tencent.com/document/api/1342/53778#TaskResultInfo)

	* 新增成员：QueryResultTime


### 第 79 次发布

发布时间：2023-12-15 19:29:56

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CancelSparkSessionBatchSQL](https://cloud.tencent.com/document/api/1342/92839)

	* 新增入参：CustomKey

* [CreateSparkSessionBatchSQL](https://cloud.tencent.com/document/api/1342/92838)

	* 新增入参：CustomKey

* [DescribeSparkSessionBatchSQL](https://cloud.tencent.com/document/api/1342/98747)

	* 新增入参：CustomKey

* [DescribeSparkSessionBatchSqlLog](https://cloud.tencent.com/document/api/1342/92837)

	* 新增入参：CustomKey


### 第 78 次发布

发布时间：2023-12-07 01:38:53

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [NotebookSessionInfo](https://cloud.tencent.com/document/api/1342/53778#NotebookSessionInfo)

	* <font color="#dd0000">**修改成员**：</font>ExecutorMaxNumbers

* [TableResponseInfo](https://cloud.tencent.com/document/api/1342/53778#TableResponseInfo)

	* 新增成员：HeatValue

* [TaskResponseInfo](https://cloud.tencent.com/document/api/1342/53778#TaskResponseInfo)

	* 新增成员：ResultFormat


### 第 77 次发布

发布时间：2023-11-30 03:35:40

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [AssignMangedTableProperties](https://cloud.tencent.com/document/api/1342/102049)

### 第 76 次发布

发布时间：2023-11-17 01:13:25

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeTablesName](https://cloud.tencent.com/document/api/1342/101641)

### 第 75 次发布

发布时间：2023-11-16 01:15:33

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeUpdatableDataEngines](https://cloud.tencent.com/document/api/1342/101606)

修改接口：

* [CreateDataEngine](https://cloud.tencent.com/document/api/1342/87875)

	* 新增入参：EngineNetworkId, EngineGeneration

* [DescribeDataEngines](https://cloud.tencent.com/document/api/1342/86308)

	* 新增入参：EngineGeneration, EngineTypeDetail


新增数据结构：

* [DataEngineBasicInfo](https://cloud.tencent.com/document/api/1342/53778#DataEngineBasicInfo)

### 第 74 次发布

发布时间：2023-11-15 01:31:42

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [DataEngineInfo](https://cloud.tencent.com/document/api/1342/53778#DataEngineInfo)

	* 新增成员：EngineGeneration, EngineTypeDetail


### 第 73 次发布

发布时间：2023-11-13 00:11:03

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeDataEngineEvents](https://cloud.tencent.com/document/api/1342/101534)

新增数据结构：

* [HouseEventsInfo](https://cloud.tencent.com/document/api/1342/53778#HouseEventsInfo)

### 第 72 次发布

发布时间：2023-10-27 01:38:16

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeDatasourceConnection](https://cloud.tencent.com/document/api/1342/98586)

	* 新增入参：HiveVersion


### 第 71 次发布

发布时间：2023-10-24 01:13:16

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateSparkSessionBatchSQL](https://cloud.tencent.com/document/api/1342/92838)

	* 新增出参：Statements


新增数据结构：

* [StatementInformation](https://cloud.tencent.com/document/api/1342/53778#StatementInformation)

### 第 70 次发布

发布时间：2023-10-23 00:09:07

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeAdvancedStoreLocation](https://cloud.tencent.com/document/api/1342/100578)
* [ModifyAdvancedStoreLocation](https://cloud.tencent.com/document/api/1342/100577)

### 第 69 次发布

发布时间：2023-10-20 01:13:30

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeLakeFsTaskResult](https://cloud.tencent.com/document/api/1342/100446)

	* 新增入参：FsPath

	* 新增出参：AccessToken


新增数据结构：

* [LakeFileSystemToken](https://cloud.tencent.com/document/api/1342/53778#LakeFileSystemToken)

### 第 68 次发布

发布时间：2023-10-19 16:04:04

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeLakeFsTaskResult](https://cloud.tencent.com/document/api/1342/100446)

### 第 67 次发布

发布时间：2023-10-18 01:49:18

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateDataEngine](https://cloud.tencent.com/document/api/1342/87875)

	* 新增入参：AutoAuthorization


修改数据结构：

* [DataEngineInfo](https://cloud.tencent.com/document/api/1342/53778#DataEngineInfo)

	* 新增成员：AutoAuthorization

* [DataFormat](https://cloud.tencent.com/document/api/1342/53778#DataFormat)

	* <font color="#dd0000">**修改成员**：</font>TextFile, CSV, Json, Parquet, ORC, AVRO

* [DatabaseResponseInfo](https://cloud.tencent.com/document/api/1342/53778#DatabaseResponseInfo)

	* <font color="#dd0000">**修改成员**：</font>Comment, Properties, CreateTime, ModifiedTime

* [Other](https://cloud.tencent.com/document/api/1342/53778#Other)

	* <font color="#dd0000">**修改成员**：</font>Format

* [Partition](https://cloud.tencent.com/document/api/1342/53778#Partition)

	* <font color="#dd0000">**修改成员**：</font>Name, Type, Comment, Transform, TransformArgs, CreateTime

* [TableResponseInfo](https://cloud.tencent.com/document/api/1342/53778#TableResponseInfo)

	* <font color="#dd0000">**修改成员**：</font>MapMaterializedViewName

* [TextFile](https://cloud.tencent.com/document/api/1342/53778#TextFile)

	* <font color="#dd0000">**修改成员**：</font>Format, Regex


### 第 66 次发布

发布时间：2023-10-12 01:49:02

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [TColumn](https://cloud.tencent.com/document/api/1342/53778#TColumn)

	* 新增成员：Precision, Scale


### 第 65 次发布

发布时间：2023-10-11 01:40:01

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeUserDataEngineConfig](https://cloud.tencent.com/document/api/1342/99278)

	* 新增入参：Sorting, Limit, Offset, SortBy, Filters

	* 新增出参：DataEngineConfigInstanceInfos, TotalCount

* [RestartDataEngine](https://cloud.tencent.com/document/api/1342/99268)

	* 新增入参：DataEngineId, ForcedOperation

* [RollbackDataEngineImage](https://cloud.tencent.com/document/api/1342/99267)

	* 新增入参：DataEngineId, FromRecordId, ToRecordId

* [SwitchDataEngineImage](https://cloud.tencent.com/document/api/1342/99266)

	* 新增入参：DataEngineId, NewImageVersionId

* [UpdateDataEngineConfig](https://cloud.tencent.com/document/api/1342/99265)

	* 新增入参：DataEngineIds, DataEngineConfigCommand

* [UpdateUserDataEngineConfig](https://cloud.tencent.com/document/api/1342/99264)

	* 新增入参：DataEngineId, DataEngineConfigPairs, SessionResourceTemplate

* [UpgradeDataEngineImage](https://cloud.tencent.com/document/api/1342/99263)

	* 新增入参：DataEngineId


新增数据结构：

* [DataEngineConfigInstanceInfo](https://cloud.tencent.com/document/api/1342/53778#DataEngineConfigInstanceInfo)

修改数据结构：

* [DataEngineConfigPair](https://cloud.tencent.com/document/api/1342/53778#DataEngineConfigPair)

	* 新增成员：ConfigItem, ConfigValue


### 第 64 次发布

发布时间：2023-10-10 01:35:31

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [GetOptimizerPolicy](https://cloud.tencent.com/document/api/1342/99695)

新增数据结构：

* [FavorInfo](https://cloud.tencent.com/document/api/1342/53778#FavorInfo)
* [ResourceInfo](https://cloud.tencent.com/document/api/1342/53778#ResourceInfo)
* [SmartOptimizerIndexPolicy](https://cloud.tencent.com/document/api/1342/53778#SmartOptimizerIndexPolicy)
* [SmartOptimizerLifecyclePolicy](https://cloud.tencent.com/document/api/1342/53778#SmartOptimizerLifecyclePolicy)
* [SmartOptimizerPolicy](https://cloud.tencent.com/document/api/1342/53778#SmartOptimizerPolicy)
* [SmartOptimizerWrittenPolicy](https://cloud.tencent.com/document/api/1342/53778#SmartOptimizerWrittenPolicy)
* [SmartPolicy](https://cloud.tencent.com/document/api/1342/53778#SmartPolicy)
* [SmartPolicyBaseInfo](https://cloud.tencent.com/document/api/1342/53778#SmartPolicyBaseInfo)

修改数据结构：

* [TableBaseInfo](https://cloud.tencent.com/document/api/1342/53778#TableBaseInfo)

	* 新增成员：SmartPolicy


### 第 63 次发布

发布时间：2023-10-09 01:13:07

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CheckDataEngineConfigPairsValidity](https://cloud.tencent.com/document/api/1342/99277)
* [CheckDataEngineImageCanBeRollback](https://cloud.tencent.com/document/api/1342/99276)
* [CheckDataEngineImageCanBeUpgrade](https://cloud.tencent.com/document/api/1342/99275)
* [DeleteDataEngine](https://cloud.tencent.com/document/api/1342/99279)
* [DescribeDataEngine](https://cloud.tencent.com/document/api/1342/99274)
* [DescribeDataEngineImageVersions](https://cloud.tencent.com/document/api/1342/99270)
* [DescribeDataEnginePythonSparkImages](https://cloud.tencent.com/document/api/1342/99273)
* [DescribeUserDataEngineConfig](https://cloud.tencent.com/document/api/1342/99278)
* [DescribeUserInfo](https://cloud.tencent.com/document/api/1342/99262)
* [DescribeUserType](https://cloud.tencent.com/document/api/1342/99261)
* [DescribeWorkGroupInfo](https://cloud.tencent.com/document/api/1342/99260)
* [ModifyDataEngineDescription](https://cloud.tencent.com/document/api/1342/99269)
* [ModifyUserType](https://cloud.tencent.com/document/api/1342/99259)
* [RenewDataEngine](https://cloud.tencent.com/document/api/1342/99272)
* [RestartDataEngine](https://cloud.tencent.com/document/api/1342/99268)
* [RollbackDataEngineImage](https://cloud.tencent.com/document/api/1342/99267)
* [SwitchDataEngineImage](https://cloud.tencent.com/document/api/1342/99266)
* [UpdateDataEngine](https://cloud.tencent.com/document/api/1342/99271)
* [UpdateDataEngineConfig](https://cloud.tencent.com/document/api/1342/99265)
* [UpdateUserDataEngineConfig](https://cloud.tencent.com/document/api/1342/99264)
* [UpgradeDataEngineImage](https://cloud.tencent.com/document/api/1342/99263)

新增数据结构：

* [DataEngineImageVersion](https://cloud.tencent.com/document/api/1342/53778#DataEngineImageVersion)
* [Policys](https://cloud.tencent.com/document/api/1342/53778#Policys)
* [PythonSparkImage](https://cloud.tencent.com/document/api/1342/53778#PythonSparkImage)
* [UserDetailInfo](https://cloud.tencent.com/document/api/1342/53778#UserDetailInfo)
* [Users](https://cloud.tencent.com/document/api/1342/53778#Users)
* [WorkGroupDetailInfo](https://cloud.tencent.com/document/api/1342/53778#WorkGroupDetailInfo)
* [WorkGroups](https://cloud.tencent.com/document/api/1342/53778#WorkGroups)

### 第 62 次发布

发布时间：2023-09-22 01:40:45

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeSparkSessionBatchSQL](https://cloud.tencent.com/document/api/1342/98747)

新增数据结构：

* [BatchSqlTask](https://cloud.tencent.com/document/api/1342/53778#BatchSqlTask)

### 第 61 次发布

发布时间：2023-09-18 01:38:17

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeDatasourceConnection](https://cloud.tencent.com/document/api/1342/98586)

新增数据结构：

* [DataSourceInfo](https://cloud.tencent.com/document/api/1342/53778#DataSourceInfo)
* [DatasourceConnectionConfig](https://cloud.tencent.com/document/api/1342/53778#DatasourceConnectionConfig)
* [DatasourceConnectionInfo](https://cloud.tencent.com/document/api/1342/53778#DatasourceConnectionInfo)
* [DatasourceConnectionLocation](https://cloud.tencent.com/document/api/1342/53778#DatasourceConnectionLocation)
* [ElasticsearchInfo](https://cloud.tencent.com/document/api/1342/53778#ElasticsearchInfo)
* [HiveInfo](https://cloud.tencent.com/document/api/1342/53778#HiveInfo)
* [IpPortPair](https://cloud.tencent.com/document/api/1342/53778#IpPortPair)
* [KafkaInfo](https://cloud.tencent.com/document/api/1342/53778#KafkaInfo)
* [KerberosInfo](https://cloud.tencent.com/document/api/1342/53778#KerberosInfo)
* [MysqlInfo](https://cloud.tencent.com/document/api/1342/53778#MysqlInfo)
* [OtherDatasourceConnection](https://cloud.tencent.com/document/api/1342/53778#OtherDatasourceConnection)

### 第 60 次发布

发布时间：2023-09-15 01:40:11

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [QueryResult](https://cloud.tencent.com/document/api/1342/98524)

### 第 59 次发布

发布时间：2023-08-09 01:22:16

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateNotebookSession](https://cloud.tencent.com/document/api/1342/86113)

	* 新增入参：IsInherit

* [CreateSparkSessionBatchSQL](https://cloud.tencent.com/document/api/1342/92838)

	* 新增入参：IsInherit


### 第 58 次发布

发布时间：2023-08-07 01:10:42

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeUserRoles](https://cloud.tencent.com/document/api/1342/96019)

新增数据结构：

* [CosPermission](https://cloud.tencent.com/document/api/1342/53778#CosPermission)
* [UserRole](https://cloud.tencent.com/document/api/1342/53778#UserRole)

### 第 57 次发布

发布时间：2023-08-01 01:17:48

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [CommonMetrics](https://cloud.tencent.com/document/api/1342/53778#CommonMetrics)

	* <font color="#dd0000">**修改成员**：</font>CreateTaskTime, ProcessTime, QueueTime, ExecutionTime, IsResultCacheHit, MatchedMVBytes, MatchedMVs, AffectedBytes, AffectedRows, ProcessedBytes, ProcessedRows


### 第 56 次发布

发布时间：2023-07-20 01:23:15

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [SparkJobInfo](https://cloud.tencent.com/document/api/1342/53778#SparkJobInfo)

	* 新增成员：IsSessionStarted

	* <font color="#dd0000">**修改成员**：</font>JobExecutorMaxNumbers, SparkImageVersion, SessionId, DataEngineClusterType, DataEngineImageVersion, IsInherit


### 第 55 次发布

发布时间：2023-07-18 01:26:15

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [TaskResponseInfo](https://cloud.tencent.com/document/api/1342/53778#TaskResponseInfo)

	* <font color="#dd0000">**修改成员**：</font>DriverSize, ExecutorSize, ExecutorNums, ExecutorMaxNumbers, CommonMetrics, SparkMonitorMetrics, PrestoMonitorMetrics


### 第 54 次发布

发布时间：2023-07-05 01:21:49

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateNotebookSession](https://cloud.tencent.com/document/api/1342/86113)

	* 新增入参：SparkImage

* [CreateSparkApp](https://cloud.tencent.com/document/api/1342/74538)

	* 新增入参：IsSessionStarted

* [ModifySparkApp](https://cloud.tencent.com/document/api/1342/74532)

	* 新增入参：IsSessionStarted


### 第 53 次发布

发布时间：2023-07-03 01:18:43

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateDataEngine](https://cloud.tencent.com/document/api/1342/87875)


### 第 52 次发布

发布时间：2023-06-20 01:28:13

本次发布包含了以下内容：

改善已有的文档。

新增数据结构：

* [CommonMetrics](https://cloud.tencent.com/document/api/1342/53778#CommonMetrics)
* [PrestoMonitorMetrics](https://cloud.tencent.com/document/api/1342/53778#PrestoMonitorMetrics)
* [SparkMonitorMetrics](https://cloud.tencent.com/document/api/1342/53778#SparkMonitorMetrics)

修改数据结构：

* [TaskResponseInfo](https://cloud.tencent.com/document/api/1342/53778#TaskResponseInfo)

	* 新增成员：CommonMetrics, SparkMonitorMetrics, PrestoMonitorMetrics


### 第 51 次发布

发布时间：2023-06-07 01:20:44

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [ModifySparkAppBatch](https://cloud.tencent.com/document/api/1342/93213)

### 第 50 次发布

发布时间：2023-06-05 01:24:50

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateDataEngine](https://cloud.tencent.com/document/api/1342/87875)

	* 新增入参：SessionResourceTemplate

* [CreateSparkApp](https://cloud.tencent.com/document/api/1342/74538)

	* 新增入参：IsInherit

* [ModifySparkApp](https://cloud.tencent.com/document/api/1342/74532)

	* 新增入参：IsInherit


新增数据结构：

* [SessionResourceTemplate](https://cloud.tencent.com/document/api/1342/53778#SessionResourceTemplate)

修改数据结构：

* [DataEngineInfo](https://cloud.tencent.com/document/api/1342/53778#DataEngineInfo)

	* 新增成员：DefaultHouse, MaxConcurrency, TolerableQueueTime, UserAppId, UserUin, SessionResourceTemplate

* [SparkJobInfo](https://cloud.tencent.com/document/api/1342/53778#SparkJobInfo)

	* 新增成员：IsInherit

* [TableResponseInfo](https://cloud.tencent.com/document/api/1342/53778#TableResponseInfo)

	* 新增成员：MapMaterializedViewName

* [TaskResponseInfo](https://cloud.tencent.com/document/api/1342/53778#TaskResponseInfo)

	* 新增成员：ImageVersion, DriverSize, ExecutorSize, ExecutorNums, ExecutorMaxNumbers


### 第 49 次发布

发布时间：2023-05-29 01:21:27

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CancelSparkSessionBatchSQL](https://cloud.tencent.com/document/api/1342/92839)
* [CreateSparkSessionBatchSQL](https://cloud.tencent.com/document/api/1342/92838)
* [DescribeSparkSessionBatchSqlLog](https://cloud.tencent.com/document/api/1342/92837)

新增数据结构：

* [SparkSessionBatchLog](https://cloud.tencent.com/document/api/1342/53778#SparkSessionBatchLog)
* [SparkSessionBatchLogOperate](https://cloud.tencent.com/document/api/1342/53778#SparkSessionBatchLogOperate)

### 第 48 次发布

发布时间：2023-05-15 01:32:47

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [GenerateCreateMangedTableSql](https://cloud.tencent.com/document/api/1342/86306)

	* 新增入参：UpsertKeys


修改数据结构：

* [DataGovernPolicy](https://cloud.tencent.com/document/api/1342/53778#DataGovernPolicy)

	* 新增成员：RuleType, GovernEngine

* [TableBaseInfo](https://cloud.tencent.com/document/api/1342/53778#TableBaseInfo)

	* 新增成员：DbGovernPolicyIsDisable


### 第 47 次发布

发布时间：2023-04-27 01:17:49

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [SparkJobInfo](https://cloud.tencent.com/document/api/1342/53778#SparkJobInfo)

	* 新增成员：DataEngineClusterType, DataEngineImageVersion


### 第 46 次发布

发布时间：2023-04-19 01:26:51

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateSparkApp](https://cloud.tencent.com/document/api/1342/74538)

	* 新增入参：SessionId

* [DescribeNotebookSessionStatement](https://cloud.tencent.com/document/api/1342/86311)

	* 新增入参：TaskId

* [ListTaskJobLogDetail](https://cloud.tencent.com/document/api/1342/75645)

	* 新增入参：BatchId

	* 新增出参：LogUrl

* [ModifySparkApp](https://cloud.tencent.com/document/api/1342/74532)

	* 新增入参：SessionId


修改数据结构：

* [DataEngineInfo](https://cloud.tencent.com/document/api/1342/53778#DataEngineInfo)

	* 新增成员：ElasticSwitch, ElasticLimit

* [JobLogResult](https://cloud.tencent.com/document/api/1342/53778#JobLogResult)

	* 新增成员：PkgLogId

* [SparkJobInfo](https://cloud.tencent.com/document/api/1342/53778#SparkJobInfo)

	* 新增成员：SessionId


### 第 45 次发布

发布时间：2023-04-11 01:16:50

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateDataEngine](https://cloud.tencent.com/document/api/1342/87875)

	* 新增入参：ElasticSwitch, ElasticLimit


### 第 44 次发布

发布时间：2023-03-27 01:43:04

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [SparkJobInfo](https://cloud.tencent.com/document/api/1342/53778#SparkJobInfo)

	* 新增成员：SparkImageVersion


### 第 43 次发布

发布时间：2023-03-10 01:29:04

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeForbiddenTablePro](https://cloud.tencent.com/document/api/1342/88102)

### 第 42 次发布

发布时间：2023-03-07 01:19:41

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateDataEngine](https://cloud.tencent.com/document/api/1342/87875)
* [DescribeEngineUsageInfo](https://cloud.tencent.com/document/api/1342/87876)
* [DescribeLakeFsDirSummary](https://cloud.tencent.com/document/api/1342/87874)
* [DescribeLakeFsInfo](https://cloud.tencent.com/document/api/1342/87873)
* [SwitchDataEngine](https://cloud.tencent.com/document/api/1342/87872)
* [UpdateRowFilter](https://cloud.tencent.com/document/api/1342/87871)

新增数据结构：

* [DataEngineConfigPair](https://cloud.tencent.com/document/api/1342/53778#DataEngineConfigPair)

修改数据结构：

* [DataEngineInfo](https://cloud.tencent.com/document/api/1342/53778#DataEngineInfo)

	* 新增成员：StartStandbyCluster

* [Policy](https://cloud.tencent.com/document/api/1342/53778#Policy)

	* 新增成员：Id


### 第 41 次发布

发布时间：2023-02-16 01:22:07

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [DataEngineInfo](https://cloud.tencent.com/document/api/1342/53778#DataEngineInfo)

	* 新增成员：ResourceType, ImageVersionId, ChildImageVersionId, ImageVersionName


### 第 40 次发布

发布时间：2023-02-10 01:28:27

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [GenerateCreateMangedTableSql](https://cloud.tencent.com/document/api/1342/86306)

	* 新增入参：TableBaseInfo, Columns, Partitions, Properties

	* 新增出参：Execution


### 第 39 次发布

发布时间：2023-02-09 01:30:43

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CancelNotebookSessionStatement](https://cloud.tencent.com/document/api/1342/86317)
* [CancelNotebookSessionStatementBatch](https://cloud.tencent.com/document/api/1342/86316)
* [CreateNotebookSessionStatement](https://cloud.tencent.com/document/api/1342/86315)
* [CreateNotebookSessionStatementSupportBatchSQL](https://cloud.tencent.com/document/api/1342/86314)
* [DeleteNotebookSession](https://cloud.tencent.com/document/api/1342/86313)
* [DescribeDataEngines](https://cloud.tencent.com/document/api/1342/86308)
* [DescribeNotebookSessionLog](https://cloud.tencent.com/document/api/1342/86312)
* [DescribeNotebookSessionStatement](https://cloud.tencent.com/document/api/1342/86311)
* [DescribeNotebookSessionStatementSqlResult](https://cloud.tencent.com/document/api/1342/86307)
* [DescribeNotebookSessionStatements](https://cloud.tencent.com/document/api/1342/86310)
* [DescribeNotebookSessions](https://cloud.tencent.com/document/api/1342/86309)
* [GenerateCreateMangedTableSql](https://cloud.tencent.com/document/api/1342/86306)

新增数据结构：

* [CrontabResumeSuspendStrategy](https://cloud.tencent.com/document/api/1342/53778#CrontabResumeSuspendStrategy)
* [DataEngineInfo](https://cloud.tencent.com/document/api/1342/53778#DataEngineInfo)
* [NetworkConnection](https://cloud.tencent.com/document/api/1342/53778#NetworkConnection)
* [NotebookSessionStatementBatchInformation](https://cloud.tencent.com/document/api/1342/53778#NotebookSessionStatementBatchInformation)
* [NotebookSessionStatementInfo](https://cloud.tencent.com/document/api/1342/53778#NotebookSessionStatementInfo)
* [NotebookSessions](https://cloud.tencent.com/document/api/1342/53778#NotebookSessions)
* [StatementOutput](https://cloud.tencent.com/document/api/1342/53778#StatementOutput)
* [TagInfo](https://cloud.tencent.com/document/api/1342/53778#TagInfo)

### 第 38 次发布

发布时间：2023-02-08 01:31:40

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateInternalTable](https://cloud.tencent.com/document/api/1342/86255)

新增数据结构：

* [TColumn](https://cloud.tencent.com/document/api/1342/53778#TColumn)
* [TPartition](https://cloud.tencent.com/document/api/1342/53778#TPartition)

### 第 37 次发布

发布时间：2023-02-07 01:25:26

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [ModifyGovernEventRule](https://cloud.tencent.com/document/api/1342/86163)

修改接口：

* [CreateSparkApp](https://cloud.tencent.com/document/api/1342/74538)

	* 新增入参：SparkImage, SparkImageVersion, AppExecutorMaxNumbers

	* 新增出参：SparkAppId

* [ModifySparkApp](https://cloud.tencent.com/document/api/1342/74532)

	* 新增入参：SparkImage, SparkImageVersion, AppExecutorMaxNumbers


修改数据结构：

* [SparkJobInfo](https://cloud.tencent.com/document/api/1342/53778#SparkJobInfo)

	* 新增成员：SparkImage, JobExecutorMaxNumbers


### 第 36 次发布

发布时间：2023-02-06 01:36:57

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateNotebookSession](https://cloud.tencent.com/document/api/1342/86113)
* [DescribeNotebookSession](https://cloud.tencent.com/document/api/1342/86112)

新增数据结构：

* [NotebookSessionInfo](https://cloud.tencent.com/document/api/1342/53778#NotebookSessionInfo)

### 第 35 次发布

发布时间：2023-01-10 01:20:24

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [SuspendResumeDataEngine](https://cloud.tencent.com/document/api/1342/85563)

### 第 34 次发布

发布时间：2022-11-24 06:27:21

本次发布包含了以下内容：

改善已有的文档。

新增数据结构：

* [DataGovernPolicy](https://cloud.tencent.com/document/api/1342/53778#DataGovernPolicy)

修改数据结构：

* [DatabaseResponseInfo](https://cloud.tencent.com/document/api/1342/53778#DatabaseResponseInfo)

	* 新增成员：GovernPolicy, DatabaseId

* [TableBaseInfo](https://cloud.tencent.com/document/api/1342/53778#TableBaseInfo)

	* 新增成员：GovernPolicy


### 第 33 次发布

发布时间：2022-10-27 14:41:42

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateResultDownload](https://cloud.tencent.com/document/api/1342/82008)
* [DescribeResultDownload](https://cloud.tencent.com/document/api/1342/82007)

### 第 32 次发布

发布时间：2022-09-14 06:20:02

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [TaskResponseInfo](https://cloud.tencent.com/document/api/1342/53778#TaskResponseInfo)

	* 新增成员：CmdArgs


### 第 31 次发布

发布时间：2022-08-30 06:26:45

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeTasks](https://cloud.tencent.com/document/api/1342/53771)

	* 新增出参：TasksOverview


新增数据结构：

* [TasksOverview](https://cloud.tencent.com/document/api/1342/53778#TasksOverview)

修改数据结构：

* [TaskResponseInfo](https://cloud.tencent.com/document/api/1342/53778#TaskResponseInfo)

	* 新增成员：TotalTime

* [TaskResultInfo](https://cloud.tencent.com/document/api/1342/53778#TaskResultInfo)

	* 新增成员：TotalTime


### 第 30 次发布

发布时间：2022-07-28 06:10:28

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [ListTaskJobLogDetail](https://cloud.tencent.com/document/api/1342/75645)

	* 新增入参：Asc, Filters


修改数据结构：

* [SparkJobInfo](https://cloud.tencent.com/document/api/1342/53778#SparkJobInfo)

	* 新增成员：DataEngineStatus


### 第 29 次发布

发布时间：2022-07-21 06:07:59

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeSparkAppTasks](https://cloud.tencent.com/document/api/1342/74533)

	* 新增入参：StartTime, EndTime, Filters


修改数据结构：

* [DatabaseResponseInfo](https://cloud.tencent.com/document/api/1342/53778#DatabaseResponseInfo)

	* 新增成员：Location, UserAlias, UserSubUin

* [TableBaseInfo](https://cloud.tencent.com/document/api/1342/53778#TableBaseInfo)

	* 新增成员：UserAlias, UserSubUin

* [ViewBaseInfo](https://cloud.tencent.com/document/api/1342/53778#ViewBaseInfo)

	* 新增成员：UserAlias, UserSubUin


### 第 28 次发布

发布时间：2022-07-13 06:09:56

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateSparkApp](https://cloud.tencent.com/document/api/1342/74538)

	* 新增入参：IsLocalArchives, AppArchives

* [ModifySparkApp](https://cloud.tencent.com/document/api/1342/74532)

	* 新增入参：IsLocalArchives, AppArchives


修改数据结构：

* [SparkJobInfo](https://cloud.tencent.com/document/api/1342/53778#SparkJobInfo)

	* 新增成员：IsLocalArchives, JobArchives, JobPythonFiles, TaskNum


### 第 27 次发布

发布时间：2022-07-06 06:11:44

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [AlterDMSDatabase](https://cloud.tencent.com/document/api/1342/76232)

	* 新增入参：CurrentName, SchemaName, Location, Asset

* [CreateDMSDatabase](https://cloud.tencent.com/document/api/1342/76229)

	* 新增入参：Asset, SchemaName, Location

* [DescribeDMSDatabase](https://cloud.tencent.com/document/api/1342/76227)

	* 新增入参：Name, SchemaName, Pattern

	* 新增出参：Name, SchemaName, Location, Asset

* [DescribeDMSPartitions](https://cloud.tencent.com/document/api/1342/76226)

	* 新增入参：Expression

* [DropDMSDatabase](https://cloud.tencent.com/document/api/1342/76223)

	* 新增入参：Name, DeleteData, Cascade


修改数据结构：

* [Asset](https://cloud.tencent.com/document/api/1342/53778#Asset)

	* 新增成员：Id, Name, Guid, Catalog, Description, Owner, OwnerAccount, PermValues, Params, BizParams, DataVersion, CreateTime, ModifiedTime, DatasourceId


### 第 26 次发布

发布时间：2022-07-05 06:12:13

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [AlterDMSTable](https://cloud.tencent.com/document/api/1342/76230)

	* 新增入参：Name


### 第 25 次发布

发布时间：2022-07-04 06:07:50

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [ReportHeartbeatMetaData](https://cloud.tencent.com/document/api/1342/76375)

### 第 24 次发布

发布时间：2022-07-01 06:10:47

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CheckLockMetaData](https://cloud.tencent.com/document/api/1342/76325)
* [LockMetaData](https://cloud.tencent.com/document/api/1342/76324)
* [UnlockMetaData](https://cloud.tencent.com/document/api/1342/76323)

新增数据结构：

* [LockComponentInfo](https://cloud.tencent.com/document/api/1342/53778#LockComponentInfo)

### 第 23 次发布

发布时间：2022-06-30 06:05:38

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [AddDMSPartitions](https://cloud.tencent.com/document/api/1342/76233)
* [AlterDMSDatabase](https://cloud.tencent.com/document/api/1342/76232)
* [AlterDMSPartition](https://cloud.tencent.com/document/api/1342/76231)
* [AlterDMSTable](https://cloud.tencent.com/document/api/1342/76230)
* [CreateDMSDatabase](https://cloud.tencent.com/document/api/1342/76229)
* [CreateDMSTable](https://cloud.tencent.com/document/api/1342/76228)
* [DescribeDMSDatabase](https://cloud.tencent.com/document/api/1342/76227)
* [DescribeDMSPartitions](https://cloud.tencent.com/document/api/1342/76226)
* [DescribeDMSTable](https://cloud.tencent.com/document/api/1342/76225)
* [DescribeDMSTables](https://cloud.tencent.com/document/api/1342/76224)
* [DropDMSDatabase](https://cloud.tencent.com/document/api/1342/76223)
* [DropDMSPartitions](https://cloud.tencent.com/document/api/1342/76222)
* [DropDMSTable](https://cloud.tencent.com/document/api/1342/76221)

新增数据结构：

* [Asset](https://cloud.tencent.com/document/api/1342/53778#Asset)
* [DMSColumn](https://cloud.tencent.com/document/api/1342/53778#DMSColumn)
* [DMSColumnOrder](https://cloud.tencent.com/document/api/1342/53778#DMSColumnOrder)
* [DMSPartition](https://cloud.tencent.com/document/api/1342/53778#DMSPartition)
* [DMSSds](https://cloud.tencent.com/document/api/1342/53778#DMSSds)
* [DMSTable](https://cloud.tencent.com/document/api/1342/53778#DMSTable)
* [DMSTableInfo](https://cloud.tencent.com/document/api/1342/53778#DMSTableInfo)

### 第 22 次发布

发布时间：2022-06-21 06:06:29

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeSparkAppTasks](https://cloud.tencent.com/document/api/1342/74533)

	* 新增入参：TaskId


### 第 21 次发布

发布时间：2022-06-16 06:06:01

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [ListTaskJobLogDetail](https://cloud.tencent.com/document/api/1342/75645)

新增数据结构：

* [JobLogResult](https://cloud.tencent.com/document/api/1342/53778#JobLogResult)

### 第 20 次发布

发布时间：2022-06-14 06:10:10

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [Column](https://cloud.tencent.com/document/api/1342/53778#Column)

	* 新增成员：IsPartition


### 第 19 次发布

发布时间：2022-06-07 06:06:14

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeSparkAppTasks](https://cloud.tencent.com/document/api/1342/74533)

	* 新增出参：SparkAppTasks


### 第 18 次发布

发布时间：2022-06-01 06:09:45

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateSparkApp](https://cloud.tencent.com/document/api/1342/74538)

	* 新增入参：IsLocalPythonFiles, AppPythonFiles

* [ModifySparkApp](https://cloud.tencent.com/document/api/1342/74532)

	* 新增入参：IsLocalPythonFiles, AppPythonFiles


修改数据结构：

* [SparkJobInfo](https://cloud.tencent.com/document/api/1342/53778#SparkJobInfo)

	* 新增成员：IsLocalPythonFiles, AppPythonFiles


### 第 17 次发布

发布时间：2022-05-26 18:17:40

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateSparkApp](https://cloud.tencent.com/document/api/1342/74538)
* [CreateSparkAppTask](https://cloud.tencent.com/document/api/1342/74537)
* [DeleteSparkApp](https://cloud.tencent.com/document/api/1342/74536)
* [DescribeSparkAppJob](https://cloud.tencent.com/document/api/1342/74535)
* [DescribeSparkAppJobs](https://cloud.tencent.com/document/api/1342/74534)
* [DescribeSparkAppTasks](https://cloud.tencent.com/document/api/1342/74533)
* [ModifySparkApp](https://cloud.tencent.com/document/api/1342/74532)

新增数据结构：

* [SparkJobInfo](https://cloud.tencent.com/document/api/1342/53778#SparkJobInfo)
* [StreamingStatistics](https://cloud.tencent.com/document/api/1342/53778#StreamingStatistics)

### 第 16 次发布

发布时间：2022-05-20 06:10:49

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [TaskResponseInfo](https://cloud.tencent.com/document/api/1342/53778#TaskResponseInfo)

	* 新增成员：SparkJobName, SparkJobId, SparkJobFile, UiUrl


### 第 15 次发布

发布时间：2022-05-12 06:10:06

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeTables](https://cloud.tencent.com/document/api/1342/53767)

	* 新增入参：TableFormat


修改数据结构：

* [Partition](https://cloud.tencent.com/document/api/1342/53778#Partition)

	* 新增成员：Transform, TransformArgs, CreateTime

* [Policy](https://cloud.tencent.com/document/api/1342/53778#Policy)

	* 新增成员：SourceId, SourceName


### 第 14 次发布

发布时间：2022-04-27 06:09:39

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [TasksInfo](https://cloud.tencent.com/document/api/1342/53778#TasksInfo)

	* 新增成员：Params


### 第 13 次发布

发布时间：2022-04-21 06:11:18

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateUser](https://cloud.tencent.com/document/api/1342/58465)

	* 新增入参：UserAlias


修改数据结构：

* [TaskResponseInfo](https://cloud.tencent.com/document/api/1342/53778#TaskResponseInfo)

	* 新增成员：UserAlias

* [UserInfo](https://cloud.tencent.com/document/api/1342/53778#UserInfo)

	* 新增成员：UserAlias

* [UserMessage](https://cloud.tencent.com/document/api/1342/53778#UserMessage)

	* 新增成员：UserAlias


### 第 12 次发布

发布时间：2022-03-22 08:08:11

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateExportTask](https://cloud.tencent.com/document/api/1342/71477)
* [CreateImportTask](https://cloud.tencent.com/document/api/1342/71476)

### 第 11 次发布

发布时间：2022-03-18 08:10:58

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateUser](https://cloud.tencent.com/document/api/1342/58465)

	* 新增入参：UserType, WorkGroupIds

* [CreateWorkGroup](https://cloud.tencent.com/document/api/1342/58464)

	* 新增入参：UserIds


### 第 10 次发布

发布时间：2022-03-17 08:06:17

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeUsers](https://cloud.tencent.com/document/api/1342/58460)

	* 新增入参：Filters


修改数据结构：

* [Policy](https://cloud.tencent.com/document/api/1342/53778#Policy)

	* 新增成员：Function, View, Column, DataEngine, ReAuth, Source, Mode, Operator, CreateTime

* [TableResponseInfo](https://cloud.tencent.com/document/api/1342/53778#TableResponseInfo)

	* 新增成员：StorageSize, RecordCount

* [UserInfo](https://cloud.tencent.com/document/api/1342/53778#UserInfo)

	* 新增成员：UserType


### 第 9 次发布

发布时间：2021-12-22 08:10:52

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeTaskResult](https://cloud.tencent.com/document/api/1342/66644)

新增数据结构：

* [TaskResultInfo](https://cloud.tencent.com/document/api/1342/53778#TaskResultInfo)

### 第 8 次发布

发布时间：2021-12-17 08:10:39

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateTask](https://cloud.tencent.com/document/api/1342/53775)

	* 新增入参：DataEngineName

* [CreateTasks](https://cloud.tencent.com/document/api/1342/59274)

	* 新增入参：DataEngineName

* [DescribeDatabases](https://cloud.tencent.com/document/api/1342/53773)

	* 新增入参：Sort, Asc

* [DescribeTables](https://cloud.tencent.com/document/api/1342/53767)

	* 新增入参：StartTime, EndTime, Sort, Asc, TableType

* [DescribeTasks](https://cloud.tencent.com/document/api/1342/53771)

	* 新增入参：DataEngineName

* [DescribeViews](https://cloud.tencent.com/document/api/1342/53766)

	* 新增入参：Sort, Asc, StartTime, EndTime


修改数据结构：

* [Column](https://cloud.tencent.com/document/api/1342/53778#Column)

	* 新增成员：Position, CreateTime, ModifiedTime

* [DatabaseInfo](https://cloud.tencent.com/document/api/1342/53778#DatabaseInfo)

	* 新增成员：Location

* [TableBaseInfo](https://cloud.tencent.com/document/api/1342/53778#TableBaseInfo)

	* 新增成员：TableComment, Type, TableFormat

* [TaskResponseInfo](https://cloud.tencent.com/document/api/1342/53778#TaskResponseInfo)

	* 新增成员：UpdateTime, DataEngineId, OperateUin, DataEngineName, InputType, InputConf, DataNumber, CanDownload


### 第 7 次发布

发布时间：2021-09-28 08:04:47

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [Column](https://cloud.tencent.com/document/api/1342/53778#Column)

	* 新增成员：Precision, Scale, Nullable

* [Policy](https://cloud.tencent.com/document/api/1342/53778#Policy)

	* 新增成员：PolicyType


### 第 6 次发布

发布时间：2021-08-25 08:00:48

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [TaskResponseInfo](https://cloud.tencent.com/document/api/1342/53778#TaskResponseInfo)

	* 新增成员：ProgressDetail


### 第 5 次发布

发布时间：2021-07-29 08:00:52

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateTasks](https://cloud.tencent.com/document/api/1342/59274)

### 第 4 次发布

发布时间：2021-07-28 08:00:47

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateTasksInOrder](https://cloud.tencent.com/document/api/1342/59238)

新增数据结构：

* [TasksInfo](https://cloud.tencent.com/document/api/1342/53778#TasksInfo)

### 第 3 次发布

发布时间：2021-07-12 08:00:40

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [AddUsersToWorkGroup](https://cloud.tencent.com/document/api/1342/58469)
* [AttachUserPolicy](https://cloud.tencent.com/document/api/1342/58468)
* [AttachWorkGroupPolicy](https://cloud.tencent.com/document/api/1342/58467)
* [BindWorkGroupsToUser](https://cloud.tencent.com/document/api/1342/58466)
* [CancelTask](https://cloud.tencent.com/document/api/1342/58476)
* [CreateUser](https://cloud.tencent.com/document/api/1342/58465)
* [CreateWorkGroup](https://cloud.tencent.com/document/api/1342/58464)
* [DeleteUser](https://cloud.tencent.com/document/api/1342/58463)
* [DeleteUsersFromWorkGroup](https://cloud.tencent.com/document/api/1342/58462)
* [DeleteWorkGroup](https://cloud.tencent.com/document/api/1342/58461)
* [DescribeStoreLocation](https://cloud.tencent.com/document/api/1342/58471)
* [DescribeUsers](https://cloud.tencent.com/document/api/1342/58460)
* [DescribeWorkGroups](https://cloud.tencent.com/document/api/1342/58459)
* [DetachUserPolicy](https://cloud.tencent.com/document/api/1342/58458)
* [DetachWorkGroupPolicy](https://cloud.tencent.com/document/api/1342/58457)
* [ModifyUser](https://cloud.tencent.com/document/api/1342/58456)
* [ModifyWorkGroup](https://cloud.tencent.com/document/api/1342/58455)
* [UnbindWorkGroupsFromUser](https://cloud.tencent.com/document/api/1342/58454)

新增数据结构：

* [Policy](https://cloud.tencent.com/document/api/1342/53778#Policy)
* [UserIdSetOfWorkGroupId](https://cloud.tencent.com/document/api/1342/53778#UserIdSetOfWorkGroupId)
* [UserInfo](https://cloud.tencent.com/document/api/1342/53778#UserInfo)
* [UserMessage](https://cloud.tencent.com/document/api/1342/53778#UserMessage)
* [WorkGroupIdSetOfUserId](https://cloud.tencent.com/document/api/1342/53778#WorkGroupIdSetOfUserId)
* [WorkGroupInfo](https://cloud.tencent.com/document/api/1342/53778#WorkGroupInfo)
* [WorkGroupMessage](https://cloud.tencent.com/document/api/1342/53778#WorkGroupMessage)

### 第 2 次发布

发布时间：2021-06-16 08:00:39

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateStoreLocation](https://cloud.tencent.com/document/api/1342/57367)

修改接口：

* [CreateDatabase](https://cloud.tencent.com/document/api/1342/53777)

	* 新增入参：DatasourceConnectionName

* [CreateTask](https://cloud.tencent.com/document/api/1342/53775)

	* 新增入参：DatasourceConnectionName

* [DescribeDatabases](https://cloud.tencent.com/document/api/1342/53773)

	* 新增入参：DatasourceConnectionName

* [DescribeTable](https://cloud.tencent.com/document/api/1342/53768)

	* 新增入参：DatasourceConnectionName

* [DescribeTables](https://cloud.tencent.com/document/api/1342/53767)

	* 新增入参：DatasourceConnectionName

* [DescribeViews](https://cloud.tencent.com/document/api/1342/53766)

	* 新增入参：DatasourceConnectionName


新增数据结构：

* [KVPair](https://cloud.tencent.com/document/api/1342/53778#KVPair)

修改数据结构：

* [SQLTask](https://cloud.tencent.com/document/api/1342/53778#SQLTask)

	* 新增成员：Config

* [TableBaseInfo](https://cloud.tencent.com/document/api/1342/53778#TableBaseInfo)

	* 新增成员：DatasourceConnectionName

* [Task](https://cloud.tencent.com/document/api/1342/53778#Task)

	* 新增成员：SparkSQLTask

	* <font color="#dd0000">**修改成员**：</font>SQLTask

* [TaskResponseInfo](https://cloud.tencent.com/document/api/1342/53778#TaskResponseInfo)

	* 新增成员：TaskType


### 第 1 次发布

发布时间：2021-03-17 14:31:09

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateDatabase](https://cloud.tencent.com/document/api/1342/53777)
* [CreateScript](https://cloud.tencent.com/document/api/1342/53776)
* [CreateTable](https://cloud.tencent.com/document/api/1342/53769)
* [CreateTask](https://cloud.tencent.com/document/api/1342/53775)
* [DeleteScript](https://cloud.tencent.com/document/api/1342/53774)
* [DescribeDatabases](https://cloud.tencent.com/document/api/1342/53773)
* [DescribeScripts](https://cloud.tencent.com/document/api/1342/53772)
* [DescribeTable](https://cloud.tencent.com/document/api/1342/53768)
* [DescribeTables](https://cloud.tencent.com/document/api/1342/53767)
* [DescribeTasks](https://cloud.tencent.com/document/api/1342/53771)
* [DescribeViews](https://cloud.tencent.com/document/api/1342/53766)

新增数据结构：

* [CSV](https://cloud.tencent.com/document/api/1342/53778#CSV)
* [CSVSerde](https://cloud.tencent.com/document/api/1342/53778#CSVSerde)
* [Column](https://cloud.tencent.com/document/api/1342/53778#Column)
* [DataFormat](https://cloud.tencent.com/document/api/1342/53778#DataFormat)
* [DatabaseInfo](https://cloud.tencent.com/document/api/1342/53778#DatabaseInfo)
* [DatabaseResponseInfo](https://cloud.tencent.com/document/api/1342/53778#DatabaseResponseInfo)
* [Execution](https://cloud.tencent.com/document/api/1342/53778#Execution)
* [Filter](https://cloud.tencent.com/document/api/1342/53778#Filter)
* [Other](https://cloud.tencent.com/document/api/1342/53778#Other)
* [Partition](https://cloud.tencent.com/document/api/1342/53778#Partition)
* [Property](https://cloud.tencent.com/document/api/1342/53778#Property)
* [SQLTask](https://cloud.tencent.com/document/api/1342/53778#SQLTask)
* [Script](https://cloud.tencent.com/document/api/1342/53778#Script)
* [TableBaseInfo](https://cloud.tencent.com/document/api/1342/53778#TableBaseInfo)
* [TableInfo](https://cloud.tencent.com/document/api/1342/53778#TableInfo)
* [TableResponseInfo](https://cloud.tencent.com/document/api/1342/53778#TableResponseInfo)
* [Task](https://cloud.tencent.com/document/api/1342/53778#Task)
* [TaskResponseInfo](https://cloud.tencent.com/document/api/1342/53778#TaskResponseInfo)
* [TextFile](https://cloud.tencent.com/document/api/1342/53778#TextFile)
* [ViewBaseInfo](https://cloud.tencent.com/document/api/1342/53778#ViewBaseInfo)
* [ViewResponseInfo](https://cloud.tencent.com/document/api/1342/53778#ViewResponseInfo)




## DNSPod(dnspod) 版本：2021-03-23

### 第 32 次发布

发布时间：2024-07-11 01:14:33

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateRecord](https://cloud.tencent.com/document/api/1427/56180)

	* 新增入参：GroupId


### 第 31 次发布

发布时间：2024-05-30 01:33:24

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [ModifyDomainToGroup](https://cloud.tencent.com/document/api/1427/106668)

### 第 30 次发布

发布时间：2024-03-14 01:14:21

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeRecordLineCategoryList](https://cloud.tencent.com/document/api/1427/104320)

修改接口：

* [CreateRecord](https://cloud.tencent.com/document/api/1427/56180)

	* 新增入参：DnssecConflictMode

* [ModifyRecord](https://cloud.tencent.com/document/api/1427/56157)

	* 新增入参：DnssecConflictMode


新增数据结构：

* [LineItem](https://cloud.tencent.com/document/api/1427/56185#LineItem)

### 第 29 次发布

发布时间：2024-01-10 01:13:10

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [ModifyRecord](https://cloud.tencent.com/document/api/1427/56157)

	* 新增入参：Remark


### 第 28 次发布

发布时间：2023-12-22 01:14:13

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [DomainInfo](https://cloud.tencent.com/document/api/1427/56185#DomainInfo)

	* 新增成员：SlaveDNS


### 第 27 次发布

发布时间：2023-11-09 01:12:46

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [DomainListItem](https://cloud.tencent.com/document/api/1427/56185#DomainListItem)

	* <font color="#dd0000">**修改成员**：</font>TagList


### 第 26 次发布

发布时间：2023-11-03 01:13:17

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateDomainCustomLine](https://cloud.tencent.com/document/api/1427/101085)
* [DeleteDomainCustomLine](https://cloud.tencent.com/document/api/1427/101084)
* [DescribeDomainCustomLineList](https://cloud.tencent.com/document/api/1427/101083)
* [ModifyDomainCustomLine](https://cloud.tencent.com/document/api/1427/101082)

新增数据结构：

* [CustomLineInfo](https://cloud.tencent.com/document/api/1427/56185#CustomLineInfo)

### 第 25 次发布

发布时间：2023-10-26 01:13:41

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [WhoisInfo](https://cloud.tencent.com/document/api/1427/56185#WhoisInfo)

	* 新增成员：Dnssec


### 第 24 次发布

发布时间：2023-09-04 01:44:32

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [DomainInfo](https://cloud.tencent.com/document/api/1427/56185#DomainInfo)

	* 新增成员：SearchEnginePush

	* <font color="#dd0000">**修改成员**：</font>IsGracePeriod, VipBuffered, VipStartAt, VipEndAt, VipAutoRenew, VipResourceId, IsSubDomain, TagList


### 第 23 次发布

发布时间：2023-07-28 01:23:03

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateRecord](https://cloud.tencent.com/document/api/1427/56180)

	* 新增入参：Remark


### 第 22 次发布

发布时间：2023-07-26 01:17:12

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeRecordFilterList](https://cloud.tencent.com/document/api/1427/95521)

### 第 21 次发布

发布时间：2023-07-10 01:22:33

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateDomain](https://cloud.tencent.com/document/api/1427/56184)

	* 新增入参：TransferSubDomain, Tags

* [DescribeDomainFilterList](https://cloud.tencent.com/document/api/1427/93276)

	* 新增入参：Tags

* [DescribeDomainList](https://cloud.tencent.com/document/api/1427/56172)

	* 新增入参：Tags


新增数据结构：

* [TagItem](https://cloud.tencent.com/document/api/1427/56185#TagItem)
* [TagItemFilter](https://cloud.tencent.com/document/api/1427/56185#TagItemFilter)

修改数据结构：

* [DomainInfo](https://cloud.tencent.com/document/api/1427/56185#DomainInfo)

	* 新增成员：TagList

* [DomainListItem](https://cloud.tencent.com/document/api/1427/56185#DomainListItem)

	* 新增成员：TagList


### 第 20 次发布

发布时间：2023-07-03 01:19:17

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DeleteRecordBatch](https://cloud.tencent.com/document/api/1427/94422)

新增数据结构：

* [DeleteRecordBatchDetail](https://cloud.tencent.com/document/api/1427/56185#DeleteRecordBatchDetail)

### 第 19 次发布

发布时间：2023-06-21 01:16:19

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [BatchRecordInfo](https://cloud.tencent.com/document/api/1427/56185#BatchRecordInfo)

	* 新增成员：Remark


### 第 18 次发布

发布时间：2023-06-09 01:17:37

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [DomainInfo](https://cloud.tencent.com/document/api/1427/56185#DomainInfo)

	* 新增成员：IsGracePeriod, VipBuffered, VipStartAt, VipEndAt, VipAutoRenew, VipResourceId, IsSubDomain


### 第 17 次发布

发布时间：2023-06-08 01:24:45

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeDomainFilterList](https://cloud.tencent.com/document/api/1427/93276)

### 第 16 次发布

发布时间：2023-04-26 01:20:43

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [RollbackSnapshot](https://cloud.tencent.com/document/api/1427/83174)

	* 新增入参：RecordList


修改数据结构：

* [DomainAliasInfo](https://cloud.tencent.com/document/api/1427/56185#DomainAliasInfo)

	* 新增成员：Status

* [SnapshotRecord](https://cloud.tencent.com/document/api/1427/56185#SnapshotRecord)

	* 新增成员：Weight, Reason


### 第 15 次发布

发布时间：2023-04-11 01:17:18

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [CreateRecordBatchRecord](https://cloud.tencent.com/document/api/1427/56185#CreateRecordBatchRecord)

	* 新增成员：Weight


### 第 14 次发布

发布时间：2023-03-13 01:32:06

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [BatchRecordInfo](https://cloud.tencent.com/document/api/1427/56185#BatchRecordInfo)

	* 新增成员：Weight


### 第 13 次发布

发布时间：2023-02-15 01:26:19

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DeleteDomainBatch](https://cloud.tencent.com/document/api/1427/86549)
* [DescribeDomainPreview](https://cloud.tencent.com/document/api/1427/86553)
* [DescribeDomainWhois](https://cloud.tencent.com/document/api/1427/86552)
* [DescribePackageDetail](https://cloud.tencent.com/document/api/1427/86551)
* [DescribeRecordExistExceptDefaultNS](https://cloud.tencent.com/document/api/1427/86548)
* [DescribeVASStatistic](https://cloud.tencent.com/document/api/1427/86550)

新增数据结构：

* [DeleteDomainBatchDetail](https://cloud.tencent.com/document/api/1427/56185#DeleteDomainBatchDetail)
* [PackageDetailItem](https://cloud.tencent.com/document/api/1427/56185#PackageDetailItem)
* [PreviewDetail](https://cloud.tencent.com/document/api/1427/56185#PreviewDetail)
* [VASStatisticItem](https://cloud.tencent.com/document/api/1427/56185#VASStatisticItem)
* [WhoisContact](https://cloud.tencent.com/document/api/1427/56185#WhoisContact)
* [WhoisContactAddress](https://cloud.tencent.com/document/api/1427/56185#WhoisContactAddress)
* [WhoisInfo](https://cloud.tencent.com/document/api/1427/56185#WhoisInfo)

### 第 12 次发布

发布时间：2023-02-14 01:21:31

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [RecordListItem](https://cloud.tencent.com/document/api/1427/56185#RecordListItem)

	* 新增成员：DefaultNS


### 第 11 次发布

发布时间：2022-11-25 06:28:38

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [ModifyRecordFields](https://cloud.tencent.com/document/api/1427/83364)

新增数据结构：

* [KeyValue](https://cloud.tencent.com/document/api/1427/56185#KeyValue)

### 第 10 次发布

发布时间：2022-11-23 06:24:39

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateRecordGroup](https://cloud.tencent.com/document/api/1427/83227)
* [DeleteRecordGroup](https://cloud.tencent.com/document/api/1427/83226)
* [DescribeRecordGroupList](https://cloud.tencent.com/document/api/1427/83225)
* [ModifyRecordGroup](https://cloud.tencent.com/document/api/1427/83224)
* [ModifyRecordToGroup](https://cloud.tencent.com/document/api/1427/83223)

新增数据结构：

* [RecordGroupInfo](https://cloud.tencent.com/document/api/1427/56185#RecordGroupInfo)

### 第 9 次发布

发布时间：2022-11-22 06:27:31

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CheckRecordSnapshotRollback](https://cloud.tencent.com/document/api/1427/83186)
* [CheckSnapshotRollback](https://cloud.tencent.com/document/api/1427/83185)
* [CreateSnapshot](https://cloud.tencent.com/document/api/1427/83184)
* [DeleteSnapshot](https://cloud.tencent.com/document/api/1427/83183)
* [DescribeRecordSnapshotRollbackResult](https://cloud.tencent.com/document/api/1427/83182)
* [DescribeSnapshotConfig](https://cloud.tencent.com/document/api/1427/83181)
* [DescribeSnapshotList](https://cloud.tencent.com/document/api/1427/83180)
* [DescribeSnapshotRollbackResult](https://cloud.tencent.com/document/api/1427/83179)
* [DescribeSnapshotRollbackTask](https://cloud.tencent.com/document/api/1427/83178)
* [DownloadSnapshot](https://cloud.tencent.com/document/api/1427/83177)
* [ModifySnapshotConfig](https://cloud.tencent.com/document/api/1427/83176)
* [RollbackRecordSnapshot](https://cloud.tencent.com/document/api/1427/83175)
* [RollbackSnapshot](https://cloud.tencent.com/document/api/1427/83174)

新增数据结构：

* [SnapshotConfig](https://cloud.tencent.com/document/api/1427/56185#SnapshotConfig)
* [SnapshotInfo](https://cloud.tencent.com/document/api/1427/56185#SnapshotInfo)
* [SnapshotPageInfo](https://cloud.tencent.com/document/api/1427/56185#SnapshotPageInfo)
* [SnapshotRecord](https://cloud.tencent.com/document/api/1427/56185#SnapshotRecord)

### 第 8 次发布

发布时间：2022-09-16 06:21:57

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeDomainGroupList](https://cloud.tencent.com/document/api/1427/80523)

新增数据结构：

* [GroupInfo](https://cloud.tencent.com/document/api/1427/56185#GroupInfo)

### 第 7 次发布

发布时间：2022-08-04 06:26:58

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [UserInfo](https://cloud.tencent.com/document/api/1427/56185#UserInfo)

	* 新增成员：FreeNs


### 第 6 次发布

发布时间：2022-06-23 06:11:27

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateDeal](https://cloud.tencent.com/document/api/1427/75921)
* [ModifyPackageAutoRenew](https://cloud.tencent.com/document/api/1427/75920)
* [ModifyVasAutoRenewStatus](https://cloud.tencent.com/document/api/1427/75919)
* [PayOrderWithBalance](https://cloud.tencent.com/document/api/1427/75918)

新增数据结构：

* [Deals](https://cloud.tencent.com/document/api/1427/56185#Deals)

### 第 5 次发布

发布时间：2022-06-20 06:07:25

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeDomainAnalytics](https://cloud.tencent.com/document/api/1427/75753)
* [DescribeSubdomainAnalytics](https://cloud.tencent.com/document/api/1427/75752)

新增数据结构：

* [DomainAliasAnalyticsItem](https://cloud.tencent.com/document/api/1427/56185#DomainAliasAnalyticsItem)
* [DomainAnalyticsDetail](https://cloud.tencent.com/document/api/1427/56185#DomainAnalyticsDetail)
* [DomainAnalyticsInfo](https://cloud.tencent.com/document/api/1427/56185#DomainAnalyticsInfo)
* [SubdomainAliasAnalyticsItem](https://cloud.tencent.com/document/api/1427/56185#SubdomainAliasAnalyticsItem)
* [SubdomainAnalyticsInfo](https://cloud.tencent.com/document/api/1427/56185#SubdomainAnalyticsInfo)

### 第 4 次发布

发布时间：2022-05-19 06:11:31

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [ModifyDynamicDNS](https://cloud.tencent.com/document/api/1427/56158)

	* 新增入参：Ttl


### 第 3 次发布

发布时间：2021-12-09 08:05:19

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeDomainAliasList](https://cloud.tencent.com/document/api/1427/65766)

新增数据结构：

* [DomainAliasInfo](https://cloud.tencent.com/document/api/1427/56185#DomainAliasInfo)

### 第 2 次发布

发布时间：2021-09-08 08:00:28

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [ModifySubdomainStatus](https://cloud.tencent.com/document/api/1427/61272)

### 第 1 次发布

发布时间：2021-05-21 17:26:08

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateDomain](https://cloud.tencent.com/document/api/1427/56184)
* [CreateDomainAlias](https://cloud.tencent.com/document/api/1427/56183)
* [CreateDomainBatch](https://cloud.tencent.com/document/api/1427/56182)
* [CreateDomainGroup](https://cloud.tencent.com/document/api/1427/56181)
* [CreateRecord](https://cloud.tencent.com/document/api/1427/56180)
* [CreateRecordBatch](https://cloud.tencent.com/document/api/1427/56179)
* [DeleteDomain](https://cloud.tencent.com/document/api/1427/56178)
* [DeleteDomainAlias](https://cloud.tencent.com/document/api/1427/56177)
* [DeleteRecord](https://cloud.tencent.com/document/api/1427/56176)
* [DeleteShareDomain](https://cloud.tencent.com/document/api/1427/56175)
* [DescribeBatchTask](https://cloud.tencent.com/document/api/1427/56174)
* [DescribeDomain](https://cloud.tencent.com/document/api/1427/56173)
* [DescribeDomainList](https://cloud.tencent.com/document/api/1427/56172)
* [DescribeDomainLogList](https://cloud.tencent.com/document/api/1427/56171)
* [DescribeDomainPurview](https://cloud.tencent.com/document/api/1427/56170)
* [DescribeDomainShareInfo](https://cloud.tencent.com/document/api/1427/56169)
* [DescribeRecord](https://cloud.tencent.com/document/api/1427/56168)
* [DescribeRecordLineList](https://cloud.tencent.com/document/api/1427/56167)
* [DescribeRecordList](https://cloud.tencent.com/document/api/1427/56166)
* [DescribeRecordType](https://cloud.tencent.com/document/api/1427/56165)
* [DescribeUserDetail](https://cloud.tencent.com/document/api/1427/56164)
* [ModifyDomainLock](https://cloud.tencent.com/document/api/1427/56163)
* [ModifyDomainOwner](https://cloud.tencent.com/document/api/1427/56162)
* [ModifyDomainRemark](https://cloud.tencent.com/document/api/1427/56161)
* [ModifyDomainStatus](https://cloud.tencent.com/document/api/1427/56160)
* [ModifyDomainUnlock](https://cloud.tencent.com/document/api/1427/56159)
* [ModifyDynamicDNS](https://cloud.tencent.com/document/api/1427/56158)
* [ModifyRecord](https://cloud.tencent.com/document/api/1427/56157)
* [ModifyRecordBatch](https://cloud.tencent.com/document/api/1427/56156)
* [ModifyRecordRemark](https://cloud.tencent.com/document/api/1427/56155)
* [ModifyRecordStatus](https://cloud.tencent.com/document/api/1427/56154)

新增数据结构：

* [AddRecordBatch](https://cloud.tencent.com/document/api/1427/56185#AddRecordBatch)
* [BatchRecordInfo](https://cloud.tencent.com/document/api/1427/56185#BatchRecordInfo)
* [CreateDomainBatchDetail](https://cloud.tencent.com/document/api/1427/56185#CreateDomainBatchDetail)
* [CreateDomainBatchRecord](https://cloud.tencent.com/document/api/1427/56185#CreateDomainBatchRecord)
* [CreateRecordBatchDetail](https://cloud.tencent.com/document/api/1427/56185#CreateRecordBatchDetail)
* [CreateRecordBatchRecord](https://cloud.tencent.com/document/api/1427/56185#CreateRecordBatchRecord)
* [DescribeBatchTaskDetail](https://cloud.tencent.com/document/api/1427/56185#DescribeBatchTaskDetail)
* [DomainCountInfo](https://cloud.tencent.com/document/api/1427/56185#DomainCountInfo)
* [DomainCreateInfo](https://cloud.tencent.com/document/api/1427/56185#DomainCreateInfo)
* [DomainInfo](https://cloud.tencent.com/document/api/1427/56185#DomainInfo)
* [DomainListItem](https://cloud.tencent.com/document/api/1427/56185#DomainListItem)
* [DomainShareInfo](https://cloud.tencent.com/document/api/1427/56185#DomainShareInfo)
* [LineGroupInfo](https://cloud.tencent.com/document/api/1427/56185#LineGroupInfo)
* [LineInfo](https://cloud.tencent.com/document/api/1427/56185#LineInfo)
* [LockInfo](https://cloud.tencent.com/document/api/1427/56185#LockInfo)
* [ModifyRecordBatchDetail](https://cloud.tencent.com/document/api/1427/56185#ModifyRecordBatchDetail)
* [PurviewInfo](https://cloud.tencent.com/document/api/1427/56185#PurviewInfo)
* [RecordCountInfo](https://cloud.tencent.com/document/api/1427/56185#RecordCountInfo)
* [RecordInfo](https://cloud.tencent.com/document/api/1427/56185#RecordInfo)
* [RecordListItem](https://cloud.tencent.com/document/api/1427/56185#RecordListItem)
* [UserInfo](https://cloud.tencent.com/document/api/1427/56185#UserInfo)




## 域名注册(domain) 版本：2018-08-08

### 第 41 次发布

发布时间：2024-07-02 01:14:51

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [DomainBatchDetailSet](https://cloud.tencent.com/document/api/242/38895#DomainBatchDetailSet)

	* <font color="#dd0000">**修改成员**：</font>BigDealId

* [DomainBatchLogSet](https://cloud.tencent.com/document/api/242/38895#DomainBatchLogSet)

	* <font color="#dd0000">**修改成员**：</font>Success, Doing, Failed


### 第 40 次发布

发布时间：2024-06-27 01:11:00

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [ReservedPreDomains](https://cloud.tencent.com/document/api/242/103887)

	* 新增出参：SucDomains


新增数据结构：

* [SucDomainInfo](https://cloud.tencent.com/document/api/242/38895#SucDomainInfo)

### 第 39 次发布

发布时间：2024-06-10 01:40:58

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DeleteBidding](https://cloud.tencent.com/document/api/242/106603)

	* 新增入参：BusinessID

* [DescribeBiddingAppointDetail](https://cloud.tencent.com/document/api/242/106601)

	* 新增入参：BusinessID

	* 新增出参：Domain, AppointNum, AppointStartTime, AppointEndTime, RegTime, ExpireTime, DeleteTime, AppointPrice, AppointBondPrice

* [DescribeBiddingAppointList](https://cloud.tencent.com/document/api/242/106600)

	* 新增入参：PageNumber, Domain

	* 新增出参：Total, AppointList

* [DescribeBiddingDetail](https://cloud.tencent.com/document/api/242/106599)

	* 新增入参：BusinessID

	* 新增出参：Domain, BiddingNum, BiddingStartTime, BiddingEndTime, RegTime, ExpireTime, DeleteTime, CurrentPrice, CurrentNickname, BiddingBondPrice, Status, BiddingFlag, BiddingBondRefund, BiddingPrice

* [DescribeBiddingList](https://cloud.tencent.com/document/api/242/106598)

	* 新增入参：PageNumber, Domain

	* 新增出参：Total, BiddingList

* [DescribeBiddingSuccessfulDetail](https://cloud.tencent.com/document/api/242/106597)

	* 新增入参：BusinessID

	* 新增出参：Domain, SuccessfulTime, SuccessfulPrice, RegTime, ExpireTime, DeleteTime, PayEndTime, BiddingBondPrice

* [DescribeBiddingSuccessfulList](https://cloud.tencent.com/document/api/242/106596)

	* 新增入参：PageNumber, Domain

	* 新增出参：Total, SuccessfulList


新增数据结构：

* [BiddingAppointResult](https://cloud.tencent.com/document/api/242/38895#BiddingAppointResult)
* [BiddingResult](https://cloud.tencent.com/document/api/242/38895#BiddingResult)
* [BiddingSuccessfulResult](https://cloud.tencent.com/document/api/242/38895#BiddingSuccessfulResult)

### 第 38 次发布

发布时间：2024-06-04 01:35:42

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [ReservedPreDomains](https://cloud.tencent.com/document/api/242/103887)

	* 新增入参：IsAutoPay, IsBidAutoPay


### 第 37 次发布

发布时间：2024-05-28 01:34:04

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [BidDetailPage](https://cloud.tencent.com/document/api/242/106605)
* [BiddingPreRelease](https://cloud.tencent.com/document/api/242/106604)
* [DeleteBidding](https://cloud.tencent.com/document/api/242/106603)
* [DescribeAuctionList](https://cloud.tencent.com/document/api/242/106602)
* [DescribeBiddingAppointDetail](https://cloud.tencent.com/document/api/242/106601)
* [DescribeBiddingAppointList](https://cloud.tencent.com/document/api/242/106600)
* [DescribeBiddingDetail](https://cloud.tencent.com/document/api/242/106599)
* [DescribeBiddingList](https://cloud.tencent.com/document/api/242/106598)
* [DescribeBiddingSuccessfulDetail](https://cloud.tencent.com/document/api/242/106597)
* [DescribeBiddingSuccessfulList](https://cloud.tencent.com/document/api/242/106596)
* [DescribePayWaitDetail](https://cloud.tencent.com/document/api/242/106595)
* [DescribePreAuctionList](https://cloud.tencent.com/document/api/242/106594)
* [DescribePreReleaseList](https://cloud.tencent.com/document/api/242/106593)
* [DescribeUnPreDomainDetail](https://cloud.tencent.com/document/api/242/106592)

新增数据结构：

* [AuctionInfo](https://cloud.tencent.com/document/api/242/38895#AuctionInfo)
* [PreAuctionInfo](https://cloud.tencent.com/document/api/242/38895#PreAuctionInfo)
* [PreReleaseInfo](https://cloud.tencent.com/document/api/242/38895#PreReleaseInfo)
* [PriceScopeConf](https://cloud.tencent.com/document/api/242/38895#PriceScopeConf)

### 第 36 次发布

发布时间：2024-04-29 01:14:52

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [ModifyTemplate](https://cloud.tencent.com/document/api/242/105750)

### 第 35 次发布

发布时间：2024-04-18 01:18:45

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeReservedBidInfo](https://cloud.tencent.com/document/api/242/105132)

	* 新增出参：BidEndTime, IsUp, NextPrice, Status


### 第 34 次发布

发布时间：2024-04-15 01:34:58

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [BidPreDomains](https://cloud.tencent.com/document/api/242/105133)
* [DescribeReservedBidInfo](https://cloud.tencent.com/document/api/242/105132)

新增数据结构：

* [ReserveBidInfo](https://cloud.tencent.com/document/api/242/38895#ReserveBidInfo)

修改数据结构：

* [ReservedPreDomainInfo](https://cloud.tencent.com/document/api/242/38895#ReservedPreDomainInfo)

	* 新增成员：BusinessId


### 第 33 次发布

发布时间：2024-04-03 11:17:24

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeTldList](https://cloud.tencent.com/document/api/242/104832)

### 第 32 次发布

发布时间：2024-03-13 01:14:31

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribePreDomainList](https://cloud.tencent.com/document/api/242/103889)

	* 新增入参：UpTime


### 第 31 次发布

发布时间：2024-02-29 01:14:41

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribePreDomainList](https://cloud.tencent.com/document/api/242/103889)

	* 新增入参：EndTime


### 第 30 次发布

发布时间：2024-02-22 01:14:15

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DeleteReservedPreDomainInfo](https://cloud.tencent.com/document/api/242/103890)
* [DescribePreDomainList](https://cloud.tencent.com/document/api/242/103889)
* [DescribeReservedPreDomainInfo](https://cloud.tencent.com/document/api/242/103888)
* [ReservedPreDomains](https://cloud.tencent.com/document/api/242/103887)

新增数据结构：

* [FailReservedDomainInfo](https://cloud.tencent.com/document/api/242/38895#FailReservedDomainInfo)
* [ReservedDomainInfo](https://cloud.tencent.com/document/api/242/38895#ReservedDomainInfo)
* [ReservedPreDomainInfo](https://cloud.tencent.com/document/api/242/38895#ReservedPreDomainInfo)

### 第 29 次发布

发布时间：2023-12-15 01:10:52

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [DomainBatchDetailSet](https://cloud.tencent.com/document/api/242/38895#DomainBatchDetailSet)

	* 新增成员：Action, BigDealId

* [DomainBatchLogSet](https://cloud.tencent.com/document/api/242/38895#DomainBatchLogSet)

	* 新增成员：Success, Doing, Failed


### 第 28 次发布

发布时间：2023-12-12 01:41:31

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [TemplateInfo](https://cloud.tencent.com/document/api/242/38895#TemplateInfo)

	* <font color="#dd0000">**修改成员**：</font>IsBlack


### 第 27 次发布

发布时间：2023-10-20 01:14:01

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DeleteCustomDnsHost](https://cloud.tencent.com/document/api/242/100536)
* [DescribeCustomDnsHostSet](https://cloud.tencent.com/document/api/242/100535)
* [ModifyCustomDnsHost](https://cloud.tencent.com/document/api/242/100534)
* [ModifyIntlCustomDnsHost](https://cloud.tencent.com/document/api/242/100537)
* [SyncCustomDnsHost](https://cloud.tencent.com/document/api/242/100533)

新增数据结构：

* [CustomDnsHost](https://cloud.tencent.com/document/api/242/38895#CustomDnsHost)

### 第 26 次发布

发布时间：2023-10-18 01:53:41

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateCustomDnsHost](https://cloud.tencent.com/document/api/242/100418)

### 第 25 次发布

发布时间：2023-07-24 01:25:15

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateDomainRedemption](https://cloud.tencent.com/document/api/242/95411)

### 第 24 次发布

发布时间：2023-05-18 01:23:17

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [CertificateInfo](https://cloud.tencent.com/document/api/242/38895#CertificateInfo)

	* 新增成员：OriginImgUrl


### 第 23 次发布

发布时间：2023-04-19 01:27:47

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [CertificateInfo](https://cloud.tencent.com/document/api/242/38895#CertificateInfo)

	* 新增成员：RegistrantCertificateCode, RegistrantCertificateType, RegistrantImgUrl


### 第 22 次发布

发布时间：2023-02-22 01:23:19

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateDomainBatch](https://cloud.tencent.com/document/api/242/48942)

	* 新增入参：ChannelFrom, OrderFrom, ActivityId

* [RenewDomainBatch](https://cloud.tencent.com/document/api/242/49210)

	* 新增入参：PackageResourceId, ChannelFrom, OrderFrom, ActivityId

* [TransferInDomainBatch](https://cloud.tencent.com/document/api/242/49195)

	* 新增入参：ChannelFrom, OrderFrom, ActivityId


### 第 21 次发布

发布时间：2023-02-13 01:35:50

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [TemplateInfo](https://cloud.tencent.com/document/api/242/38895#TemplateInfo)

	* 新增成员：IsBlack


### 第 20 次发布

发布时间：2022-05-24 06:11:36

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [ModifyDomainOwnerBatch](https://cloud.tencent.com/document/api/242/49196)

	* 新增入参：NewOwnerAppId


### 第 19 次发布

发布时间：2022-04-21 06:11:32

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeDomainSimpleInfo](https://cloud.tencent.com/document/api/242/72837)

新增数据结构：

* [DomainSimpleInfo](https://cloud.tencent.com/document/api/242/38895#DomainSimpleInfo)

### 第 18 次发布

发布时间：2021-12-06 08:05:24

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateDomainBatch](https://cloud.tencent.com/document/api/242/48942)

	* 新增入参：UpdateProhibition, TransferProhibition

* [TransferInDomainBatch](https://cloud.tencent.com/document/api/242/49195)

	* 新增入参：UpdateProhibition, TransferProhibition


### 第 17 次发布

发布时间：2021-12-03 08:05:53

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [PhoneEmailData](https://cloud.tencent.com/document/api/242/38895#PhoneEmailData)

	* 新增成员：CheckStatus


### 第 16 次发布

发布时间：2021-10-14 08:08:15

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreatePhoneEmail](https://cloud.tencent.com/document/api/242/62669)
* [DeletePhoneEmail](https://cloud.tencent.com/document/api/242/62668)
* [DescribePhoneEmailList](https://cloud.tencent.com/document/api/242/62667)
* [SendPhoneEmailCode](https://cloud.tencent.com/document/api/242/62666)

新增数据结构：

* [PhoneEmailData](https://cloud.tencent.com/document/api/242/38895#PhoneEmailData)

### 第 15 次发布

发布时间：2021-07-21 08:05:41

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [ModifyDomainOwnerBatch](https://cloud.tencent.com/document/api/242/49196)

	* 新增入参：TransferDns


### 第 14 次发布

发布时间：2021-05-20 08:04:37

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeTemplateList](https://cloud.tencent.com/document/api/242/48940)

	* 新增入参：Keyword


### 第 13 次发布

发布时间：2021-04-21 08:04:37

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateDomainBatch](https://cloud.tencent.com/document/api/242/48942)

	* 新增入参：PackageResourceId


### 第 12 次发布

发布时间：2021-01-15 08:03:53

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [BatchModifyDomainInfo](https://cloud.tencent.com/document/api/242/49197)

	* 新增入参：LockTransfer

* [DescribeDomainBaseInfo](https://cloud.tencent.com/document/api/242/48757)

	* 新增出参：Uin

* [TransferInDomainBatch](https://cloud.tencent.com/document/api/242/49195)

	* 新增入参：LockTransfer


修改数据结构：

* [DomainBaseInfo](https://cloud.tencent.com/document/api/242/38895#DomainBaseInfo)

	* 新增成员：LockTransfer, LockEndTime


### 第 11 次发布

发布时间：2020-12-17 08:03:55

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateDomainBatch](https://cloud.tencent.com/document/api/242/48942)

	* 新增入参：AutoRenewFlag

* [RenewDomainBatch](https://cloud.tencent.com/document/api/242/49210)

	* 新增入参：AutoRenewFlag

* [TransferInDomainBatch](https://cloud.tencent.com/document/api/242/49195)

	* 新增入参：AutoRenewFlag


### 第 10 次发布

发布时间：2020-12-07 08:03:40

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [DomainBaseInfo](https://cloud.tencent.com/document/api/242/38895#DomainBaseInfo)

	* 新增成员：NameServer


### 第 9 次发布

发布时间：2020-11-18 08:17:27

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeTemplate](https://cloud.tencent.com/document/api/242/50018)

### 第 8 次发布

发布时间：2020-10-26 08:03:14

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeBatchOperationLogDetails](https://cloud.tencent.com/document/api/242/49357)
* [DescribeBatchOperationLogs](https://cloud.tencent.com/document/api/242/49356)

新增数据结构：

* [DomainBatchDetailSet](https://cloud.tencent.com/document/api/242/38895#DomainBatchDetailSet)
* [DomainBatchLogSet](https://cloud.tencent.com/document/api/242/38895#DomainBatchLogSet)

### 第 7 次发布

发布时间：2020-10-19 08:03:20

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateTemplate](https://cloud.tencent.com/document/api/242/49208)
* [DeleteTemplate](https://cloud.tencent.com/document/api/242/49207)
* [ModifyDomainDNSBatch](https://cloud.tencent.com/document/api/242/49211)
* [RenewDomainBatch](https://cloud.tencent.com/document/api/242/49210)
* [SetDomainAutoRenew](https://cloud.tencent.com/document/api/242/49209)
* [UploadImage](https://cloud.tencent.com/document/api/242/49206)

### 第 6 次发布

发布时间：2020-10-16 08:03:53

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [BatchModifyDomainInfo](https://cloud.tencent.com/document/api/242/49197)
* [ModifyDomainOwnerBatch](https://cloud.tencent.com/document/api/242/49196)
* [TransferInDomainBatch](https://cloud.tencent.com/document/api/242/49195)
* [TransferProhibitionBatch](https://cloud.tencent.com/document/api/242/49194)
* [UpdateProhibitionBatch](https://cloud.tencent.com/document/api/242/49193)

### 第 5 次发布

发布时间：2020-09-30 08:03:21

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CheckBatchStatus](https://cloud.tencent.com/document/api/242/48943)
* [CreateDomainBatch](https://cloud.tencent.com/document/api/242/48942)
* [DescribeDomainNameList](https://cloud.tencent.com/document/api/242/48941)
* [DescribeTemplateList](https://cloud.tencent.com/document/api/242/48940)

新增数据结构：

* [BatchStatus](https://cloud.tencent.com/document/api/242/38895#BatchStatus)
* [CertificateInfo](https://cloud.tencent.com/document/api/242/38895#CertificateInfo)
* [ContactInfo](https://cloud.tencent.com/document/api/242/38895#ContactInfo)
* [DomainList](https://cloud.tencent.com/document/api/242/38895#DomainList)
* [TemplateInfo](https://cloud.tencent.com/document/api/242/38895#TemplateInfo)

### 第 4 次发布

发布时间：2020-09-25 08:03:31

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeDomainBaseInfo](https://cloud.tencent.com/document/api/242/48757)

新增数据结构：

* [DomainBaseInfo](https://cloud.tencent.com/document/api/242/38895#DomainBaseInfo)

### 第 3 次发布

发布时间：2020-07-13 08:25:10

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CheckDomain](https://cloud.tencent.com/document/api/242/38894)

	* 新增出参：RecordSupport


### 第 2 次发布

发布时间：2020-03-16 08:08:32

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CheckDomain](https://cloud.tencent.com/document/api/242/38894)

	* 新增入参：Period

	* 新增出参：Describe, FeeRenew, RealPrice, FeeTransfer, FeeRestore, Period

* [DescribeDomainPriceList](https://cloud.tencent.com/document/api/242/38893)

	* 新增入参：Year, Operation


### 第 1 次发布

发布时间：2019-10-31 15:54:17

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CheckDomain](https://cloud.tencent.com/document/api/242/38894)
* [DescribeDomainPriceList](https://cloud.tencent.com/document/api/242/38893)

新增数据结构：

* [PriceInfo](https://cloud.tencent.com/document/api/242/38895#PriceInfo)




## 数字版权管理(drm) 版本：2018-11-15

### 第 6 次发布

发布时间：2023-11-10 01:14:28

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [GenerateTDRMKey](https://cloud.tencent.com/document/api/1000/101455)

### 第 5 次发布

发布时间：2023-11-02 01:38:44

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeDRMLicense](https://cloud.tencent.com/document/api/1000/101057)

### 第 4 次发布

发布时间：2020-01-09 17:18:24

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateEncryptKeys](https://cloud.tencent.com/document/api/1000/40960)
* [DescribeAllKeys](https://cloud.tencent.com/document/api/1000/40959)

新增数据结构：

* [KeyParam](https://cloud.tencent.com/document/api/1000/30712#KeyParam)

修改数据结构：

* [Key](https://cloud.tencent.com/document/api/1000/30712#Key)

	* 新增成员：InsertTimestamp


### 第 3 次发布

发布时间：2019-07-18 20:12:34

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [AddFairPlayPem](https://cloud.tencent.com/document/api/1000/36301)
* [DeleteFairPlayPem](https://cloud.tencent.com/document/api/1000/36300)
* [DescribeFairPlayPem](https://cloud.tencent.com/document/api/1000/36299)
* [ModifyFairPlayPem](https://cloud.tencent.com/document/api/1000/36298)

新增数据结构：

* [FairPlayPemDigestInfo](https://cloud.tencent.com/document/api/1000/30712#FairPlayPemDigestInfo)

### 第 2 次发布

发布时间：2019-02-28 20:07:54

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateLicense](https://cloud.tencent.com/document/api/1000/30711)

	* 新增出参：ContentId


### 第 1 次发布

发布时间：2018-11-22 20:08:34

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateLicense](https://cloud.tencent.com/document/api/1000/30711)
* [DescribeKeys](https://cloud.tencent.com/document/api/1000/30707)
* [StartEncryption](https://cloud.tencent.com/document/api/1000/30709)

新增数据结构：

* [DrmOutputObject](https://cloud.tencent.com/document/api/1000/30712#DrmOutputObject)
* [DrmOutputPara](https://cloud.tencent.com/document/api/1000/30712#DrmOutputPara)
* [DrmSourceObject](https://cloud.tencent.com/document/api/1000/30712#DrmSourceObject)
* [Key](https://cloud.tencent.com/document/api/1000/30712#Key)
* [PlaybackPolicy](https://cloud.tencent.com/document/api/1000/30712#PlaybackPolicy)




## 文档服务(ds) 版本：2018-05-23

### 第 4 次发布

发布时间：2020-03-16 08:08:49

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateContractByUpload](https://cloud.tencent.com/document/api/869/17795)

	* <font color="#dd0000">**修改入参**：</font>Initiator

* [CreateEnterpriseAccount](https://cloud.tencent.com/document/api/869/17794)

	* 新增入参：Email

* [SignContractByCoordinate](https://cloud.tencent.com/document/api/869/17786)

	* <font color="#dd0000">**修改入参**：</font>AuthorizationTime, Position

* [SignContractByKeyword](https://cloud.tencent.com/document/api/869/17960)

	* <font color="#dd0000">**修改入参**：</font>AuthorizationTime, Position


修改数据结构：

* [SignInfo](https://cloud.tencent.com/document/api/869/17797#SignInfo)

	* <font color="#dd0000">**修改成员**：</font>AuthorizationTime, Location


### 第 3 次发布

发布时间：2019-05-09 19:43:21

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateContractByUpload](https://cloud.tencent.com/document/api/869/17795)

	* 新增入参：ExpireTime

* [CreateSeal](https://cloud.tencent.com/document/api/869/17792)

	* 新增入参：ImgData

* [SignContractByCoordinate](https://cloud.tencent.com/document/api/869/17786)

	* 新增入参：CertType, ImageData

* [SignContractByKeyword](https://cloud.tencent.com/document/api/869/17960)

	* 新增入参：CertType, ImageData


修改数据结构：

* [SignInfo](https://cloud.tencent.com/document/api/869/17797#SignInfo)

	* 新增成员：SignLocation


### 第 2 次发布

发布时间：2018-06-21 14:34:22

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [SignContractByKeyword](https://cloud.tencent.com/document/api/869/17960)

新增数据结构：

* [SignKeyword](https://cloud.tencent.com/document/api/869/17797#SignKeyword)

修改数据结构：

* [SignInfo](https://cloud.tencent.com/document/api/869/17797#SignInfo)

	* 新增成员：AuthorizationTime, Location, SealId, ImageData, CertType


### 第 1 次发布

发布时间：2018-06-07 15:01:42

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CheckVcode](https://cloud.tencent.com/document/api/869/17796)
* [CreateContractByUpload](https://cloud.tencent.com/document/api/869/17795)
* [CreateEnterpriseAccount](https://cloud.tencent.com/document/api/869/17794)
* [CreatePersonalAccount](https://cloud.tencent.com/document/api/869/17793)
* [CreateSeal](https://cloud.tencent.com/document/api/869/17792)
* [DeleteAccount](https://cloud.tencent.com/document/api/869/17791)
* [DeleteSeal](https://cloud.tencent.com/document/api/869/17790)
* [DescribeTaskStatus](https://cloud.tencent.com/document/api/869/17789)
* [DownloadContract](https://cloud.tencent.com/document/api/869/17788)
* [SendVcode](https://cloud.tencent.com/document/api/869/17787)
* [SignContractByCoordinate](https://cloud.tencent.com/document/api/869/17786)

新增数据结构：

* [SignInfo](https://cloud.tencent.com/document/api/869/17797#SignInfo)
* [SignLocation](https://cloud.tencent.com/document/api/869/17797#SignLocation)




## 数据安全治理中心(dsgc) 版本：2019-07-23

### 第 17 次发布

发布时间：2024-08-06 01:35:34

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [ModifyDSPAAssessmentRiskLatest](https://cloud.tencent.com/document/api/1087/97199)

	* <font color="#dd0000">**修改入参**：</font>RiskLatestTableId


### 第 16 次发布

发布时间：2024-07-18 01:10:11

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateDSPADiscoveryTask](https://cloud.tencent.com/document/api/1087/97252)

	* 新增入参：Order, Rows, GlobalOrderField

* [DescribeDSPAESDataSample](https://cloud.tencent.com/document/api/1087/97209)

	* 新增入参：Order, OrderField

* [DescribeDSPATaskResultDataSample](https://cloud.tencent.com/document/api/1087/97203)

	* 新增入参：Order, OrderField


### 第 15 次发布

发布时间：2024-06-25 01:13:45

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [CosTaskResult](https://cloud.tencent.com/document/api/1087/96844#CosTaskResult)

	* <font color="#dd0000">**修改成员**：</font>Result, ResultDescription, ErrDescription, ResourceId


### 第 14 次发布

发布时间：2024-06-13 01:38:46

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [ExportAssetDetailData](https://cloud.tencent.com/document/api/1087/97201)

	* 新增入参：CasbId


### 第 13 次发布

发布时间：2024-05-27 01:34:38

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [DspaInstance](https://cloud.tencent.com/document/api/1087/96844#DspaInstance)

	* 新增成员：Channel


### 第 12 次发布

发布时间：2024-05-21 01:34:24

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [PrivilegeRisk](https://cloud.tencent.com/document/api/1087/96844#PrivilegeRisk)

	* <font color="#dd0000">**修改成员**：</font>AccountName, TableName, Description


### 第 11 次发布

发布时间：2024-05-14 01:46:03

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [AKSKLeak](https://cloud.tencent.com/document/api/1087/96844#AKSKLeak)

	* <font color="#dd0000">**修改成员**：</font>AK, SK, URL

* [AssetCosDetail](https://cloud.tencent.com/document/api/1087/96844#AssetCosDetail)

	* <font color="#dd0000">**修改成员**：</font>Bucket, DataType, FileNums, SensitiveFileNums, DistributionData, MatchedNum

* [DSPACosMetaDataInfo](https://cloud.tencent.com/document/api/1087/96844#DSPACosMetaDataInfo)

	* <font color="#dd0000">**修改成员**：</font>BindStatus, Storage

* [DbRelationStatusItem](https://cloud.tencent.com/document/api/1087/96844#DbRelationStatusItem)

	* <font color="#dd0000">**修改成员**：</font>DbName, BindStatus, ValidStatus

* [DbTaskResult](https://cloud.tencent.com/document/api/1087/96844#DbTaskResult)

	* <font color="#dd0000">**修改成员**：</font>Result, ResultDescription, ErrDescription, ResourceId, DbName

* [ErrDescription](https://cloud.tencent.com/document/api/1087/96844#ErrDescription)

	* <font color="#dd0000">**修改成员**：</font>ErrCode, ErrMessage

* [SuggestRiskLevelMatrixItem](https://cloud.tencent.com/document/api/1087/96844#SuggestRiskLevelMatrixItem)

	* <font color="#dd0000">**修改成员**：</font>SensitiveLevel, VulnerabilityLevel, RiskName, RiskScore


### 第 10 次发布

发布时间：2024-04-17 01:12:45

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateDSPACosMetaResources](https://cloud.tencent.com/document/api/1087/97180)

	* 新增入参：CosBucketItems

	* <font color="#dd0000">**修改入参**：</font>ResourceRegion, Buckets

* [CreateDSPADbMetaResources](https://cloud.tencent.com/document/api/1087/96843)

	* 新增入参：CloudResourceItems

	* <font color="#dd0000">**修改入参**：</font>ResourceRegion, UpdateStatus, UpdateId, Items


新增数据结构：

* [CloudResourceItem](https://cloud.tencent.com/document/api/1087/96844#CloudResourceItem)
* [CosBucketItem](https://cloud.tencent.com/document/api/1087/96844#CosBucketItem)

### 第 9 次发布

发布时间：2024-03-28 01:15:37

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [GetUserQuotaInfo](https://cloud.tencent.com/document/api/1087/97170)

	* 新增出参：DBUnbindNum, COSUnbindNum


### 第 8 次发布

发布时间：2024-03-12 01:27:10

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeDSPASupportedMetas](https://cloud.tencent.com/document/api/1087/97175)

	* 新增出参：MaxDBInstanceLimit


### 第 7 次发布

发布时间：2024-03-07 01:14:47

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateDSPASelfBuildMetaResource](https://cloud.tencent.com/document/api/1087/97178)

	* 新增入参：InstanceType, InstanceValue

* [DescribeDSPADataSourceDbInfo](https://cloud.tencent.com/document/api/1087/97216)

	* 新增入参：DataSourceType

* [DescribeDSPAESDataAssetByComplianceId](https://cloud.tencent.com/document/api/1087/97144)

	* 新增入参：BuildType, DataSourceType

* [DescribeDSPARDBDataAssetByComplianceId](https://cloud.tencent.com/document/api/1087/97205)

	* 新增入参：BuildType

* [ModifyDSPACOSTaskResult](https://cloud.tencent.com/document/api/1087/97197)

	* 新增入参：FileName, BucketName, DataSourceId


修改数据结构：

* [DspaCOSDataAssetDetail](https://cloud.tencent.com/document/api/1087/96844#DspaCOSDataAssetDetail)

	* 新增成员：IdentifyType, CheckStatus

* [DspaDiscoveryTaskDataSource](https://cloud.tencent.com/document/api/1087/96844#DspaDiscoveryTaskDataSource)

	* 新增成员：DataSourceType

* [DspaUserResourceMeta](https://cloud.tencent.com/document/api/1087/96844#DspaUserResourceMeta)

	* 新增成员：InstanceType, InstanceValue


### 第 6 次发布

发布时间：2023-11-21 01:16:05

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [RiskLevelRisk](https://cloud.tencent.com/document/api/1087/96844#RiskLevelRisk)

	* <font color="#dd0000">**修改成员**：</font>Id, RiskLevelName, RiskLevelDescription, IdentifyComplianceName, Type


### 第 5 次发布

发布时间：2023-11-16 01:16:33

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeDSPAESDataAssetDetail](https://cloud.tencent.com/document/api/1087/97143)

	* 新增入参：CreditScore

* [DescribeDSPARDBDataAssetDetail](https://cloud.tencent.com/document/api/1087/97204)

	* 新增入参：CreditScore

* [ModifyDSPAESTaskResult](https://cloud.tencent.com/document/api/1087/97191)

	* 新增入参：SrcRuleId, SrcCategoryId, SrcLevelId, IdentifyType

* [ModifyDSPATaskResult](https://cloud.tencent.com/document/api/1087/97190)

	* 新增入参：SrcRuleId, SrcCategoryId, SrcLevelId, IdentifyType


修改数据结构：

* [DspaRDBDataAssetDetail](https://cloud.tencent.com/document/api/1087/96844#DspaRDBDataAssetDetail)

	* 新增成员：IdentifyType, CheckStatus, IsSensitiveData

* [ESDataAssetDetail](https://cloud.tencent.com/document/api/1087/96844#ESDataAssetDetail)

	* 新增成员：IdentifyType, CheckStatus


### 第 4 次发布

发布时间：2023-09-19 01:13:28

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeDSPAAssessmentLatestRiskList](https://cloud.tencent.com/document/api/1087/97157)

	* 新增入参：TimeSort


修改数据结构：

* [AssessmentRisk](https://cloud.tencent.com/document/api/1087/96844#AssessmentRisk)

	* 新增成员：DataSourceType

* [AssessmentTask](https://cloud.tencent.com/document/api/1087/96844#AssessmentTask)

	* 新增成员：TaskUid, TemplateUid, ProgressPercent

* [AssessmentTemplate](https://cloud.tencent.com/document/api/1087/96844#AssessmentTemplate)

	* 新增成员：IdentifyComplianceId

* [RiskItemInfo](https://cloud.tencent.com/document/api/1087/96844#RiskItemInfo)

	* 新增成员：APIRiskLinkURL, Remark


### 第 3 次发布

发布时间：2023-08-31 01:14:45

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeDSPAAssessmentRiskSideDistributed](https://cloud.tencent.com/document/api/1087/97607)
* [DescribeDSPAAssessmentRiskSideList](https://cloud.tencent.com/document/api/1087/97606)

修改接口：

* [CreateDSPAAssessmentTask](https://cloud.tencent.com/document/api/1087/97259)

	* <font color="#dd0000">**修改入参**：</font>DiscoveryCondition

* [DescribeDSPAAssessmentHighRiskTop10Overview](https://cloud.tencent.com/document/api/1087/97159)

	* 新增入参：Filter

* [DescribeDSPAAssessmentLatestRiskList](https://cloud.tencent.com/document/api/1087/97157)

	* 新增入参：RiskSide

* [DescribeDSPAAssessmentRiskDistributionOverview](https://cloud.tencent.com/document/api/1087/97152)

	* 新增入参：Filter

* [DescribeDSPAAssessmentRiskTemplateVulnerableList](https://cloud.tencent.com/document/api/1087/97148)

	* 新增入参：RiskSide

* [DescribeDSPAESDiscoveryTaskResultDetail](https://cloud.tencent.com/document/api/1087/97208)

	* 新增入参：DbName

* [ModifyDSPAAssessmentRiskLatest](https://cloud.tencent.com/document/api/1087/97199)

	* 新增入参：BathRiskIdList


新增数据结构：

* [RiskSideDistributed](https://cloud.tencent.com/document/api/1087/96844#RiskSideDistributed)
* [TemplateInfo](https://cloud.tencent.com/document/api/1087/96844#TemplateInfo)

修改数据结构：

* [AssessmentRisk](https://cloud.tencent.com/document/api/1087/96844#AssessmentRisk)

	* 新增成员：RiskSide

	* <font color="#dd0000">**修改成员**：</font>AssetName, SecurityProduct, RiskType

* [AssessmentRiskItem](https://cloud.tencent.com/document/api/1087/96844#AssessmentRiskItem)

	* 新增成员：RiskSide, ReferTemplateList

* [AssessmentTemplate](https://cloud.tencent.com/document/api/1087/96844#AssessmentTemplate)

	* 新增成员：IsASMTemplate

	* <font color="#dd0000">**修改成员**：</font>Id, SupportDataSource

* [ESTaskResultDetail](https://cloud.tencent.com/document/api/1087/96844#ESTaskResultDetail)

	* 新增成员：LevelRiskScore

* [HighRiskAssetsDetail](https://cloud.tencent.com/document/api/1087/96844#HighRiskAssetsDetail)

	* 新增成员：DataSourceType, DataSourceName, RiskSide, ResourceRegion

	* <font color="#dd0000">**修改成员**：</font>InstanceId, AssetsName, HighRiskCount, RiskType, TotalRiskCount

* [RiskCountInfo](https://cloud.tencent.com/document/api/1087/96844#RiskCountInfo)

	* 新增成员：RiskLevelName

* [RiskItemInfo](https://cloud.tencent.com/document/api/1087/96844#RiskItemInfo)

	* 新增成员：ResourceRegion, RiskSide


### 第 2 次发布

发布时间：2023-08-25 01:34:20

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [AuthorizeDSPAMetaResources](https://cloud.tencent.com/document/api/1087/97183)
* [BindDSPAResourceCosBuckets](https://cloud.tencent.com/document/api/1087/97182)
* [BindDSPAResourceDatabases](https://cloud.tencent.com/document/api/1087/97181)
* [CopyDSPATemplate](https://cloud.tencent.com/document/api/1087/97260)
* [CreateAssetSortingReportRetryTask](https://cloud.tencent.com/document/api/1087/97141)
* [CreateAssetSortingReportTask](https://cloud.tencent.com/document/api/1087/97140)
* [CreateClassificationRule](https://cloud.tencent.com/document/api/1087/97278)
* [CreateDSPAAssessmentRiskLevel](https://cloud.tencent.com/document/api/1087/97162)
* [CreateDSPAAssessmentRiskTemplate](https://cloud.tencent.com/document/api/1087/97161)
* [CreateDSPAAssessmentTask](https://cloud.tencent.com/document/api/1087/97259)
* [CreateDSPACOSDiscoveryTask](https://cloud.tencent.com/document/api/1087/97258)
* [CreateDSPACategory](https://cloud.tencent.com/document/api/1087/97257)
* [CreateDSPACategoryRelation](https://cloud.tencent.com/document/api/1087/97256)
* [CreateDSPAComplianceGroup](https://cloud.tencent.com/document/api/1087/97255)
* [CreateDSPAComplianceRules](https://cloud.tencent.com/document/api/1087/97254)
* [CreateDSPACosMetaResources](https://cloud.tencent.com/document/api/1087/97180)
* [CreateDSPADiscoveryRule](https://cloud.tencent.com/document/api/1087/97253)
* [CreateDSPADiscoveryTask](https://cloud.tencent.com/document/api/1087/97252)
* [CreateDSPALevelGroup](https://cloud.tencent.com/document/api/1087/97251)
* [CreateDSPAMetaResources](https://cloud.tencent.com/document/api/1087/97179)
* [CreateDSPASelfBuildMetaResource](https://cloud.tencent.com/document/api/1087/97178)
* [CreateIdentifyRuleAnotherName](https://cloud.tencent.com/document/api/1087/97250)
* [CreateNewClassification](https://cloud.tencent.com/document/api/1087/97277)
* [CreateOrCopyStandard](https://cloud.tencent.com/document/api/1087/97276)
* [DecribeSuggestRiskLevelMatrix](https://cloud.tencent.com/document/api/1087/97160)
* [DeleteCosMetaResource](https://cloud.tencent.com/document/api/1087/97177)
* [DeleteDSPAAssessmentTask](https://cloud.tencent.com/document/api/1087/97249)
* [DeleteDSPACOSDiscoveryTask](https://cloud.tencent.com/document/api/1087/97248)
* [DeleteDSPACOSDiscoveryTaskResult](https://cloud.tencent.com/document/api/1087/97247)
* [DeleteDSPADiscoveryTask](https://cloud.tencent.com/document/api/1087/97246)
* [DeleteDSPADiscoveryTaskResult](https://cloud.tencent.com/document/api/1087/97245)
* [DeleteDSPAMetaResource](https://cloud.tencent.com/document/api/1087/97176)
* [DescribeAssetDetailDataExportResult](https://cloud.tencent.com/document/api/1087/97244)
* [DescribeAssetOverview](https://cloud.tencent.com/document/api/1087/97139)
* [DescribeBindDBList](https://cloud.tencent.com/document/api/1087/97138)
* [DescribeCOSAssetSensitiveDistribution](https://cloud.tencent.com/document/api/1087/97137)
* [DescribeClassificationInfo](https://cloud.tencent.com/document/api/1087/97275)
* [DescribeClassificationRuleCount](https://cloud.tencent.com/document/api/1087/97274)
* [DescribeDSPAAssessmentHighRiskTop10Overview](https://cloud.tencent.com/document/api/1087/97159)
* [DescribeDSPAAssessmentLatestRiskDetailInfo](https://cloud.tencent.com/document/api/1087/97158)
* [DescribeDSPAAssessmentLatestRiskList](https://cloud.tencent.com/document/api/1087/97157)
* [DescribeDSPAAssessmentNewDiscoveredRiskOverview](https://cloud.tencent.com/document/api/1087/97156)
* [DescribeDSPAAssessmentPendingRiskOverview](https://cloud.tencent.com/document/api/1087/97155)
* [DescribeDSPAAssessmentProcessingRiskOverview](https://cloud.tencent.com/document/api/1087/97154)
* [DescribeDSPAAssessmentRiskAmountOverview](https://cloud.tencent.com/document/api/1087/97153)
* [DescribeDSPAAssessmentRiskDatasourceTop5](https://cloud.tencent.com/document/api/1087/97243)
* [DescribeDSPAAssessmentRiskDealedOverview](https://cloud.tencent.com/document/api/1087/97242)
* [DescribeDSPAAssessmentRiskDealedTrend](https://cloud.tencent.com/document/api/1087/97241)
* [DescribeDSPAAssessmentRiskDistributionOverview](https://cloud.tencent.com/document/api/1087/97152)
* [DescribeDSPAAssessmentRiskItemTop5](https://cloud.tencent.com/document/api/1087/97240)
* [DescribeDSPAAssessmentRiskLevelDetail](https://cloud.tencent.com/document/api/1087/97151)
* [DescribeDSPAAssessmentRiskLevelList](https://cloud.tencent.com/document/api/1087/97150)
* [DescribeDSPAAssessmentRiskLevelTrend](https://cloud.tencent.com/document/api/1087/97239)
* [DescribeDSPAAssessmentRiskOverview](https://cloud.tencent.com/document/api/1087/97238)
* [DescribeDSPAAssessmentRiskProcessHistory](https://cloud.tencent.com/document/api/1087/97237)
* [DescribeDSPAAssessmentRiskTemplateDetail](https://cloud.tencent.com/document/api/1087/97149)
* [DescribeDSPAAssessmentRiskTemplateVulnerableList](https://cloud.tencent.com/document/api/1087/97148)
* [DescribeDSPAAssessmentRisks](https://cloud.tencent.com/document/api/1087/97236)
* [DescribeDSPAAssessmentTasks](https://cloud.tencent.com/document/api/1087/97235)
* [DescribeDSPAAssessmentTemplateControlItems](https://cloud.tencent.com/document/api/1087/97234)
* [DescribeDSPAAssessmentTemplates](https://cloud.tencent.com/document/api/1087/97233)
* [DescribeDSPACOSDataAssetBuckets](https://cloud.tencent.com/document/api/1087/97232)
* [DescribeDSPACOSDataAssetByComplianceId](https://cloud.tencent.com/document/api/1087/97231)
* [DescribeDSPACOSDataAssetDetail](https://cloud.tencent.com/document/api/1087/97230)
* [DescribeDSPACOSDiscoveryTaskDetail](https://cloud.tencent.com/document/api/1087/97229)
* [DescribeDSPACOSDiscoveryTaskFiles](https://cloud.tencent.com/document/api/1087/97228)
* [DescribeDSPACOSDiscoveryTaskResult](https://cloud.tencent.com/document/api/1087/97227)
* [DescribeDSPACOSDiscoveryTasks](https://cloud.tencent.com/document/api/1087/97226)
* [DescribeDSPACOSTaskResultDetail](https://cloud.tencent.com/document/api/1087/97225)
* [DescribeDSPACategories](https://cloud.tencent.com/document/api/1087/97224)
* [DescribeDSPACategoryRuleStatistic](https://cloud.tencent.com/document/api/1087/97223)
* [DescribeDSPACategoryRules](https://cloud.tencent.com/document/api/1087/97222)
* [DescribeDSPACategoryTree](https://cloud.tencent.com/document/api/1087/97221)
* [DescribeDSPACategoryTreeWithRules](https://cloud.tencent.com/document/api/1087/97220)
* [DescribeDSPAComplianceGroupDetail](https://cloud.tencent.com/document/api/1087/97219)
* [DescribeDSPAComplianceGroups](https://cloud.tencent.com/document/api/1087/97218)
* [DescribeDSPAComplianceUpdateNotification](https://cloud.tencent.com/document/api/1087/97217)
* [DescribeDSPADataSourceDbInfo](https://cloud.tencent.com/document/api/1087/97216)
* [DescribeDSPADiscoveryRules](https://cloud.tencent.com/document/api/1087/97215)
* [DescribeDSPADiscoveryServiceStatus](https://cloud.tencent.com/document/api/1087/97214)
* [DescribeDSPADiscoveryTaskDetail](https://cloud.tencent.com/document/api/1087/97213)
* [DescribeDSPADiscoveryTaskResult](https://cloud.tencent.com/document/api/1087/97212)
* [DescribeDSPADiscoveryTaskResultDetail](https://cloud.tencent.com/document/api/1087/97211)
* [DescribeDSPADiscoveryTaskTables](https://cloud.tencent.com/document/api/1087/97210)
* [DescribeDSPAESDataAssetByComplianceId](https://cloud.tencent.com/document/api/1087/97144)
* [DescribeDSPAESDataAssetDetail](https://cloud.tencent.com/document/api/1087/97143)
* [DescribeDSPAESDataSample](https://cloud.tencent.com/document/api/1087/97209)
* [DescribeDSPAESDiscoveryTaskResultDetail](https://cloud.tencent.com/document/api/1087/97208)
* [DescribeDSPALevelDetail](https://cloud.tencent.com/document/api/1087/97207)
* [DescribeDSPALevelGroups](https://cloud.tencent.com/document/api/1087/97206)
* [DescribeDSPARDBDataAssetByComplianceId](https://cloud.tencent.com/document/api/1087/97205)
* [DescribeDSPARDBDataAssetDetail](https://cloud.tencent.com/document/api/1087/97204)
* [DescribeDSPASupportedMetas](https://cloud.tencent.com/document/api/1087/97175)
* [DescribeDSPATaskResultDataSample](https://cloud.tencent.com/document/api/1087/97203)
* [DescribeESAssetSensitiveDistribution](https://cloud.tencent.com/document/api/1087/97136)
* [DescribeExportTaskResult](https://cloud.tencent.com/document/api/1087/97128)
* [DescribeLeafClassification](https://cloud.tencent.com/document/api/1087/97273)
* [DescribeMongoAssetSensitiveDistribution](https://cloud.tencent.com/document/api/1087/97135)
* [DescribeRDBAssetSensitiveDistribution](https://cloud.tencent.com/document/api/1087/97134)
* [DescribeReportTaskDownloadUrl](https://cloud.tencent.com/document/api/1087/97133)
* [DescribeReportTasks](https://cloud.tencent.com/document/api/1087/97132)
* [DescribeRuleDetail](https://cloud.tencent.com/document/api/1087/97272)
* [DescribeRuleList](https://cloud.tencent.com/document/api/1087/97271)
* [DescribeSensitiveCOSDataDistribution](https://cloud.tencent.com/document/api/1087/97131)
* [DescribeSensitiveRDBDataDistribution](https://cloud.tencent.com/document/api/1087/97130)
* [DisableDSPAMetaResourceAuth](https://cloud.tencent.com/document/api/1087/97174)
* [EnableDSPADiscoveryRule](https://cloud.tencent.com/document/api/1087/97202)
* [EnableTrialVersion](https://cloud.tencent.com/document/api/1087/97173)
* [ExportAssetDetailData](https://cloud.tencent.com/document/api/1087/97201)
* [GetResourceConnectionStatus](https://cloud.tencent.com/document/api/1087/97172)
* [GetTrialVersion](https://cloud.tencent.com/document/api/1087/97171)
* [GetUserQuotaInfo](https://cloud.tencent.com/document/api/1087/97170)
* [ListDSPAClusters](https://cloud.tencent.com/document/api/1087/97169)
* [ListDSPACosMetaResources](https://cloud.tencent.com/document/api/1087/97168)
* [ListDSPAMetaResources](https://cloud.tencent.com/document/api/1087/97167)
* [ModifyClassificationRule](https://cloud.tencent.com/document/api/1087/97270)
* [ModifyClassificationRuleState](https://cloud.tencent.com/document/api/1087/97269)
* [ModifyDSPAAssessmentRisk](https://cloud.tencent.com/document/api/1087/97200)
* [ModifyDSPAAssessmentRiskLatest](https://cloud.tencent.com/document/api/1087/97199)
* [ModifyDSPAAssessmentRiskLevel](https://cloud.tencent.com/document/api/1087/97147)
* [ModifyDSPAAssessmentRiskTemplate](https://cloud.tencent.com/document/api/1087/97146)
* [ModifyDSPACOSDiscoveryTask](https://cloud.tencent.com/document/api/1087/97198)
* [ModifyDSPACOSTaskResult](https://cloud.tencent.com/document/api/1087/97197)
* [ModifyDSPACategory](https://cloud.tencent.com/document/api/1087/97196)
* [ModifyDSPACategoryRelation](https://cloud.tencent.com/document/api/1087/97195)
* [ModifyDSPAClusterInfo](https://cloud.tencent.com/document/api/1087/97166)
* [ModifyDSPAComplianceGroup](https://cloud.tencent.com/document/api/1087/97194)
* [ModifyDSPADiscoveryRule](https://cloud.tencent.com/document/api/1087/97193)
* [ModifyDSPADiscoveryTask](https://cloud.tencent.com/document/api/1087/97192)
* [ModifyDSPAESTaskResult](https://cloud.tencent.com/document/api/1087/97191)
* [ModifyDSPATaskResult](https://cloud.tencent.com/document/api/1087/97190)
* [ModifyLevelInfo](https://cloud.tencent.com/document/api/1087/97264)
* [ModifyLevelName](https://cloud.tencent.com/document/api/1087/97263)
* [ModifyLevelState](https://cloud.tencent.com/document/api/1087/97262)
* [ModifyMergeClassification](https://cloud.tencent.com/document/api/1087/97268)
* [ModifyNewClassification](https://cloud.tencent.com/document/api/1087/97267)
* [ModifyStandardInfo](https://cloud.tencent.com/document/api/1087/97266)
* [QueryDSPAMetaResourceDbList](https://cloud.tencent.com/document/api/1087/97165)
* [QueryResourceDbBindStatus](https://cloud.tencent.com/document/api/1087/97164)
* [RestartDSPAAssessmentTask](https://cloud.tencent.com/document/api/1087/97189)
* [StartDSPADiscoveryTask](https://cloud.tencent.com/document/api/1087/97188)
* [StopDSPADiscoveryTask](https://cloud.tencent.com/document/api/1087/97187)
* [UpdateDSPASelfBuildResource](https://cloud.tencent.com/document/api/1087/97163)
* [VerifyDSPACOSRule](https://cloud.tencent.com/document/api/1087/97186)
* [VerifyDSPADiscoveryRule](https://cloud.tencent.com/document/api/1087/97185)

新增数据结构：

* [AKSKLeak](https://cloud.tencent.com/document/api/1087/96844#AKSKLeak)
* [AccountRisk](https://cloud.tencent.com/document/api/1087/96844#AccountRisk)
* [AssessmentControlItem](https://cloud.tencent.com/document/api/1087/96844#AssessmentControlItem)
* [AssessmentRisk](https://cloud.tencent.com/document/api/1087/96844#AssessmentRisk)
* [AssessmentRiskItem](https://cloud.tencent.com/document/api/1087/96844#AssessmentRiskItem)
* [AssessmentTask](https://cloud.tencent.com/document/api/1087/96844#AssessmentTask)
* [AssessmentTemplate](https://cloud.tencent.com/document/api/1087/96844#AssessmentTemplate)
* [AssetCosDetail](https://cloud.tencent.com/document/api/1087/96844#AssetCosDetail)
* [AssetDBDetail](https://cloud.tencent.com/document/api/1087/96844#AssetDBDetail)
* [AssetList](https://cloud.tencent.com/document/api/1087/96844#AssetList)
* [COSDataRule](https://cloud.tencent.com/document/api/1087/96844#COSDataRule)
* [COSInstance](https://cloud.tencent.com/document/api/1087/96844#COSInstance)
* [CategoryRule](https://cloud.tencent.com/document/api/1087/96844#CategoryRule)
* [CategoryRuleStatistic](https://cloud.tencent.com/document/api/1087/96844#CategoryRuleStatistic)
* [ComplianceGroupDetail](https://cloud.tencent.com/document/api/1087/96844#ComplianceGroupDetail)
* [ComplianceGroupRuleIdInfo](https://cloud.tencent.com/document/api/1087/96844#ComplianceGroupRuleIdInfo)
* [CosAsset](https://cloud.tencent.com/document/api/1087/96844#CosAsset)
* [CosResourceItem](https://cloud.tencent.com/document/api/1087/96844#CosResourceItem)
* [CosTaskResult](https://cloud.tencent.com/document/api/1087/96844#CosTaskResult)
* [CreateComplianceRules](https://cloud.tencent.com/document/api/1087/96844#CreateComplianceRules)
* [DBInstanceInfo](https://cloud.tencent.com/document/api/1087/96844#DBInstanceInfo)
* [DBStatements](https://cloud.tencent.com/document/api/1087/96844#DBStatements)
* [DSPACosMetaDataInfo](https://cloud.tencent.com/document/api/1087/96844#DSPACosMetaDataInfo)
* [DSPADataSourceDbInfo](https://cloud.tencent.com/document/api/1087/96844#DSPADataSourceDbInfo)
* [DSPAMetaType](https://cloud.tencent.com/document/api/1087/96844#DSPAMetaType)
* [DSPATableInfo](https://cloud.tencent.com/document/api/1087/96844#DSPATableInfo)
* [DataCategory](https://cloud.tencent.com/document/api/1087/96844#DataCategory)
* [DataContent](https://cloud.tencent.com/document/api/1087/96844#DataContent)
* [DataRule](https://cloud.tencent.com/document/api/1087/96844#DataRule)
* [DataRules](https://cloud.tencent.com/document/api/1087/96844#DataRules)
* [DataSourceInfo](https://cloud.tencent.com/document/api/1087/96844#DataSourceInfo)
* [DatagovRuleExtendParameter](https://cloud.tencent.com/document/api/1087/96844#DatagovRuleExtendParameter)
* [DbInfo](https://cloud.tencent.com/document/api/1087/96844#DbInfo)
* [DbRelationStatusItem](https://cloud.tencent.com/document/api/1087/96844#DbRelationStatusItem)
* [DbResourceItem](https://cloud.tencent.com/document/api/1087/96844#DbResourceItem)
* [DbTaskResult](https://cloud.tencent.com/document/api/1087/96844#DbTaskResult)
* [DiscoveryCondition](https://cloud.tencent.com/document/api/1087/96844#DiscoveryCondition)
* [DspaAssessmentFilter](https://cloud.tencent.com/document/api/1087/96844#DspaAssessmentFilter)
* [DspaCOSDataAssetCount](https://cloud.tencent.com/document/api/1087/96844#DspaCOSDataAssetCount)
* [DspaCOSDataAssetDetail](https://cloud.tencent.com/document/api/1087/96844#DspaCOSDataAssetDetail)
* [DspaCOSDiscoveryTask](https://cloud.tencent.com/document/api/1087/96844#DspaCOSDiscoveryTask)
* [DspaCOSDiscoveryTaskDataSourceInfo](https://cloud.tencent.com/document/api/1087/96844#DspaCOSDiscoveryTaskDataSourceInfo)
* [DspaCOSDiscoveryTaskDetail](https://cloud.tencent.com/document/api/1087/96844#DspaCOSDiscoveryTaskDetail)
* [DspaCOSDiscoveryTaskResult](https://cloud.tencent.com/document/api/1087/96844#DspaCOSDiscoveryTaskResult)
* [DspaDataCategoryDistributed](https://cloud.tencent.com/document/api/1087/96844#DspaDataCategoryDistributed)
* [DspaDataSourceMngFilter](https://cloud.tencent.com/document/api/1087/96844#DspaDataSourceMngFilter)
* [DspaDiscoveryCOSDataRule](https://cloud.tencent.com/document/api/1087/96844#DspaDiscoveryCOSDataRule)
* [DspaDiscoveryCOSRules](https://cloud.tencent.com/document/api/1087/96844#DspaDiscoveryCOSRules)
* [DspaDiscoveryCOSTaskResultDetail](https://cloud.tencent.com/document/api/1087/96844#DspaDiscoveryCOSTaskResultDetail)
* [DspaDiscoveryComplianceGroup](https://cloud.tencent.com/document/api/1087/96844#DspaDiscoveryComplianceGroup)
* [DspaDiscoveryComplianceGroupInfo](https://cloud.tencent.com/document/api/1087/96844#DspaDiscoveryComplianceGroupInfo)
* [DspaDiscoveryComplianceGroupRule](https://cloud.tencent.com/document/api/1087/96844#DspaDiscoveryComplianceGroupRule)
* [DspaDiscoveryComplianceGroupRuleInfo](https://cloud.tencent.com/document/api/1087/96844#DspaDiscoveryComplianceGroupRuleInfo)
* [DspaDiscoveryDataContent](https://cloud.tencent.com/document/api/1087/96844#DspaDiscoveryDataContent)
* [DspaDiscoveryDataRule](https://cloud.tencent.com/document/api/1087/96844#DspaDiscoveryDataRule)
* [DspaDiscoveryDataRules](https://cloud.tencent.com/document/api/1087/96844#DspaDiscoveryDataRules)
* [DspaDiscoveryLevelDetail](https://cloud.tencent.com/document/api/1087/96844#DspaDiscoveryLevelDetail)
* [DspaDiscoveryRDBRules](https://cloud.tencent.com/document/api/1087/96844#DspaDiscoveryRDBRules)
* [DspaDiscoveryRuleDetail](https://cloud.tencent.com/document/api/1087/96844#DspaDiscoveryRuleDetail)
* [DspaDiscoveryTaskCOSCondition](https://cloud.tencent.com/document/api/1087/96844#DspaDiscoveryTaskCOSCondition)
* [DspaDiscoveryTaskDataSource](https://cloud.tencent.com/document/api/1087/96844#DspaDiscoveryTaskDataSource)
* [DspaDiscoveryTaskDbResult](https://cloud.tencent.com/document/api/1087/96844#DspaDiscoveryTaskDbResult)
* [DspaDiscoveryTaskDetail](https://cloud.tencent.com/document/api/1087/96844#DspaDiscoveryTaskDetail)
* [DspaDiscoveryTaskResultDetail](https://cloud.tencent.com/document/api/1087/96844#DspaDiscoveryTaskResultDetail)
* [DspaFieldResultDataSample](https://cloud.tencent.com/document/api/1087/96844#DspaFieldResultDataSample)
* [DspaInstance](https://cloud.tencent.com/document/api/1087/96844#DspaInstance)
* [DspaRDBDataAssetCount](https://cloud.tencent.com/document/api/1087/96844#DspaRDBDataAssetCount)
* [DspaRDBDataAssetDetail](https://cloud.tencent.com/document/api/1087/96844#DspaRDBDataAssetDetail)
* [DspaResourceAccount](https://cloud.tencent.com/document/api/1087/96844#DspaResourceAccount)
* [DspaSafeGuard](https://cloud.tencent.com/document/api/1087/96844#DspaSafeGuard)
* [DspaTaskResult](https://cloud.tencent.com/document/api/1087/96844#DspaTaskResult)
* [DspaUserResourceMeta](https://cloud.tencent.com/document/api/1087/96844#DspaUserResourceMeta)
* [ESAsset](https://cloud.tencent.com/document/api/1087/96844#ESAsset)
* [ESAssetDBDetail](https://cloud.tencent.com/document/api/1087/96844#ESAssetDBDetail)
* [ESDataAssetCountDto](https://cloud.tencent.com/document/api/1087/96844#ESDataAssetCountDto)
* [ESDataAssetDetail](https://cloud.tencent.com/document/api/1087/96844#ESDataAssetDetail)
* [ESInstance](https://cloud.tencent.com/document/api/1087/96844#ESInstance)
* [ESTaskResultDetail](https://cloud.tencent.com/document/api/1087/96844#ESTaskResultDetail)
* [ErrDescription](https://cloud.tencent.com/document/api/1087/96844#ErrDescription)
* [Filter](https://cloud.tencent.com/document/api/1087/96844#Filter)
* [HighRiskAssetsDetail](https://cloud.tencent.com/document/api/1087/96844#HighRiskAssetsDetail)
* [ItemLevel](https://cloud.tencent.com/document/api/1087/96844#ItemLevel)
* [LevelItem](https://cloud.tencent.com/document/api/1087/96844#LevelItem)
* [MongoAsset](https://cloud.tencent.com/document/api/1087/96844#MongoAsset)
* [MongoAssetDBDetail](https://cloud.tencent.com/document/api/1087/96844#MongoAssetDBDetail)
* [NOSQLInstance](https://cloud.tencent.com/document/api/1087/96844#NOSQLInstance)
* [Note](https://cloud.tencent.com/document/api/1087/96844#Note)
* [PrivilegeRisk](https://cloud.tencent.com/document/api/1087/96844#PrivilegeRisk)
* [ProcessHistory](https://cloud.tencent.com/document/api/1087/96844#ProcessHistory)
* [RDBAsset](https://cloud.tencent.com/document/api/1087/96844#RDBAsset)
* [RDBInstance](https://cloud.tencent.com/document/api/1087/96844#RDBInstance)
* [ReportInfo](https://cloud.tencent.com/document/api/1087/96844#ReportInfo)
* [RiskCountInfo](https://cloud.tencent.com/document/api/1087/96844#RiskCountInfo)
* [RiskDealedTrendItem](https://cloud.tencent.com/document/api/1087/96844#RiskDealedTrendItem)
* [RiskItem](https://cloud.tencent.com/document/api/1087/96844#RiskItem)
* [RiskItemInfo](https://cloud.tencent.com/document/api/1087/96844#RiskItemInfo)
* [RiskLevelMatrix](https://cloud.tencent.com/document/api/1087/96844#RiskLevelMatrix)
* [RiskLevelRisk](https://cloud.tencent.com/document/api/1087/96844#RiskLevelRisk)
* [RiskLevelTrendItem](https://cloud.tencent.com/document/api/1087/96844#RiskLevelTrendItem)
* [RiskMatrixLevel](https://cloud.tencent.com/document/api/1087/96844#RiskMatrixLevel)
* [RuleDistribution](https://cloud.tencent.com/document/api/1087/96844#RuleDistribution)
* [ScanTaskCOSRules](https://cloud.tencent.com/document/api/1087/96844#ScanTaskCOSRules)
* [ScanTaskComplianceInfo](https://cloud.tencent.com/document/api/1087/96844#ScanTaskComplianceInfo)
* [ScanTaskRDBRules](https://cloud.tencent.com/document/api/1087/96844#ScanTaskRDBRules)
* [ScanTaskResult](https://cloud.tencent.com/document/api/1087/96844#ScanTaskResult)
* [SecurityProduct](https://cloud.tencent.com/document/api/1087/96844#SecurityProduct)
* [SensitiveLevel](https://cloud.tencent.com/document/api/1087/96844#SensitiveLevel)
* [SuggestRiskLevelMatrix](https://cloud.tencent.com/document/api/1087/96844#SuggestRiskLevelMatrix)
* [SuggestRiskLevelMatrixItem](https://cloud.tencent.com/document/api/1087/96844#SuggestRiskLevelMatrixItem)
* [TopAsset](https://cloud.tencent.com/document/api/1087/96844#TopAsset)
* [TopAssetStat](https://cloud.tencent.com/document/api/1087/96844#TopAssetStat)

### 第 1 次发布

发布时间：2023-08-22 15:36:03

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateDSPADbMetaResources](https://cloud.tencent.com/document/api/1087/96843)

新增数据结构：

* [DspaCloudResourceMeta](https://cloud.tencent.com/document/api/1087/96844#DspaCloudResourceMeta)




## 分布式事务 DTF(dtf) 版本：2020-05-06

### 第 1 次发布

发布时间：2021-07-02 08:00:03

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeTransactions](https://cloud.tencent.com/document/api/1224/58100)

新增数据结构：

* [PagedTransaction](https://cloud.tencent.com/document/api/1224/58101#PagedTransaction)
* [Transaction](https://cloud.tencent.com/document/api/1224/58101#Transaction)




## 数据传输服务(dts) 版本：2018-03-30

### 第 22 次发布

发布时间：2024-06-21 01:37:37

本次发布包含了以下内容：

改善已有的文档。

<font color="#dd0000">**删除接口**：</font>

* DescribeRegionConf

<font color="#dd0000">**删除数据结构**：</font>

* SubscribeRegionConf

### 第 21 次发布

发布时间：2024-06-13 01:40:12

本次发布包含了以下内容：

改善已有的文档。

<font color="#dd0000">**预下线接口**：</font>

* DescribeRegionConf

### 第 20 次发布

发布时间：2024-06-07 01:43:53

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [SubsErr](https://cloud.tencent.com/document/api/571/18131#SubsErr)

	* <font color="#dd0000">**修改成员**：</font>Message


### 第 19 次发布

发布时间：2022-04-28 06:11:50

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeSubscribeConf](https://cloud.tencent.com/document/api/571/42716)

	* 新增出参：SubscribeVersion, Errors


新增数据结构：

* [SubsErr](https://cloud.tencent.com/document/api/571/18131#SubsErr)

修改数据结构：

* [MigrateJobInfo](https://cloud.tencent.com/document/api/571/18131#MigrateJobInfo)

	* 新增成员：SrcInfoMulti


### 第 18 次发布

发布时间：2022-04-26 06:09:43

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateSubscribe](https://cloud.tencent.com/document/api/571/42719)

	* 新增入参：Name


### 第 17 次发布

发布时间：2022-04-22 06:09:15

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateMigrateJob](https://cloud.tencent.com/document/api/571/18141)

	* 新增入参：SrcNodeType, SrcInfoMulti

* [ModifyMigrateJob](https://cloud.tencent.com/document/api/571/18138)

	* 新增入参：SrcNodeType, SrcInfoMulti


### 第 16 次发布

发布时间：2021-12-21 08:05:11

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateMigrateJob](https://cloud.tencent.com/document/api/571/18141)

	* 新增入参：Tags


### 第 15 次发布

发布时间：2021-11-09 08:10:46

本次发布包含了以下内容：

改善已有的文档。

<font color="#dd0000">**删除接口**：</font>

* DescribeSyncCheckJob
* ModifySyncJob

<font color="#dd0000">**删除数据结构**：</font>

* SyncCheckStepInfo
* SyncOption

### 第 14 次发布

发布时间：2021-11-08 08:05:43

本次发布包含了以下内容：

改善已有的文档。

<font color="#dd0000">**删除接口**：</font>

* CreateSyncCheckJob
* CreateSyncJob
* DeleteSyncJob
* DescribeSyncJobs
* StartSyncJob
* SwitchDrToMaster

<font color="#dd0000">**删除数据结构**：</font>

* SyncDetailInfo
* SyncInstanceInfo
* SyncJobInfo
* SyncStepDetailInfo

### 第 13 次发布

发布时间：2021-09-02 08:04:47

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeMigrateJobs](https://cloud.tencent.com/document/api/571/18130)

	* 新增入参：TagFilters


修改数据结构：

* [DstInfo](https://cloud.tencent.com/document/api/571/18131#DstInfo)

	* <font color="#dd0000">**修改成员**：</font>InstanceId

* [MigrateJobInfo](https://cloud.tencent.com/document/api/571/18131#MigrateJobInfo)

	* 新增成员：Tags


### 第 12 次发布

发布时间：2021-06-16 08:05:20

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CompleteMigrateJob](https://cloud.tencent.com/document/api/571/18143)

	* 新增入参：CompleteMode


### 第 11 次发布

发布时间：2021-02-03 08:04:31

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeSubscribes](https://cloud.tencent.com/document/api/571/42715)

	* 新增入参：SubscribeVersion


修改数据结构：

* [SubscribeInfo](https://cloud.tencent.com/document/api/571/18131#SubscribeInfo)

	* 新增成员：SubscribeVersion


### 第 10 次发布

发布时间：2020-08-28 08:03:00

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [ModifySubscribeAutoRenewFlag](https://cloud.tencent.com/document/api/571/47894)

修改接口：

* [CreateSubscribe](https://cloud.tencent.com/document/api/571/42719)

	* 新增入参：Tags

* [DescribeSubscribeConf](https://cloud.tencent.com/document/api/571/42716)

	* 新增出参：Tags, AutoRenewFlag

* [DescribeSubscribes](https://cloud.tencent.com/document/api/571/42715)

	* 新增入参：TagFilters


新增数据结构：

* [TagFilter](https://cloud.tencent.com/document/api/571/18131#TagFilter)
* [TagItem](https://cloud.tencent.com/document/api/571/18131#TagItem)

修改数据结构：

* [SubscribeInfo](https://cloud.tencent.com/document/api/571/18131#SubscribeInfo)

	* 新增成员：Tags, AutoRenewFlag


### 第 9 次发布

发布时间：2020-04-29 08:09:34

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [DstInfo](https://cloud.tencent.com/document/api/571/18131#DstInfo)

	* 新增成员：User, Password


### 第 8 次发布

发布时间：2020-03-20 08:07:26

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [ActivateSubscribe](https://cloud.tencent.com/document/api/571/42720)
* [CreateSubscribe](https://cloud.tencent.com/document/api/571/42719)
* [DescribeAsyncRequestInfo](https://cloud.tencent.com/document/api/571/42718)
* [DescribeRegionConf](https://cloud.tencent.com/document/api/571/42717)
* [DescribeSubscribeConf](https://cloud.tencent.com/document/api/571/42716)
* [DescribeSubscribes](https://cloud.tencent.com/document/api/571/42715)
* [IsolateSubscribe](https://cloud.tencent.com/document/api/571/42714)
* [ModifySubscribeConsumeTime](https://cloud.tencent.com/document/api/571/42713)
* [ModifySubscribeName](https://cloud.tencent.com/document/api/571/42712)
* [ModifySubscribeObjects](https://cloud.tencent.com/document/api/571/42711)
* [ModifySubscribeVipVport](https://cloud.tencent.com/document/api/571/42710)
* [OfflineIsolatedSubscribe](https://cloud.tencent.com/document/api/571/42709)
* [ResetSubscribe](https://cloud.tencent.com/document/api/571/42708)

新增数据结构：

* [SubscribeInfo](https://cloud.tencent.com/document/api/571/18131#SubscribeInfo)
* [SubscribeObject](https://cloud.tencent.com/document/api/571/18131#SubscribeObject)
* [SubscribeRegionConf](https://cloud.tencent.com/document/api/571/18131#SubscribeRegionConf)

### 第 7 次发布

发布时间：2020-03-19 08:07:50

本次发布包含了以下内容：

改善已有的文档。

新增数据结构：

* [ErrorInfo](https://cloud.tencent.com/document/api/571/18131#ErrorInfo)

修改数据结构：

* [MigrateJobInfo](https://cloud.tencent.com/document/api/571/18131#MigrateJobInfo)

	* 新增成员：ErrorInfo


### 第 6 次发布

发布时间：2020-03-16 08:09:01

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [MigrateStepDetailInfo](https://cloud.tencent.com/document/api/571/18131#MigrateStepDetailInfo)

	* 新增成员：StartTime


### 第 5 次发布

发布时间：2019-10-17 19:45:33

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [SrcInfo](https://cloud.tencent.com/document/api/571/18131#SrcInfo)

	* 新增成员：EngineVersion


### 第 4 次发布

发布时间：2019-08-16 16:50:11

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [DstInfo](https://cloud.tencent.com/document/api/571/18131#DstInfo)

	* <font color="#dd0000">**修改成员**：</font>Region


### 第 3 次发布

发布时间：2019-08-08 23:41:19

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [SrcInfo](https://cloud.tencent.com/document/api/571/18131#SrcInfo)

	* 新增成员：CcnId


### 第 2 次发布

发布时间：2018-07-26 12:26:57

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateSyncCheckJob](https://cloud.tencent.com/document/api/571/18574)
* [CreateSyncJob](https://cloud.tencent.com/document/api/571/18573)
* [DeleteSyncJob](https://cloud.tencent.com/document/api/571/18572)
* [DescribeSyncCheckJob](https://cloud.tencent.com/document/api/571/18571)
* [DescribeSyncJobs](https://cloud.tencent.com/document/api/571/18570)
* [ModifySyncJob](https://cloud.tencent.com/document/api/571/18569)
* [StartSyncJob](https://cloud.tencent.com/document/api/571/18568)
* [SwitchDrToMaster](https://cloud.tencent.com/document/api/571/18567)

新增数据结构：

* [SyncCheckStepInfo](https://cloud.tencent.com/document/api/571/18131#SyncCheckStepInfo)
* [SyncDetailInfo](https://cloud.tencent.com/document/api/571/18131#SyncDetailInfo)
* [SyncInstanceInfo](https://cloud.tencent.com/document/api/571/18131#SyncInstanceInfo)
* [SyncJobInfo](https://cloud.tencent.com/document/api/571/18131#SyncJobInfo)
* [SyncOption](https://cloud.tencent.com/document/api/571/18131#SyncOption)
* [SyncStepDetailInfo](https://cloud.tencent.com/document/api/571/18131#SyncStepDetailInfo)

### 第 1 次发布

发布时间：2018-06-29 17:14:44

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CompleteMigrateJob](https://cloud.tencent.com/document/api/571/18143)
* [CreateMigrateCheckJob](https://cloud.tencent.com/document/api/571/18142)
* [CreateMigrateJob](https://cloud.tencent.com/document/api/571/18141)
* [DeleteMigrateJob](https://cloud.tencent.com/document/api/571/18140)
* [DescribeMigrateCheckJob](https://cloud.tencent.com/document/api/571/18139)
* [DescribeMigrateJobs](https://cloud.tencent.com/document/api/571/18130)
* [ModifyMigrateJob](https://cloud.tencent.com/document/api/571/18138)
* [StartMigrateJob](https://cloud.tencent.com/document/api/571/18137)
* [StopMigrateJob](https://cloud.tencent.com/document/api/571/18136)

新增数据结构：

* [ConsistencyParams](https://cloud.tencent.com/document/api/571/18131#ConsistencyParams)
* [DstInfo](https://cloud.tencent.com/document/api/571/18131#DstInfo)
* [MigrateDetailInfo](https://cloud.tencent.com/document/api/571/18131#MigrateDetailInfo)
* [MigrateJobInfo](https://cloud.tencent.com/document/api/571/18131#MigrateJobInfo)
* [MigrateOption](https://cloud.tencent.com/document/api/571/18131#MigrateOption)
* [MigrateStepDetailInfo](https://cloud.tencent.com/document/api/571/18131#MigrateStepDetailInfo)
* [SrcInfo](https://cloud.tencent.com/document/api/571/18131#SrcInfo)



## 数据传输服务(dts) 版本：2021-12-06

### 第 31 次发布

发布时间：2024-07-24 01:36:02

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [StopCompare](https://cloud.tencent.com/document/api/571/82072)

	* 新增入参：ForceStop


### 第 30 次发布

发布时间：2024-07-03 01:15:22

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [Endpoint](https://cloud.tencent.com/document/api/571/82108#Endpoint)

	* 新增成员：SetId


### 第 29 次发布

发布时间：2024-06-06 01:45:02

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeSubscribeJobs](https://cloud.tencent.com/document/api/571/102943)

	* 新增入参：Topic


### 第 28 次发布

发布时间：2024-04-10 01:14:34

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [ConfigureSyncJob](https://cloud.tencent.com/document/api/571/82107)

	* 新增入参：SrcConnectType


修改数据结构：

* [DBEndpointInfo](https://cloud.tencent.com/document/api/571/82108#DBEndpointInfo)

	* 新增成员：ConnectType


### 第 27 次发布

发布时间：2024-03-29 01:16:13

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [Endpoint](https://cloud.tencent.com/document/api/571/82108#Endpoint)

	* 新增成员：ChildInstanceId, ChildInstanceType

* [EndpointItem](https://cloud.tencent.com/document/api/571/82108#EndpointItem)

	* 新增成员：ChildInstanceId, ChildInstanceType


### 第 26 次发布

发布时间：2024-03-27 01:15:59

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeSubscribeDetail](https://cloud.tencent.com/document/api/571/102944)

	* 新增出参：KafkaVersion


### 第 25 次发布

发布时间：2024-03-14 01:15:02

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [DBInfo](https://cloud.tencent.com/document/api/571/82108#DBInfo)

	* 新增成员：SetId


### 第 24 次发布

发布时间：2024-03-08 01:15:05

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [Options](https://cloud.tencent.com/document/api/571/82108#Options)

	* 新增成员：FilterBeginCommit, FilterCheckpoint

* [TopicRule](https://cloud.tencent.com/document/api/571/82108#TopicRule)

	* 新增成员：Columns


### 第 23 次发布

发布时间：2024-02-23 01:14:38

本次发布包含了以下内容：

改善已有的文档。

新增数据结构：

* [AdvancedObjectsItem](https://cloud.tencent.com/document/api/571/82108#AdvancedObjectsItem)
* [DifferenceAdvancedObjectsDetail](https://cloud.tencent.com/document/api/571/82108#DifferenceAdvancedObjectsDetail)
* [DifferenceData](https://cloud.tencent.com/document/api/571/82108#DifferenceData)
* [DifferenceDataDetail](https://cloud.tencent.com/document/api/571/82108#DifferenceDataDetail)
* [DifferenceRowDetail](https://cloud.tencent.com/document/api/571/82108#DifferenceRowDetail)
* [RowsCountDifference](https://cloud.tencent.com/document/api/571/82108#RowsCountDifference)

修改数据结构：

* [CompareDetailInfo](https://cloud.tencent.com/document/api/571/82108#CompareDetailInfo)

	* 新增成员：DifferenceAdvancedObjects, DifferenceData, DifferenceRow


### 第 22 次发布

发布时间：2024-01-12 01:14:12

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [MigrateOption](https://cloud.tencent.com/document/api/571/82108#MigrateOption)

	* 新增成员：MigrateWay


### 第 21 次发布

发布时间：2024-01-10 01:13:50

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [ConfigureSubscribeJob](https://cloud.tencent.com/document/api/571/102952)
* [CreateConsumerGroup](https://cloud.tencent.com/document/api/571/102951)
* [CreateSubscribe](https://cloud.tencent.com/document/api/571/102950)
* [CreateSubscribeCheckJob](https://cloud.tencent.com/document/api/571/102949)
* [DeleteConsumerGroup](https://cloud.tencent.com/document/api/571/102948)
* [DescribeConsumerGroups](https://cloud.tencent.com/document/api/571/102947)
* [DescribeOffsetByTime](https://cloud.tencent.com/document/api/571/102946)
* [DescribeSubscribeCheckJob](https://cloud.tencent.com/document/api/571/102945)
* [DescribeSubscribeDetail](https://cloud.tencent.com/document/api/571/102944)
* [DescribeSubscribeJobs](https://cloud.tencent.com/document/api/571/102943)
* [DescribeSubscribeReturnable](https://cloud.tencent.com/document/api/571/102942)
* [DestroyIsolatedSubscribe](https://cloud.tencent.com/document/api/571/102941)
* [IsolateSubscribe](https://cloud.tencent.com/document/api/571/102940)
* [ModifyConsumerGroupDescription](https://cloud.tencent.com/document/api/571/102939)
* [ModifyConsumerGroupPassword](https://cloud.tencent.com/document/api/571/102938)
* [ModifySubscribeAutoRenewFlag](https://cloud.tencent.com/document/api/571/102937)
* [ModifySubscribeName](https://cloud.tencent.com/document/api/571/102936)
* [ModifySubscribeObjects](https://cloud.tencent.com/document/api/571/102935)
* [ResetConsumerGroupOffset](https://cloud.tencent.com/document/api/571/102934)
* [ResetSubscribe](https://cloud.tencent.com/document/api/571/102933)
* [ResumeSubscribe](https://cloud.tencent.com/document/api/571/102932)
* [StartSubscribe](https://cloud.tencent.com/document/api/571/102931)

新增数据结构：

* [DistributeRule](https://cloud.tencent.com/document/api/571/82108#DistributeRule)
* [EndpointItem](https://cloud.tencent.com/document/api/571/82108#EndpointItem)
* [GroupInfo](https://cloud.tencent.com/document/api/571/82108#GroupInfo)
* [ModifiedSubscribeObject](https://cloud.tencent.com/document/api/571/82108#ModifiedSubscribeObject)
* [MonitorInfo](https://cloud.tencent.com/document/api/571/82108#MonitorInfo)
* [OffsetTimeMap](https://cloud.tencent.com/document/api/571/82108#OffsetTimeMap)
* [PartitionAssignment](https://cloud.tencent.com/document/api/571/82108#PartitionAssignment)
* [PipelineInfo](https://cloud.tencent.com/document/api/571/82108#PipelineInfo)
* [SubsErr](https://cloud.tencent.com/document/api/571/82108#SubsErr)
* [SubscribeCheckStepInfo](https://cloud.tencent.com/document/api/571/82108#SubscribeCheckStepInfo)
* [SubscribeCheckStepTip](https://cloud.tencent.com/document/api/571/82108#SubscribeCheckStepTip)
* [SubscribeInfo](https://cloud.tencent.com/document/api/571/82108#SubscribeInfo)
* [SubscribeKafkaConfig](https://cloud.tencent.com/document/api/571/82108#SubscribeKafkaConfig)
* [SubscribeObject](https://cloud.tencent.com/document/api/571/82108#SubscribeObject)

### 第 20 次发布

发布时间：2023-12-27 01:17:28

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [ErrInfo](https://cloud.tencent.com/document/api/571/82108#ErrInfo)

	* <font color="#dd0000">**修改成员**：</font>Reason, Message, Solution

* [JobItem](https://cloud.tencent.com/document/api/571/82108#JobItem)

	* <font color="#dd0000">**修改成员**：</font>DumperResumeCtrl


### 第 19 次发布

发布时间：2023-11-15 01:36:06

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [ResumeMigrateJob](https://cloud.tencent.com/document/api/571/82075)

	* <font color="#dd0000">**修改入参**：</font>ResumeOption


### 第 18 次发布

发布时间：2023-10-23 15:36:37

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [ModifyMigrateRuntimeAttribute](https://cloud.tencent.com/document/api/571/100600)

### 第 17 次发布

发布时间：2023-10-10 01:36:36

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [SyncJobInfo](https://cloud.tencent.com/document/api/571/82108#SyncJobInfo)

	* <font color="#dd0000">**修改成员**：</font>SrcNodeType, SrcInfos, DstNodeType, DstInfos, DumperResumeCtrl


### 第 16 次发布

发布时间：2023-09-01 01:13:57

本次发布包含了以下内容：

改善已有的文档。

新增数据结构：

* [Column](https://cloud.tencent.com/document/api/571/82108#Column)
* [CompareColumnItem](https://cloud.tencent.com/document/api/571/82108#CompareColumnItem)

修改数据结构：

* [CompareTableItem](https://cloud.tencent.com/document/api/571/82108#CompareTableItem)

	* 新增成员：ColumnMode, Columns

* [Table](https://cloud.tencent.com/document/api/571/82108#Table)

	* 新增成员：ColumnMode, Columns


### 第 15 次发布

发布时间：2023-08-18 16:50:40

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [ModifyMigrateRateLimit](https://cloud.tencent.com/document/api/571/96732)
* [ModifySyncRateLimit](https://cloud.tencent.com/document/api/571/96733)

### 第 14 次发布

发布时间：2023-08-09 01:23:41

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeMigrationDetail](https://cloud.tencent.com/document/api/571/82085)

	* 新增出参：DumperResumeCtrl, RateLimitOption


新增数据结构：

* [ErrInfo](https://cloud.tencent.com/document/api/571/82108#ErrInfo)
* [RateLimitOption](https://cloud.tencent.com/document/api/571/82108#RateLimitOption)

修改数据结构：

* [Endpoint](https://cloud.tencent.com/document/api/571/82108#Endpoint)

	* 新增成员：CcnOwnerUin

* [JobItem](https://cloud.tencent.com/document/api/571/82108#JobItem)

	* 新增成员：DumperResumeCtrl

* [Options](https://cloud.tencent.com/document/api/571/82108#Options)

	* 新增成员：RateLimitOption, AutoRetryTimeRangeMinutes

* [SyncDetailInfo](https://cloud.tencent.com/document/api/571/82108#SyncDetailInfo)

	* 新增成员：ErrInfo

	* <font color="#dd0000">**修改成员**：</font>CauseOfCompareDisable

* [SyncJobInfo](https://cloud.tencent.com/document/api/571/82108#SyncJobInfo)

	* 新增成员：SrcNodeType, SrcInfos, DstNodeType, DstInfos, DumperResumeCtrl


### 第 13 次发布

发布时间：2023-05-29 14:42:50

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateModifyCheckSyncJob](https://cloud.tencent.com/document/api/571/92849)
* [DescribeModifyCheckSyncJobResult](https://cloud.tencent.com/document/api/571/92848)
* [ModifySyncJobConfig](https://cloud.tencent.com/document/api/571/92847)
* [StartModifySyncJob](https://cloud.tencent.com/document/api/571/92846)

新增数据结构：

* [DynamicOptions](https://cloud.tencent.com/document/api/571/82108#DynamicOptions)

### 第 12 次发布

发布时间：2023-03-14 01:22:11

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [ConfigureSyncJob](https://cloud.tencent.com/document/api/571/82107)

	* 新增入参：SrcInfos, SrcNodeType, DstInfos, DstNodeType


新增数据结构：

* [KafkaOption](https://cloud.tencent.com/document/api/571/82108#KafkaOption)
* [SyncDBEndpointInfos](https://cloud.tencent.com/document/api/571/82108#SyncDBEndpointInfos)
* [TopicRule](https://cloud.tencent.com/document/api/571/82108#TopicRule)

修改数据结构：

* [Options](https://cloud.tencent.com/document/api/571/82108#Options)

	* 新增成员：KafkaOption


### 第 11 次发布

发布时间：2023-02-27 01:22:55

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [ConfigureSyncJob](https://cloud.tencent.com/document/api/571/82107)

	* <font color="#dd0000">**修改入参**：</font>Options


### 第 10 次发布

发布时间：2023-02-22 01:24:05

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [DBEndpointInfo](https://cloud.tencent.com/document/api/571/82108#DBEndpointInfo)

	* 新增成员：DatabaseNetEnv


### 第 9 次发布

发布时间：2023-02-16 01:24:00

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [Endpoint](https://cloud.tencent.com/document/api/571/82108#Endpoint)

	* 新增成员：DatabaseNetEnv

* [SyncDetailInfo](https://cloud.tencent.com/document/api/571/82108#SyncDetailInfo)

	* 新增成员：CauseOfCompareDisable


### 第 8 次发布

发布时间：2023-02-10 01:32:00

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [OnlineDDL](https://cloud.tencent.com/document/api/571/82108#OnlineDDL)

	* 新增成员：Status

* [Table](https://cloud.tencent.com/document/api/571/82108#Table)

	* 新增成员：TmpTables, TableEditMode


### 第 7 次发布

发布时间：2023-01-12 01:17:34

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [SkipCheckItem](https://cloud.tencent.com/document/api/571/83864)

	* 新增入参：ForeignKeyFlag

	* 新增出参：Message


### 第 6 次发布

发布时间：2023-01-05 01:19:52

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [ContinueMigrateJob](https://cloud.tencent.com/document/api/571/85142)
* [ContinueSyncJob](https://cloud.tencent.com/document/api/571/85140)
* [PauseMigrateJob](https://cloud.tencent.com/document/api/571/85139)

修改接口：

* [CreateCompareTask](https://cloud.tencent.com/document/api/571/82093)

	* 新增入参：Options

* [DescribeCompareTasks](https://cloud.tencent.com/document/api/571/82088)

	* 新增入参：CompareTaskId, Status

* [ModifyCompareTask](https://cloud.tencent.com/document/api/571/82081)

	* 新增入参：Options


新增数据结构：

* [CompareOptions](https://cloud.tencent.com/document/api/571/82108#CompareOptions)

修改数据结构：

* [CompareAbstractInfo](https://cloud.tencent.com/document/api/571/82108#CompareAbstractInfo)

	* 新增成员：Options, Objects, NearlyTableCount, SrcSampleRows, DstSampleRows, StartedAt, FinishedAt

* [CompareObject](https://cloud.tencent.com/document/api/571/82108#CompareObject)

	* 新增成员：AdvancedObjects

* [CompareTaskItem](https://cloud.tencent.com/document/api/571/82108#CompareTaskItem)

	* 新增成员：Method, Options, Message


### 第 5 次发布

发布时间：2023-01-04 01:20:09

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [PauseSyncJob](https://cloud.tencent.com/document/api/571/84960)

### 第 4 次发布

发布时间：2022-12-23 01:28:44

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [ConfigureSyncJob](https://cloud.tencent.com/document/api/571/82107)

	* 新增入参：JobMode, AutoRetryTimeRangeMinutes

	* <font color="#dd0000">**修改入参**：</font>SrcInfo, DstInfo

* [ModifyMigrationJob](https://cloud.tencent.com/document/api/571/82077)

	* 新增入参：AutoRetryTimeRangeMinutes


新增数据结构：

* [OnlineDDL](https://cloud.tencent.com/document/api/571/82108#OnlineDDL)

修改数据结构：

* [Database](https://cloud.tencent.com/document/api/571/82108#Database)

	* 新增成员：TriggerMode, Triggers, EventMode, Events

* [Endpoint](https://cloud.tencent.com/document/api/571/82108#Endpoint)

	* 新增成员：Role, EncryptConn

* [JobItem](https://cloud.tencent.com/document/api/571/82108#JobItem)

	* 新增成员：AutoRetryTimeRangeMinutes

* [Objects](https://cloud.tencent.com/document/api/571/82108#Objects)

	* 新增成员：OnlineDDL

* [SyncJobInfo](https://cloud.tencent.com/document/api/571/82108#SyncJobInfo)

	* 新增成员：AutoRetryTimeRangeMinutes


### 第 3 次发布

发布时间：2022-12-12 01:23:41

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [SkipCheckItem](https://cloud.tencent.com/document/api/571/83864)
* [SkipSyncCheckItem](https://cloud.tencent.com/document/api/571/83865)

### 第 2 次发布

发布时间：2022-12-05 06:45:09

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [Endpoint](https://cloud.tencent.com/document/api/571/82108#Endpoint)

	* 新增成员：RoleExternalId

* [StepTip](https://cloud.tencent.com/document/api/571/82108#StepTip)

	* 新增成员：SkipInfo

* [SyncJobInfo](https://cloud.tencent.com/document/api/571/82108#SyncJobInfo)

	* 新增成员：TradeStatus, InstanceClass, AutoRenew, OfflineTime


### 第 1 次发布

发布时间：2022-10-28 16:26:38

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CompleteMigrateJob](https://cloud.tencent.com/document/api/571/82094)
* [ConfigureSyncJob](https://cloud.tencent.com/document/api/571/82107)
* [CreateCheckSyncJob](https://cloud.tencent.com/document/api/571/82106)
* [CreateCompareTask](https://cloud.tencent.com/document/api/571/82093)
* [CreateMigrateCheckJob](https://cloud.tencent.com/document/api/571/82092)
* [CreateMigrationService](https://cloud.tencent.com/document/api/571/82091)
* [CreateSyncJob](https://cloud.tencent.com/document/api/571/82105)
* [DeleteCompareTask](https://cloud.tencent.com/document/api/571/82090)
* [DescribeCheckSyncJobResult](https://cloud.tencent.com/document/api/571/82104)
* [DescribeCompareReport](https://cloud.tencent.com/document/api/571/82089)
* [DescribeCompareTasks](https://cloud.tencent.com/document/api/571/82088)
* [DescribeMigrateDBInstances](https://cloud.tencent.com/document/api/571/82087)
* [DescribeMigrationCheckJob](https://cloud.tencent.com/document/api/571/82086)
* [DescribeMigrationDetail](https://cloud.tencent.com/document/api/571/82085)
* [DescribeMigrationJobs](https://cloud.tencent.com/document/api/571/82084)
* [DescribeSyncJobs](https://cloud.tencent.com/document/api/571/82103)
* [DestroyMigrateJob](https://cloud.tencent.com/document/api/571/82083)
* [DestroySyncJob](https://cloud.tencent.com/document/api/571/82102)
* [IsolateMigrateJob](https://cloud.tencent.com/document/api/571/82082)
* [IsolateSyncJob](https://cloud.tencent.com/document/api/571/82101)
* [ModifyCompareTask](https://cloud.tencent.com/document/api/571/82081)
* [ModifyCompareTaskName](https://cloud.tencent.com/document/api/571/82080)
* [ModifyMigrateJobSpec](https://cloud.tencent.com/document/api/571/82079)
* [ModifyMigrateName](https://cloud.tencent.com/document/api/571/82078)
* [ModifyMigrationJob](https://cloud.tencent.com/document/api/571/82077)
* [RecoverMigrateJob](https://cloud.tencent.com/document/api/571/82076)
* [RecoverSyncJob](https://cloud.tencent.com/document/api/571/82100)
* [ResizeSyncJob](https://cloud.tencent.com/document/api/571/82099)
* [ResumeMigrateJob](https://cloud.tencent.com/document/api/571/82075)
* [ResumeSyncJob](https://cloud.tencent.com/document/api/571/82098)
* [StartCompare](https://cloud.tencent.com/document/api/571/82074)
* [StartMigrateJob](https://cloud.tencent.com/document/api/571/82073)
* [StartSyncJob](https://cloud.tencent.com/document/api/571/82097)
* [StopCompare](https://cloud.tencent.com/document/api/571/82072)
* [StopMigrateJob](https://cloud.tencent.com/document/api/571/82071)
* [StopSyncJob](https://cloud.tencent.com/document/api/571/82096)

新增数据结构：

* [CheckStep](https://cloud.tencent.com/document/api/571/82108#CheckStep)
* [CheckStepInfo](https://cloud.tencent.com/document/api/571/82108#CheckStepInfo)
* [CompareAbstractInfo](https://cloud.tencent.com/document/api/571/82108#CompareAbstractInfo)
* [CompareDetailInfo](https://cloud.tencent.com/document/api/571/82108#CompareDetailInfo)
* [CompareObject](https://cloud.tencent.com/document/api/571/82108#CompareObject)
* [CompareObjectItem](https://cloud.tencent.com/document/api/571/82108#CompareObjectItem)
* [CompareTableItem](https://cloud.tencent.com/document/api/571/82108#CompareTableItem)
* [CompareTaskInfo](https://cloud.tencent.com/document/api/571/82108#CompareTaskInfo)
* [CompareTaskItem](https://cloud.tencent.com/document/api/571/82108#CompareTaskItem)
* [CompareViewItem](https://cloud.tencent.com/document/api/571/82108#CompareViewItem)
* [ConflictHandleOption](https://cloud.tencent.com/document/api/571/82108#ConflictHandleOption)
* [ConsistencyOption](https://cloud.tencent.com/document/api/571/82108#ConsistencyOption)
* [DBEndpointInfo](https://cloud.tencent.com/document/api/571/82108#DBEndpointInfo)
* [DBInfo](https://cloud.tencent.com/document/api/571/82108#DBInfo)
* [DBItem](https://cloud.tencent.com/document/api/571/82108#DBItem)
* [Database](https://cloud.tencent.com/document/api/571/82108#Database)
* [DatabaseTableObject](https://cloud.tencent.com/document/api/571/82108#DatabaseTableObject)
* [DdlOption](https://cloud.tencent.com/document/api/571/82108#DdlOption)
* [DetailCheckItem](https://cloud.tencent.com/document/api/571/82108#DetailCheckItem)
* [DifferenceDetail](https://cloud.tencent.com/document/api/571/82108#DifferenceDetail)
* [DifferenceItem](https://cloud.tencent.com/document/api/571/82108#DifferenceItem)
* [Endpoint](https://cloud.tencent.com/document/api/571/82108#Endpoint)
* [ErrorInfoItem](https://cloud.tencent.com/document/api/571/82108#ErrorInfoItem)
* [JobItem](https://cloud.tencent.com/document/api/571/82108#JobItem)
* [KeyValuePairOption](https://cloud.tencent.com/document/api/571/82108#KeyValuePairOption)
* [MigrateAction](https://cloud.tencent.com/document/api/571/82108#MigrateAction)
* [MigrateDBItem](https://cloud.tencent.com/document/api/571/82108#MigrateDBItem)
* [MigrateDetailInfo](https://cloud.tencent.com/document/api/571/82108#MigrateDetailInfo)
* [MigrateOption](https://cloud.tencent.com/document/api/571/82108#MigrateOption)
* [Objects](https://cloud.tencent.com/document/api/571/82108#Objects)
* [Options](https://cloud.tencent.com/document/api/571/82108#Options)
* [ProcessProgress](https://cloud.tencent.com/document/api/571/82108#ProcessProgress)
* [ProcessStepTip](https://cloud.tencent.com/document/api/571/82108#ProcessStepTip)
* [RoleItem](https://cloud.tencent.com/document/api/571/82108#RoleItem)
* [SkippedDetail](https://cloud.tencent.com/document/api/571/82108#SkippedDetail)
* [SkippedItem](https://cloud.tencent.com/document/api/571/82108#SkippedItem)
* [StepDetailInfo](https://cloud.tencent.com/document/api/571/82108#StepDetailInfo)
* [StepInfo](https://cloud.tencent.com/document/api/571/82108#StepInfo)
* [StepTip](https://cloud.tencent.com/document/api/571/82108#StepTip)
* [SyncDetailInfo](https://cloud.tencent.com/document/api/571/82108#SyncDetailInfo)
* [SyncJobInfo](https://cloud.tencent.com/document/api/571/82108#SyncJobInfo)
* [Table](https://cloud.tencent.com/document/api/571/82108#Table)
* [TableItem](https://cloud.tencent.com/document/api/571/82108#TableItem)
* [TagFilter](https://cloud.tencent.com/document/api/571/82108#TagFilter)
* [TagItem](https://cloud.tencent.com/document/api/571/82108#TagItem)
* [TradeInfo](https://cloud.tencent.com/document/api/571/82108#TradeInfo)
* [View](https://cloud.tencent.com/document/api/571/82108#View)
* [ViewItem](https://cloud.tencent.com/document/api/571/82108#ViewItem)




## 事件总线(eb) 版本：2021-04-16

### 第 14 次发布

发布时间：2024-04-18 01:19:26

本次发布包含了以下内容：

改善已有的文档。

新增数据结构：

* [Tag](https://cloud.tencent.com/document/api/1359/67704#Tag)

修改数据结构：

* [Event](https://cloud.tencent.com/document/api/1359/67704#Event)

	* 新增成员：Region, Status, Id, TagList


### 第 13 次发布

发布时间：2023-11-24 01:14:11

本次发布包含了以下内容：

改善已有的文档。

新增数据结构：

* [TDMQParams](https://cloud.tencent.com/document/api/1359/67704#TDMQParams)

修改数据结构：

* [ConnectionDescription](https://cloud.tencent.com/document/api/1359/67704#ConnectionDescription)

	* 新增成员：TDMQParams

* [DTSParams](https://cloud.tencent.com/document/api/1359/67704#DTSParams)

	* 新增成员：ConsumerGroupName, Account, Password


### 第 12 次发布

发布时间：2023-09-08 01:48:45

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [GetPlatformEventTemplate](https://cloud.tencent.com/document/api/1359/97863)
* [ListPlatformEventNames](https://cloud.tencent.com/document/api/1359/97862)
* [ListPlatformEventPatterns](https://cloud.tencent.com/document/api/1359/97861)
* [ListPlatformProducts](https://cloud.tencent.com/document/api/1359/97860)

新增数据结构：

* [PlatformEventDetail](https://cloud.tencent.com/document/api/1359/67704#PlatformEventDetail)
* [PlatformEventSummary](https://cloud.tencent.com/document/api/1359/67704#PlatformEventSummary)
* [PlatformProduct](https://cloud.tencent.com/document/api/1359/67704#PlatformProduct)

### 第 11 次发布

发布时间：2023-08-22 01:12:28

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CheckRule](https://cloud.tencent.com/document/api/1359/67698)

	* 新增入参：Event, EventPattern


### 第 10 次发布

发布时间：2023-03-24 01:40:42

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeLogTagValue](https://cloud.tencent.com/document/api/1359/89221)
* [SearchLog](https://cloud.tencent.com/document/api/1359/89220)

新增数据结构：

* [LogFilter](https://cloud.tencent.com/document/api/1359/67704#LogFilter)
* [LogFilters](https://cloud.tencent.com/document/api/1359/67704#LogFilters)
* [SearchLogResult](https://cloud.tencent.com/document/api/1359/67704#SearchLogResult)

### 第 9 次发布

发布时间：2023-02-28 01:29:39

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateEventBus](https://cloud.tencent.com/document/api/1359/67686)

	* 新增入参：EnableStore

* [GetEventBus](https://cloud.tencent.com/document/api/1359/67684)

	* 新增出参：PayMode, SaveDays, LogTopicId, EnableStore, LinkMode


新增数据结构：

* [ConnectionBrief](https://cloud.tencent.com/document/api/1359/67704#ConnectionBrief)
* [DTSParams](https://cloud.tencent.com/document/api/1359/67704#DTSParams)

修改数据结构：

* [ConnectionDescription](https://cloud.tencent.com/document/api/1359/67704#ConnectionDescription)

	* 新增成员：DTSParams

* [EventBus](https://cloud.tencent.com/document/api/1359/67704#EventBus)

	* 新增成员：PayMode, ConnectionBriefs, TargetBriefs


### 第 8 次发布

发布时间：2023-02-27 01:23:14

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [UpdateEventBus](https://cloud.tencent.com/document/api/1359/67681)

	* 新增入参：EnableStore


### 第 7 次发布

发布时间：2023-02-16 01:24:24

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateEventBus](https://cloud.tencent.com/document/api/1359/67686)

	* 新增入参：SaveDays

* [UpdateEventBus](https://cloud.tencent.com/document/api/1359/67681)

	* 新增入参：SaveDays, LogTopicId


### 第 6 次发布

发布时间：2022-08-23 06:27:55

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [UpdateRule](https://cloud.tencent.com/document/api/1359/67693)

	* 新增入参：EventPattern


### 第 5 次发布

发布时间：2022-06-30 06:06:12

本次发布包含了以下内容：

改善已有的文档。

新增数据结构：

* [ESTargetParams](https://cloud.tencent.com/document/api/1359/67704#ESTargetParams)

修改数据结构：

* [TargetDescription](https://cloud.tencent.com/document/api/1359/67704#TargetDescription)

	* 新增成员：ESTargetParams


### 第 4 次发布

发布时间：2022-06-28 06:09:50

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [ListTargets](https://cloud.tencent.com/document/api/1359/67701)

	* <font color="#dd0000">**修改入参**：</font>RuleId


### 第 3 次发布

发布时间：2022-05-26 06:11:01

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [Event](https://cloud.tencent.com/document/api/1359/67704#Event)

	* 新增成员：Time


### 第 2 次发布

发布时间：2022-01-20 08:09:25

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [PutEvents](https://cloud.tencent.com/document/api/1359/68465)

### 第 1 次发布

发布时间：2022-01-06 16:11:19

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CheckRule](https://cloud.tencent.com/document/api/1359/67698)
* [CheckTransformation](https://cloud.tencent.com/document/api/1359/67679)
* [CreateConnection](https://cloud.tencent.com/document/api/1359/67691)
* [CreateEventBus](https://cloud.tencent.com/document/api/1359/67686)
* [CreateRule](https://cloud.tencent.com/document/api/1359/67697)
* [CreateTarget](https://cloud.tencent.com/document/api/1359/67703)
* [CreateTransformation](https://cloud.tencent.com/document/api/1359/67678)
* [DeleteConnection](https://cloud.tencent.com/document/api/1359/67690)
* [DeleteEventBus](https://cloud.tencent.com/document/api/1359/67685)
* [DeleteRule](https://cloud.tencent.com/document/api/1359/67696)
* [DeleteTarget](https://cloud.tencent.com/document/api/1359/67702)
* [DeleteTransformation](https://cloud.tencent.com/document/api/1359/67677)
* [GetEventBus](https://cloud.tencent.com/document/api/1359/67684)
* [GetRule](https://cloud.tencent.com/document/api/1359/67695)
* [GetTransformation](https://cloud.tencent.com/document/api/1359/67676)
* [ListConnections](https://cloud.tencent.com/document/api/1359/67689)
* [ListEventBuses](https://cloud.tencent.com/document/api/1359/67683)
* [ListRules](https://cloud.tencent.com/document/api/1359/67694)
* [ListTargets](https://cloud.tencent.com/document/api/1359/67701)
* [PublishEvent](https://cloud.tencent.com/document/api/1359/67682)
* [UpdateConnection](https://cloud.tencent.com/document/api/1359/67688)
* [UpdateEventBus](https://cloud.tencent.com/document/api/1359/67681)
* [UpdateRule](https://cloud.tencent.com/document/api/1359/67693)
* [UpdateTarget](https://cloud.tencent.com/document/api/1359/67700)
* [UpdateTransformation](https://cloud.tencent.com/document/api/1359/67675)

新增数据结构：

* [APIGWParams](https://cloud.tencent.com/document/api/1359/67704#APIGWParams)
* [CkafkaDeliveryParams](https://cloud.tencent.com/document/api/1359/67704#CkafkaDeliveryParams)
* [CkafkaParams](https://cloud.tencent.com/document/api/1359/67704#CkafkaParams)
* [CkafkaTargetParams](https://cloud.tencent.com/document/api/1359/67704#CkafkaTargetParams)
* [Connection](https://cloud.tencent.com/document/api/1359/67704#Connection)
* [ConnectionDescription](https://cloud.tencent.com/document/api/1359/67704#ConnectionDescription)
* [DeadLetterConfig](https://cloud.tencent.com/document/api/1359/67704#DeadLetterConfig)
* [EtlFilter](https://cloud.tencent.com/document/api/1359/67704#EtlFilter)
* [Event](https://cloud.tencent.com/document/api/1359/67704#Event)
* [EventBus](https://cloud.tencent.com/document/api/1359/67704#EventBus)
* [Extraction](https://cloud.tencent.com/document/api/1359/67704#Extraction)
* [Filter](https://cloud.tencent.com/document/api/1359/67704#Filter)
* [OutputStructParam](https://cloud.tencent.com/document/api/1359/67704#OutputStructParam)
* [RetryPolicy](https://cloud.tencent.com/document/api/1359/67704#RetryPolicy)
* [Rule](https://cloud.tencent.com/document/api/1359/67704#Rule)
* [SCFParams](https://cloud.tencent.com/document/api/1359/67704#SCFParams)
* [Target](https://cloud.tencent.com/document/api/1359/67704#Target)
* [TargetBrief](https://cloud.tencent.com/document/api/1359/67704#TargetBrief)
* [TargetDescription](https://cloud.tencent.com/document/api/1359/67704#TargetDescription)
* [TextParams](https://cloud.tencent.com/document/api/1359/67704#TextParams)
* [Transform](https://cloud.tencent.com/document/api/1359/67704#Transform)
* [Transformation](https://cloud.tencent.com/document/api/1359/67704#Transformation)




## 英文作文批改(ecc) 版本：2018-12-13

### 第 4 次发布

发布时间：2023-09-13 01:42:58

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CorrectMultiImage](https://cloud.tencent.com/document/api/1076/41242)

	* 新增出参：ResultData

* [EHOCR](https://cloud.tencent.com/document/api/1076/35210)

	* 新增出参：ResultData


新增数据结构：

* [CompositionContext](https://cloud.tencent.com/document/api/1076/35212#CompositionContext)

### 第 3 次发布

发布时间：2020-02-13 14:09:59

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CorrectMultiImage](https://cloud.tencent.com/document/api/1076/41242)

### 第 2 次发布

发布时间：2019-09-05 21:11:56

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeTask](https://cloud.tencent.com/document/api/1076/37821)

修改接口：

* [ECC](https://cloud.tencent.com/document/api/1076/35211)

	* 新增入参：Requirement, ModelTitle, EccAppid, IsAsync, SessionId

	* <font color="#dd0000">**删除入参**：</font>Outline, ModelSubject

	* 新增出参：TaskId

* [EHOCR](https://cloud.tencent.com/document/api/1076/35210)

	* 新增入参：EccAppid, SessionId, ServerType, Title, Grade, Requirement, ModelTitle, ModelContent, IsAsync


新增数据结构：

* [ErrorCoordinate](https://cloud.tencent.com/document/api/1076/35212#ErrorCoordinate)

修改数据结构：

* [Aspect](https://cloud.tencent.com/document/api/1076/35212#Aspect)

	* 新增成员：Percentage

* [CompostionContext](https://cloud.tencent.com/document/api/1076/35212#CompostionContext)

	* 新增成员：CorrectData, TaskId, SessionId

* [ScoreCategory](https://cloud.tencent.com/document/api/1076/35212#ScoreCategory)

	* 新增成员：Score, Percentage

* [SentenceSuggest](https://cloud.tencent.com/document/api/1076/35212#SentenceSuggest)

	* 新增成员：ErrorPosition, ErrorCoordinates


### 第 1 次发布

发布时间：2019-05-30 21:52:26

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [ECC](https://cloud.tencent.com/document/api/1076/35211)
* [EHOCR](https://cloud.tencent.com/document/api/1076/35210)

新增数据结构：

* [Aspect](https://cloud.tencent.com/document/api/1076/35212#Aspect)
* [CompostionContext](https://cloud.tencent.com/document/api/1076/35212#CompostionContext)
* [CorrectData](https://cloud.tencent.com/document/api/1076/35212#CorrectData)
* [ScoreCategory](https://cloud.tencent.com/document/api/1076/35212#ScoreCategory)
* [SentenceCom](https://cloud.tencent.com/document/api/1076/35212#SentenceCom)
* [SentenceItem](https://cloud.tencent.com/document/api/1076/35212#SentenceItem)
* [SentenceSuggest](https://cloud.tencent.com/document/api/1076/35212#SentenceSuggest)




## 全站加速网络(ecdn) 版本：2019-10-12

### 第 13 次发布

发布时间：2023-05-05 01:16:29

本次发布包含了以下内容：

改善已有的文档。

<font color="#dd0000">**预下线接口**：</font>

* DescribePurgeQuota

### 第 12 次发布

发布时间：2023-04-27 01:19:24

本次发布包含了以下内容：

改善已有的文档。

<font color="#dd0000">**预下线接口**：</font>

* AddEcdnDomain
* CreateVerifyRecord
* DeleteEcdnDomain
* PurgePathCache
* StartEcdnDomain
* StopEcdnDomain
* UpdateDomainConfig

### 第 11 次发布

发布时间：2022-01-18 08:09:09

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [DomainBriefInfo](https://cloud.tencent.com/document/api/570/42478#DomainBriefInfo)

	* 新增成员：Tag


### 第 10 次发布

发布时间：2021-12-22 08:11:17

本次发布包含了以下内容：

改善已有的文档。

新增数据结构：

* [AdvanceHttps](https://cloud.tencent.com/document/api/570/42478#AdvanceHttps)

修改数据结构：

* [Origin](https://cloud.tencent.com/document/api/570/42478#Origin)

	* 新增成员：AdvanceHttps


### 第 9 次发布

发布时间：2021-05-28 08:01:48

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateVerifyRecord](https://cloud.tencent.com/document/api/570/56368)

### 第 8 次发布

发布时间：2021-03-18 08:01:21

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeEcdnDomainStatistics](https://cloud.tencent.com/document/api/570/42467)

	* 新增入参：Area

* [DescribeEcdnStatistics](https://cloud.tencent.com/document/api/570/42466)

	* 新增入参：Area


### 第 7 次发布

发布时间：2021-01-14 08:01:15

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [IpStatus](https://cloud.tencent.com/document/api/570/42478#IpStatus)

	* 新增成员：CreateTime


### 第 6 次发布

发布时间：2020-11-23 08:01:26

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [AddEcdnDomain](https://cloud.tencent.com/document/api/570/42472)

	* 新增入参：WebSocket

* [UpdateDomainConfig](https://cloud.tencent.com/document/api/570/42460)

	* 新增入参：WebSocket


新增数据结构：

* [WebSocket](https://cloud.tencent.com/document/api/570/42478#WebSocket)

修改数据结构：

* [DomainDetailInfo](https://cloud.tencent.com/document/api/570/42478#DomainDetailInfo)

	* 新增成员：WebSocket


### 第 5 次发布

发布时间：2020-11-04 08:00:52

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [AddEcdnDomain](https://cloud.tencent.com/document/api/570/42472)

	* 新增入参：Tag


新增数据结构：

* [Tag](https://cloud.tencent.com/document/api/570/42478#Tag)

修改数据结构：

* [DomainDetailInfo](https://cloud.tencent.com/document/api/570/42478#DomainDetailInfo)

	* 新增成员：Tag


### 第 4 次发布

发布时间：2020-10-16 08:00:40

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeIpStatus](https://cloud.tencent.com/document/api/570/49184)

新增数据结构：

* [IpStatus](https://cloud.tencent.com/document/api/570/42478#IpStatus)

### 第 3 次发布

发布时间：2020-06-30 08:02:35

本次发布包含了以下内容：

改善已有的文档。

新增数据结构：

* [Hsts](https://cloud.tencent.com/document/api/570/42478#Hsts)

修改数据结构：

* [Https](https://cloud.tencent.com/document/api/570/42478#Https)

	* 新增成员：Hsts


### 第 2 次发布

发布时间：2020-04-16 08:01:06

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [Cache](https://cloud.tencent.com/document/api/570/42478#Cache)

	* 新增成员：FollowOrigin


### 第 1 次发布

发布时间：2020-03-17 15:54:37

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [AddEcdnDomain](https://cloud.tencent.com/document/api/570/42472)
* [DeleteEcdnDomain](https://cloud.tencent.com/document/api/570/42471)
* [DescribeDomains](https://cloud.tencent.com/document/api/570/42462)
* [DescribeDomainsConfig](https://cloud.tencent.com/document/api/570/42461)
* [DescribeEcdnDomainLogs](https://cloud.tencent.com/document/api/570/42464)
* [DescribeEcdnDomainStatistics](https://cloud.tencent.com/document/api/570/42467)
* [DescribeEcdnStatistics](https://cloud.tencent.com/document/api/570/42466)
* [DescribePurgeQuota](https://cloud.tencent.com/document/api/570/42477)
* [DescribePurgeTasks](https://cloud.tencent.com/document/api/570/42476)
* [PurgePathCache](https://cloud.tencent.com/document/api/570/42475)
* [PurgeUrlsCache](https://cloud.tencent.com/document/api/570/42474)
* [StartEcdnDomain](https://cloud.tencent.com/document/api/570/42470)
* [StopEcdnDomain](https://cloud.tencent.com/document/api/570/42469)
* [UpdateDomainConfig](https://cloud.tencent.com/document/api/570/42460)

新增数据结构：

* [Cache](https://cloud.tencent.com/document/api/570/42478#Cache)
* [CacheKey](https://cloud.tencent.com/document/api/570/42478#CacheKey)
* [CacheRule](https://cloud.tencent.com/document/api/570/42478#CacheRule)
* [ClientCert](https://cloud.tencent.com/document/api/570/42478#ClientCert)
* [DetailData](https://cloud.tencent.com/document/api/570/42478#DetailData)
* [DomainBriefInfo](https://cloud.tencent.com/document/api/570/42478#DomainBriefInfo)
* [DomainData](https://cloud.tencent.com/document/api/570/42478#DomainData)
* [DomainDetailInfo](https://cloud.tencent.com/document/api/570/42478#DomainDetailInfo)
* [DomainFilter](https://cloud.tencent.com/document/api/570/42478#DomainFilter)
* [DomainLogs](https://cloud.tencent.com/document/api/570/42478#DomainLogs)
* [EcdnData](https://cloud.tencent.com/document/api/570/42478#EcdnData)
* [ForceRedirect](https://cloud.tencent.com/document/api/570/42478#ForceRedirect)
* [HttpHeaderPathRule](https://cloud.tencent.com/document/api/570/42478#HttpHeaderPathRule)
* [Https](https://cloud.tencent.com/document/api/570/42478#Https)
* [IpFilter](https://cloud.tencent.com/document/api/570/42478#IpFilter)
* [IpFreqLimit](https://cloud.tencent.com/document/api/570/42478#IpFreqLimit)
* [Origin](https://cloud.tencent.com/document/api/570/42478#Origin)
* [PurgeTask](https://cloud.tencent.com/document/api/570/42478#PurgeTask)
* [Quota](https://cloud.tencent.com/document/api/570/42478#Quota)
* [ResourceData](https://cloud.tencent.com/document/api/570/42478#ResourceData)
* [ResponseHeader](https://cloud.tencent.com/document/api/570/42478#ResponseHeader)
* [ServerCert](https://cloud.tencent.com/document/api/570/42478#ServerCert)
* [Sort](https://cloud.tencent.com/document/api/570/42478#Sort)
* [TimestampData](https://cloud.tencent.com/document/api/570/42478#TimestampData)




## 边缘计算机器(ecm) 版本：2019-07-19

### 第 75 次发布

发布时间：2024-07-26 01:38:19

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [ModifyVpcAttribute](https://cloud.tencent.com/document/api/1108/43567)

	* 新增入参：DnsServers, DomainName


### 第 74 次发布

发布时间：2024-02-21 01:14:56

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [Module](https://cloud.tencent.com/document/api/1108/42574#Module)

	* <font color="#dd0000">**修改成员**：</font>DisableWanIp

* [NetworkStorageRange](https://cloud.tencent.com/document/api/1108/42574#NetworkStorageRange)

	* 新增成员：CBSSupported, DiskNumLimit

* [Position](https://cloud.tencent.com/document/api/1108/42574#Position)

	* 新增成员：Ipv6Supported

* [VirtualPrivateCloud](https://cloud.tencent.com/document/api/1108/42574#VirtualPrivateCloud)

	* 新增成员：Ipv6SubnetIds


### 第 73 次发布

发布时间：2024-02-20 01:15:12

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [Node](https://cloud.tencent.com/document/api/1108/42574#Node)

	* <font color="#dd0000">**修改成员**：</font>LBSupported


### 第 72 次发布

发布时间：2023-10-23 00:10:30

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [ISPCounter](https://cloud.tencent.com/document/api/1108/42574#ISPCounter)

	* 新增成员：ProviderInstanceNum


### 第 71 次发布

发布时间：2023-10-17 01:16:27

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [AssignIpv6Addresses](https://cloud.tencent.com/document/api/1108/51094)


### 第 70 次发布

发布时间：2023-09-05 10:56:15

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateSubnet](https://cloud.tencent.com/document/api/1108/43594)

	* 新增入参：IPv6CidrBlock


### 第 69 次发布

发布时间：2023-09-01 01:14:14

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [ZoneInstanceCountISP](https://cloud.tencent.com/document/api/1108/42574#ZoneInstanceCountISP)

	* 新增成员：Ipv6SubnetIds


### 第 68 次发布

发布时间：2023-08-18 01:11:07

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateVpc](https://cloud.tencent.com/document/api/1108/43569)

	* 新增入参：ISPTypes


### 第 67 次发布

发布时间：2023-07-11 01:20:38

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [AllocateIpv6AddressesBandwidth](https://cloud.tencent.com/document/api/1108/94901)
* [AssignIpv6CidrBlock](https://cloud.tencent.com/document/api/1108/94896)
* [AssignIpv6CidrBlocks](https://cloud.tencent.com/document/api/1108/94895)
* [AssignIpv6SubnetCidrBlock](https://cloud.tencent.com/document/api/1108/94903)
* [DescribeRegionIpv6Addresses](https://cloud.tencent.com/document/api/1108/94900)
* [ModifyIpv6AddressesBandwidth](https://cloud.tencent.com/document/api/1108/94899)
* [QueryVpcTaskResult](https://cloud.tencent.com/document/api/1108/94894)
* [ReleaseIpv6AddressesBandwidth](https://cloud.tencent.com/document/api/1108/94898)
* [UnassignIpv6SubnetCidrBlock](https://cloud.tencent.com/document/api/1108/94902)

新增数据结构：

* [ISPTypeItem](https://cloud.tencent.com/document/api/1108/42574#ISPTypeItem)
* [Ipv6SubnetCidrBlock](https://cloud.tencent.com/document/api/1108/42574#Ipv6SubnetCidrBlock)

### 第 66 次发布

发布时间：2023-07-07 01:25:16

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [AssignIpv6Addresses](https://cloud.tencent.com/document/api/1108/51094)

	* 新增入参：ISPType, SkipCheckIPv6Address, SkipAllocateBandwidth


新增数据结构：

* [ISPIPv6CidrBlock](https://cloud.tencent.com/document/api/1108/42574#ISPIPv6CidrBlock)

修改数据结构：

* [Subnet](https://cloud.tencent.com/document/api/1108/42574#Subnet)

	* 新增成员：ISPType

* [VpcInfo](https://cloud.tencent.com/document/api/1108/42574#VpcInfo)

	* 新增成员：Ipv6ISP, Ipv6CidrBlockSet


### 第 65 次发布

发布时间：2023-06-06 01:28:52

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [DiskInfo](https://cloud.tencent.com/document/api/1108/42574#DiskInfo)

	* 新增成员：DeleteWithInstance, SnapshotId

* [Module](https://cloud.tencent.com/document/api/1108/42574#Module)

	* 新增成员：DisableWanIp

* [Node](https://cloud.tencent.com/document/api/1108/42574#Node)

	* 新增成员：LBSupported


### 第 64 次发布

发布时间：2023-04-24 01:17:53

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [Route](https://cloud.tencent.com/document/api/1108/42574#Route)

	* 新增成员：RouteTableId


### 第 63 次发布

发布时间：2023-01-09 01:21:37

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateLoadBalancer](https://cloud.tencent.com/document/api/1108/48465)

	* 新增入参：AddressIPVersion, SubnetId


修改数据结构：

* [LoadBalancer](https://cloud.tencent.com/document/api/1108/42574#LoadBalancer)

	* 新增成员：AddressIPv6


### 第 62 次发布

发布时间：2022-09-09 06:24:10

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribePriceRunInstance](https://cloud.tencent.com/document/api/1108/64437)

	* 新增入参：InstanceChargeType


### 第 61 次发布

发布时间：2022-06-09 06:11:09

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [AssignIpv6Addresses](https://cloud.tencent.com/document/api/1108/51094)

	* 新增入参：Ipv6ISP


### 第 60 次发布

发布时间：2022-05-20 06:11:20

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [NetworkInterface](https://cloud.tencent.com/document/api/1108/42574#NetworkInterface)

	* 新增成员：Business


### 第 59 次发布

发布时间：2021-11-18 20:07:06

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribePriceRunInstance](https://cloud.tencent.com/document/api/1108/64437)

新增数据结构：

* [InstancePricesPartDetail](https://cloud.tencent.com/document/api/1108/42574#InstancePricesPartDetail)
* [InstancesPrice](https://cloud.tencent.com/document/api/1108/42574#InstancesPrice)
* [PriceDetail](https://cloud.tencent.com/document/api/1108/42574#PriceDetail)

### 第 58 次发布

发布时间：2021-11-11 11:01:56

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateListener](https://cloud.tencent.com/document/api/1108/48466)

	* 新增入参：EndPorts


### 第 57 次发布

发布时间：2021-11-10 08:06:34

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [Listener](https://cloud.tencent.com/document/api/1108/42574#Listener)

	* 新增成员：EndPort


### 第 56 次发布

发布时间：2021-10-27 08:07:01

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateKeyPair](https://cloud.tencent.com/document/api/1108/63368)
* [DisassociateInstancesKeyPairs](https://cloud.tencent.com/document/api/1108/63367)

新增数据结构：

* [KeyPair](https://cloud.tencent.com/document/api/1108/42574#KeyPair)

### 第 55 次发布

发布时间：2021-10-25 08:05:17

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribePackingQuotaGroup](https://cloud.tencent.com/document/api/1108/63290)

修改接口：

* [CreateModule](https://cloud.tencent.com/document/api/1108/42557)

	* 新增入参：SystemDisk, DataDisks

* [ModifyModuleConfig](https://cloud.tencent.com/document/api/1108/47143)

	* 新增入参：DefaultSystemDiskSize, SystemDisk, DataDisks


新增数据结构：

* [PackingQuotaGroup](https://cloud.tencent.com/document/api/1108/42574#PackingQuotaGroup)
* [PackingQuotaInfo](https://cloud.tencent.com/document/api/1108/42574#PackingQuotaInfo)

### 第 54 次发布

发布时间：2021-10-21 11:26:12

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [DataDisk](https://cloud.tencent.com/document/api/1108/42574#DataDisk)

	* 新增成员：DiskSize, DiskType


### 第 53 次发布

发布时间：2021-10-20 08:10:10

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [RunInstances](https://cloud.tencent.com/document/api/1108/43513)

	* 新增入参：SystemDisk, DataDisks


新增数据结构：

* [DataDisk](https://cloud.tencent.com/document/api/1108/42574#DataDisk)
* [SystemDisk](https://cloud.tencent.com/document/api/1108/42574#SystemDisk)

修改数据结构：

* [Module](https://cloud.tencent.com/document/api/1108/42574#Module)

	* 新增成员：SystemDisk, DataDisks


### 第 52 次发布

发布时间：2021-09-16 08:02:38

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [AttachDisks](https://cloud.tencent.com/document/api/1108/61560)
* [CreateDisks](https://cloud.tencent.com/document/api/1108/61559)
* [DeleteSnapshots](https://cloud.tencent.com/document/api/1108/61554)
* [DescribeDisks](https://cloud.tencent.com/document/api/1108/61558)
* [DescribeSnapshots](https://cloud.tencent.com/document/api/1108/61553)
* [DetachDisks](https://cloud.tencent.com/document/api/1108/61557)
* [TerminateDisks](https://cloud.tencent.com/document/api/1108/61556)

新增数据结构：

* [Disk](https://cloud.tencent.com/document/api/1108/42574#Disk)
* [DiskChargePrepaid](https://cloud.tencent.com/document/api/1108/42574#DiskChargePrepaid)
* [Placement](https://cloud.tencent.com/document/api/1108/42574#Placement)
* [Snapshot](https://cloud.tencent.com/document/api/1108/42574#Snapshot)

### 第 51 次发布

发布时间：2021-08-31 08:02:05

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [ResetInstances](https://cloud.tencent.com/document/api/1108/42561)

	* 新增入参：KeepImageLogin

* [RunInstances](https://cloud.tencent.com/document/api/1108/43513)

	* 新增入参：KeepImageLogin


### 第 50 次发布

发布时间：2021-08-13 08:01:53

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [RunInstances](https://cloud.tencent.com/document/api/1108/43513)

	* 新增入参：KeyIds


### 第 49 次发布

发布时间：2021-08-06 08:01:49

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [Image](https://cloud.tencent.com/document/api/1108/42574#Image)

	* 新增成员：IsSupportCloudInit

* [Module](https://cloud.tencent.com/document/api/1108/42574#Module)

	* 新增成员：UserData


### 第 48 次发布

发布时间：2021-06-17 08:01:43

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [SecurityGroupPolicy](https://cloud.tencent.com/document/api/1108/42574#SecurityGroupPolicy)

	* 新增成员：Ipv6CidrBlock


### 第 47 次发布

发布时间：2021-04-28 08:01:54

本次发布包含了以下内容：

改善已有的文档。

新增数据结构：

* [PhysicalPosition](https://cloud.tencent.com/document/api/1108/42574#PhysicalPosition)

修改数据结构：

* [Instance](https://cloud.tencent.com/document/api/1108/42574#Instance)

	* 新增成员：PhysicalPosition


### 第 46 次发布

发布时间：2021-04-09 08:01:03

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeMonthPeakNetwork](https://cloud.tencent.com/document/api/1108/54487)

新增数据结构：

* [MonthNetwork](https://cloud.tencent.com/document/api/1108/42574#MonthNetwork)

### 第 45 次发布

发布时间：2021-04-08 08:01:07

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [RunInstances](https://cloud.tencent.com/document/api/1108/43513)

	* 新增入参：InstanceChargeType


### 第 44 次发布

发布时间：2021-03-17 08:00:56

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeConfig](https://cloud.tencent.com/document/api/1108/42572)

	* 新增出参：DefaultIPDirect


### 第 43 次发布

发布时间：2021-03-03 08:00:59

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeConfig](https://cloud.tencent.com/document/api/1108/42572)

	* 新增出参：ImageLimits


新增数据结构：

* [ImageLimitConfig](https://cloud.tencent.com/document/api/1108/42574#ImageLimitConfig)

### 第 42 次发布

发布时间：2021-03-02 08:00:59

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribePeakNetworkOverview](https://cloud.tencent.com/document/api/1108/42569)

	* 新增入参：Period


修改数据结构：

* [PeakNetwork](https://cloud.tencent.com/document/api/1108/42574#PeakNetwork)

	* 新增成员：ChargeNetwork


### 第 41 次发布

发布时间：2021-02-23 08:00:50

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeConfig](https://cloud.tencent.com/document/api/1108/42572)

	* 新增出参：InstanceNetworkLimitConfigs


新增数据结构：

* [InstanceNetworkLimitConfig](https://cloud.tencent.com/document/api/1108/42574#InstanceNetworkLimitConfig)

### 第 40 次发布

发布时间：2021-02-05 08:00:58

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [ModifyPrivateIpAddressesAttribute](https://cloud.tencent.com/document/api/1108/52868)

修改接口：

* [AllocateAddresses](https://cloud.tencent.com/document/api/1108/43589)

	* 新增入参：InstanceId, NetworkInterfaceId, PrivateIpAddress

* [TerminateInstances](https://cloud.tencent.com/document/api/1108/42559)

	* 新增入参：AssociatedResourceDestroy


### 第 39 次发布

发布时间：2021-02-04 08:02:38

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [InstanceTypeConfig](https://cloud.tencent.com/document/api/1108/42574#InstanceTypeConfig)

	* 新增成员：Vgpu, GpuModelName


### 第 38 次发布

发布时间：2021-01-25 08:00:54

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [SetLoadBalancerSecurityGroups](https://cloud.tencent.com/document/api/1108/52408)
* [SetSecurityGroupForLoadbalancers](https://cloud.tencent.com/document/api/1108/52407)

修改接口：

* [CreateLoadBalancer](https://cloud.tencent.com/document/api/1108/48465)

	* 新增入参：SecurityGroups

* [DescribeLoadBalancers](https://cloud.tencent.com/document/api/1108/48459)

	* 新增入参：SecurityGroup

* [ModifyLoadBalancerAttributes](https://cloud.tencent.com/document/api/1108/48455)

	* 新增入参：LoadBalancerPassToTarget


修改数据结构：

* [LoadBalancer](https://cloud.tencent.com/document/api/1108/42574#LoadBalancer)

	* 新增成员：SecureGroups, LoadBalancerPassToTarget


### 第 37 次发布

发布时间：2020-12-29 08:00:50

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [ModifyModuleDisableWanIp](https://cloud.tencent.com/document/api/1108/51572)

修改接口：

* [CreateModule](https://cloud.tencent.com/document/api/1108/42557)

	* 新增入参：DisableWanIp


### 第 36 次发布

发布时间：2020-12-17 08:00:43

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [AssignIpv6Addresses](https://cloud.tencent.com/document/api/1108/51094)
* [ModifyIpv6AddressesAttribute](https://cloud.tencent.com/document/api/1108/51093)
* [ReleaseIpv6Addresses](https://cloud.tencent.com/document/api/1108/51092)

### 第 35 次发布

发布时间：2020-12-15 08:01:47

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [AddressInfo](https://cloud.tencent.com/document/api/1108/42574#AddressInfo)

	* 新增成员：PublicIPv6AddressInfo

* [Ipv6Address](https://cloud.tencent.com/document/api/1108/42574#Ipv6Address)

	* <font color="#dd0000">**修改成员**：</font>Primary, AddressId, Description, IsWanIpBlocked, State

* [ZoneInstanceCountISP](https://cloud.tencent.com/document/api/1108/42574#ZoneInstanceCountISP)

	* 新增成员：Ipv6AddressCount


### 第 34 次发布

发布时间：2020-11-24 08:00:47

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateHaVip](https://cloud.tencent.com/document/api/1108/50173)

	* 新增入参：VpcId, SubnetId, HaVipName, Vip

	* 新增出参：HaVip

* [DeleteHaVip](https://cloud.tencent.com/document/api/1108/50172)

	* 新增入参：HaVipId

* [DescribeHaVips](https://cloud.tencent.com/document/api/1108/50171)

	* 新增入参：HaVipIds, Filters, Offset, Limit, EcmRegion

	* 新增出参：TotalCount, HaVipSet

* [ModifyHaVipAttribute](https://cloud.tencent.com/document/api/1108/50170)

	* 新增入参：HaVipId, HaVipName


新增数据结构：

* [HaVip](https://cloud.tencent.com/document/api/1108/42574#HaVip)

### 第 33 次发布

发布时间：2020-11-23 08:00:45

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateHaVip](https://cloud.tencent.com/document/api/1108/50173)
* [CreateRouteTable](https://cloud.tencent.com/document/api/1108/50186)
* [CreateRoutes](https://cloud.tencent.com/document/api/1108/50185)
* [DeleteHaVip](https://cloud.tencent.com/document/api/1108/50172)
* [DeleteRouteTable](https://cloud.tencent.com/document/api/1108/50184)
* [DeleteRoutes](https://cloud.tencent.com/document/api/1108/50183)
* [DescribeHaVips](https://cloud.tencent.com/document/api/1108/50171)
* [DescribeRouteConflicts](https://cloud.tencent.com/document/api/1108/50182)
* [DescribeRouteTables](https://cloud.tencent.com/document/api/1108/50181)
* [DisableRoutes](https://cloud.tencent.com/document/api/1108/50180)
* [EnableRoutes](https://cloud.tencent.com/document/api/1108/50179)
* [ModifyHaVipAttribute](https://cloud.tencent.com/document/api/1108/50170)
* [ModifyRouteTableAttribute](https://cloud.tencent.com/document/api/1108/50178)
* [ReplaceRouteTableAssociation](https://cloud.tencent.com/document/api/1108/50177)
* [ReplaceRoutes](https://cloud.tencent.com/document/api/1108/50176)
* [ResetRoutes](https://cloud.tencent.com/document/api/1108/50175)

新增数据结构：

* [Route](https://cloud.tencent.com/document/api/1108/42574#Route)
* [RouteConflict](https://cloud.tencent.com/document/api/1108/42574#RouteConflict)
* [RouteTable](https://cloud.tencent.com/document/api/1108/42574#RouteTable)
* [RouteTableAssociation](https://cloud.tencent.com/document/api/1108/42574#RouteTableAssociation)

### 第 32 次发布

发布时间：2020-11-20 08:00:35

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateListener](https://cloud.tencent.com/document/api/1108/48466)

	* 新增入参：SessionType


修改数据结构：

* [Listener](https://cloud.tencent.com/document/api/1108/42574#Listener)

	* 新增成员：SessionType


### 第 31 次发布

发布时间：2020-11-19 08:00:34

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [RunInstances](https://cloud.tencent.com/document/api/1108/43513)

	* 新增入参：InternetMaxBandwidthIn


### 第 30 次发布

发布时间：2020-11-04 08:00:32

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [AssociateAddress](https://cloud.tencent.com/document/api/1108/43588)

	* 新增出参：TaskId


### 第 29 次发布

发布时间：2020-11-03 08:00:35

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [AssociateAddress](https://cloud.tencent.com/document/api/1108/43588)

	* <font color="#dd0000">**删除出参**：</font>TaskId


### 第 28 次发布

发布时间：2020-10-27 08:00:29

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [Image](https://cloud.tencent.com/document/api/1108/42574#Image)

	* 新增成员：TaskId


### 第 27 次发布

发布时间：2020-10-19 08:00:23

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateModule](https://cloud.tencent.com/document/api/1108/42557)

	* 新增入参：DefaultBandWidthIn

* [ModifyModuleNetwork](https://cloud.tencent.com/document/api/1108/42551)

	* 新增入参：DefaultBandwidthIn

* [ResetInstancesMaxBandwidth](https://cloud.tencent.com/document/api/1108/42560)

	* 新增入参：MaxBandwidthIn


修改数据结构：

* [Module](https://cloud.tencent.com/document/api/1108/42574#Module)

	* 新增成员：DefaultBandwidthIn

* [PublicIPAddressInfo](https://cloud.tencent.com/document/api/1108/42574#PublicIPAddressInfo)

	* 新增成员：MaxBandwidthIn


### 第 26 次发布

发布时间：2020-10-15 08:00:25

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeNetworkInterfaces](https://cloud.tencent.com/document/api/1108/43575)

	* <font color="#dd0000">**修改入参**：</font>EcmRegion


新增数据结构：

* [AddressInfo](https://cloud.tencent.com/document/api/1108/42574#AddressInfo)
* [InstanceNetworkInfo](https://cloud.tencent.com/document/api/1108/42574#InstanceNetworkInfo)

修改数据结构：

* [Instance](https://cloud.tencent.com/document/api/1108/42574#Instance)

	* 新增成员：ISP

* [Internet](https://cloud.tencent.com/document/api/1108/42574#Internet)

	* 新增成员：InstanceNetworkInfoSet

* [NetworkInterface](https://cloud.tencent.com/document/api/1108/42574#NetworkInterface)

	* 新增成员：EcmRegion


### 第 25 次发布

发布时间：2020-09-17 08:00:30

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [BatchDeregisterTargets](https://cloud.tencent.com/document/api/1108/48469)
* [BatchModifyTargetWeight](https://cloud.tencent.com/document/api/1108/48468)
* [BatchRegisterTargets](https://cloud.tencent.com/document/api/1108/48467)
* [CreateListener](https://cloud.tencent.com/document/api/1108/48466)
* [CreateLoadBalancer](https://cloud.tencent.com/document/api/1108/48465)
* [DeleteListener](https://cloud.tencent.com/document/api/1108/48464)
* [DeleteLoadBalancer](https://cloud.tencent.com/document/api/1108/48463)
* [DeleteLoadBalancerListeners](https://cloud.tencent.com/document/api/1108/48462)
* [DescribeListeners](https://cloud.tencent.com/document/api/1108/48461)
* [DescribeLoadBalanceTaskStatus](https://cloud.tencent.com/document/api/1108/48460)
* [DescribeLoadBalancers](https://cloud.tencent.com/document/api/1108/48459)
* [DescribeTargetHealth](https://cloud.tencent.com/document/api/1108/48458)
* [DescribeTargets](https://cloud.tencent.com/document/api/1108/48457)
* [ModifyListener](https://cloud.tencent.com/document/api/1108/48456)
* [ModifyLoadBalancerAttributes](https://cloud.tencent.com/document/api/1108/48455)
* [ModifyTargetPort](https://cloud.tencent.com/document/api/1108/48454)
* [ModifyTargetWeight](https://cloud.tencent.com/document/api/1108/48453)

新增数据结构：

* [Backend](https://cloud.tencent.com/document/api/1108/42574#Backend)
* [BatchTarget](https://cloud.tencent.com/document/api/1108/42574#BatchTarget)
* [HealthCheck](https://cloud.tencent.com/document/api/1108/42574#HealthCheck)
* [Listener](https://cloud.tencent.com/document/api/1108/42574#Listener)
* [ListenerBackend](https://cloud.tencent.com/document/api/1108/42574#ListenerBackend)
* [ListenerHealth](https://cloud.tencent.com/document/api/1108/42574#ListenerHealth)
* [LoadBalancer](https://cloud.tencent.com/document/api/1108/42574#LoadBalancer)
* [LoadBalancerHealth](https://cloud.tencent.com/document/api/1108/42574#LoadBalancerHealth)
* [LoadBalancerInternetAccessible](https://cloud.tencent.com/document/api/1108/42574#LoadBalancerInternetAccessible)
* [RuleHealth](https://cloud.tencent.com/document/api/1108/42574#RuleHealth)
* [TagInfo](https://cloud.tencent.com/document/api/1108/42574#TagInfo)
* [Target](https://cloud.tencent.com/document/api/1108/42574#Target)
* [TargetHealth](https://cloud.tencent.com/document/api/1108/42574#TargetHealth)
* [TargetsWeightRule](https://cloud.tencent.com/document/api/1108/42574#TargetsWeightRule)

### 第 24 次发布

发布时间：2020-08-21 08:02:20

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [AssociateSecurityGroups](https://cloud.tencent.com/document/api/1108/47693)
* [CreateSecurityGroupPolicies](https://cloud.tencent.com/document/api/1108/47703)
* [DeleteSecurityGroup](https://cloud.tencent.com/document/api/1108/47702)
* [DeleteSecurityGroupPolicies](https://cloud.tencent.com/document/api/1108/47701)
* [DescribeSecurityGroupAssociationStatistics](https://cloud.tencent.com/document/api/1108/47700)
* [DescribeSecurityGroupLimits](https://cloud.tencent.com/document/api/1108/47699)
* [DescribeSecurityGroupPolicies](https://cloud.tencent.com/document/api/1108/47698)
* [DescribeSecurityGroups](https://cloud.tencent.com/document/api/1108/47697)
* [DisassociateSecurityGroups](https://cloud.tencent.com/document/api/1108/47692)
* [ModifyModuleSecurityGroups](https://cloud.tencent.com/document/api/1108/47691)
* [ModifySecurityGroupAttribute](https://cloud.tencent.com/document/api/1108/47696)
* [ModifySecurityGroupPolicies](https://cloud.tencent.com/document/api/1108/47695)
* [ReplaceSecurityGroupPolicy](https://cloud.tencent.com/document/api/1108/47694)

修改接口：

* [CreateModule](https://cloud.tencent.com/document/api/1108/42557)

	* 新增入参：SecurityGroups

* [ModifyInstancesAttribute](https://cloud.tencent.com/document/api/1108/42563)

	* 新增入参：SecurityGroups


新增数据结构：

* [AddressTemplateSpecification](https://cloud.tencent.com/document/api/1108/42574#AddressTemplateSpecification)
* [InstanceStatistic](https://cloud.tencent.com/document/api/1108/42574#InstanceStatistic)
* [SecurityGroupAssociationStatistics](https://cloud.tencent.com/document/api/1108/42574#SecurityGroupAssociationStatistics)
* [SecurityGroupLimitSet](https://cloud.tencent.com/document/api/1108/42574#SecurityGroupLimitSet)
* [SecurityGroupPolicy](https://cloud.tencent.com/document/api/1108/42574#SecurityGroupPolicy)
* [SecurityGroupPolicySet](https://cloud.tencent.com/document/api/1108/42574#SecurityGroupPolicySet)
* [ServiceTemplateSpecification](https://cloud.tencent.com/document/api/1108/42574#ServiceTemplateSpecification)

修改数据结构：

* [Module](https://cloud.tencent.com/document/api/1108/42574#Module)

	* 新增成员：SecurityGroupIds


### 第 23 次发布

发布时间：2020-08-17 08:01:44

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateVpc](https://cloud.tencent.com/document/api/1108/43569)

	* 新增入参：Description

* [DescribeSubnets](https://cloud.tencent.com/document/api/1108/43592)

	* 新增入参：Sort

	* <font color="#dd0000">**修改入参**：</font>EcmRegion

* [DescribeVpcs](https://cloud.tencent.com/document/api/1108/43663)

	* 新增入参：Sort

	* <font color="#dd0000">**修改入参**：</font>EcmRegion

* [ModifySubnetAttribute](https://cloud.tencent.com/document/api/1108/43591)

	* 新增入参：Tags

* [ModifyVpcAttribute](https://cloud.tencent.com/document/api/1108/43567)

	* 新增入参：Tags, Description


新增数据结构：

* [VirtualPrivateCloud](https://cloud.tencent.com/document/api/1108/42574#VirtualPrivateCloud)

修改数据结构：

* [Instance](https://cloud.tencent.com/document/api/1108/42574#Instance)

	* 新增成员：VirtualPrivateCloud

* [Subnet](https://cloud.tencent.com/document/api/1108/42574#Subnet)

	* 新增成员：ZoneName, InstanceCount, VpcCidrBlock, VpcIpv6CidrBlock, Region

* [VpcInfo](https://cloud.tencent.com/document/api/1108/42574#VpcInfo)

	* 新增成员：Region, Description, RegionName, SubnetCount, InstanceCount


### 第 22 次发布

发布时间：2020-08-10 08:01:54

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [ModifyModuleIpDirect](https://cloud.tencent.com/document/api/1108/47275)

修改接口：

* [CreateModule](https://cloud.tencent.com/document/api/1108/42557)

	* 新增入参：CloseIpDirect, TagSpecification


修改数据结构：

* [Module](https://cloud.tencent.com/document/api/1108/42574#Module)

	* 新增成员：TagSet, CloseIpDirect


### 第 21 次发布

发布时间：2020-08-05 08:01:49

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [ModifyModuleConfig](https://cloud.tencent.com/document/api/1108/47143)

### 第 20 次发布

发布时间：2020-08-04 08:01:47

本次发布包含了以下内容：

改善已有的文档。

新增数据结构：

* [RunEIPDirectServiceEnabled](https://cloud.tencent.com/document/api/1108/42574#RunEIPDirectServiceEnabled)

修改数据结构：

* [EnhancedService](https://cloud.tencent.com/document/api/1108/42574#EnhancedService)

	* 新增成员：EIPDirectService


### 第 19 次发布

发布时间：2020-08-03 08:02:07

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateImage](https://cloud.tencent.com/document/api/1108/46515)

	* <font color="#dd0000">**修改入参**：</font>InstanceId


### 第 18 次发布

发布时间：2020-07-21 08:01:24

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateImage](https://cloud.tencent.com/document/api/1108/46515)
* [DescribeTaskStatus](https://cloud.tencent.com/document/api/1108/46516)
* [ModifyImageAttribute](https://cloud.tencent.com/document/api/1108/46514)

修改接口：

* [RunInstances](https://cloud.tencent.com/document/api/1108/43513)

	* 新增入参：SystemDiskSize


新增数据结构：

* [TaskInput](https://cloud.tencent.com/document/api/1108/42574#TaskInput)
* [TaskOutput](https://cloud.tencent.com/document/api/1108/42574#TaskOutput)

修改数据结构：

* [Address](https://cloud.tencent.com/document/api/1108/42574#Address)

	* 新增成员：Bandwidth, PayMode

* [Image](https://cloud.tencent.com/document/api/1108/42574#Image)

	* 新增成员：ImageSource

* [SrcImage](https://cloud.tencent.com/document/api/1108/42574#SrcImage)

	* 新增成员：InstanceName, InstanceId, ImageType


### 第 17 次发布

发布时间：2020-06-22 08:01:42

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeNode](https://cloud.tencent.com/document/api/1108/42567)

	* 新增入参：Filters


### 第 16 次发布

发布时间：2020-06-17 08:01:13

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeCustomImageTask](https://cloud.tencent.com/document/api/1108/45615)
* [DescribeImportImageOs](https://cloud.tencent.com/document/api/1108/45614)
* [ImportCustomImage](https://cloud.tencent.com/document/api/1108/45613)

修改接口：

* [DescribeVpcs](https://cloud.tencent.com/document/api/1108/43663)

	* <font color="#dd0000">**修改入参**：</font>EcmRegion


新增数据结构：

* [ImageOsList](https://cloud.tencent.com/document/api/1108/42574#ImageOsList)
* [ImageTask](https://cloud.tencent.com/document/api/1108/42574#ImageTask)
* [ImageUrl](https://cloud.tencent.com/document/api/1108/42574#ImageUrl)
* [OsVersion](https://cloud.tencent.com/document/api/1108/42574#OsVersion)

### 第 15 次发布

发布时间：2020-06-12 08:01:55

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [RunInstances](https://cloud.tencent.com/document/api/1108/43513)

	* 新增入参：SecurityGroupIds


修改数据结构：

* [Subnet](https://cloud.tencent.com/document/api/1108/42574#Subnet)

	* 新增成员：Zone

* [ZoneInstanceCountISP](https://cloud.tencent.com/document/api/1108/42574#ZoneInstanceCountISP)

	* 新增成员：VpcId, SubnetId, PrivateIpAddresses


### 第 14 次发布

发布时间：2020-06-11 08:01:11

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateSecurityGroup](https://cloud.tencent.com/document/api/1108/45479)

新增数据结构：

* [SecurityGroup](https://cloud.tencent.com/document/api/1108/42574#SecurityGroup)

修改数据结构：

* [Instance](https://cloud.tencent.com/document/api/1108/42574#Instance)

	* 新增成员：SecurityGroupIds


### 第 13 次发布

发布时间：2020-06-02 08:01:13

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [RunInstances](https://cloud.tencent.com/document/api/1108/43513)

	* 新增入参：InstanceType, DataDiskSize

	* <font color="#dd0000">**修改入参**：</font>ModuleId


### 第 12 次发布

发布时间：2020-06-01 08:02:08

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeDefaultSubnet](https://cloud.tencent.com/document/api/1108/45039)
* [ModifyDefaultSubnet](https://cloud.tencent.com/document/api/1108/45038)

### 第 11 次发布

发布时间：2020-05-22 19:56:07

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeInstances](https://cloud.tencent.com/document/api/1108/42565)

	* 新增入参：OrderByField, OrderDirection

* [DescribeModule](https://cloud.tencent.com/document/api/1108/42555)

	* 新增入参：OrderByField, OrderDirection


### 第 10 次发布

发布时间：2020-05-19 08:01:15

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [ResetInstances](https://cloud.tencent.com/document/api/1108/42561)

	* 新增入参：KeepData


### 第 9 次发布

发布时间：2020-04-30 08:01:11

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeInstanceVncUrl](https://cloud.tencent.com/document/api/1108/44158)

### 第 8 次发布

发布时间：2020-04-29 08:01:24

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [Instance](https://cloud.tencent.com/document/api/1108/42574#Instance)

	* 新增成员：NewFlag


### 第 7 次发布

发布时间：2020-04-23 08:00:50

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [ResetInstancesPassword](https://cloud.tencent.com/document/api/1108/43707)
* [StartInstances](https://cloud.tencent.com/document/api/1108/43706)
* [StopInstances](https://cloud.tencent.com/document/api/1108/43705)

### 第 6 次发布

发布时间：2020-04-22 08:00:43

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeVpcs](https://cloud.tencent.com/document/api/1108/43663)

### 第 5 次发布

发布时间：2020-04-21 08:01:09

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [AllocateAddresses](https://cloud.tencent.com/document/api/1108/43589)
* [AssignPrivateIpAddresses](https://cloud.tencent.com/document/api/1108/43579)
* [AssociateAddress](https://cloud.tencent.com/document/api/1108/43588)
* [AttachNetworkInterface](https://cloud.tencent.com/document/api/1108/43578)
* [CreateNetworkInterface](https://cloud.tencent.com/document/api/1108/43577)
* [CreateSubnet](https://cloud.tencent.com/document/api/1108/43594)
* [CreateVpc](https://cloud.tencent.com/document/api/1108/43569)
* [DeleteNetworkInterface](https://cloud.tencent.com/document/api/1108/43576)
* [DeleteSubnet](https://cloud.tencent.com/document/api/1108/43593)
* [DeleteVpc](https://cloud.tencent.com/document/api/1108/43568)
* [DescribeAddressQuota](https://cloud.tencent.com/document/api/1108/43587)
* [DescribeAddresses](https://cloud.tencent.com/document/api/1108/43586)
* [DescribeNetworkInterfaces](https://cloud.tencent.com/document/api/1108/43575)
* [DescribeSubnets](https://cloud.tencent.com/document/api/1108/43592)
* [DescribeTaskResult](https://cloud.tencent.com/document/api/1108/43585)
* [DetachNetworkInterface](https://cloud.tencent.com/document/api/1108/43574)
* [DisassociateAddress](https://cloud.tencent.com/document/api/1108/43584)
* [MigrateNetworkInterface](https://cloud.tencent.com/document/api/1108/43573)
* [MigratePrivateIpAddress](https://cloud.tencent.com/document/api/1108/43572)
* [ModifyAddressAttribute](https://cloud.tencent.com/document/api/1108/43583)
* [ModifyAddressesBandwidth](https://cloud.tencent.com/document/api/1108/43582)
* [ModifySubnetAttribute](https://cloud.tencent.com/document/api/1108/43591)
* [ModifyVpcAttribute](https://cloud.tencent.com/document/api/1108/43567)
* [ReleaseAddresses](https://cloud.tencent.com/document/api/1108/43581)
* [RemovePrivateIpAddresses](https://cloud.tencent.com/document/api/1108/43571)

新增数据结构：

* [Address](https://cloud.tencent.com/document/api/1108/42574#Address)
* [AssistantCidr](https://cloud.tencent.com/document/api/1108/42574#AssistantCidr)
* [EipQuota](https://cloud.tencent.com/document/api/1108/42574#EipQuota)
* [Ipv6Address](https://cloud.tencent.com/document/api/1108/42574#Ipv6Address)
* [NetworkInterface](https://cloud.tencent.com/document/api/1108/42574#NetworkInterface)
* [NetworkInterfaceAttachment](https://cloud.tencent.com/document/api/1108/42574#NetworkInterfaceAttachment)
* [PrivateIpAddressSpecification](https://cloud.tencent.com/document/api/1108/42574#PrivateIpAddressSpecification)
* [Subnet](https://cloud.tencent.com/document/api/1108/42574#Subnet)
* [VpcInfo](https://cloud.tencent.com/document/api/1108/42574#VpcInfo)

### 第 4 次发布

发布时间：2020-04-20 08:00:54

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [RunInstances](https://cloud.tencent.com/document/api/1108/43513)

新增数据结构：

* [TagSpecification](https://cloud.tencent.com/document/api/1108/42574#TagSpecification)
* [ZoneInstanceCountISP](https://cloud.tencent.com/document/api/1108/42574#ZoneInstanceCountISP)

### 第 3 次发布

发布时间：2020-04-08 08:00:24

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [ImportImage](https://cloud.tencent.com/document/api/1108/43183)

### 第 2 次发布

发布时间：2020-03-19 12:49:34

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [Position](https://cloud.tencent.com/document/api/1108/42574#Position)

	* <font color="#dd0000">**修改成员**：</font>Country, Province, City


### 第 1 次发布

发布时间：2020-03-18 16:14:20

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateModule](https://cloud.tencent.com/document/api/1108/42557)
* [DeleteImage](https://cloud.tencent.com/document/api/1108/42549)
* [DeleteModule](https://cloud.tencent.com/document/api/1108/42556)
* [DescribeBaseOverview](https://cloud.tencent.com/document/api/1108/42573)
* [DescribeConfig](https://cloud.tencent.com/document/api/1108/42572)
* [DescribeImage](https://cloud.tencent.com/document/api/1108/42548)
* [DescribeInstanceTypeConfig](https://cloud.tencent.com/document/api/1108/42571)
* [DescribeInstances](https://cloud.tencent.com/document/api/1108/42565)
* [DescribeInstancesDeniedActions](https://cloud.tencent.com/document/api/1108/42564)
* [DescribeModule](https://cloud.tencent.com/document/api/1108/42555)
* [DescribeModuleDetail](https://cloud.tencent.com/document/api/1108/42554)
* [DescribeNode](https://cloud.tencent.com/document/api/1108/42567)
* [DescribePeakBaseOverview](https://cloud.tencent.com/document/api/1108/42570)
* [DescribePeakNetworkOverview](https://cloud.tencent.com/document/api/1108/42569)
* [ModifyInstancesAttribute](https://cloud.tencent.com/document/api/1108/42563)
* [ModifyModuleImage](https://cloud.tencent.com/document/api/1108/42553)
* [ModifyModuleName](https://cloud.tencent.com/document/api/1108/42552)
* [ModifyModuleNetwork](https://cloud.tencent.com/document/api/1108/42551)
* [RebootInstances](https://cloud.tencent.com/document/api/1108/42562)
* [ResetInstances](https://cloud.tencent.com/document/api/1108/42561)
* [ResetInstancesMaxBandwidth](https://cloud.tencent.com/document/api/1108/42560)
* [TerminateInstances](https://cloud.tencent.com/document/api/1108/42559)

新增数据结构：

* [Area](https://cloud.tencent.com/document/api/1108/42574#Area)
* [City](https://cloud.tencent.com/document/api/1108/42574#City)
* [Country](https://cloud.tencent.com/document/api/1108/42574#Country)
* [DiskInfo](https://cloud.tencent.com/document/api/1108/42574#DiskInfo)
* [EnhancedService](https://cloud.tencent.com/document/api/1108/42574#EnhancedService)
* [Filter](https://cloud.tencent.com/document/api/1108/42574#Filter)
* [ISP](https://cloud.tencent.com/document/api/1108/42574#ISP)
* [ISPCounter](https://cloud.tencent.com/document/api/1108/42574#ISPCounter)
* [Image](https://cloud.tencent.com/document/api/1108/42574#Image)
* [Instance](https://cloud.tencent.com/document/api/1108/42574#Instance)
* [InstanceFamilyConfig](https://cloud.tencent.com/document/api/1108/42574#InstanceFamilyConfig)
* [InstanceFamilyTypeConfig](https://cloud.tencent.com/document/api/1108/42574#InstanceFamilyTypeConfig)
* [InstanceOperator](https://cloud.tencent.com/document/api/1108/42574#InstanceOperator)
* [InstanceTypeConfig](https://cloud.tencent.com/document/api/1108/42574#InstanceTypeConfig)
* [Internet](https://cloud.tencent.com/document/api/1108/42574#Internet)
* [Module](https://cloud.tencent.com/document/api/1108/42574#Module)
* [ModuleCounter](https://cloud.tencent.com/document/api/1108/42574#ModuleCounter)
* [ModuleItem](https://cloud.tencent.com/document/api/1108/42574#ModuleItem)
* [NetworkStorageRange](https://cloud.tencent.com/document/api/1108/42574#NetworkStorageRange)
* [Node](https://cloud.tencent.com/document/api/1108/42574#Node)
* [NodeInstanceNum](https://cloud.tencent.com/document/api/1108/42574#NodeInstanceNum)
* [OperatorAction](https://cloud.tencent.com/document/api/1108/42574#OperatorAction)
* [PeakBase](https://cloud.tencent.com/document/api/1108/42574#PeakBase)
* [PeakFamilyInfo](https://cloud.tencent.com/document/api/1108/42574#PeakFamilyInfo)
* [PeakNetwork](https://cloud.tencent.com/document/api/1108/42574#PeakNetwork)
* [PeakNetworkRegionInfo](https://cloud.tencent.com/document/api/1108/42574#PeakNetworkRegionInfo)
* [Position](https://cloud.tencent.com/document/api/1108/42574#Position)
* [PrivateIPAddressInfo](https://cloud.tencent.com/document/api/1108/42574#PrivateIPAddressInfo)
* [Province](https://cloud.tencent.com/document/api/1108/42574#Province)
* [PublicIPAddressInfo](https://cloud.tencent.com/document/api/1108/42574#PublicIPAddressInfo)
* [RegionInfo](https://cloud.tencent.com/document/api/1108/42574#RegionInfo)
* [RunMonitorServiceEnabled](https://cloud.tencent.com/document/api/1108/42574#RunMonitorServiceEnabled)
* [RunSecurityServiceEnabled](https://cloud.tencent.com/document/api/1108/42574#RunSecurityServiceEnabled)
* [SimpleModule](https://cloud.tencent.com/document/api/1108/42574#SimpleModule)
* [SrcImage](https://cloud.tencent.com/document/api/1108/42574#SrcImage)
* [Tag](https://cloud.tencent.com/document/api/1108/42574#Tag)
* [ZoneInfo](https://cloud.tencent.com/document/api/1108/42574#ZoneInfo)
* [ZoneInstanceInfo](https://cloud.tencent.com/document/api/1108/42574#ZoneInstanceInfo)




## 数字身份管控平台（员工版）(eiam) 版本：2021-04-20

### 第 14 次发布

发布时间：2022-01-18 08:09:35

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeUserInfo](https://cloud.tencent.com/document/api/1442/73337)

	* 新增出参：AdminFlag


### 第 13 次发布

发布时间：2022-01-12 20:31:09

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeOrgResourcesAuthorization](https://cloud.tencent.com/document/api/1442/73341)

	* <font color="#dd0000">**修改出参**：</font>AuthorizationOrgResourceList

* [DescribeUserGroupResourcesAuthorization](https://cloud.tencent.com/document/api/1442/73338)

	* <font color="#dd0000">**修改出参**：</font>AuthorizationUserGroupResourceList


新增数据结构：

* [AuthorizationResourceEntityInfo](https://cloud.tencent.com/document/api/1442/57931#AuthorizationResourceEntityInfo)

<font color="#dd0000">**删除数据结构**：</font>

* AuthorizationResouceEntityInfo

### 第 12 次发布

发布时间：2022-01-05 08:08:30

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [AddUserToUserGroup](https://cloud.tencent.com/document/api/1442/73351)

	* 新增出参：FailedItems

* [CreateUser](https://cloud.tencent.com/document/api/1442/73348)

	* 新增入参：SecondaryOrgNodeIdList

* [DescribeUserInfo](https://cloud.tencent.com/document/api/1442/73337)

	* 新增出参：SecondaryOrgNodeIdList

* [ListApplications](https://cloud.tencent.com/document/api/1442/73333)

	* 新增入参：ApplicationIdList

* [ListUsersInUserGroup](https://cloud.tencent.com/document/api/1442/73325)

	* 新增入参：SearchCondition, Sort, Offset, Limit

* [ModifyUserInfo](https://cloud.tencent.com/document/api/1442/73233)

	* 新增入参：SecondaryOrgNodeIdList


### 第 11 次发布

发布时间：2021-12-15 08:07:41

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [AddAccountToAccountGroup](https://cloud.tencent.com/document/api/1442/73362)
* [CreateAccountGroup](https://cloud.tencent.com/document/api/1442/73361)
* [CreateAppAccount](https://cloud.tencent.com/document/api/1442/73350)
* [DeleteAccountGroup](https://cloud.tencent.com/document/api/1442/73360)
* [DeleteAppAccount](https://cloud.tencent.com/document/api/1442/73359)
* [DeleteUsers](https://cloud.tencent.com/document/api/1442/73358)
* [DescribeAccountGroup](https://cloud.tencent.com/document/api/1442/73357)
* [DescribeAppAccount](https://cloud.tencent.com/document/api/1442/73356)
* [DescribeUserThirdPartyAccountInfo](https://cloud.tencent.com/document/api/1442/73355)
* [ListAccountInAccountGroup](https://cloud.tencent.com/document/api/1442/73335)
* [ModifyAccountGroup](https://cloud.tencent.com/document/api/1442/73354)
* [ModifyAppAccount](https://cloud.tencent.com/document/api/1442/73353)
* [RemoveAccountFromAccountGroup](https://cloud.tencent.com/document/api/1442/73352)

修改接口：

* [DescribeOrgNode](https://cloud.tencent.com/document/api/1442/73342)

	* 新增出参：Description

* [DescribeUserInfo](https://cloud.tencent.com/document/api/1442/73337)

	* 新增出参：PwdNeedReset

* [ListUserGroupsOfUser](https://cloud.tencent.com/document/api/1442/73328)

	* 新增入参：SearchCondition, Sort, Offset, Limit

	* 新增出参：UserGroupInfoList, TotalCount

* [ListUsersInOrgNode](https://cloud.tencent.com/document/api/1442/73326)

	* 新增入参：SearchCondition, Sort, Offset, Limit

	* 新增出参：OrgNodeIdPath, OrgNodeNamePath

* [ModifyUserInfo](https://cloud.tencent.com/document/api/1442/73233)

	* 新增入参：OrgNodeId


新增数据结构：

* [AccountGroupInfo](https://cloud.tencent.com/document/api/1442/57931#AccountGroupInfo)
* [AccountGroupSearchCriteria](https://cloud.tencent.com/document/api/1442/57931#AccountGroupSearchCriteria)
* [AppAccountInfo](https://cloud.tencent.com/document/api/1442/57931#AppAccountInfo)
* [AppAccountSearchCriteria](https://cloud.tencent.com/document/api/1442/57931#AppAccountSearchCriteria)
* [LinkUserInfo](https://cloud.tencent.com/document/api/1442/57931#LinkUserInfo)
* [ListUsersInOrgNodeSearchCriteria](https://cloud.tencent.com/document/api/1442/57931#ListUsersInOrgNodeSearchCriteria)
* [ThirdPartyAccountInfo](https://cloud.tencent.com/document/api/1442/57931#ThirdPartyAccountInfo)
* [UserGroupInfo](https://cloud.tencent.com/document/api/1442/57931#UserGroupInfo)
* [UserGroupInformationSearchCriteria](https://cloud.tencent.com/document/api/1442/57931#UserGroupInformationSearchCriteria)

修改数据结构：

* [ApplicationAuthorizationInfo](https://cloud.tencent.com/document/api/1442/57931#ApplicationAuthorizationInfo)

	* 新增成员：ApplicationName, CreatedDate

* [OrgNodeChildInfo](https://cloud.tencent.com/document/api/1442/57931#OrgNodeChildInfo)

	* 新增成员：Description

* [OrgNodeChildUserInfo](https://cloud.tencent.com/document/api/1442/57931#OrgNodeChildUserInfo)

	* 新增成员：OrgNodeIdPath, OrgNodeNamePath


### 第 10 次发布

发布时间：2021-12-14 08:09:55

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [UserInfo](https://cloud.tencent.com/document/api/1442/57931#UserInfo)

	* 新增成员：UserName, Phone, Email, Status, DataSource


### 第 9 次发布

发布时间：2021-09-22 08:07:57

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeOrgResourcesAuthorization](https://cloud.tencent.com/document/api/1442/73341)

	* 新增出参：TotalCount


修改数据结构：

* [AuthorizationResouceEntityInfo](https://cloud.tencent.com/document/api/1442/57931#AuthorizationResouceEntityInfo)

	* 新增成员：ResourceName

* [AuthorizationUserResouceInfo](https://cloud.tencent.com/document/api/1442/57931#AuthorizationUserResouceInfo)

	* 新增成员：ResourceName


### 第 8 次发布

发布时间：2021-08-21 15:18:03

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeUserResourcesAuthorization](https://cloud.tencent.com/document/api/1442/73336)

	* <font color="#dd0000">**修改入参**：</font>UserId


### 第 7 次发布

发布时间：2021-08-13 08:12:10

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeOrgResourcesAuthorization](https://cloud.tencent.com/document/api/1442/73341)
* [DescribeUserGroupResourcesAuthorization](https://cloud.tencent.com/document/api/1442/73338)
* [DescribeUserResourcesAuthorization](https://cloud.tencent.com/document/api/1442/73336)

新增数据结构：

* [AuthorizationResouceEntityInfo](https://cloud.tencent.com/document/api/1442/57931#AuthorizationResouceEntityInfo)
* [AuthorizationUserResouceInfo](https://cloud.tencent.com/document/api/1442/57931#AuthorizationUserResouceInfo)

### 第 6 次发布

发布时间：2021-08-12 08:12:27

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [ModifyApplication](https://cloud.tencent.com/document/api/1442/73324)

修改接口：

* [DescribeApplication](https://cloud.tencent.com/document/api/1442/73343)

	* 新增出参：IconUrl, SecureLevel, AppStatus, Description


### 第 5 次发布

发布时间：2021-07-12 08:11:57

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribePublicKey](https://cloud.tencent.com/document/api/1442/73340)
* [ListApplicationAuthorizations](https://cloud.tencent.com/document/api/1442/73334)
* [ListApplications](https://cloud.tencent.com/document/api/1442/73333)
* [ListUserGroups](https://cloud.tencent.com/document/api/1442/73329)
* [ListUsers](https://cloud.tencent.com/document/api/1442/73327)

新增数据结构：

* [ApplicationInfoSearchCriteria](https://cloud.tencent.com/document/api/1442/57931#ApplicationInfoSearchCriteria)
* [ApplicationInformation](https://cloud.tencent.com/document/api/1442/57931#ApplicationInformation)
* [AuthorizationInfo](https://cloud.tencent.com/document/api/1442/57931#AuthorizationInfo)
* [AuthorizationInfoSearchCriteria](https://cloud.tencent.com/document/api/1442/57931#AuthorizationInfoSearchCriteria)
* [SortCondition](https://cloud.tencent.com/document/api/1442/57931#SortCondition)
* [UserGroupInfoSearchCriteria](https://cloud.tencent.com/document/api/1442/57931#UserGroupInfoSearchCriteria)
* [UserGroupInformation](https://cloud.tencent.com/document/api/1442/57931#UserGroupInformation)
* [UserInformation](https://cloud.tencent.com/document/api/1442/57931#UserInformation)
* [UserSearchCriteria](https://cloud.tencent.com/document/api/1442/57931#UserSearchCriteria)

### 第 4 次发布

发布时间：2021-07-08 20:20:57

本次发布包含了以下内容：

改善已有的文档。

<font color="#dd0000">**删除接口**：</font>

* DecribePublicKey

### 第 3 次发布

发布时间：2021-06-29 08:18:37

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [ModifyUserInfo](https://cloud.tencent.com/document/api/1442/73233)

### 第 2 次发布

发布时间：2021-06-28 08:11:39

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [AddUserToUserGroup](https://cloud.tencent.com/document/api/1442/73351)
* [CreateUserGroup](https://cloud.tencent.com/document/api/1442/73347)
* [DecribePublicKey](https://cloud.tencent.com/document/api/1442/57989)
* [DeleteUser](https://cloud.tencent.com/document/api/1442/73345)
* [DeleteUserGroup](https://cloud.tencent.com/document/api/1442/73344)
* [DescribeApplication](https://cloud.tencent.com/document/api/1442/73343)
* [DescribeUserGroup](https://cloud.tencent.com/document/api/1442/73339)
* [DescribeUserInfo](https://cloud.tencent.com/document/api/1442/73337)
* [ListAuthorizedApplicationsToOrgNode](https://cloud.tencent.com/document/api/1442/73332)
* [ListAuthorizedApplicationsToUser](https://cloud.tencent.com/document/api/1442/73331)
* [ListAuthorizedApplicationsToUserGroup](https://cloud.tencent.com/document/api/1442/73330)
* [ListUsersInUserGroup](https://cloud.tencent.com/document/api/1442/73325)
* [RemoveUserFromUserGroup](https://cloud.tencent.com/document/api/1442/73231)

新增数据结构：

* [ApplicationAuthorizationInfo](https://cloud.tencent.com/document/api/1442/57931#ApplicationAuthorizationInfo)
* [InheritedForm](https://cloud.tencent.com/document/api/1442/57931#InheritedForm)

### 第 1 次发布

发布时间：2021-06-25 16:46:58

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateOrgNode](https://cloud.tencent.com/document/api/1442/73349)
* [CreateUser](https://cloud.tencent.com/document/api/1442/73348)
* [DeleteOrgNode](https://cloud.tencent.com/document/api/1442/73346)
* [DescribeOrgNode](https://cloud.tencent.com/document/api/1442/73342)
* [ListUserGroupsOfUser](https://cloud.tencent.com/document/api/1442/73328)
* [ListUsersInOrgNode](https://cloud.tencent.com/document/api/1442/73326)
* [UpdateOrgNode](https://cloud.tencent.com/document/api/1442/71353)

新增数据结构：

* [OrgNodeChildInfo](https://cloud.tencent.com/document/api/1442/57931#OrgNodeChildInfo)
* [OrgNodeChildUserInfo](https://cloud.tencent.com/document/api/1442/57931#OrgNodeChildUserInfo)
* [UserInfo](https://cloud.tencent.com/document/api/1442/57931#UserInfo)




## 数据连接器(eis) 版本：2020-07-15

### 第 1 次发布

发布时间：2021-05-26 08:00:07

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeEisConnectorConfig](https://cloud.tencent.com/document/api/1270/56304)
* [ListEisConnectorOperations](https://cloud.tencent.com/document/api/1270/56303)
* [ListEisConnectors](https://cloud.tencent.com/document/api/1270/56302)

新增数据结构：

* [EisConnectionOperation](https://cloud.tencent.com/document/api/1270/56305#EisConnectionOperation)
* [EisConnectorSummary](https://cloud.tencent.com/document/api/1270/56305#EisConnectorSummary)



## 数据连接器(eis) 版本：2021-06-01

### 第 9 次发布

发布时间：2023-08-10 01:17:44

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [GetRuntimeResourceMonitorMetricMC](https://cloud.tencent.com/document/api/1270/57966)

	* 新增入参：AggregationType

* [ListRuntimeDeployedInstancesMC](https://cloud.tencent.com/document/api/1270/57964)

	* 新增入参：RuntimeClass


### 第 8 次发布

发布时间：2023-08-08 01:16:41

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [ListDeployableRuntimesMC](https://cloud.tencent.com/document/api/1270/57965)

	* 新增入参：RuntimeClass


修改数据结构：

* [AbstractRuntimeMC](https://cloud.tencent.com/document/api/1270/57968#AbstractRuntimeMC)

	* 新增成员：MatchExtensions

* [RuntimeExtensionMC](https://cloud.tencent.com/document/api/1270/57968#RuntimeExtensionMC)

	* <font color="#dd0000">**修改成员**：</font>Size, Replica, Name, Status, CreatedAt, UpdatedAt


### 第 7 次发布

发布时间：2023-05-15 01:37:48

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [ListRuntimesMC](https://cloud.tencent.com/document/api/1270/57963)

	* 新增入参：PlanType


### 第 6 次发布

发布时间：2023-05-12 01:25:04

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [ListDeployableRuntimesMC](https://cloud.tencent.com/document/api/1270/57965)

	* 新增入参：ProjectId, InstanceId, PlanType


### 第 5 次发布

发布时间：2022-11-16 06:22:42

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [GetRuntimeMC](https://cloud.tencent.com/document/api/1270/57967)

	* 新增入参：RuntimeClass

* [GetRuntimeResourceMonitorMetricMC](https://cloud.tencent.com/document/api/1270/57966)

	* 新增入参：RuntimeClass

* [ListRuntimesMC](https://cloud.tencent.com/document/api/1270/57963)

	* 新增入参：RuntimeClass


新增数据结构：

* [RuntimeExtensionMC](https://cloud.tencent.com/document/api/1270/57968#RuntimeExtensionMC)

修改数据结构：

* [AbstractRuntimeMC](https://cloud.tencent.com/document/api/1270/57968#AbstractRuntimeMC)

	* 新增成员：RuntimeClass, Deployed

* [RuntimeDeployedInstanceMC](https://cloud.tencent.com/document/api/1270/57968#RuntimeDeployedInstanceMC)

	* 新增成员：ProjectVersion

* [RuntimeMC](https://cloud.tencent.com/document/api/1270/57968#RuntimeMC)

	* 新增成员：WorkerExtensions, RuntimeType, RuntimeClass, BandwidthOutUsed, BandwidthOutLimit


### 第 4 次发布

发布时间：2022-08-16 06:23:41

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [ListRuntimeDeployedInstancesMC](https://cloud.tencent.com/document/api/1270/57964)

	* 新增入参：GroupId, Status


### 第 3 次发布

发布时间：2022-06-16 06:06:58

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [ListRuntimeDeployedInstancesMC](https://cloud.tencent.com/document/api/1270/57964)

	* 新增入参：ApiVersion


修改数据结构：

* [AbstractRuntimeMC](https://cloud.tencent.com/document/api/1270/57968#AbstractRuntimeMC)

	* 新增成员：Status, ExpiredAt

* [RuntimeMC](https://cloud.tencent.com/document/api/1270/57968#RuntimeMC)

	* 新增成员：ExpiredAt, ChargeType, ResourceLimitType, AutoRenewal


### 第 2 次发布

发布时间：2022-01-14 08:10:42

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [RuntimeDeployedInstanceMC](https://cloud.tencent.com/document/api/1270/57968#RuntimeDeployedInstanceMC)

	* 新增成员：ProjectType

* [RuntimeMC](https://cloud.tencent.com/document/api/1270/57968#RuntimeMC)

	* 新增成员：CpuUsed, CpuLimit, MemoryUsed, MemoryLimit


### 第 1 次发布

发布时间：2021-06-28 08:00:17

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [GetRuntimeMC](https://cloud.tencent.com/document/api/1270/57967)
* [GetRuntimeResourceMonitorMetricMC](https://cloud.tencent.com/document/api/1270/57966)
* [ListDeployableRuntimesMC](https://cloud.tencent.com/document/api/1270/57965)
* [ListRuntimeDeployedInstancesMC](https://cloud.tencent.com/document/api/1270/57964)
* [ListRuntimesMC](https://cloud.tencent.com/document/api/1270/57963)

新增数据结构：

* [AbstractRuntimeMC](https://cloud.tencent.com/document/api/1270/57968#AbstractRuntimeMC)
* [MetricValueMC](https://cloud.tencent.com/document/api/1270/57968#MetricValueMC)
* [RuntimeDeployedInstanceMC](https://cloud.tencent.com/document/api/1270/57968#RuntimeDeployedInstanceMC)
* [RuntimeMC](https://cloud.tencent.com/document/api/1270/57968#RuntimeMC)




## 弹性 MapReduce(emr) 版本：2019-01-03

### 第 70 次发布

发布时间：2024-08-01 01:40:41

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateCluster](https://cloud.tencent.com/document/api/589/83953)

	* 新增入参：CosBucket

* [CreateInstance](https://cloud.tencent.com/document/api/589/34261)

	* 新增入参：CosBucket


### 第 69 次发布

发布时间：2024-07-25 14:51:25

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeTrinoQueryInfo](https://cloud.tencent.com/document/api/589/109323)

修改接口：

* [InquiryPriceRenewInstance](https://cloud.tencent.com/document/api/589/38064)

	* <font color="#dd0000">**修改入参**：</font>Placement

* [InquiryPriceUpdateInstance](https://cloud.tencent.com/document/api/589/38063)

	* <font color="#dd0000">**修改入参**：</font>UpdateSpec, Placement

	* 新增出参：NewConfigPrice


新增数据结构：

* [PriceResult](https://cloud.tencent.com/document/api/589/33981#PriceResult)
* [TrinoQueryInfo](https://cloud.tencent.com/document/api/589/33981#TrinoQueryInfo)

<font color="#dd0000">**删除数据结构**：</font>

* TriggerConditions

修改数据结构：

* [LoadAutoScaleStrategy](https://cloud.tencent.com/document/api/589/33981#LoadAutoScaleStrategy)

	* <font color="#dd0000">**删除成员**：</font>LoadMetrics, MetricId, StatisticPeriod, TriggerThreshold, TriggerConditions


### 第 68 次发布

发布时间：2024-07-01 01:15:45

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [StartStopServiceOrMonitor](https://cloud.tencent.com/document/api/589/90011)

	* 新增入参：KeepMonitorButNotRecoverProcess


### 第 67 次发布

发布时间：2024-06-28 01:11:14

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [AddMetricScaleStrategy](https://cloud.tencent.com/document/api/589/103997)

	* 新增入参：LoadAutoScaleStrategy

* [DescribeAutoScaleRecords](https://cloud.tencent.com/document/api/589/100248)

	* 新增入参：RecordSource

* [DescribeAutoScaleStrategies](https://cloud.tencent.com/document/api/589/103998)

	* 新增出参：LoadAutoScaleStrategies

* [ModifyAutoScaleStrategy](https://cloud.tencent.com/document/api/589/103995)

	* 新增入参：LoadAutoScaleStrategies


新增数据结构：

* [LoadAutoScaleStrategy](https://cloud.tencent.com/document/api/589/33981#LoadAutoScaleStrategy)
* [LoadMetricsCondition](https://cloud.tencent.com/document/api/589/33981#LoadMetricsCondition)
* [LoadMetricsConditions](https://cloud.tencent.com/document/api/589/33981#LoadMetricsConditions)
* [TriggerCondition](https://cloud.tencent.com/document/api/589/33981#TriggerCondition)
* [TriggerConditions](https://cloud.tencent.com/document/api/589/33981#TriggerConditions)

修改数据结构：

* [AutoScaleRecord](https://cloud.tencent.com/document/api/589/33981#AutoScaleRecord)

	* 新增成员：RetryEnReason, RetryReason

* [AutoScaleResourceConf](https://cloud.tencent.com/document/api/589/33981#AutoScaleResourceConf)

	* 新增成员：HardwareType, PayMode, PostPayPercentMin, ChangeToPod, GroupName, YarnNodeLabel, GroupStatus, Parallel, EnableMNode


### 第 66 次发布

发布时间：2024-06-12 17:52:35

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeClusterFlowStatusDetail](https://cloud.tencent.com/document/api/589/107224)

新增数据结构：

* [FlowExtraDetail](https://cloud.tencent.com/document/api/589/33981#FlowExtraDetail)
* [FlowParam](https://cloud.tencent.com/document/api/589/33981#FlowParam)
* [FlowParamsDesc](https://cloud.tencent.com/document/api/589/33981#FlowParamsDesc)
* [StageInfoDetail](https://cloud.tencent.com/document/api/589/33981#StageInfoDetail)

修改数据结构：

* [NodeHardwareInfo](https://cloud.tencent.com/document/api/589/33981#NodeHardwareInfo)

	* 新增成员：Remark


### 第 65 次发布

发布时间：2024-06-10 01:46:51

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [ScaleOutCluster](https://cloud.tencent.com/document/api/589/83952)

	* 新增出参：TraceId

* [ScaleOutInstance](https://cloud.tencent.com/document/api/589/34264)

	* 新增出参：TraceId


### 第 64 次发布

发布时间：2024-05-17 01:39:38

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeEmrOverviewMetrics](https://cloud.tencent.com/document/api/589/106350)
* [DescribeHBaseTableOverview](https://cloud.tencent.com/document/api/589/106349)

修改接口：

* [InquiryPriceScaleOutInstance](https://cloud.tencent.com/document/api/589/34265)

	* 新增入参：ResourceBaseType, ComputeResourceId

* [ScaleOutInstance](https://cloud.tencent.com/document/api/589/34264)

	* 新增入参：ResourceBaseType, ComputeResourceId

* [TerminateInstance](https://cloud.tencent.com/document/api/589/34260)

	* 新增入参：ResourceBaseType, ComputeResourceId


新增数据结构：

* [MetricTags](https://cloud.tencent.com/document/api/589/33981#MetricTags)
* [OverviewMetricData](https://cloud.tencent.com/document/api/589/33981#OverviewMetricData)
* [OverviewRow](https://cloud.tencent.com/document/api/589/33981#OverviewRow)
* [TableSchemaItem](https://cloud.tencent.com/document/api/589/33981#TableSchemaItem)

### 第 63 次发布

发布时间：2024-05-14 01:50:50

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [ImpalaQuery](https://cloud.tencent.com/document/api/589/33981#ImpalaQuery)

	* 新增成员：BackendsCount, FragmentInstancesCount, RemainingFragmentCount


### 第 62 次发布

发布时间：2024-03-15 01:14:37

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [StartStopServiceOrMonitor](https://cloud.tencent.com/document/api/589/90011)

	* 新增入参：StopParams


新增数据结构：

* [Arg](https://cloud.tencent.com/document/api/589/33981#Arg)
* [StopParams](https://cloud.tencent.com/document/api/589/33981#StopParams)

修改数据结构：

* [StrategyConfig](https://cloud.tencent.com/document/api/589/33981#StrategyConfig)

	* 新增成员：Args


### 第 61 次发布

发布时间：2024-03-14 01:15:43

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeHiveQueries](https://cloud.tencent.com/document/api/589/94487)

	* 新增入参：State, EndTimeGte, EndTimeLte

* [DescribeImpalaQueries](https://cloud.tencent.com/document/api/589/94486)

	* 新增入参：State, EndTimeGte, EndTimeLte


### 第 60 次发布

发布时间：2024-02-28 01:16:01

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [AddMetricScaleStrategy](https://cloud.tencent.com/document/api/589/103997)
* [DeleteAutoScaleStrategy](https://cloud.tencent.com/document/api/589/103996)
* [DescribeAutoScaleGroupGlobalConf](https://cloud.tencent.com/document/api/589/103999)
* [DescribeAutoScaleStrategies](https://cloud.tencent.com/document/api/589/103998)
* [ModifyAutoScaleStrategy](https://cloud.tencent.com/document/api/589/103995)

新增数据结构：

* [AutoScaleResourceConf](https://cloud.tencent.com/document/api/589/33981#AutoScaleResourceConf)
* [DayRepeatStrategy](https://cloud.tencent.com/document/api/589/33981#DayRepeatStrategy)
* [GroupGlobalConfs](https://cloud.tencent.com/document/api/589/33981#GroupGlobalConfs)
* [MonthRepeatStrategy](https://cloud.tencent.com/document/api/589/33981#MonthRepeatStrategy)
* [NotRepeatStrategy](https://cloud.tencent.com/document/api/589/33981#NotRepeatStrategy)
* [RepeatStrategy](https://cloud.tencent.com/document/api/589/33981#RepeatStrategy)
* [TimeAutoScaleStrategy](https://cloud.tencent.com/document/api/589/33981#TimeAutoScaleStrategy)
* [WeekRepeatStrategy](https://cloud.tencent.com/document/api/589/33981#WeekRepeatStrategy)

### 第 59 次发布

发布时间：2024-02-21 01:15:23

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [ScaleOutCluster](https://cloud.tencent.com/document/api/589/83952)

	* 新增入参：ScaleOutServiceConfGroupsInfo


新增数据结构：

* [ScaleOutServiceConfGroupsInfo](https://cloud.tencent.com/document/api/589/33981#ScaleOutServiceConfGroupsInfo)

### 第 58 次发布

发布时间：2024-01-29 01:13:24

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [EmrListInstance](https://cloud.tencent.com/document/api/589/33981#EmrListInstance)

	* 新增成员：IsDedicatedCluster

	* <font color="#dd0000">**修改成员**：</font>IsSupportOutsideCluster


### 第 57 次发布

发布时间：2024-01-24 01:28:23

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [ImpalaQuery](https://cloud.tencent.com/document/api/589/33981#ImpalaQuery)

	* 新增成员：SessionId, PerNodePeakMemoryBytesSum

	* <font color="#dd0000">**修改成员**：</font>Statement, Id, StartTime, Duration, EndTime, State, RowsFetched, User, DefaultDB, Coordinator, MaxNodePeakMemoryUsage, QueryType, ScanHDFSRows, ScanKUDURows, ScanRowsTotal, TotalBytesRead, TotalBytesSent, TotalCpuTime, TotalInnerBytesSent, TotalScanBytesSent, EstimatedPerHostMemBytes, NumRowsFetchedFromCache


### 第 56 次发布

发布时间：2024-01-18 01:15:51

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeInsightList](https://cloud.tencent.com/document/api/589/103078)

新增数据结构：

* [InsightResult](https://cloud.tencent.com/document/api/589/33981#InsightResult)

### 第 55 次发布

发布时间：2023-12-25 00:10:01

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeClusterNodes](https://cloud.tencent.com/document/api/589/41707)

	* 新增入参：ExportDb


新增数据结构：

* [EmrProductConfigDetail](https://cloud.tencent.com/document/api/589/33981#EmrProductConfigDetail)
* [ResourceDetail](https://cloud.tencent.com/document/api/589/33981#ResourceDetail)

修改数据结构：

* [AutoScaleRecord](https://cloud.tencent.com/document/api/589/33981#AutoScaleRecord)

	* 新增成员：RetryCount, RetryInfo

* [ClusterInstancesInfo](https://cloud.tencent.com/document/api/589/33981#ClusterInstancesInfo)

	* 新增成员：ClusterTitle, ConfigDetail

* [ScriptBootstrapActionConfig](https://cloud.tencent.com/document/api/589/33981#ScriptBootstrapActionConfig)

	* 新增成员：Remark


### 第 54 次发布

发布时间：2023-12-19 01:39:39

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [PreExecuteFileSettings](https://cloud.tencent.com/document/api/589/33981#PreExecuteFileSettings)

	* 新增成员：Remark


### 第 53 次发布

发布时间：2023-10-16 01:15:50

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeAutoScaleRecords](https://cloud.tencent.com/document/api/589/100248)

新增数据结构：

* [AutoScaleRecord](https://cloud.tencent.com/document/api/589/33981#AutoScaleRecord)
* [KeyValue](https://cloud.tencent.com/document/api/589/33981#KeyValue)

### 第 52 次发布

发布时间：2023-10-10 01:37:17

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [ModifyUserManagerPwd](https://cloud.tencent.com/document/api/589/99696)

### 第 51 次发布

发布时间：2023-09-28 01:13:27

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [ModifyResourcesTags](https://cloud.tencent.com/document/api/589/96242)

	* 新增出参：ClusterToFlowIdList


新增数据结构：

* [ClusterIDToFlowID](https://cloud.tencent.com/document/api/589/33981#ClusterIDToFlowID)

### 第 50 次发布

发布时间：2023-08-16 01:23:36

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [ModifyResourcesTags](https://cloud.tencent.com/document/api/589/96242)

新增数据结构：

* [ModifyResourceTags](https://cloud.tencent.com/document/api/589/33981#ModifyResourceTags)

### 第 49 次发布

发布时间：2023-08-01 01:21:59

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [NodeHardwareInfo](https://cloud.tencent.com/document/api/589/33981#NodeHardwareInfo)

	* 新增成员：ServicesStatus


### 第 48 次发布

发布时间：2023-07-05 01:26:25

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeHiveQueries](https://cloud.tencent.com/document/api/589/94487)
* [DescribeImpalaQueries](https://cloud.tencent.com/document/api/589/94486)
* [DescribeYarnApplications](https://cloud.tencent.com/document/api/589/94485)

新增数据结构：

* [HiveQuery](https://cloud.tencent.com/document/api/589/33981#HiveQuery)
* [ImpalaQuery](https://cloud.tencent.com/document/api/589/33981#ImpalaQuery)
* [YarnApplication](https://cloud.tencent.com/document/api/589/33981#YarnApplication)

修改数据结构：

* [NodeHardwareInfo](https://cloud.tencent.com/document/api/589/33981#NodeHardwareInfo)

	* <font color="#dd0000">**修改成员**：</font>AppId, SerialNo, OrderNo, WanIp, Flag, Spec, CpuNum, MemSize, MemDesc, RegionId, ZoneId, ApplyTime, FreeTime, DiskSize, NameTag, Services, StorageType, RootSize, ChargeType, CdbIp, CdbPort, HwDiskSize, HwDiskSizeDesc, HwMemSize, HwMemSizeDesc, ExpireTime, EmrResourceId, IsAutoRenew, DeviceClass, Mutable, MCMultiDisk, CdbNodeInfo, Ip, Destroyable, Tags, AutoFlag, HardwareResourceType, IsDynamicSpec, DynamicPodSpec, SupportModifyPayMode, RootStorageType, Zone, SubnetInfo, Clients, CurrentTime, IsFederation, DeviceName, ServiceClient, DisableApiTermination, TradeVersion


### 第 47 次发布

发布时间：2023-06-12 01:20:35

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [StartStopServiceOrMonitor](https://cloud.tencent.com/document/api/589/90011)

	* 新增入参：StrategyConfig


新增数据结构：

* [StrategyConfig](https://cloud.tencent.com/document/api/589/33981#StrategyConfig)

### 第 46 次发布

发布时间：2023-06-01 09:50:15

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DeleteUserManagerUserList](https://cloud.tencent.com/document/api/589/83729)

	* 新增入参：TkeClusterId, DisplayStrategy, UserGroupList

	* <font color="#dd0000">**修改入参**：</font>UserNameList


新增数据结构：

* [UserAndGroup](https://cloud.tencent.com/document/api/589/33981#UserAndGroup)

### 第 45 次发布

发布时间：2023-04-10 01:29:11

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [StartStopServiceOrMonitor](https://cloud.tencent.com/document/api/589/90011)
* [TerminateClusterNodes](https://cloud.tencent.com/document/api/589/90010)

新增数据结构：

* [ComponentBasicRestartInfo](https://cloud.tencent.com/document/api/589/33981#ComponentBasicRestartInfo)
* [OpScope](https://cloud.tencent.com/document/api/589/33981#OpScope)
* [ServiceBasicRestartInfo](https://cloud.tencent.com/document/api/589/33981#ServiceBasicRestartInfo)

### 第 44 次发布

发布时间：2023-03-27 01:51:55

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [EmrListInstance](https://cloud.tencent.com/document/api/589/33981#EmrListInstance)

	* 新增成员：IsSupportOutsideCluster


### 第 43 次发布

发布时间：2023-02-14 01:26:03

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [ClusterInstancesInfo](https://cloud.tencent.com/document/api/589/33981#ClusterInstancesInfo)

	* 新增成员：IsCvmReplace


### 第 42 次发布

发布时间：2023-01-04 01:22:01

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [InquiryPriceCreateInstance](https://cloud.tencent.com/document/api/589/33980)

	* 新增出参：PriceList

* [InquiryPriceScaleOutInstance](https://cloud.tencent.com/document/api/589/34265)

	* 新增出参：MultipleEmrPrice


新增数据结构：

* [EmrPrice](https://cloud.tencent.com/document/api/589/33981#EmrPrice)
* [NodeDetailPriceResult](https://cloud.tencent.com/document/api/589/33981#NodeDetailPriceResult)
* [PartDetailPriceItem](https://cloud.tencent.com/document/api/589/33981#PartDetailPriceItem)
* [SoftDependInfo](https://cloud.tencent.com/document/api/589/33981#SoftDependInfo)
* [ZoneDetailPriceResult](https://cloud.tencent.com/document/api/589/33981#ZoneDetailPriceResult)

修改数据结构：

* [EmrListInstance](https://cloud.tencent.com/document/api/589/33981#EmrListInstance)

	* 新增成员：OutSideSoftInfo

* [NodeHardwareInfo](https://cloud.tencent.com/document/api/589/33981#NodeHardwareInfo)

	* <font color="#dd0000">**修改成员**：</font>AppId, SerialNo, OrderNo, WanIp, Flag, Spec, CpuNum, MemSize, MemDesc, RegionId, ZoneId, ApplyTime, FreeTime, DiskSize, NameTag, Services, StorageType, RootSize, ChargeType, CdbIp, CdbPort, HwDiskSize, HwDiskSizeDesc, HwMemSize, HwMemSizeDesc, ExpireTime, EmrResourceId, IsAutoRenew, DeviceClass, Mutable, MCMultiDisk, CdbNodeInfo, Ip, Destroyable, Tags, AutoFlag, HardwareResourceType, IsDynamicSpec, DynamicPodSpec, SupportModifyPayMode, RootStorageType, Zone, SubnetInfo, Clients, CurrentTime, IsFederation, DeviceName, ServiceClient, DisableApiTermination, TradeVersion


### 第 41 次发布

发布时间：2022-12-13 10:29:37

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateCluster](https://cloud.tencent.com/document/api/589/83953)
* [ScaleOutCluster](https://cloud.tencent.com/document/api/589/83952)

新增数据结构：

* [AllNodeResourceSpec](https://cloud.tencent.com/document/api/589/33981#AllNodeResourceSpec)
* [CustomMetaDBInfo](https://cloud.tencent.com/document/api/589/33981#CustomMetaDBInfo)
* [DependService](https://cloud.tencent.com/document/api/589/33981#DependService)
* [DiskSpecInfo](https://cloud.tencent.com/document/api/589/33981#DiskSpecInfo)
* [NodeResourceSpec](https://cloud.tencent.com/document/api/589/33981#NodeResourceSpec)
* [PodNewParameter](https://cloud.tencent.com/document/api/589/33981#PodNewParameter)
* [PodNewSpec](https://cloud.tencent.com/document/api/589/33981#PodNewSpec)
* [PodSpecInfo](https://cloud.tencent.com/document/api/589/33981#PodSpecInfo)
* [ScaleOutNodeConfig](https://cloud.tencent.com/document/api/589/33981#ScaleOutNodeConfig)
* [SceneSoftwareConfig](https://cloud.tencent.com/document/api/589/33981#SceneSoftwareConfig)
* [ScriptBootstrapActionConfig](https://cloud.tencent.com/document/api/589/33981#ScriptBootstrapActionConfig)
* [VirtualPrivateCloud](https://cloud.tencent.com/document/api/589/33981#VirtualPrivateCloud)
* [ZoneResourceConfiguration](https://cloud.tencent.com/document/api/589/33981#ZoneResourceConfiguration)

### 第 40 次发布

发布时间：2022-12-07 06:38:34

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DeleteUserManagerUserList](https://cloud.tencent.com/document/api/589/83729)

### 第 39 次发布

发布时间：2022-11-24 06:31:27

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [InquiryPriceUpdateInstance](https://cloud.tencent.com/document/api/589/38063)

	* 新增入参：ResourceIdList

	* 新增出参：PriceDetail

* [ModifyResourceScheduleConfig](https://cloud.tencent.com/document/api/589/73096)

	* 新增出参：Data


新增数据结构：

* [PriceDetail](https://cloud.tencent.com/document/api/589/33981#PriceDetail)

修改数据结构：

* [NodeHardwareInfo](https://cloud.tencent.com/document/api/589/33981#NodeHardwareInfo)

	* 新增成员：DisableApiTermination, TradeVersion

* [Placement](https://cloud.tencent.com/document/api/589/33981#Placement)

	* <font color="#dd0000">**修改成员**：</font>ProjectId


### 第 38 次发布

发布时间：2022-10-27 06:31:19

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [ScaleOutInstance](https://cloud.tencent.com/document/api/589/34264)

	* 新增入参：AutoRenew


修改数据结构：

* [EmrListInstance](https://cloud.tencent.com/document/api/589/33981#EmrListInstance)

	* 新增成员：IsHandsCluster


### 第 37 次发布

发布时间：2022-09-06 06:30:34

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeClusterNodes](https://cloud.tencent.com/document/api/589/41707)

	* 新增入参：OrderField, Asc


修改数据结构：

* [JobResult](https://cloud.tencent.com/document/api/589/33981#JobResult)

	* 新增成员：ApplicationId

* [NodeHardwareInfo](https://cloud.tencent.com/document/api/589/33981#NodeHardwareInfo)

	* 新增成员：CurrentTime, IsFederation, DeviceName, ServiceClient


### 第 36 次发布

发布时间：2022-07-21 06:09:30

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeEmrApplicationStatics](https://cloud.tencent.com/document/api/589/77586)

新增数据结构：

* [ApplicationStatics](https://cloud.tencent.com/document/api/589/33981#ApplicationStatics)

### 第 35 次发布

发布时间：2022-07-14 06:10:00

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [ScaleOutInstance](https://cloud.tencent.com/document/api/589/34264)

	* 新增入参：ScaleOutServiceConfAssign


### 第 34 次发布

发布时间：2022-06-09 06:11:36

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [UserManagerFilter](https://cloud.tencent.com/document/api/589/33981#UserManagerFilter)

	* 新增成员：UserName


### 第 33 次发布

发布时间：2022-06-08 06:09:23

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [AddUsersForUserManager](https://cloud.tencent.com/document/api/589/74069)

	* 新增入参：InstanceId

	* 新增出参：SuccessUserList, FailedUserList

* [DescribeUsersForUserManager](https://cloud.tencent.com/document/api/589/74225)

	* 新增入参：InstanceId, PageNo, PageSize, UserManagerFilter

	* 新增出参：TotalCnt, UserManagerUserList


新增数据结构：

* [UserManagerFilter](https://cloud.tencent.com/document/api/589/33981#UserManagerFilter)
* [UserManagerUserBriefInfo](https://cloud.tencent.com/document/api/589/33981#UserManagerUserBriefInfo)

### 第 32 次发布

发布时间：2022-05-23 06:08:01

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeUsersForUserManager](https://cloud.tencent.com/document/api/589/74225)

### 第 31 次发布

发布时间：2022-05-20 06:11:47

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [AddUsersForUserManager](https://cloud.tencent.com/document/api/589/74069)
* [DescribeInstancesList](https://cloud.tencent.com/document/api/589/74070)

新增数据结构：

* [EmrListInstance](https://cloud.tencent.com/document/api/589/33981#EmrListInstance)
* [Filters](https://cloud.tencent.com/document/api/589/33981#Filters)
* [UserInfoForUserManager](https://cloud.tencent.com/document/api/589/33981#UserInfoForUserManager)

### 第 30 次发布

发布时间：2022-05-13 06:12:03

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateInstance](https://cloud.tencent.com/document/api/589/34261)

	* 新增入参：VersionID, MultiZone, MultiZoneSettings

	* <font color="#dd0000">**修改入参**：</font>VPCSettings, ResourceSpec, Placement

* [InquiryPriceCreateInstance](https://cloud.tencent.com/document/api/589/33980)

	* 新增入参：VersionID, MultiZoneSettings

	* <font color="#dd0000">**修改入参**：</font>ResourceSpec, Placement, VPCSettings

* [ScaleOutInstance](https://cloud.tencent.com/document/api/589/34264)

	* 新增入参：ZoneId, SubnetId


新增数据结构：

* [MultiZoneSetting](https://cloud.tencent.com/document/api/589/33981#MultiZoneSetting)
* [ShortNodeInfo](https://cloud.tencent.com/document/api/589/33981#ShortNodeInfo)
* [SubnetInfo](https://cloud.tencent.com/document/api/589/33981#SubnetInfo)
* [TopologyInfo](https://cloud.tencent.com/document/api/589/33981#TopologyInfo)

修改数据结构：

* [ClusterInstancesInfo](https://cloud.tencent.com/document/api/589/33981#ClusterInstancesInfo)

	* 新增成员：UniqVpcId, UniqSubnetId, TopologyInfoList, IsMultiZoneCluster

* [NodeHardwareInfo](https://cloud.tencent.com/document/api/589/33981#NodeHardwareInfo)

	* 新增成员：RootStorageType, Zone, SubnetInfo, Clients

* [PodSpec](https://cloud.tencent.com/document/api/589/33981#PodSpec)

	* 新增成员：PodName


### 第 29 次发布

发布时间：2022-04-28 06:12:20

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [ModifyResourceScheduler](https://cloud.tencent.com/document/api/589/73140)

### 第 28 次发布

发布时间：2022-04-26 06:10:23

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeResourceSchedule](https://cloud.tencent.com/document/api/589/73098)
* [ModifyResourcePools](https://cloud.tencent.com/document/api/589/73097)
* [ModifyResourceScheduleConfig](https://cloud.tencent.com/document/api/589/73096)

### 第 27 次发布

发布时间：2022-03-03 08:06:04

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateInstance](https://cloud.tencent.com/document/api/589/34261)

	* 新增入参：ExternalService


新增数据结构：

* [ClusterExternalServiceInfo](https://cloud.tencent.com/document/api/589/33981#ClusterExternalServiceInfo)

修改数据结构：

* [ClusterInstancesInfo](https://cloud.tencent.com/document/api/589/33981#ClusterInstancesInfo)

	* 新增成员：ClusterExternalServiceInfo

* [EmrProductConfigOutter](https://cloud.tencent.com/document/api/589/33981#EmrProductConfigOutter)

	* 新增成员：PublicKeyId


### 第 26 次发布

发布时间：2022-01-17 08:08:00

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [InquiryPriceCreateInstance](https://cloud.tencent.com/document/api/589/33980)

	* 新增入参：ExternalService


新增数据结构：

* [CustomServiceDefine](https://cloud.tencent.com/document/api/589/33981#CustomServiceDefine)
* [ExternalService](https://cloud.tencent.com/document/api/589/33981#ExternalService)

### 第 25 次发布

发布时间：2021-12-10 08:06:20

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateInstance](https://cloud.tencent.com/document/api/589/34261)

	* 新增入参：SceneName

* [InquiryPriceCreateInstance](https://cloud.tencent.com/document/api/589/33980)

	* 新增入参：SceneName


### 第 24 次发布

发布时间：2021-12-08 08:10:26

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [ClusterInstancesInfo](https://cloud.tencent.com/document/api/589/33981#ClusterInstancesInfo)

	* 新增成员：SceneName, SceneServiceClass, SceneEmrVersion, DisplayName, VpcName, SubnetName


### 第 23 次发布

发布时间：2021-08-04 08:05:32

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeCvmQuota](https://cloud.tencent.com/document/api/589/59472)
* [SyncPodState](https://cloud.tencent.com/document/api/589/59471)

新增数据结构：

* [PodSaleSpec](https://cloud.tencent.com/document/api/589/33981#PodSaleSpec)
* [PodState](https://cloud.tencent.com/document/api/589/33981#PodState)
* [QuotaEntity](https://cloud.tencent.com/document/api/589/33981#QuotaEntity)

### 第 22 次发布

发布时间：2021-07-16 08:05:52

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateInstance](https://cloud.tencent.com/document/api/589/34261)

	* 新增出参：InstanceId

* [InquiryPriceRenewInstance](https://cloud.tencent.com/document/api/589/38064)

	* 新增入参：ModifyPayMode

* [ScaleOutInstance](https://cloud.tencent.com/document/api/589/34264)

	* 新增入参：StartServiceAfterScaleOut


修改数据结构：

* [NodeHardwareInfo](https://cloud.tencent.com/document/api/589/33981#NodeHardwareInfo)

	* 新增成员：SupportModifyPayMode

* [PodSpec](https://cloud.tencent.com/document/api/589/33981#PodSpec)

	* 新增成员：VpcId, SubnetId


### 第 21 次发布

发布时间：2021-06-28 08:05:21

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [ClusterInstancesInfo](https://cloud.tencent.com/document/api/589/33981#ClusterInstancesInfo)

	* 新增成员：Zone

* [EmrProductConfigOutter](https://cloud.tencent.com/document/api/589/33981#EmrProductConfigOutter)

	* 新增成员：ApplicationRole, SecurityGroups


### 第 20 次发布

发布时间：2021-05-10 08:04:43

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [InquiryPriceScaleOutInstance](https://cloud.tencent.com/document/api/589/34265)

	* 新增入参：MasterCount


### 第 19 次发布

发布时间：2021-04-02 08:04:37

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [NodeHardwareInfo](https://cloud.tencent.com/document/api/589/33981#NodeHardwareInfo)

	* 新增成员：IsDynamicSpec, DynamicPodSpec


### 第 18 次发布

发布时间：2021-04-01 08:04:35

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [ScaleOutInstance](https://cloud.tencent.com/document/api/589/34264)

	* 新增入参：PodParameter, MasterCount


新增数据结构：

* [DynamicPodSpec](https://cloud.tencent.com/document/api/589/33981#DynamicPodSpec)
* [PodParameter](https://cloud.tencent.com/document/api/589/33981#PodParameter)

修改数据结构：

* [PodSpec](https://cloud.tencent.com/document/api/589/33981#PodSpec)

	* 新增成员：IsDynamicSpec, DynamicPodSpec


### 第 17 次发布

发布时间：2021-03-17 08:05:12

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeInstanceRenewNodes](https://cloud.tencent.com/document/api/589/53702)
* [InquirePriceRenewEmr](https://cloud.tencent.com/document/api/589/53701)

新增数据结构：

* [RenewInstancesInfo](https://cloud.tencent.com/document/api/589/33981#RenewInstancesInfo)

### 第 16 次发布

发布时间：2020-12-16 08:04:29

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeJobFlow](https://cloud.tencent.com/document/api/589/51012)
* [RunJobFlow](https://cloud.tencent.com/document/api/589/51011)

新增数据结构：

* [BootstrapAction](https://cloud.tencent.com/document/api/589/33981#BootstrapAction)
* [ClusterSetting](https://cloud.tencent.com/document/api/589/33981#ClusterSetting)
* [Configuration](https://cloud.tencent.com/document/api/589/33981#Configuration)
* [DiskGroup](https://cloud.tencent.com/document/api/589/33981#DiskGroup)
* [DiskSpec](https://cloud.tencent.com/document/api/589/33981#DiskSpec)
* [Execution](https://cloud.tencent.com/document/api/589/33981#Execution)
* [InstanceChargePrepaid](https://cloud.tencent.com/document/api/589/33981#InstanceChargePrepaid)
* [JobFlowResource](https://cloud.tencent.com/document/api/589/33981#JobFlowResource)
* [JobFlowResourceSpec](https://cloud.tencent.com/document/api/589/33981#JobFlowResourceSpec)
* [JobResult](https://cloud.tencent.com/document/api/589/33981#JobResult)
* [MetaDbInfo](https://cloud.tencent.com/document/api/589/33981#MetaDbInfo)
* [Step](https://cloud.tencent.com/document/api/589/33981#Step)

### 第 15 次发布

发布时间：2020-10-23 08:04:56

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateInstance](https://cloud.tencent.com/document/api/589/34261)

	* 新增入参：ApplicationRole


### 第 14 次发布

发布时间：2020-09-21 08:03:23

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [ScaleOutInstance](https://cloud.tencent.com/document/api/589/34264)

	* 新增入参：ClickHouseClusterName, ClickHouseClusterType, YarnNodeLabel


修改数据结构：

* [PersistentVolumeContext](https://cloud.tencent.com/document/api/589/33981#PersistentVolumeContext)

	* 新增成员：DiskNum


### 第 13 次发布

发布时间：2020-08-19 08:11:03

本次发布包含了以下内容：

改善已有的文档。

新增数据结构：

* [HostVolumeContext](https://cloud.tencent.com/document/api/589/33981#HostVolumeContext)
* [PersistentVolumeContext](https://cloud.tencent.com/document/api/589/33981#PersistentVolumeContext)
* [PodVolume](https://cloud.tencent.com/document/api/589/33981#PodVolume)

修改数据结构：

* [PodSpec](https://cloud.tencent.com/document/api/589/33981#PodSpec)

	* 新增成员：CpuType, PodVolumes

	* <font color="#dd0000">**修改成员**：</font>DataVolumes


### 第 12 次发布

发布时间：2020-07-16 08:10:49

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeClusterNodes](https://cloud.tencent.com/document/api/589/41707)

	* 新增入参：HardwareResourceType, SearchFields

	* 新增出参：HardwareResourceTypeList

* [ScaleOutInstance](https://cloud.tencent.com/document/api/589/34264)

	* 新增入参：HardwareResourceType, PodSpec


新增数据结构：

* [PodSpec](https://cloud.tencent.com/document/api/589/33981#PodSpec)
* [SearchItem](https://cloud.tencent.com/document/api/589/33981#SearchItem)

修改数据结构：

* [NodeHardwareInfo](https://cloud.tencent.com/document/api/589/33981#NodeHardwareInfo)

	* 新增成员：HardwareResourceType


### 第 11 次发布

发布时间：2020-04-23 08:09:03

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [ClusterInstancesInfo](https://cloud.tencent.com/document/api/589/33981#ClusterInstancesInfo)

	* 新增成员：ProductId


### 第 10 次发布

发布时间：2020-04-02 08:08:50

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [ClusterInstancesInfo](https://cloud.tencent.com/document/api/589/33981#ClusterInstancesInfo)

	* 新增成员：AliasInfo


### 第 9 次发布

发布时间：2020-03-16 08:09:17

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [ClusterInstancesInfo](https://cloud.tencent.com/document/api/589/33981#ClusterInstancesInfo)

	* 新增成员：ServiceClass

* [NodeHardwareInfo](https://cloud.tencent.com/document/api/589/33981#NodeHardwareInfo)

	* 新增成员：AutoFlag

* [PriceResource](https://cloud.tencent.com/document/api/589/33981#PriceResource)

	* 新增成员：DiskNum, LocalDiskNum


### 第 8 次发布

发布时间：2020-02-28 19:34:32

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeClusterNodes](https://cloud.tencent.com/document/api/589/41707)

新增数据结构：

* [CdbInfo](https://cloud.tencent.com/document/api/589/33981#CdbInfo)
* [MultiDiskMC](https://cloud.tencent.com/document/api/589/33981#MultiDiskMC)
* [NodeHardwareInfo](https://cloud.tencent.com/document/api/589/33981#NodeHardwareInfo)

### 第 7 次发布

发布时间：2020-02-21 16:04:57

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateInstance](https://cloud.tencent.com/document/api/589/34261)

	* 新增入参：CbsEncrypt, MetaType, UnifyMetaInstanceId, MetaDBInfo

* [InquiryPriceCreateInstance](https://cloud.tencent.com/document/api/589/33980)

	* 新增入参：MetaType, UnifyMetaInstanceId, MetaDBInfo, ProductId


新增数据结构：

* [CustomMetaInfo](https://cloud.tencent.com/document/api/589/33981#CustomMetaInfo)

### 第 6 次发布

发布时间：2020-02-21 09:42:59

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateInstance](https://cloud.tencent.com/document/api/589/34261)

	* 新增入参：Tags, DisasterRecoverGroupIds

* [DescribeInstances](https://cloud.tencent.com/document/api/589/34266)

	* 新增出参：TagKeys

* [InquiryPriceScaleOutInstance](https://cloud.tencent.com/document/api/589/34265)

	* 新增入参：RouterCount

* [ScaleOutInstance](https://cloud.tencent.com/document/api/589/34264)

	* 新增入参：RouterCount, SoftDeployInfo, ServiceNodeInfo, DisasterRecoverGroupIds, Tags

	* 新增出参：FlowId, BillId


新增数据结构：

* [Tag](https://cloud.tencent.com/document/api/589/33981#Tag)

修改数据结构：

* [ClusterInstancesInfo](https://cloud.tencent.com/document/api/589/33981#ClusterInstancesInfo)

	* 新增成员：IsWoodpeckerCluster, MetaDb, Tags, HiveMetaDb

* [EmrProductConfigOutter](https://cloud.tencent.com/document/api/589/33981#EmrProductConfigOutter)

	* 新增成员：RouterNodeSize, SupportHA, SecurityOn, SecurityGroup, CbsEncrypt

* [OutterResource](https://cloud.tencent.com/document/api/589/33981#OutterResource)

	* 新增成员：InstanceType

* [PriceResource](https://cloud.tencent.com/document/api/589/33981#PriceResource)

	* 新增成员：InstanceType, Tags

* [Resource](https://cloud.tencent.com/document/api/589/33981#Resource)

	* 新增成员：Tags, InstanceType, LocalDiskNum, DiskNum

* [UpdateInstanceSettings](https://cloud.tencent.com/document/api/589/33981#UpdateInstanceSettings)

	* 新增成员：InstanceType


### 第 5 次发布

发布时间：2019-09-19 14:52:04

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [InquiryPriceRenewInstance](https://cloud.tencent.com/document/api/589/38064)
* [InquiryPriceUpdateInstance](https://cloud.tencent.com/document/api/589/38063)

修改接口：

* [CreateInstance](https://cloud.tencent.com/document/api/589/34261)

	* 新增入参：CheckSecurity, ExtendFsField

	* <font color="#dd0000">**修改入参**：</font>ResourceSpec, ClientToken

	* <font color="#dd0000">**删除出参**：</font>Result

* [DescribeInstances](https://cloud.tencent.com/document/api/589/34266)

	* 新增入参：DisplayStrategy, ProjectId, OrderField, Asc

	* 新增出参：TotalCnt, ClusterList

	* <font color="#dd0000">**删除出参**：</font>Result

* [InquiryPriceCreateInstance](https://cloud.tencent.com/document/api/589/33980)

	* <font color="#dd0000">**修改入参**：</font>ResourceSpec

	* 新增出参：OriginalCost, DiscountCost, TimeUnit, TimeSpan

	* <font color="#dd0000">**删除出参**：</font>Result

* [InquiryPriceScaleOutInstance](https://cloud.tencent.com/document/api/589/34265)

	* 新增出参：OriginalCost, DiscountCost, Unit, PriceSpec

	* <font color="#dd0000">**删除出参**：</font>Result

* [ScaleOutInstance](https://cloud.tencent.com/document/api/589/34264)

	* 新增入参：UnNecessaryNodeList

	* <font color="#dd0000">**修改入参**：</font>ClientToken

	* 新增出参：InstanceId, DealNames, ClientToken

	* <font color="#dd0000">**删除出参**：</font>Result

* [TerminateInstance](https://cloud.tencent.com/document/api/589/34260)

	* 新增入参：ResourceIds

	* <font color="#dd0000">**删除出参**：</font>Result

* [TerminateTasks](https://cloud.tencent.com/document/api/589/34263)

	* <font color="#dd0000">**删除出参**：</font>Result


新增数据结构：

* [ClusterInstancesInfo](https://cloud.tencent.com/document/api/589/33981#ClusterInstancesInfo)
* [EmrProductConfigOutter](https://cloud.tencent.com/document/api/589/33981#EmrProductConfigOutter)
* [NewResourceSpec](https://cloud.tencent.com/document/api/589/33981#NewResourceSpec)
* [OutterResource](https://cloud.tencent.com/document/api/589/33981#OutterResource)
* [PriceResource](https://cloud.tencent.com/document/api/589/33981#PriceResource)
* [Resource](https://cloud.tencent.com/document/api/589/33981#Resource)
* [UpdateInstanceSettings](https://cloud.tencent.com/document/api/589/33981#UpdateInstanceSettings)

<font color="#dd0000">**删除数据结构**：</font>

* ClusterInfoResult
* ClusterInstanceInfo
* CreateInstanceResult
* EMRProductConfigSettings
* InquiryPriceResult
* NodeSpec
* ResourceSpec
* ScaleOutInstanceResult
* TerminateResult

修改数据结构：

* [COSSettings](https://cloud.tencent.com/document/api/589/33981#COSSettings)

	* <font color="#dd0000">**修改成员**：</font>LogOnCosPath

* [Placement](https://cloud.tencent.com/document/api/589/33981#Placement)

	* <font color="#dd0000">**修改成员**：</font>ProjectId


### 第 4 次发布

发布时间：2019-08-09 13:06:05

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateInstance](https://cloud.tencent.com/document/api/589/34261)

	* 新增入参：RemoteLoginAtCreate

	* <font color="#dd0000">**修改入参**：</font>PreExecutedFileSettings

* [ScaleOutInstance](https://cloud.tencent.com/document/api/589/34264)

	* <font color="#dd0000">**修改入参**：</font>PreExecutedFileSettings


修改数据结构：

* [MultiDisk](https://cloud.tencent.com/document/api/589/33981#MultiDisk)

	* 新增成员：Count

	* <font color="#dd0000">**修改成员**：</font>DiskType, Volume

* [PreExecuteFileSettings](https://cloud.tencent.com/document/api/589/33981#PreExecuteFileSettings)

	* 新增成员：RunOrder, WhenRun, CosFileName, CosFileURI, CosSecretId, CosSecretKey, AppId

	* <font color="#dd0000">**修改成员**：</font>Path, Args, Bucket, Region, Domain


### 第 3 次发布

发布时间：2019-05-16 16:14:48

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateInstance](https://cloud.tencent.com/document/api/589/34261)

	* 新增入参：NeedMasterWan


新增数据结构：

* [MultiDisk](https://cloud.tencent.com/document/api/589/33981#MultiDisk)

修改数据结构：

* [NodeSpec](https://cloud.tencent.com/document/api/589/33981#NodeSpec)

	* 新增成员：MultiDisks


### 第 2 次发布

发布时间：2019-04-12 12:08:42

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateInstance](https://cloud.tencent.com/document/api/589/34261)
* [DescribeInstances](https://cloud.tencent.com/document/api/589/34266)
* [InquiryPriceScaleOutInstance](https://cloud.tencent.com/document/api/589/34265)
* [ScaleOutInstance](https://cloud.tencent.com/document/api/589/34264)
* [TerminateInstance](https://cloud.tencent.com/document/api/589/34260)
* [TerminateTasks](https://cloud.tencent.com/document/api/589/34263)

新增数据结构：

* [COSSettings](https://cloud.tencent.com/document/api/589/33981#COSSettings)
* [ClusterInfoResult](https://cloud.tencent.com/document/api/589/33981#ClusterInfoResult)
* [ClusterInstanceInfo](https://cloud.tencent.com/document/api/589/33981#ClusterInstanceInfo)
* [CreateInstanceResult](https://cloud.tencent.com/document/api/589/33981#CreateInstanceResult)
* [EMRProductConfigSettings](https://cloud.tencent.com/document/api/589/33981#EMRProductConfigSettings)
* [LoginSettings](https://cloud.tencent.com/document/api/589/33981#LoginSettings)
* [PreExecuteFileSettings](https://cloud.tencent.com/document/api/589/33981#PreExecuteFileSettings)
* [ScaleOutInstanceResult](https://cloud.tencent.com/document/api/589/33981#ScaleOutInstanceResult)
* [TerminateResult](https://cloud.tencent.com/document/api/589/33981#TerminateResult)

### 第 1 次发布

发布时间：2019-03-28 20:22:49

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [InquiryPriceCreateInstance](https://cloud.tencent.com/document/api/589/33980)

新增数据结构：

* [InquiryPriceResult](https://cloud.tencent.com/document/api/589/33981#InquiryPriceResult)
* [NodeSpec](https://cloud.tencent.com/document/api/589/33981#NodeSpec)
* [Placement](https://cloud.tencent.com/document/api/589/33981#Placement)
* [ResourceSpec](https://cloud.tencent.com/document/api/589/33981#ResourceSpec)
* [VPCSettings](https://cloud.tencent.com/document/api/589/33981#VPCSettings)




## Elasticsearch Service(es) 版本：2018-04-16

### 第 63 次发布

发布时间：2024-07-22 01:39:08

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [RestartNodes](https://cloud.tencent.com/document/api/845/48473)

	* 新增入参：ShardAllocationConcurrents, ShardAllocationBytes

* [UpgradeInstance](https://cloud.tencent.com/document/api/845/36270)

	* 新增入参：ShardAllocationConcurrents, ShardAllocationBytes


### 第 62 次发布

发布时间：2024-07-17 01:15:53

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [UpdateInstance](https://cloud.tencent.com/document/api/845/30629)

	* 新增入参：ShardAllocationConcurrents, ShardAllocationBytes


### 第 61 次发布

发布时间：2024-07-09 01:14:44

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [ServerlessIndexOptionsField](https://cloud.tencent.com/document/api/845/30634#ServerlessIndexOptionsField)

	* 新增成员：SinkCycleAge


### 第 60 次发布

发布时间：2024-07-05 18:47:21

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeServerlessMetrics](https://cloud.tencent.com/document/api/845/108288)

修改接口：

* [CreateInstance](https://cloud.tencent.com/document/api/845/30633)

	* 新增入参：DisasterRecoverGroupAffinity


修改数据结构：

* [InstanceInfo](https://cloud.tencent.com/document/api/845/30634#InstanceInfo)

	* 新增成员：DisasterRecoverGroupAffinity


### 第 59 次发布

发布时间：2024-06-14 01:50:54

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [ServerlessSpace](https://cloud.tencent.com/document/api/845/30634#ServerlessSpace)

	* 新增成员：ClusterType


### 第 58 次发布

发布时间：2024-05-14 01:51:30

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [ServerlessSpace](https://cloud.tencent.com/document/api/845/30634#ServerlessSpace)

	* 新增成员：KibanaLanguage


### 第 57 次发布

发布时间：2024-04-19 01:17:21

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeServerlessInstances](https://cloud.tencent.com/document/api/845/105352)

新增数据结构：

* [ServerlessIndexMetaField](https://cloud.tencent.com/document/api/845/30634#ServerlessIndexMetaField)
* [ServerlessIndexNetworkField](https://cloud.tencent.com/document/api/845/30634#ServerlessIndexNetworkField)
* [ServerlessIndexOptionsField](https://cloud.tencent.com/document/api/845/30634#ServerlessIndexOptionsField)
* [ServerlessIndexSettingsField](https://cloud.tencent.com/document/api/845/30634#ServerlessIndexSettingsField)

### 第 56 次发布

发布时间：2024-04-11 16:23:06

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateServerlessInstance](https://cloud.tencent.com/document/api/845/104318)

	* <font color="#dd0000">**修改入参**：</font>Zone, VpcId, SubnetId


### 第 55 次发布

发布时间：2024-03-28 10:47:55

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateIndex](https://cloud.tencent.com/document/api/845/74384)

	* <font color="#dd0000">**修改入参**：</font>IndexMetaJson

* [RestartNodes](https://cloud.tencent.com/document/api/845/48473)

	* 新增入参：CvmDelayOnlineTime

* [UpdateInstance](https://cloud.tencent.com/document/api/845/30629)

	* 新增入参：OutboundPublicAcls, OutboundPublicAccess, CvmDelayOnlineTime

* [UpgradeInstance](https://cloud.tencent.com/document/api/845/36270)

	* 新增入参：CvmDelayOnlineTime


新增数据结构：

* [OutboundPublicAcl](https://cloud.tencent.com/document/api/845/30634#OutboundPublicAcl)

修改数据结构：

* [InstanceInfo](https://cloud.tencent.com/document/api/845/30634#InstanceInfo)

	* 新增成员：OutboundPublicAcls, NetConnectScheme

* [NodeView](https://cloud.tencent.com/document/api/845/30634#NodeView)

	* 新增成员：CVMStatus

	* <font color="#dd0000">**修改成员**：</font>IsCoordinationNode


### 第 54 次发布

发布时间：2024-03-14 01:15:53

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CheckMigrateIndexMetaData](https://cloud.tencent.com/document/api/845/104323)
* [CreateCosMigrateToServerlessInstance](https://cloud.tencent.com/document/api/845/104322)
* [DescribeUserCosSnapshotList](https://cloud.tencent.com/document/api/845/104321)

新增数据结构：

* [CommonIndexInfo](https://cloud.tencent.com/document/api/845/30634#CommonIndexInfo)
* [CosSnapShotInfo](https://cloud.tencent.com/document/api/845/30634#CosSnapShotInfo)
* [DataStreamInfo](https://cloud.tencent.com/document/api/845/30634#DataStreamInfo)

### 第 53 次发布

发布时间：2024-03-13 16:49:04

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateServerlessInstance](https://cloud.tencent.com/document/api/845/104318)
* [CreateServerlessSpaceV2](https://cloud.tencent.com/document/api/845/104317)
* [DeleteServerlessInstance](https://cloud.tencent.com/document/api/845/104316)
* [DeleteServerlessSpaceUser](https://cloud.tencent.com/document/api/845/104315)
* [DescribeServerlessSpaceUser](https://cloud.tencent.com/document/api/845/104314)
* [DescribeServerlessSpaces](https://cloud.tencent.com/document/api/845/104313)
* [UpdateServerlessInstance](https://cloud.tencent.com/document/api/845/104312)
* [UpdateServerlessSpace](https://cloud.tencent.com/document/api/845/104311)

新增数据结构：

* [DiData](https://cloud.tencent.com/document/api/845/30634#DiData)
* [DiDataSinkServerless](https://cloud.tencent.com/document/api/845/30634#DiDataSinkServerless)
* [DiDataSourceCvm](https://cloud.tencent.com/document/api/845/30634#DiDataSourceCvm)
* [DiDataSourceCvmInstance](https://cloud.tencent.com/document/api/845/30634#DiDataSourceCvmInstance)
* [DiDataSourceTke](https://cloud.tencent.com/document/api/845/30634#DiDataSourceTke)
* [DiSourceCvm](https://cloud.tencent.com/document/api/845/30634#DiSourceCvm)
* [DiSourceTke](https://cloud.tencent.com/document/api/845/30634#DiSourceTke)
* [DiSourceTkePodLabel](https://cloud.tencent.com/document/api/845/30634#DiSourceTkePodLabel)
* [KibanaPublicAcl](https://cloud.tencent.com/document/api/845/30634#KibanaPublicAcl)
* [ServerlessDi](https://cloud.tencent.com/document/api/845/30634#ServerlessDi)
* [ServerlessSpace](https://cloud.tencent.com/document/api/845/30634#ServerlessSpace)
* [ServerlessSpaceUser](https://cloud.tencent.com/document/api/845/30634#ServerlessSpaceUser)
* [VpcInfo](https://cloud.tencent.com/document/api/845/30634#VpcInfo)

### 第 52 次发布

发布时间：2024-01-25 01:13:20

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [UpdateInstance](https://cloud.tencent.com/document/api/845/30629)

	* 新增入参：Protocol


### 第 51 次发布

发布时间：2023-12-05 01:46:13

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [InquirePriceRenewInstance](https://cloud.tencent.com/document/api/845/102193)

### 第 50 次发布

发布时间：2023-11-23 01:18:36

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [RestartInstance](https://cloud.tencent.com/document/api/845/30630)

	* 新增入参：UpgradeKernel

* [UpdateInstance](https://cloud.tencent.com/document/api/845/30629)

	* 新增入参：KibanaPrivateDomain, CerebroPrivateDomain


修改数据结构：

* [InstanceInfo](https://cloud.tencent.com/document/api/845/30634#InstanceInfo)

	* 新增成员：KibanaPrivateVip, CustomKibanaPrivateUrl

* [OptionalWebServiceInfo](https://cloud.tencent.com/document/api/845/30634#OptionalWebServiceInfo)

	* 新增成员：PrivateVip, CustomPrivateUrl


### 第 49 次发布

发布时间：2023-10-30 00:42:05

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeDiagnose](https://cloud.tencent.com/document/api/845/100954)
* [DescribeInstancePluginList](https://cloud.tencent.com/document/api/845/100953)
* [GetDiagnoseSettings](https://cloud.tencent.com/document/api/845/100952)

新增数据结构：

* [DescribeInstancePluginInfo](https://cloud.tencent.com/document/api/845/30634#DescribeInstancePluginInfo)
* [DiagnoseJobMeta](https://cloud.tencent.com/document/api/845/30634#DiagnoseJobMeta)
* [DiagnoseJobResult](https://cloud.tencent.com/document/api/845/30634#DiagnoseJobResult)
* [DiagnoseResult](https://cloud.tencent.com/document/api/845/30634#DiagnoseResult)
* [Dimension](https://cloud.tencent.com/document/api/845/30634#Dimension)
* [JobParam](https://cloud.tencent.com/document/api/845/30634#JobParam)
* [LogDetail](https://cloud.tencent.com/document/api/845/30634#LogDetail)
* [Metric](https://cloud.tencent.com/document/api/845/30634#Metric)
* [MetricDetail](https://cloud.tencent.com/document/api/845/30634#MetricDetail)
* [SettingDetail](https://cloud.tencent.com/document/api/845/30634#SettingDetail)

### 第 48 次发布

发布时间：2023-10-12 01:57:01

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [NodeView](https://cloud.tencent.com/document/api/845/30634#NodeView)

	* 新增成员：IsCoordinationNode


### 第 47 次发布

发布时间：2023-10-09 01:15:32

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [IndexMetaField](https://cloud.tencent.com/document/api/845/30634#IndexMetaField)

	* 新增成员：IndexMetaJson


### 第 46 次发布

发布时间：2023-09-14 01:45:31

本次发布包含了以下内容：

改善已有的文档。

新增数据结构：

* [ProcessDetail](https://cloud.tencent.com/document/api/845/30634#ProcessDetail)

修改数据结构：

* [Operation](https://cloud.tencent.com/document/api/845/30634#Operation)

	* 新增成员：SubAccountUin

* [TaskDetail](https://cloud.tencent.com/document/api/845/30634#TaskDetail)

	* 新增成员：ProcessInfo


### 第 45 次发布

发布时间：2023-08-29 01:14:45

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateInstance](https://cloud.tencent.com/document/api/845/30633)

	* 新增入参：CdcId


修改数据结构：

* [InstanceInfo](https://cloud.tencent.com/document/api/845/30634#InstanceInfo)

	* 新增成员：HasKernelUpgrade, CdcId


### 第 44 次发布

发布时间：2023-07-12 01:24:00

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [ModifyEsVipSecurityGroup](https://cloud.tencent.com/document/api/845/94985)

### 第 43 次发布

发布时间：2023-05-11 01:24:36

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [InstanceLog](https://cloud.tencent.com/document/api/845/30634#InstanceLog)

	* 新增成员：NodeID

* [KibanaView](https://cloud.tencent.com/document/api/845/30634#KibanaView)

	* 新增成员：NodeId


### 第 42 次发布

发布时间：2023-02-01 01:24:04

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateInstance](https://cloud.tencent.com/document/api/845/30633)

	* 新增入参：EnableDiagnose


### 第 41 次发布

发布时间：2022-12-12 01:25:49

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [IndexMetaField](https://cloud.tencent.com/document/api/845/30634#IndexMetaField)

	* 新增成员：IndexDocs


### 第 40 次发布

发布时间：2022-11-17 06:25:50

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeLogstashInstances](https://cloud.tencent.com/document/api/845/77239)

	* 新增入参：TagList

* [RestartNodes](https://cloud.tencent.com/document/api/845/48473)

	* 新增入参：RestartMode, IsOffline


修改数据结构：

* [LogstashInstanceInfo](https://cloud.tencent.com/document/api/845/30634#LogstashInstanceInfo)

	* 新增成员：CpuNum, TagList, MemSize


### 第 39 次发布

发布时间：2022-11-02 06:23:18

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [IndexPolicyField](https://cloud.tencent.com/document/api/845/30634#IndexPolicyField)

	* 新增成员：ColdAction


### 第 38 次发布

发布时间：2022-10-25 06:33:48

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateInstance](https://cloud.tencent.com/document/api/845/30633)

	* 新增入参：DiskEnhance


修改数据结构：

* [InstanceInfo](https://cloud.tencent.com/document/api/845/30634#InstanceInfo)

	* 新增成员：ProcessPercent, KibanaAlteringPublicAccess

* [NodeInfo](https://cloud.tencent.com/document/api/845/30634#NodeInfo)

	* 新增成员：DiskEnhance


### 第 37 次发布

发布时间：2022-09-28 06:30:23

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [UpdateInstance](https://cloud.tencent.com/document/api/845/30629)

	* 新增入参：KibanaAlteringPublicAccess

* [UpgradeInstance](https://cloud.tencent.com/document/api/845/36270)

	* 新增入参：SkipCheckForceRestart


### 第 36 次发布

发布时间：2022-09-26 06:30:30

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [TaskDetail](https://cloud.tencent.com/document/api/845/30634#TaskDetail)

	* 新增成员：ElapsedTime


### 第 35 次发布

发布时间：2022-09-16 06:24:23

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateLogstashInstance](https://cloud.tencent.com/document/api/845/77244)

	* 新增入参：OperationDuration

* [UpdateLogstashInstance](https://cloud.tencent.com/document/api/845/77233)

	* 新增入参：OperationDuration


修改数据结构：

* [LogstashInstanceInfo](https://cloud.tencent.com/document/api/845/30634#LogstashInstanceInfo)

	* 新增成员：OperationDuration


### 第 34 次发布

发布时间：2022-09-02 06:30:38

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateInstance](https://cloud.tencent.com/document/api/845/30633)

	* 新增入参：EnableHybridStorage


修改数据结构：

* [InstanceInfo](https://cloud.tencent.com/document/api/845/30634#InstanceInfo)

	* 新增成员：EnableHybridStorage


### 第 33 次发布

发布时间：2022-08-16 06:24:00

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [UpdateIndex](https://cloud.tencent.com/document/api/845/74380)

	* 新增入参：RolloverBackingIndex


新增数据结构：

* [OptionalWebServiceInfo](https://cloud.tencent.com/document/api/845/30634#OptionalWebServiceInfo)

修改数据结构：

* [InstanceInfo](https://cloud.tencent.com/document/api/845/30634#InstanceInfo)

	* 新增成员：OptionalWebServiceInfos, AutoIndexEnabled


### 第 32 次发布

发布时间：2022-08-03 06:23:52

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeLogstashInstances](https://cloud.tencent.com/document/api/845/77239)

	* 新增入参：VpcIds


### 第 31 次发布

发布时间：2022-07-14 06:10:06

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateLogstashInstance](https://cloud.tencent.com/document/api/845/77244)
* [DeleteLogstashInstance](https://cloud.tencent.com/document/api/845/77243)
* [DeleteLogstashPipelines](https://cloud.tencent.com/document/api/845/77242)
* [DescribeLogstashInstanceLogs](https://cloud.tencent.com/document/api/845/77241)
* [DescribeLogstashInstanceOperations](https://cloud.tencent.com/document/api/845/77240)
* [DescribeLogstashInstances](https://cloud.tencent.com/document/api/845/77239)
* [DescribeLogstashPipelines](https://cloud.tencent.com/document/api/845/77238)
* [RestartLogstashInstance](https://cloud.tencent.com/document/api/845/77237)
* [SaveAndDeployLogstashPipeline](https://cloud.tencent.com/document/api/845/77236)
* [StartLogstashPipelines](https://cloud.tencent.com/document/api/845/77235)
* [StopLogstashPipelines](https://cloud.tencent.com/document/api/845/77234)
* [UpdateLogstashInstance](https://cloud.tencent.com/document/api/845/77233)
* [UpdateLogstashPipelineDesc](https://cloud.tencent.com/document/api/845/77232)

新增数据结构：

* [LogstashBindedES](https://cloud.tencent.com/document/api/845/30634#LogstashBindedES)
* [LogstashExtendedFile](https://cloud.tencent.com/document/api/845/30634#LogstashExtendedFile)
* [LogstashInstanceInfo](https://cloud.tencent.com/document/api/845/30634#LogstashInstanceInfo)
* [LogstashNodeInfo](https://cloud.tencent.com/document/api/845/30634#LogstashNodeInfo)
* [LogstashPipeline](https://cloud.tencent.com/document/api/845/30634#LogstashPipeline)
* [LogstashPipelineInfo](https://cloud.tencent.com/document/api/845/30634#LogstashPipelineInfo)

### 第 30 次发布

发布时间：2022-07-13 06:11:03

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateInstance](https://cloud.tencent.com/document/api/845/30633)

	* 新增入参：OperationDuration

* [DescribeInstances](https://cloud.tencent.com/document/api/845/30631)

	* 新增入参：VpcIds

* [UpdateInstance](https://cloud.tencent.com/document/api/845/30629)

	* 新增入参：OperationDuration


新增数据结构：

* [OperationDuration](https://cloud.tencent.com/document/api/845/30634#OperationDuration)
* [OperationDurationUpdated](https://cloud.tencent.com/document/api/845/30634#OperationDurationUpdated)

修改数据结构：

* [InstanceInfo](https://cloud.tencent.com/document/api/845/30634#InstanceInfo)

	* 新增成员：OperationDuration


### 第 29 次发布

发布时间：2022-07-05 06:13:25

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [NodeInfo](https://cloud.tencent.com/document/api/845/30634#NodeInfo)

	* 新增成员：CpuNum, MemSize


### 第 28 次发布

发布时间：2022-06-20 06:08:20

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [InstanceInfo](https://cloud.tencent.com/document/api/845/30634#InstanceInfo)

	* 新增成员：EsConfigSets


### 第 27 次发布

发布时间：2022-05-25 06:08:55

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateIndex](https://cloud.tencent.com/document/api/845/74384)
* [DeleteIndex](https://cloud.tencent.com/document/api/845/74383)
* [DescribeIndexList](https://cloud.tencent.com/document/api/845/74382)
* [DescribeIndexMeta](https://cloud.tencent.com/document/api/845/74381)
* [UpdateIndex](https://cloud.tencent.com/document/api/845/74380)

修改接口：

* [UpdateInstance](https://cloud.tencent.com/document/api/845/30629)

	* 新增入参：EsConfigSet


新增数据结构：

* [BackingIndexMetaField](https://cloud.tencent.com/document/api/845/30634#BackingIndexMetaField)
* [EsConfigSetInfo](https://cloud.tencent.com/document/api/845/30634#EsConfigSetInfo)
* [IndexMetaField](https://cloud.tencent.com/document/api/845/30634#IndexMetaField)
* [IndexOptionsField](https://cloud.tencent.com/document/api/845/30634#IndexOptionsField)
* [IndexPolicyField](https://cloud.tencent.com/document/api/845/30634#IndexPolicyField)
* [IndexSettingsField](https://cloud.tencent.com/document/api/845/30634#IndexSettingsField)

### 第 26 次发布

发布时间：2022-03-21 11:04:25

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [UpdateDictionaries](https://cloud.tencent.com/document/api/845/71442)

### 第 25 次发布

发布时间：2022-03-09 08:11:10

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [UpgradeInstance](https://cloud.tencent.com/document/api/845/36270)

	* 新增入参：CosBackup


### 第 24 次发布

发布时间：2022-02-18 08:09:35

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [InstanceInfo](https://cloud.tencent.com/document/api/845/30634#InstanceInfo)

	* 新增成员：EsPrivateUrl, EsPrivateDomain


### 第 23 次发布

发布时间：2022-01-20 08:10:01

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeInstances](https://cloud.tencent.com/document/api/845/30631)

	* 新增入参：HealthStatus


修改数据结构：

* [InstanceInfo](https://cloud.tencent.com/document/api/845/30634#InstanceInfo)

	* 新增成员：HealthStatus


### 第 22 次发布

发布时间：2021-12-30 08:09:09

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateInstance](https://cloud.tencent.com/document/api/845/30633)

	* 新增出参：DealName

* [DescribeInstances](https://cloud.tencent.com/document/api/845/30631)

	* 新增入参：ZoneList

* [UpdateInstance](https://cloud.tencent.com/document/api/845/30629)

	* 新增出参：DealName

* [UpdatePlugins](https://cloud.tencent.com/document/api/845/46048)

	* 新增入参：PluginType

* [UpgradeLicense](https://cloud.tencent.com/document/api/845/36269)

	* 新增出参：DealName


修改数据结构：

* [ClusterView](https://cloud.tencent.com/document/api/845/30634#ClusterView)

	* 新增成员：TotalCosStorage, SearchableSnapshotCosBucket, SearchableSnapshotCosAppId

* [InstanceInfo](https://cloud.tencent.com/document/api/845/30634#InstanceInfo)

	* 新增成员：ColdNodeType, ColdNodeNum, ColdCpuNum, ColdMemSize, ColdDiskType, ColdDiskSize, FrozenNodeType, FrozenNodeNum, FrozenCpuNum, FrozenMemSize, FrozenDiskType, FrozenDiskSize


### 第 21 次发布

发布时间：2021-12-22 16:41:08

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeViews](https://cloud.tencent.com/document/api/845/66674)

新增数据结构：

* [ClusterView](https://cloud.tencent.com/document/api/845/30634#ClusterView)
* [KibanaView](https://cloud.tencent.com/document/api/845/30634#KibanaView)
* [NodeView](https://cloud.tencent.com/document/api/845/30634#NodeView)

### 第 20 次发布

发布时间：2021-11-08 08:06:16

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateInstance](https://cloud.tencent.com/document/api/845/30633)

	* 新增入参：Protocol

* [UpdateInstance](https://cloud.tencent.com/document/api/845/30629)

	* 新增入参：SwitchPrivateLink, EnableCerebro, CerebroPublicAccess, CerebroPrivateAccess


修改数据结构：

* [InstanceInfo](https://cloud.tencent.com/document/api/845/30634#InstanceInfo)

	* 新增成员：Protocol, SecurityGroups


### 第 19 次发布

发布时间：2021-09-30 08:05:14

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [UpdateJdk](https://cloud.tencent.com/document/api/845/62148)

### 第 18 次发布

发布时间：2021-08-13 08:05:41

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [RestartInstance](https://cloud.tencent.com/document/api/845/30630)

	* 新增入参：RestartMode

* [UpdateInstance](https://cloud.tencent.com/document/api/845/30629)

	* 新增入参：WebNodeTypeInfo


修改数据结构：

* [InstanceInfo](https://cloud.tencent.com/document/api/845/30634#InstanceInfo)

	* 新增成员：WebNodeTypeInfo, Jdk


### 第 17 次发布

发布时间：2021-06-22 08:06:05

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateInstance](https://cloud.tencent.com/document/api/845/30633)

	* 新增入参：WebNodeTypeInfo


新增数据结构：

* [KibanaNodeInfo](https://cloud.tencent.com/document/api/845/30634#KibanaNodeInfo)
* [WebNodeTypeInfo](https://cloud.tencent.com/document/api/845/30634#WebNodeTypeInfo)

修改数据结构：

* [InstanceInfo](https://cloud.tencent.com/document/api/845/30634#InstanceInfo)

	* 新增成员：KibanaNodeInfo


### 第 16 次发布

发布时间：2021-05-11 08:05:19

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DiagnoseInstance](https://cloud.tencent.com/document/api/845/55630)
* [UpdateDiagnoseSettings](https://cloud.tencent.com/document/api/845/55629)

### 第 15 次发布

发布时间：2021-03-09 08:04:52

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [UpdatePlugins](https://cloud.tencent.com/document/api/845/46048)

	* 新增入参：ForceUpdate


### 第 14 次发布

发布时间：2020-12-28 08:04:02

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [InstanceInfo](https://cloud.tencent.com/document/api/845/30634#InstanceInfo)

	* 新增成员：KibanaConfig


### 第 13 次发布

发布时间：2020-12-25 08:04:28

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [GetRequestTargetNodeTypes](https://cloud.tencent.com/document/api/845/51493)
* [UpdateRequestTargetNodeTypes](https://cloud.tencent.com/document/api/845/51492)

### 第 12 次发布

发布时间：2020-11-24 08:04:34

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [RestartKibana](https://cloud.tencent.com/document/api/845/50224)

修改接口：

* [UpdateInstance](https://cloud.tencent.com/document/api/845/30629)

	* 新增入参：KibanaConfig


### 第 11 次发布

发布时间：2020-09-17 08:03:49

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [RestartNodes](https://cloud.tencent.com/document/api/845/48473)

修改接口：

* [CreateInstance](https://cloud.tencent.com/document/api/845/30633)

	* 新增入参：SceneType

* [UpdateInstance](https://cloud.tencent.com/document/api/845/30629)

	* 新增入参：MultiZoneInfo, SceneType

* [UpgradeInstance](https://cloud.tencent.com/document/api/845/36270)

	* 新增入参：UpgradeMode


修改数据结构：

* [InstanceInfo](https://cloud.tencent.com/document/api/845/30634#InstanceInfo)

	* 新增成员：SceneType


### 第 10 次发布

发布时间：2020-07-08 08:10:51

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [UpdatePlugins](https://cloud.tencent.com/document/api/845/46048)

修改接口：

* [UpdateInstance](https://cloud.tencent.com/document/api/845/30629)

	* 新增入参：ScaleType


修改数据结构：

* [EsDictionaryInfo](https://cloud.tencent.com/document/api/845/30634#EsDictionaryInfo)

	* 新增成员：QQDict, Synonym, UpdateType

* [NodeInfo](https://cloud.tencent.com/document/api/845/30634#NodeInfo)

	* 新增成员：DiskEncrypt


### 第 9 次发布

发布时间：2020-05-08 08:10:10

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [UpdateInstance](https://cloud.tencent.com/document/api/845/30629)

	* 新增入参：KibanaPrivatePort


### 第 8 次发布

发布时间：2020-04-13 08:08:57

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [NodeInfo](https://cloud.tencent.com/document/api/845/30634#NodeInfo)

	* 新增成员：DiskCount


### 第 7 次发布

发布时间：2020-04-09 08:08:32

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [UpdateInstance](https://cloud.tencent.com/document/api/845/30629)

	* 新增入参：BasicSecurityType


新增数据结构：

* [LocalDiskInfo](https://cloud.tencent.com/document/api/845/30634#LocalDiskInfo)

修改数据结构：

* [NodeInfo](https://cloud.tencent.com/document/api/845/30634#NodeInfo)

	* 新增成员：LocalDiskInfo


### 第 6 次发布

发布时间：2020-01-02 10:20:54

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateInstance](https://cloud.tencent.com/document/api/845/30633)

	* 新增入参：NodeInfoList, TagList, BasicSecurityType

	* <font color="#dd0000">**修改入参**：</font>NodeNum, NodeType, DiskSize, MultiZoneInfo

* [DescribeInstances](https://cloud.tencent.com/document/api/845/30631)

	* 新增入参：TagList, IpList

* [UpdateInstance](https://cloud.tencent.com/document/api/845/30629)

	* 新增入参：NodeInfoList, PublicAccess, EsPublicAcl, KibanaPublicAccess, KibanaPrivateAccess

* [UpgradeInstance](https://cloud.tencent.com/document/api/845/36270)

	* 新增入参：BasicSecurityType

* [UpgradeLicense](https://cloud.tencent.com/document/api/845/36269)

	* 新增入参：BasicSecurityType, ForceRestart


新增数据结构：

* [EsPublicAcl](https://cloud.tencent.com/document/api/845/30634#EsPublicAcl)
* [NodeInfo](https://cloud.tencent.com/document/api/845/30634#NodeInfo)
* [ZoneDetail](https://cloud.tencent.com/document/api/845/30634#ZoneDetail)

<font color="#dd0000">**删除数据结构**：</font>

* MultiZoneInfo

修改数据结构：

* [InstanceInfo](https://cloud.tencent.com/document/api/845/30634#InstanceInfo)

	* 新增成员：EnableHotWarmMode, WarmNodeType, WarmNodeNum, WarmCpuNum, WarmMemSize, WarmDiskType, WarmDiskSize, NodeInfoList, EsPublicUrl, MultiZoneInfo, DeployMode, PublicAccess, EsPublicAcl, KibanaPrivateUrl, KibanaPublicAccess, KibanaPrivateAccess, SecurityType


### 第 5 次发布

发布时间：2019-07-18 11:17:30

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [UpgradeInstance](https://cloud.tencent.com/document/api/845/36270)
* [UpgradeLicense](https://cloud.tencent.com/document/api/845/36269)

修改数据结构：

* [SubTaskDetail](https://cloud.tencent.com/document/api/845/30634#SubTaskDetail)

	* 新增成员：Type, Status, FailedIndices, FinishTime, Level


### 第 4 次发布

发布时间：2019-05-30 20:41:02

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateInstance](https://cloud.tencent.com/document/api/845/30633)

	* 新增入参：DeployMode, MultiZoneInfo, LicenseType


新增数据结构：

* [MultiZoneInfo](https://cloud.tencent.com/document/api/845/30634#MultiZoneInfo)
* [TagInfo](https://cloud.tencent.com/document/api/845/30634#TagInfo)

修改数据结构：

* [InstanceInfo](https://cloud.tencent.com/document/api/845/30634#InstanceInfo)

	* 新增成员：TagList, LicenseType


### 第 3 次发布

发布时间：2019-03-14 16:33:24

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeInstanceLogs](https://cloud.tencent.com/document/api/845/33760)
* [DescribeInstanceOperations](https://cloud.tencent.com/document/api/845/33759)

修改接口：

* [CreateInstance](https://cloud.tencent.com/document/api/845/30633)

	* 新增入参：ClusterNameInConf

* [UpdateInstance](https://cloud.tencent.com/document/api/845/30629)

	* 新增入参：CosBackup


新增数据结构：

* [InstanceLog](https://cloud.tencent.com/document/api/845/30634#InstanceLog)
* [KeyValue](https://cloud.tencent.com/document/api/845/30634#KeyValue)
* [Operation](https://cloud.tencent.com/document/api/845/30634#Operation)
* [OperationDetail](https://cloud.tencent.com/document/api/845/30634#OperationDetail)
* [SubTaskDetail](https://cloud.tencent.com/document/api/845/30634#SubTaskDetail)
* [TaskDetail](https://cloud.tencent.com/document/api/845/30634#TaskDetail)

### 第 2 次发布

发布时间：2019-03-07 21:24:06

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateInstance](https://cloud.tencent.com/document/api/845/30633)

	* 新增入参：EnableDedicatedMaster, MasterNodeNum, MasterNodeType, MasterNodeDiskSize

* [RestartInstance](https://cloud.tencent.com/document/api/845/30630)

	* 新增入参：ForceRestart

* [UpdateInstance](https://cloud.tencent.com/document/api/845/30629)

	* 新增入参：MasterNodeNum, MasterNodeType, MasterNodeDiskSize, ForceRestart


新增数据结构：

* [CosBackup](https://cloud.tencent.com/document/api/845/30634#CosBackup)

修改数据结构：

* [InstanceInfo](https://cloud.tencent.com/document/api/845/30634#InstanceInfo)

	* 新增成员：CosBackup, AllowCosBackup

* [MasterNodeInfo](https://cloud.tencent.com/document/api/845/30634#MasterNodeInfo)

	* 新增成员：MasterNodeDiskType


### 第 1 次发布

发布时间：2018-11-22 20:16:54

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateInstance](https://cloud.tencent.com/document/api/845/30633)
* [DeleteInstance](https://cloud.tencent.com/document/api/845/30632)
* [DescribeInstances](https://cloud.tencent.com/document/api/845/30631)
* [RestartInstance](https://cloud.tencent.com/document/api/845/30630)
* [UpdateInstance](https://cloud.tencent.com/document/api/845/30629)

新增数据结构：

* [DictInfo](https://cloud.tencent.com/document/api/845/30634#DictInfo)
* [EsAcl](https://cloud.tencent.com/document/api/845/30634#EsAcl)
* [EsDictionaryInfo](https://cloud.tencent.com/document/api/845/30634#EsDictionaryInfo)
* [InstanceInfo](https://cloud.tencent.com/document/api/845/30634#InstanceInfo)
* [MasterNodeInfo](https://cloud.tencent.com/document/api/845/30634#MasterNodeInfo)




## 腾讯电子签企业版(ess) 版本：2020-11-11

### 第 181 次发布

发布时间：2024-07-25 01:39:56

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreatePartnerAutoSignAuthUrl](https://cloud.tencent.com/document/api/1323/109065)

	* 新增入参：AuthorizedOrganizationName, AuthToMe


### 第 180 次发布

发布时间：2024-07-23 01:33:50

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreatePartnerAutoSignAuthUrl](https://cloud.tencent.com/document/api/1323/109065)

### 第 179 次发布

发布时间：2024-07-12 01:16:02

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateEmployeeQualificationSealQrCode](https://cloud.tencent.com/document/api/1323/108596)

### 第 178 次发布

发布时间：2024-07-09 01:14:53

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateFlowBlockchainEvidenceUrl](https://cloud.tencent.com/document/api/1323/107550)

	* 新增入参：ExpiredOn


### 第 177 次发布

发布时间：2024-07-02 01:16:08

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateUserVerifyUrl](https://cloud.tencent.com/document/api/1323/105961)

	* 新增入参：JumpUrl


### 第 176 次发布

发布时间：2024-06-25 01:14:54

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateLegalSealQrCode](https://cloud.tencent.com/document/api/1323/107551)


### 第 175 次发布

发布时间：2024-06-21 01:41:37

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateFlowBlockchainEvidenceUrl](https://cloud.tencent.com/document/api/1323/107550)
* [CreateLegalSealQrCode](https://cloud.tencent.com/document/api/1323/107551)

### 第 174 次发布

发布时间：2024-06-04 01:41:39

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateUserMobileChangeUrl](https://cloud.tencent.com/document/api/1323/106775)

### 第 173 次发布

发布时间：2024-05-27 01:39:33

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeUserVerifyStatus](https://cloud.tencent.com/document/api/1323/106080)

	* 新增入参：IdCardType


### 第 172 次发布

发布时间：2024-05-24 01:39:35

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateIntegrationSubOrganizationActiveRecord](https://cloud.tencent.com/document/api/1323/106550)
* [CreateOrganizationGroupInvitationLink](https://cloud.tencent.com/document/api/1323/106549)

### 第 171 次发布

发布时间：2024-05-23 01:39:14

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [RegistrationOrganizationInfo](https://cloud.tencent.com/document/api/1323/70369#RegistrationOrganizationInfo)

	* 新增成员：PowerOfAttorneys


### 第 170 次发布

发布时间：2024-05-16 01:44:57

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateUserVerifyUrl](https://cloud.tencent.com/document/api/1323/105961)

	* 新增入参：UserData


### 第 169 次发布

发布时间：2024-05-13 01:18:00

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeUserVerifyStatus](https://cloud.tencent.com/document/api/1323/106080)

### 第 168 次发布

发布时间：2024-05-10 01:46:37

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateUserVerifyUrl](https://cloud.tencent.com/document/api/1323/105961)

### 第 167 次发布

发布时间：2024-05-08 01:17:34

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [ReleasedApprover](https://cloud.tencent.com/document/api/1323/70369#ReleasedApprover)

	* 新增成员：ApproverSignSealId


### 第 166 次发布

发布时间：2024-04-29 01:16:26

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeBatchOrganizationRegistrationUrls](https://cloud.tencent.com/document/api/1323/105751)

新增数据结构：

* [OrganizationAuthUrl](https://cloud.tencent.com/document/api/1323/70369#OrganizationAuthUrl)

### 第 165 次发布

发布时间：2024-04-25 01:16:34

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateBatchSignUrl](https://cloud.tencent.com/document/api/1323/98670)

	* 新增入参：FlowBatchUrlInfo

	* <font color="#dd0000">**修改入参**：</font>Name, Mobile


新增数据结构：

* [FlowBatchApproverInfo](https://cloud.tencent.com/document/api/1323/70369#FlowBatchApproverInfo)
* [FlowBatchUrlInfo](https://cloud.tencent.com/document/api/1323/70369#FlowBatchUrlInfo)

### 第 164 次发布

发布时间：2024-04-17 01:14:00

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeBillUsage](https://cloud.tencent.com/document/api/1323/105296)

新增数据结构：

* [OrgBillSummary](https://cloud.tencent.com/document/api/1323/70369#OrgBillSummary)
* [SubOrgBillSummary](https://cloud.tencent.com/document/api/1323/70369#SubOrgBillSummary)
* [SubOrgBillUsage](https://cloud.tencent.com/document/api/1323/70369#SubOrgBillUsage)

### 第 163 次发布

发布时间：2024-04-16 01:12:05

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateOrganizationAuthUrl](https://cloud.tencent.com/document/api/1323/105134)

	* 新增入参：Operator, AuthorizationTypes, OrganizationName, UniformSocialCreditCode, LegalName, AutoJumpUrl, OrganizationAddress, AdminName, AdminMobile, AdminIdCardNumber, AdminIdCardType, UniformSocialCreditCodeSame, LegalNameSame, AdminNameSame, AdminIdCardNumberSame, AdminMobileSame, OrganizationNameSame, BusinessLicense, Endpoint

	* 新增出参：AuthUrl, ExpiredTime


### 第 162 次发布

发布时间：2024-04-15 01:40:39

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateBatchOrganizationRegistrationTasks](https://cloud.tencent.com/document/api/1323/105135)
* [CreateOrganizationAuthUrl](https://cloud.tencent.com/document/api/1323/105134)

修改接口：

* [CreateOrganizationBatchSignUrl](https://cloud.tencent.com/document/api/1323/95598)

	* 新增入参：RecipientIds


新增数据结构：

* [RegistrationOrganizationInfo](https://cloud.tencent.com/document/api/1323/70369#RegistrationOrganizationInfo)

### 第 161 次发布

发布时间：2024-04-08 11:27:30

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateUserAutoSignEnableUrl](https://cloud.tencent.com/document/api/1323/87787)

	* 新增入参：UserData


修改数据结构：

* [AutoSignConfig](https://cloud.tencent.com/document/api/1323/70369#AutoSignConfig)

	* 新增成员：JumpUrl


### 第 160 次发布

发布时间：2024-03-27 15:13:07

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [CreateFlowOption](https://cloud.tencent.com/document/api/1323/70369#CreateFlowOption)

	* <font color="#dd0000">**修改成员**：</font>ForbidAddApprover, ForbidEditFlowProperties


### 第 159 次发布

发布时间：2024-03-26 01:16:22

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateFlowApprovers](https://cloud.tencent.com/document/api/1323/80033)

	* 新增入参：FlowGroupId

	* <font color="#dd0000">**修改入参**：</font>FlowId

* [CreateFlowGroupByFiles](https://cloud.tencent.com/document/api/1323/94888)

	* 新增出参：Approvers

* [CreateFlowGroupByTemplates](https://cloud.tencent.com/document/api/1323/94887)

	* 新增出参：Approvers

* [CreateSchemeUrl](https://cloud.tencent.com/document/api/1323/70359)

	* 新增入参：FlowGroupUrlInfo


新增数据结构：

* [FlowGroupApproverInfo](https://cloud.tencent.com/document/api/1323/70369#FlowGroupApproverInfo)
* [FlowGroupApprovers](https://cloud.tencent.com/document/api/1323/70369#FlowGroupApprovers)
* [FlowGroupUrlInfo](https://cloud.tencent.com/document/api/1323/70369#FlowGroupUrlInfo)

修改数据结构：

* [ApproverInfo](https://cloud.tencent.com/document/api/1323/70369#ApproverInfo)

	* <font color="#dd0000">**修改成员**：</font>ApproverName, ApproverMobile

* [FillApproverInfo](https://cloud.tencent.com/document/api/1323/70369#FillApproverInfo)

	* 新增成员：FlowId


### 第 158 次发布

发布时间：2024-03-25 01:16:14

本次发布包含了以下内容：

改善已有的文档。

新增数据结构：

* [CreateResultPageConfig](https://cloud.tencent.com/document/api/1323/70369#CreateResultPageConfig)

修改数据结构：

* [ApproverOption](https://cloud.tencent.com/document/api/1323/70369#ApproverOption)

	* 新增成员：CanEditApprover

* [CreateFlowOption](https://cloud.tencent.com/document/api/1323/70369#CreateFlowOption)

	* 新增成员：ForbidAddApprover, ForbidEditFlowProperties, HideComponentTypes, ShowComponentTypes, ResultPageConfig


### 第 157 次发布

发布时间：2024-03-19 11:18:23

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeCancelFlowsTask](https://cloud.tencent.com/document/api/1323/104494)

修改接口：

* [CreateIntegrationEmployees](https://cloud.tencent.com/document/api/1323/81117)

	* 新增入参：Endpoint

* [UpdateIntegrationEmployees](https://cloud.tencent.com/document/api/1323/89457)

	* 新增入参：Endpoint


新增数据结构：

* [CancelFailureFlow](https://cloud.tencent.com/document/api/1323/70369#CancelFailureFlow)

### 第 156 次发布

发布时间：2024-03-19 01:14:56

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateBatchCancelFlowUrl](https://cloud.tencent.com/document/api/1323/78262)

	* 新增出参：TaskId


### 第 155 次发布

发布时间：2024-03-15 01:14:52

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [RenewAutoSignLicense](https://cloud.tencent.com/document/api/1323/104346)

### 第 154 次发布

发布时间：2024-03-11 01:15:16

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [FillApproverInfo](https://cloud.tencent.com/document/api/1323/70369#FillApproverInfo)

	* 新增成员：ApproverIdCardType, ApproverIdCardNumber


### 第 153 次发布

发布时间：2024-03-08 19:37:32

本次发布包含了以下内容：

改善已有的文档。

新增数据结构：

* [UserFlowType](https://cloud.tencent.com/document/api/1323/70369#UserFlowType)

修改数据结构：

* [TemplateInfo](https://cloud.tencent.com/document/api/1323/70369#TemplateInfo)

	* 新增成员：UserFlowType


### 第 152 次发布

发布时间：2024-03-07 01:16:07

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeSignFaceVideo](https://cloud.tencent.com/document/api/1323/104133)

新增数据结构：

* [DetectInfoVideoData](https://cloud.tencent.com/document/api/1323/70369#DetectInfoVideoData)
* [Intention](https://cloud.tencent.com/document/api/1323/70369#Intention)
* [IntentionAction](https://cloud.tencent.com/document/api/1323/70369#IntentionAction)
* [IntentionActionResult](https://cloud.tencent.com/document/api/1323/70369#IntentionActionResult)
* [IntentionActionResultDetail](https://cloud.tencent.com/document/api/1323/70369#IntentionActionResultDetail)
* [IntentionQuestion](https://cloud.tencent.com/document/api/1323/70369#IntentionQuestion)
* [IntentionQuestionResult](https://cloud.tencent.com/document/api/1323/70369#IntentionQuestionResult)

修改数据结构：

* [FlowCreateApprover](https://cloud.tencent.com/document/api/1323/70369#FlowCreateApprover)

	* 新增成员：Intention


### 第 151 次发布

发布时间：2024-03-06 01:15:49

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [TemplateInfo](https://cloud.tencent.com/document/api/1323/70369#TemplateInfo)

	* 新增成员：CreatorId


### 第 150 次发布

发布时间：2024-02-29 01:16:08

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [ApproverInfo](https://cloud.tencent.com/document/api/1323/70369#ApproverInfo)

	* 新增成员：Components


### 第 149 次发布

发布时间：2024-01-31 11:46:30

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateFlowEvidenceReport](https://cloud.tencent.com/document/api/1323/79686)

	* 新增入参：ReportType

* [DescribeFlowEvidenceReport](https://cloud.tencent.com/document/api/1323/83441)

	* 新增入参：ReportType


### 第 148 次发布

发布时间：2024-01-26 01:13:26

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateDocument](https://cloud.tencent.com/document/api/1323/70364)

	* <font color="#dd0000">**修改入参**：</font>FlowId


### 第 147 次发布

发布时间：2024-01-25 01:13:27

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [ModifyFlowDeadline](https://cloud.tencent.com/document/api/1323/103373)

修改数据结构：

* [ApproverInfo](https://cloud.tencent.com/document/api/1323/70369#ApproverInfo)

	* 新增成员：Deadline

* [FlowCreateApprover](https://cloud.tencent.com/document/api/1323/70369#FlowCreateApprover)

	* 新增成员：Deadline


### 第 146 次发布

发布时间：2024-01-16 01:14:53

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateFlowSignUrl](https://cloud.tencent.com/document/api/1323/85818)

	* 新增入参：UrlType

	* <font color="#dd0000">**修改入参**：</font>FlowApproverInfos

* [CreateIntegrationEmployees](https://cloud.tencent.com/document/api/1323/81117)

	* 新增入参：InvitationNotifyType, JumpUrl

* [UpdateIntegrationEmployees](https://cloud.tencent.com/document/api/1323/89457)

	* 新增入参：InvitationNotifyType, JumpUrl


修改数据结构：

* [SuccessCreateStaffData](https://cloud.tencent.com/document/api/1323/70369#SuccessCreateStaffData)

	* 新增成员：Url

* [SuccessUpdateStaffData](https://cloud.tencent.com/document/api/1323/70369#SuccessUpdateStaffData)

	* 新增成员：Url


### 第 145 次发布

发布时间：2023-12-29 01:16:02

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [ModifyExtendedService](https://cloud.tencent.com/document/api/1323/102771)

### 第 144 次发布

发布时间：2023-12-27 01:19:02

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateFlowGroupSignReview](https://cloud.tencent.com/document/api/1323/102692)

新增数据结构：

* [NeedReviewApproverInfo](https://cloud.tencent.com/document/api/1323/70369#NeedReviewApproverInfo)

### 第 143 次发布

发布时间：2023-12-20 01:38:18

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreatePrepareFlow](https://cloud.tencent.com/document/api/1323/83412)

	* 新增入参：CcInfos


### 第 142 次发布

发布时间：2023-12-15 19:39:22

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeExtendedServiceAuthDetail](https://cloud.tencent.com/document/api/1323/102513)

修改接口：

* [CreateBatchQuickSignUrl](https://cloud.tencent.com/document/api/1323/101058)

	* 新增入参：SignTypeSelector


新增数据结构：

* [AuthInfoDetail](https://cloud.tencent.com/document/api/1323/70369#AuthInfoDetail)
* [HasAuthOrganization](https://cloud.tencent.com/document/api/1323/70369#HasAuthOrganization)

修改数据结构：

* [FlowCreateApprover](https://cloud.tencent.com/document/api/1323/70369#FlowCreateApprover)

	* 新增成员：SignTypeSelector


### 第 141 次发布

发布时间：2023-12-14 01:47:26

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateSeal](https://cloud.tencent.com/document/api/1323/94136)

	* 新增入参：TaxIdentifyCode


### 第 140 次发布

发布时间：2023-12-12 01:48:23

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateBatchQuickSignUrl](https://cloud.tencent.com/document/api/1323/101058)

	* 新增入参：FlowGroupId

	* <font color="#dd0000">**修改入参**：</font>FlowIds


### 第 139 次发布

发布时间：2023-12-08 01:47:50

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [Recipient](https://cloud.tencent.com/document/api/1323/70369#Recipient)

	* 新增成员：ApproverVerifyTypes, ApproverSignTypes


### 第 138 次发布

发布时间：2023-11-30 16:06:35

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateEmbedWebUrl](https://cloud.tencent.com/document/api/1323/95590)

	* 新增入参：UserData


### 第 137 次发布

发布时间：2023-11-24 01:14:56

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreatePersonAuthCertificateImage](https://cloud.tencent.com/document/api/1323/95783)

	* 新增入参：SceneKey

* [CreatePreparedPersonalEsign](https://cloud.tencent.com/document/api/1323/89386)

	* 新增入参：SceneKey


修改数据结构：

* [HasAuthUser](https://cloud.tencent.com/document/api/1323/70369#HasAuthUser)

	* 新增成员：MainOrganizationId


### 第 136 次发布

发布时间：2023-11-23 01:18:49

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateSchemeUrl](https://cloud.tencent.com/document/api/1323/70359)

	* 新增入参：IdCardType, IdCardNumber


### 第 135 次发布

发布时间：2023-11-09 01:14:12

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeBillUsageDetail](https://cloud.tencent.com/document/api/1323/101383)

	* <font color="#dd0000">**修改入参**：</font>Offset


### 第 134 次发布

发布时间：2023-11-08 11:36:14

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreatePrepareFlow](https://cloud.tencent.com/document/api/1323/83412)

	* 新增出参：FlowId


### 第 133 次发布

发布时间：2023-11-08 01:38:53

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeBillUsageDetail](https://cloud.tencent.com/document/api/1323/101383)

新增数据结构：

* [BillUsageDetail](https://cloud.tencent.com/document/api/1323/70369#BillUsageDetail)

### 第 132 次发布

发布时间：2023-11-02 01:44:45

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateBatchQuickSignUrl](https://cloud.tencent.com/document/api/1323/101058)

### 第 131 次发布

发布时间：2023-10-25 01:16:49

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateExtendedServiceAuthInfos](https://cloud.tencent.com/document/api/1323/100676)
* [DeleteExtendedServiceAuthInfos](https://cloud.tencent.com/document/api/1323/100675)

### 第 130 次发布

发布时间：2023-10-23 15:56:55

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeFlowTemplates](https://cloud.tencent.com/document/api/1323/74803)

	* 新增入参：WithPreviewUrl


### 第 129 次发布

发布时间：2023-10-20 01:15:34

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [ApproverOption](https://cloud.tencent.com/document/api/1323/70369#ApproverOption)

	* 新增成员：FlowReadLimit


### 第 128 次发布

发布时间：2023-10-18 02:01:09

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [VerifyPdf](https://cloud.tencent.com/document/api/1323/80797)

	* 新增出参：PdfResourceMd5


### 第 127 次发布

发布时间：2023-10-12 01:57:39

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [ApproverInfo](https://cloud.tencent.com/document/api/1323/70369#ApproverInfo)

	* 新增成员：SignInstructionContent


### 第 126 次发布

发布时间：2023-10-11 01:48:23

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateFlowApprovers](https://cloud.tencent.com/document/api/1323/80033)

	* 新增出参：FillError


新增数据结构：

* [FillError](https://cloud.tencent.com/document/api/1323/70369#FillError)

### 第 125 次发布

发布时间：2023-10-09 17:30:41

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateUserAutoSignSealUrl](https://cloud.tencent.com/document/api/1323/99316)

### 第 124 次发布

发布时间：2023-10-09 01:15:43

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [TemplateInfo](https://cloud.tencent.com/document/api/1323/70369#TemplateInfo)

	* 新增成员：ShareTemplateId


### 第 123 次发布

发布时间：2023-09-28 01:13:45

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateOrganizationInfoChangeUrl](https://cloud.tencent.com/document/api/1323/99178)

### 第 122 次发布

发布时间：2023-09-26 16:45:49

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateDocument](https://cloud.tencent.com/document/api/1323/70364)

	* 新增出参：Approvers

* [CreateFlowApprovers](https://cloud.tencent.com/document/api/1323/80033)

	* 新增入参：FillApproverType

* [CreateFlowByFiles](https://cloud.tencent.com/document/api/1323/70360)

	* 新增出参：Approvers

* [CreateSchemeUrl](https://cloud.tencent.com/document/api/1323/70359)

	* 新增入参：RecipientId

	* 新增出参：SchemeQrcodeUrl

* [UploadFiles](https://cloud.tencent.com/document/api/1323/73066)

	* 新增入参：Agent


新增数据结构：

* [ApproverItem](https://cloud.tencent.com/document/api/1323/70369#ApproverItem)

修改数据结构：

* [ApproverInfo](https://cloud.tencent.com/document/api/1323/70369#ApproverInfo)

	* 新增成员：ApproverRoleName

* [ApproverOption](https://cloud.tencent.com/document/api/1323/70369#ApproverOption)

	* 新增成员：FillType

* [FillApproverInfo](https://cloud.tencent.com/document/api/1323/70369#FillApproverInfo)

	* 新增成员：OrganizationName

* [FlowApproverDetail](https://cloud.tencent.com/document/api/1323/70369#FlowApproverDetail)

	* 新增成员：ApproverRoleName


### 第 121 次发布

发布时间：2023-09-22 01:49:11

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribePersonCertificate](https://cloud.tencent.com/document/api/1323/98748)

修改接口：

* [CreateMultiFlowSignQRCode](https://cloud.tencent.com/document/api/1323/75450)

	* 新增入参：ApproverComponentLimitTypes


新增数据结构：

* [ApproverComponentLimitType](https://cloud.tencent.com/document/api/1323/70369#ApproverComponentLimitType)

### 第 120 次发布

发布时间：2023-09-20 01:35:54

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreatePrepareFlow](https://cloud.tencent.com/document/api/1323/83412)

	* 新增入参：InitiatorComponents

* [VerifyPdf](https://cloud.tencent.com/document/api/1323/80797)

	* 新增入参：Agent


### 第 119 次发布

发布时间：2023-09-19 01:15:03

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateBatchSignUrl](https://cloud.tencent.com/document/api/1323/98670)

### 第 118 次发布

发布时间：2023-09-18 01:46:29

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [Admin](https://cloud.tencent.com/document/api/1323/70369#Admin)

	* <font color="#dd0000">**修改成员**：</font>Name, Mobile

* [FailedUpdateStaffData](https://cloud.tencent.com/document/api/1323/70369#FailedUpdateStaffData)

	* <font color="#dd0000">**修改成员**：</font>DisplayName, Mobile, Reason, UserId, OpenId

* [IntegrationDepartment](https://cloud.tencent.com/document/api/1323/70369#IntegrationDepartment)

	* <font color="#dd0000">**修改成员**：</font>DeptId, DeptName, ParentDeptId, DeptOpenId, OrderNo

* [SuccessUpdateStaffData](https://cloud.tencent.com/document/api/1323/70369#SuccessUpdateStaffData)

	* <font color="#dd0000">**修改成员**：</font>DisplayName, Mobile, UserId


### 第 117 次发布

发布时间：2023-09-15 01:49:08

本次发布包含了以下内容：

改善已有的文档。

<font color="#dd0000">**删除接口**：</font>

* DescribeIntegrationMainOrganizationUser

<font color="#dd0000">**删除数据结构**：</font>

* IntegrationMainOrganizationUser

### 第 116 次发布

发布时间：2023-09-14 01:46:23

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [FlowGroupInfo](https://cloud.tencent.com/document/api/1323/70369#FlowGroupInfo)


### 第 115 次发布

发布时间：2023-09-13 01:46:18

本次发布包含了以下内容：

改善已有的文档。

<font color="#dd0000">**删除接口**：</font>

* CreateChannelSubOrganizationModifyQrCode

### 第 114 次发布

发布时间：2023-09-12 01:51:41

本次发布包含了以下内容：

改善已有的文档。

新增数据结构：

* [ComponentLimit](https://cloud.tencent.com/document/api/1323/70369#ComponentLimit)

修改数据结构：

* [ApproverInfo](https://cloud.tencent.com/document/api/1323/70369#ApproverInfo)

	* 新增成员：AddSignComponentsLimits


### 第 113 次发布

发布时间：2023-09-08 01:53:13

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [AutoSignConfig](https://cloud.tencent.com/document/api/1323/70369#AutoSignConfig)

	* <font color="#dd0000">**修改成员**：</font>CallbackUrl


### 第 112 次发布

发布时间：2023-09-07 01:48:58

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CancelUserAutoSignEnableUrl](https://cloud.tencent.com/document/api/1323/93320)

	* 新增入参：Agent

* [CreateReleaseFlow](https://cloud.tencent.com/document/api/1323/88045)

	* 新增入参：UserData


修改数据结构：

* [FlowApproverUrlInfo](https://cloud.tencent.com/document/api/1323/70369#FlowApproverUrlInfo)

	* <font color="#dd0000">**修改成员**：</font>SignUrl, ApproverType, ApproverName, ApproverMobile, LongUrl


### 第 111 次发布

发布时间：2023-09-05 17:35:52

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [StartFlow](https://cloud.tencent.com/document/api/1323/70357)


### 第 110 次发布

发布时间：2023-09-05 04:25:12

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [FlowApproverDetail](https://cloud.tencent.com/document/api/1323/70369#FlowApproverDetail)

	* 新增成员：SignId


### 第 109 次发布

发布时间：2023-08-31 16:45:41

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateFlowEvidenceReport](https://cloud.tencent.com/document/api/1323/79686)


### 第 108 次发布

发布时间：2023-08-30 01:14:43

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateIntegrationRole](https://cloud.tencent.com/document/api/1323/97571)
* [ModifyIntegrationRole](https://cloud.tencent.com/document/api/1323/97570)

修改接口：

* [CreatePersonAuthCertificateImage](https://cloud.tencent.com/document/api/1323/95783)

	* 新增出参：ImageCertId, SerialNumber, ValidFrom, ValidTo


### 第 107 次发布

发布时间：2023-08-29 01:14:56

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreatePersonAuthCertificateImage](https://cloud.tencent.com/document/api/1323/95783)

	* 新增入参：Agent


新增数据结构：

* [Permission](https://cloud.tencent.com/document/api/1323/70369#Permission)
* [PermissionGroup](https://cloud.tencent.com/document/api/1323/70369#PermissionGroup)

修改数据结构：

* [IntegrateRole](https://cloud.tencent.com/document/api/1323/70369#IntegrateRole)

	* 新增成员：PermissionGroups

	* <font color="#dd0000">**修改成员**：</font>RoleId, RoleName, RoleStatus, IsGroupRole, SubOrgIdList


### 第 106 次发布

发布时间：2023-08-28 16:10:43

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateMultiFlowSignQRCode](https://cloud.tencent.com/document/api/1323/75450)

* [DescribeOrganizationSeals](https://cloud.tencent.com/document/api/1323/82453)

	* 新增入参：SealStatuses


### 第 105 次发布

发布时间：2023-08-24 01:18:44

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateSeal](https://cloud.tencent.com/document/api/1323/94136)

	* 新增入参：SealStyle, SealSize


### 第 104 次发布

发布时间：2023-08-22 01:13:07

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreatePreparedPersonalEsign](https://cloud.tencent.com/document/api/1323/89386)

	* 新增入参：LicenseType

* [CreateWebThemeConfig](https://cloud.tencent.com/document/api/1323/95592)

	* 新增入参：Agent

* [DescribeUserAutoSignStatus](https://cloud.tencent.com/document/api/1323/87786)

	* 新增出参：LicenseType


修改数据结构：

* [AutoSignConfig](https://cloud.tencent.com/document/api/1323/70369#AutoSignConfig)

	* 新增成员：LicenseType


### 第 103 次发布

发布时间：2023-08-21 01:12:45

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateIntegrationDepartment](https://cloud.tencent.com/document/api/1323/93289)

	* 新增入参：Agent

* [DeleteIntegrationDepartment](https://cloud.tencent.com/document/api/1323/93288)

	* 新增入参：Agent

* [DescribeIntegrationDepartments](https://cloud.tencent.com/document/api/1323/93287)

	* 新增入参：Agent

* [ModifyIntegrationDepartment](https://cloud.tencent.com/document/api/1323/93286)

	* 新增入参：Agent


### 第 102 次发布

发布时间：2023-08-08 01:16:56

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreatePreparedPersonalEsign](https://cloud.tencent.com/document/api/1323/89386)

	* 新增入参：Agent


修改数据结构：

* [GroupOrganization](https://cloud.tencent.com/document/api/1323/70369#GroupOrganization)

	* <font color="#dd0000">**修改成员**：</font>Name, Alias, OrganizationId, UpdateTime, Status, IsMainOrganization, IdCardNumber, AdminInfo, License, LicenseExpireTime, JoinTime, FlowEngineEnable


### 第 101 次发布

发布时间：2023-08-03 01:06:38

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeOrganizationGroupOrganizations](https://cloud.tencent.com/document/api/1323/86114)

	* 新增出参：ActivatedTotal


### 第 100 次发布

发布时间：2023-08-02 01:15:29

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreatePersonAuthCertificateImage](https://cloud.tencent.com/document/api/1323/95783)

### 第 99 次发布

发布时间：2023-08-01 01:22:32

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateEmbedWebUrl](https://cloud.tencent.com/document/api/1323/95590)

	* 新增入参：Option

* [CreatePrepareFlow](https://cloud.tencent.com/document/api/1323/83412)

	* 新增入参：ResourceType, Components, FlowOption, NeedSignReview, NeedCreateReview, UserData, FlowId, FlowType


新增数据结构：

* [CreateFlowOption](https://cloud.tencent.com/document/api/1323/70369#CreateFlowOption)
* [EmbedUrlOption](https://cloud.tencent.com/document/api/1323/70369#EmbedUrlOption)

修改数据结构：

* [Component](https://cloud.tencent.com/document/api/1323/70369#Component)

	* 新增成员：LockComponentValue, ForbidMoveAndDelete

* [Department](https://cloud.tencent.com/document/api/1323/70369#Department)

	* <font color="#dd0000">**修改成员**：</font>DepartmentId, DepartmentName

* [SealInfo](https://cloud.tencent.com/document/api/1323/70369#SealInfo)

	* 新增成员：SealId, SealType, SealName

* [StaffRole](https://cloud.tencent.com/document/api/1323/70369#StaffRole)

	* <font color="#dd0000">**修改成员**：</font>RoleId, RoleName


### 第 98 次发布

发布时间：2023-07-31 01:23:57

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [FlowBrief](https://cloud.tencent.com/document/api/1323/70369#FlowBrief)

	* <font color="#dd0000">**修改成员**：</font>Creator, Deadline


### 第 97 次发布

发布时间：2023-07-26 17:55:39

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateOrganizationBatchSignUrl](https://cloud.tencent.com/document/api/1323/95598)

### 第 96 次发布

发布时间：2023-07-26 16:20:57

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateWebThemeConfig](https://cloud.tencent.com/document/api/1323/95592)

新增数据结构：

* [WebThemeConfig](https://cloud.tencent.com/document/api/1323/70369#WebThemeConfig)

### 第 95 次发布

发布时间：2023-07-26 16:06:53

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateEmbedWebUrl](https://cloud.tencent.com/document/api/1323/95590)

新增数据结构：

* [ReviewerInfo](https://cloud.tencent.com/document/api/1323/70369#ReviewerInfo)

### 第 94 次发布

发布时间：2023-07-26 11:26:03

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreatePrepareFlow](https://cloud.tencent.com/document/api/1323/83412)

	* 新增入参：Agent


修改数据结构：

* [FlowCreateApprover](https://cloud.tencent.com/document/api/1323/70369#FlowCreateApprover)

	* 新增成员：ApproverVerifyTypes, ApproverSignTypes


### 第 93 次发布

发布时间：2023-07-26 01:19:51

本次发布包含了以下内容：

改善已有的文档。

<font color="#dd0000">**预下线接口**：</font>

* DescribeIntegrationMainOrganizationUser

### 第 92 次发布

发布时间：2023-07-25 10:56:49

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [ModifyApplicationCallbackInfo](https://cloud.tencent.com/document/api/1323/86752)

	* 新增入参：Agent


### 第 91 次发布

发布时间：2023-07-24 01:28:01

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [BindEmployeeUserIdWithClientOpenId](https://cloud.tencent.com/document/api/1323/90238)

	* 新增入参：Agent

* [CreateFlowApprovers](https://cloud.tencent.com/document/api/1323/80033)

	* 新增入参：Agent

* [CreateUserAutoSignEnableUrl](https://cloud.tencent.com/document/api/1323/87787)

	* 新增入参：Agent

* [DescribeThirdPartyAuthCode](https://cloud.tencent.com/document/api/1323/70368)

	* 新增入参：Operator, Agent

* [DescribeUserAutoSignStatus](https://cloud.tencent.com/document/api/1323/87786)

	* 新增入参：Agent

* [DisableUserAutoSign](https://cloud.tencent.com/document/api/1323/87785)

	* 新增入参：Agent

* [UnbindEmployeeUserIdWithClientOpenId](https://cloud.tencent.com/document/api/1323/90239)

	* 新增入参：Agent


修改数据结构：

* [FillApproverInfo](https://cloud.tencent.com/document/api/1323/70369#FillApproverInfo)

	* 新增成员：ApproverName, ApproverMobile

	* <font color="#dd0000">**修改成员**：</font>ApproverSource, CustomUserId


### 第 90 次发布

发布时间：2023-07-21 01:23:30

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateSchemeUrl](https://cloud.tencent.com/document/api/1323/70359)

	* 新增入参：Hides


修改数据结构：

* [RegisterInfo](https://cloud.tencent.com/document/api/1323/70369#RegisterInfo)

	* 新增成员：UnifiedSocialCreditCode

	* <font color="#dd0000">**修改成员**：</font>Uscc


### 第 89 次发布

发布时间：2023-07-19 01:24:04

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateReleaseFlow](https://cloud.tencent.com/document/api/1323/88045)

	* 新增入参：Agent


### 第 88 次发布

发布时间：2023-07-18 01:29:51

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateFlowSignUrl](https://cloud.tencent.com/document/api/1323/85818)

	* 新增入参：JumpUrl


### 第 87 次发布

发布时间：2023-07-17 01:19:24

本次发布包含了以下内容：

改善已有的文档。

<font color="#dd0000">**预下线接口**：</font>

* CreateChannelSubOrganizationModifyQrCode

修改数据结构：

* [FlowCreateApprover](https://cloud.tencent.com/document/api/1323/70369#FlowCreateApprover)

	* 新增成员：SignComponents, Components, ComponentLimitType


### 第 86 次发布

发布时间：2023-07-10 14:56:45

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateFlowGroupByFiles](https://cloud.tencent.com/document/api/1323/94888)
* [CreateFlowGroupByTemplates](https://cloud.tencent.com/document/api/1323/94887)

新增数据结构：

* [FlowGroupInfo](https://cloud.tencent.com/document/api/1323/70369#FlowGroupInfo)
* [FlowGroupOptions](https://cloud.tencent.com/document/api/1323/70369#FlowGroupOptions)

### 第 85 次发布

发布时间：2023-07-10 11:31:37

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateSchemeUrl](https://cloud.tencent.com/document/api/1323/70359)

	* 新增入参：FlowGroupId

* [DescribeFlowInfo](https://cloud.tencent.com/document/api/1323/80032)

	* 新增入参：FlowGroupId

	* <font color="#dd0000">**修改入参**：</font>FlowIds

	* 新增出参：FlowGroupId, FlowGroupName


修改数据结构：

* [ApproverInfo](https://cloud.tencent.com/document/api/1323/70369#ApproverInfo)

	* <font color="#dd0000">**修改成员**：</font>SignComponents

* [FlowApproverDetail](https://cloud.tencent.com/document/api/1323/70369#FlowApproverDetail)

	* <font color="#dd0000">**修改成员**：</font>ApproveMessage

* [FlowDetailInfo](https://cloud.tencent.com/document/api/1323/70369#FlowDetailInfo)

	* <font color="#dd0000">**修改成员**：</font>CcInfos, Creator


### 第 84 次发布

发布时间：2023-07-05 01:27:03

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateFlowSignReview](https://cloud.tencent.com/document/api/1323/78980)

	* 新增入参：RecipientId, OperateType


修改数据结构：

* [FailedCreateStaffData](https://cloud.tencent.com/document/api/1323/70369#FailedCreateStaffData)

	* 新增成员：WeworkOpenId

* [Staff](https://cloud.tencent.com/document/api/1323/70369#Staff)

	* 新增成员：WeworkOpenId

* [SuccessCreateStaffData](https://cloud.tencent.com/document/api/1323/70369#SuccessCreateStaffData)

	* 新增成员：WeworkOpenId

	* <font color="#dd0000">**修改成员**：</font>Note


### 第 83 次发布

发布时间：2023-06-30 18:46:08

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateReleaseFlow](https://cloud.tencent.com/document/api/1323/88045)

	* 新增入参：Deadline


修改数据结构：

* [ReleasedApprover](https://cloud.tencent.com/document/api/1323/70369#ReleasedApprover)

	* 新增成员：ApproverSignComponentType, ApproverSignRole


### 第 82 次发布

发布时间：2023-06-30 01:25:52

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateBatchCancelFlowUrl](https://cloud.tencent.com/document/api/1323/78262)

	* 新增入参：Agent

* [CreateFlowEvidenceReport](https://cloud.tencent.com/document/api/1323/79686)

	* 新增入参：Agent

* [CreateFlowReminds](https://cloud.tencent.com/document/api/1323/86002)

	* 新增入参：Agent

* [DescribeFlowEvidenceReport](https://cloud.tencent.com/document/api/1323/83441)

	* 新增入参：Agent


### 第 81 次发布

发布时间：2023-06-29 01:21:41

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [ApproverInfo](https://cloud.tencent.com/document/api/1323/70369#ApproverInfo)

	* 新增成员：ApproverNeedSignReview

* [CcInfo](https://cloud.tencent.com/document/api/1323/70369#CcInfo)

	* 新增成员：NotifyType

* [FlowCreateApprover](https://cloud.tencent.com/document/api/1323/70369#FlowCreateApprover)

	* 新增成员：ApproverNeedSignReview


### 第 80 次发布

发布时间：2023-06-21 01:18:51

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeFlowComponents](https://cloud.tencent.com/document/api/1323/94219)

新增数据结构：

* [FilledComponent](https://cloud.tencent.com/document/api/1323/70369#FilledComponent)
* [RecipientComponentInfo](https://cloud.tencent.com/document/api/1323/70369#RecipientComponentInfo)

### 第 79 次发布

发布时间：2023-06-19 01:20:19

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateSeal](https://cloud.tencent.com/document/api/1323/94136)

### 第 78 次发布

发布时间：2023-06-16 01:23:31

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateFlow](https://cloud.tencent.com/document/api/1323/70361)

	* 新增入参：RemindedOn

* [CreateFlowByFiles](https://cloud.tencent.com/document/api/1323/70360)

	* 新增入参：RemindedOn


### 第 77 次发布

发布时间：2023-06-14 01:22:43

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeExtendedServiceAuthInfos](https://cloud.tencent.com/document/api/1323/93477)

修改接口：

* [CreatePreparedPersonalEsign](https://cloud.tencent.com/document/api/1323/89386)

* [DescribeFlowTemplates](https://cloud.tencent.com/document/api/1323/74803)


新增数据结构：

* [ExtendAuthInfo](https://cloud.tencent.com/document/api/1323/70369#ExtendAuthInfo)
* [HasAuthUser](https://cloud.tencent.com/document/api/1323/70369#HasAuthUser)
* [SealInfo](https://cloud.tencent.com/document/api/1323/70369#SealInfo)

修改数据结构：

* [TemplateInfo](https://cloud.tencent.com/document/api/1323/70369#TemplateInfo)

	* 新增成员：TemplateSeals, Seals


### 第 76 次发布

发布时间：2023-06-08 16:46:00

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CancelUserAutoSignEnableUrl](https://cloud.tencent.com/document/api/1323/93320)

### 第 75 次发布

发布时间：2023-06-08 11:16:02

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateIntegrationDepartment](https://cloud.tencent.com/document/api/1323/93289)
* [DeleteIntegrationDepartment](https://cloud.tencent.com/document/api/1323/93288)
* [DescribeIntegrationDepartments](https://cloud.tencent.com/document/api/1323/93287)
* [ModifyIntegrationDepartment](https://cloud.tencent.com/document/api/1323/93286)

新增数据结构：

* [IntegrationDepartment](https://cloud.tencent.com/document/api/1323/70369#IntegrationDepartment)

### 第 74 次发布

发布时间：2023-06-08 01:28:55

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [FlowCreateApprover](https://cloud.tencent.com/document/api/1323/70369#FlowCreateApprover)

	* 新增成员：SignId


### 第 73 次发布

发布时间：2023-06-06 15:06:22

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [ReleasedApprover](https://cloud.tencent.com/document/api/1323/70369#ReleasedApprover)

	* 新增成员：ApproverType


### 第 72 次发布

发布时间：2023-06-02 15:55:45

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateConvertTaskApi](https://cloud.tencent.com/document/api/1323/78149)

* [CreateFlow](https://cloud.tencent.com/document/api/1323/70361)

* [CreateFlowSignUrl](https://cloud.tencent.com/document/api/1323/85818)

* [CreateMultiFlowSignQRCode](https://cloud.tencent.com/document/api/1323/75450)

* [CreatePreparedPersonalEsign](https://cloud.tencent.com/document/api/1323/89386)

	* 新增入参：FileId

	* <font color="#dd0000">**修改入参**：</font>SealImage

* [DescribeFileUrls](https://cloud.tencent.com/document/api/1323/70366)

* [DescribeFlowTemplates](https://cloud.tencent.com/document/api/1323/74803)

* [DescribeIntegrationEmployees](https://cloud.tencent.com/document/api/1323/81115)

	* 新增入参：Agent

* [GetTaskResultApi](https://cloud.tencent.com/document/api/1323/78148)

* [UploadFiles](https://cloud.tencent.com/document/api/1323/73066)


修改数据结构：

* [CallbackInfo](https://cloud.tencent.com/document/api/1323/70369#CallbackInfo)

	* 新增成员：CallbackKey, CallbackToken

	* <font color="#dd0000">**修改成员**：</font>Token

* [OrganizationInfo](https://cloud.tencent.com/document/api/1323/70369#OrganizationInfo)

* [UserInfo](https://cloud.tencent.com/document/api/1323/70369#UserInfo)


### 第 71 次发布

发布时间：2023-06-02 01:26:15

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [Caller](https://cloud.tencent.com/document/api/1323/70369#Caller)

* [FlowCreateApprover](https://cloud.tencent.com/document/api/1323/70369#FlowCreateApprover)


### 第 70 次发布

发布时间：2023-05-31 01:25:51

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreatePreparedPersonalEsign](https://cloud.tencent.com/document/api/1323/89386)

	* 新增入参：SealImageCompress, SealColor, ProcessSeal


修改数据结构：

* [TemplateInfo](https://cloud.tencent.com/document/api/1323/70369#TemplateInfo)

	* 新增成员：TemplateType


### 第 69 次发布

发布时间：2023-05-30 17:10:50

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [Agent](https://cloud.tencent.com/document/api/1323/70369#Agent)


### 第 68 次发布

发布时间：2023-05-25 11:31:02

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [FlowBrief](https://cloud.tencent.com/document/api/1323/70369#FlowBrief)

	* 新增成员：Deadline


### 第 67 次发布

发布时间：2023-05-25 01:35:47

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateUserAutoSignEnableUrl](https://cloud.tencent.com/document/api/1323/87787)

	* 新增入参：ExpiredTime


### 第 66 次发布

发布时间：2023-05-19 20:06:02

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeUserAutoSignStatus](https://cloud.tencent.com/document/api/1323/87786)

	* 新增出参：LicenseFrom, LicenseTo


### 第 65 次发布

发布时间：2023-05-18 01:26:41

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateFlow](https://cloud.tencent.com/document/api/1323/70361)

	* 新增入参：AutoSignScene

* [CreateFlowByFiles](https://cloud.tencent.com/document/api/1323/70360)

	* 新增入参：AutoSignScene


### 第 64 次发布

发布时间：2023-05-11 17:55:47

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateChannelSubOrganizationModifyQrCode](https://cloud.tencent.com/document/api/1323/90975)

### 第 63 次发布

发布时间：2023-05-08 01:23:59

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateFlowSignUrl](https://cloud.tencent.com/document/api/1323/85818)

	* 新增入参：Agent


修改数据结构：

* [FlowApproverUrlInfo](https://cloud.tencent.com/document/api/1323/70369#FlowApproverUrlInfo)

	* 新增成员：LongUrl


### 第 62 次发布

发布时间：2023-05-05 01:17:54

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [FlowCreateApprover](https://cloud.tencent.com/document/api/1323/70369#FlowCreateApprover)

	* 新增成员：JumpUrl


### 第 61 次发布

发布时间：2023-04-24 01:19:11

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateDocument](https://cloud.tencent.com/document/api/1323/70364)

	* <font color="#dd0000">**修改入参**：</font>FileNames

* [CreateFlowSignUrl](https://cloud.tencent.com/document/api/1323/85818)

	* <font color="#dd0000">**修改入参**：</font>Organization


修改数据结构：

* [FlowBrief](https://cloud.tencent.com/document/api/1323/70369#FlowBrief)

	* 新增成员：Creator

* [FlowDetailInfo](https://cloud.tencent.com/document/api/1323/70369#FlowDetailInfo)

	* 新增成员：Creator


### 第 60 次发布

发布时间：2023-04-18 17:30:51

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateUserAutoSignEnableUrl](https://cloud.tencent.com/document/api/1323/87787)

	* 新增入参：NotifyType, NotifyAddress


### 第 59 次发布

发布时间：2023-04-18 11:25:48

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [UpdateIntegrationEmployees](https://cloud.tencent.com/document/api/1323/89457)

	* <font color="#dd0000">**修改入参**：</font>Agent


### 第 58 次发布

发布时间：2023-04-17 20:50:42

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [UnbindEmployeeUserIdWithClientOpenId](https://cloud.tencent.com/document/api/1323/90239)

### 第 57 次发布

发布时间：2023-04-17 20:40:51

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [BindEmployeeUserIdWithClientOpenId](https://cloud.tencent.com/document/api/1323/90238)

### 第 56 次发布

发布时间：2023-04-12 01:27:24

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [TemplateInfo](https://cloud.tencent.com/document/api/1323/70369#TemplateInfo)

	* 新增成员：Available


### 第 55 次发布

发布时间：2023-03-31 01:26:47

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [FlowDetailInfo](https://cloud.tencent.com/document/api/1323/70369#FlowDetailInfo)

	* 新增成员：CcInfos


### 第 54 次发布

发布时间：2023-03-28 10:31:03

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [ModifyApplicationCallbackInfo](https://cloud.tencent.com/document/api/1323/86752)

	* 新增入参：Operator, OperateType, CallbackInfo


新增数据结构：

* [CallbackInfo](https://cloud.tencent.com/document/api/1323/70369#CallbackInfo)

### 第 53 次发布

发布时间：2023-03-27 15:40:49

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateIntegrationUserRoles](https://cloud.tencent.com/document/api/1323/89460)
* [DeleteIntegrationRoleUsers](https://cloud.tencent.com/document/api/1323/89459)
* [DescribeIntegrationRoles](https://cloud.tencent.com/document/api/1323/89458)
* [UpdateIntegrationEmployees](https://cloud.tencent.com/document/api/1323/89457)

新增数据结构：

* [FailedCreateRoleData](https://cloud.tencent.com/document/api/1323/70369#FailedCreateRoleData)
* [FailedUpdateStaffData](https://cloud.tencent.com/document/api/1323/70369#FailedUpdateStaffData)
* [IntegrateRole](https://cloud.tencent.com/document/api/1323/70369#IntegrateRole)
* [SuccessUpdateStaffData](https://cloud.tencent.com/document/api/1323/70369#SuccessUpdateStaffData)

### 第 52 次发布

发布时间：2023-03-27 01:52:50

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreatePreparedPersonalEsign](https://cloud.tencent.com/document/api/1323/89386)

修改接口：

* [CreateIntegrationEmployees](https://cloud.tencent.com/document/api/1323/81117)

	* 新增入参：Agent

* [DeleteIntegrationEmployees](https://cloud.tencent.com/document/api/1323/81116)

	* 新增入参：Agent


修改数据结构：

* [Staff](https://cloud.tencent.com/document/api/1323/70369#Staff)

	* 新增成员：ReceiveUserId, ReceiveOpenId

* [SuccessCreateStaffData](https://cloud.tencent.com/document/api/1323/70369#SuccessCreateStaffData)

	* 新增成员：Note


### 第 51 次发布

发布时间：2023-03-23 01:38:57

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [ApproverInfo](https://cloud.tencent.com/document/api/1323/70369#ApproverInfo)

	* 新增成员：ApproverVerifyTypes, ApproverSignTypes


### 第 50 次发布

发布时间：2023-03-10 01:32:25

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateFlowByFiles](https://cloud.tencent.com/document/api/1323/70360)

	* 新增入参：CcNotifyType

* [StartFlow](https://cloud.tencent.com/document/api/1323/70357)

	* 新增入参：CcNotifyType


修改数据结构：

* [CcInfo](https://cloud.tencent.com/document/api/1323/70369#CcInfo)

	* 新增成员：Name, CcType, CcPermission


### 第 49 次发布

发布时间：2023-03-09 10:15:36

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateReleaseFlow](https://cloud.tencent.com/document/api/1323/88045)

新增数据结构：

* [ReleasedApprover](https://cloud.tencent.com/document/api/1323/70369#ReleasedApprover)
* [RelieveInfo](https://cloud.tencent.com/document/api/1323/70369#RelieveInfo)

### 第 48 次发布

发布时间：2023-03-06 01:20:52

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateUserAutoSignEnableUrl](https://cloud.tencent.com/document/api/1323/87787)
* [DescribeUserAutoSignStatus](https://cloud.tencent.com/document/api/1323/87786)
* [DisableUserAutoSign](https://cloud.tencent.com/document/api/1323/87785)

新增数据结构：

* [AutoSignConfig](https://cloud.tencent.com/document/api/1323/70369#AutoSignConfig)
* [UserThreeFactor](https://cloud.tencent.com/document/api/1323/70369#UserThreeFactor)

### 第 47 次发布

发布时间：2023-03-02 01:21:05

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateFlowApprovers](https://cloud.tencent.com/document/api/1323/80033)

	* 新增入参：Initiator


### 第 46 次发布

发布时间：2023-02-23 01:24:24

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateMultiFlowSignQRCode](https://cloud.tencent.com/document/api/1323/75450)

	* 新增入参：UserData


### 第 45 次发布

发布时间：2023-02-22 01:26:57

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [ModifyApplicationCallbackInfo](https://cloud.tencent.com/document/api/1323/86752)

### 第 44 次发布

发布时间：2023-02-14 01:26:39

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeOrganizationSeals](https://cloud.tencent.com/document/api/1323/82453)

	* 新增入参：Agent


修改数据结构：

* [Agent](https://cloud.tencent.com/document/api/1323/70369#Agent)

	* 新增成员：AppId, ProxyAppId, ProxyOrganizationId, ProxyOperator


### 第 43 次发布

发布时间：2023-02-13 01:39:26

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeOrganizationSeals](https://cloud.tencent.com/document/api/1323/82453)

	* 新增入参：SealTypes


### 第 42 次发布

发布时间：2023-02-07 11:30:44

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateSealPolicy](https://cloud.tencent.com/document/api/1323/86183)
* [DeleteSealPolicies](https://cloud.tencent.com/document/api/1323/86182)

### 第 41 次发布

发布时间：2023-02-06 01:41:26

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeIntegrationMainOrganizationUser](https://cloud.tencent.com/document/api/1323/86115)
* [DescribeOrganizationGroupOrganizations](https://cloud.tencent.com/document/api/1323/86114)

修改接口：

* [DescribeFlowInfo](https://cloud.tencent.com/document/api/1323/80032)

	* 新增入参：Agent


新增数据结构：

* [Admin](https://cloud.tencent.com/document/api/1323/70369#Admin)
* [GroupOrganization](https://cloud.tencent.com/document/api/1323/70369#GroupOrganization)
* [IntegrationMainOrganizationUser](https://cloud.tencent.com/document/api/1323/70369#IntegrationMainOrganizationUser)

### 第 40 次发布

发布时间：2023-02-01 01:24:24

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateFlowReminds](https://cloud.tencent.com/document/api/1323/86002)

新增数据结构：

* [RemindFlowRecords](https://cloud.tencent.com/document/api/1323/70369#RemindFlowRecords)

### 第 39 次发布

发布时间：2023-01-13 16:40:54

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateFlowSignUrl](https://cloud.tencent.com/document/api/1323/85818)

新增数据结构：

* [FlowApproverUrlInfo](https://cloud.tencent.com/document/api/1323/70369#FlowApproverUrlInfo)

### 第 38 次发布

发布时间：2023-01-11 01:21:38

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateFlow](https://cloud.tencent.com/document/api/1323/70361)

	* 新增入参：CcInfos


### 第 37 次发布

发布时间：2023-01-09 01:23:34

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [VerifyPdf](https://cloud.tencent.com/document/api/1323/80797)

	* 新增出参：VerifySerialNo


### 第 36 次发布

发布时间：2022-12-14 01:27:17

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [TemplateInfo](https://cloud.tencent.com/document/api/1323/70369#TemplateInfo)

	* 新增成员：TemplateVersion, Published


### 第 35 次发布

发布时间：2022-12-09 01:34:50

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [Staff](https://cloud.tencent.com/document/api/1323/70369#Staff)

	* 新增成员：QuiteJob


### 第 34 次发布

发布时间：2022-12-07 06:39:12

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeFlowTemplates](https://cloud.tencent.com/document/api/1323/74803)

	* 新增入参：Organization, ApplicationId, IsChannel


修改数据结构：

* [TemplateInfo](https://cloud.tencent.com/document/api/1323/70369#TemplateInfo)

	* 新增成员：OrganizationId, PreviewUrl


### 第 33 次发布

发布时间：2022-12-06 06:41:11

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [Component](https://cloud.tencent.com/document/api/1323/70369#Component)

	* 新增成员：ChannelComponentId, ChannelComponentSource


### 第 32 次发布

发布时间：2022-11-25 18:17:09

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeFlowEvidenceReport](https://cloud.tencent.com/document/api/1323/83441)

### 第 31 次发布

发布时间：2022-11-25 16:12:15

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreatePrepareFlow](https://cloud.tencent.com/document/api/1323/83412)

### 第 30 次发布

发布时间：2022-11-21 15:12:52

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateFlowByFiles](https://cloud.tencent.com/document/api/1323/70360)

	* 新增入参：SignBeanTag


### 第 29 次发布

发布时间：2022-11-17 06:26:17

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [Component](https://cloud.tencent.com/document/api/1323/70369#Component)

	* 新增成员：KeywordOrder, KeywordPage, RelativeLocation, KeywordIndexes


### 第 28 次发布

发布时间：2022-11-16 16:58:04

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateFlowEvidenceReport](https://cloud.tencent.com/document/api/1323/79686)

	* 新增出参：ReportId, Status


### 第 27 次发布

发布时间：2022-11-15 06:24:10

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateDocument](https://cloud.tencent.com/document/api/1323/70364)

	* 新增入参：PreviewType

* [CreateFlowByFiles](https://cloud.tencent.com/document/api/1323/70360)

	* 新增入参：PreviewType


### 第 26 次发布

发布时间：2022-11-08 06:25:11

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeOrganizationSeals](https://cloud.tencent.com/document/api/1323/82453)

	* 新增入参：SealId


### 第 25 次发布

发布时间：2022-11-07 10:56:26

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeOrganizationSeals](https://cloud.tencent.com/document/api/1323/82453)

新增数据结构：

* [AuthorizedUser](https://cloud.tencent.com/document/api/1323/70369#AuthorizedUser)
* [OccupiedSeal](https://cloud.tencent.com/document/api/1323/70369#OccupiedSeal)

### 第 24 次发布

发布时间：2022-11-04 06:23:37

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateFlowByFiles](https://cloud.tencent.com/document/api/1323/70360)

	* 新增入参：ApproverVerifyType


### 第 23 次发布

发布时间：2022-11-01 17:32:04

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateFlowByFiles](https://cloud.tencent.com/document/api/1323/70360)

	* 新增入参：UserData


### 第 22 次发布

发布时间：2022-11-01 16:03:19

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [ApproverInfo](https://cloud.tencent.com/document/api/1323/70369#ApproverInfo)

	* 新增成员：ApproverOption


### 第 21 次发布

发布时间：2022-10-26 06:35:22

本次发布包含了以下内容：

改善已有的文档。

新增数据结构：

* [ApproverOption](https://cloud.tencent.com/document/api/1323/70369#ApproverOption)

修改数据结构：

* [FlowCreateApprover](https://cloud.tencent.com/document/api/1323/70369#FlowCreateApprover)

	* 新增成员：ApproverOption


### 第 20 次发布

发布时间：2022-10-20 06:24:19

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateMultiFlowSignQRCode](https://cloud.tencent.com/document/api/1323/75450)

	* 新增入参：Restrictions


### 第 19 次发布

发布时间：2022-09-29 06:30:30

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateIntegrationEmployees](https://cloud.tencent.com/document/api/1323/81117)
* [DeleteIntegrationEmployees](https://cloud.tencent.com/document/api/1323/81116)
* [DescribeIntegrationEmployees](https://cloud.tencent.com/document/api/1323/81115)

新增数据结构：

* [CreateStaffResult](https://cloud.tencent.com/document/api/1323/70369#CreateStaffResult)
* [DeleteStaffsResult](https://cloud.tencent.com/document/api/1323/70369#DeleteStaffsResult)
* [Department](https://cloud.tencent.com/document/api/1323/70369#Department)
* [FailedCreateStaffData](https://cloud.tencent.com/document/api/1323/70369#FailedCreateStaffData)
* [FailedDeleteStaffData](https://cloud.tencent.com/document/api/1323/70369#FailedDeleteStaffData)
* [Staff](https://cloud.tencent.com/document/api/1323/70369#Staff)
* [StaffRole](https://cloud.tencent.com/document/api/1323/70369#StaffRole)
* [SuccessCreateStaffData](https://cloud.tencent.com/document/api/1323/70369#SuccessCreateStaffData)
* [SuccessDeleteStaffData](https://cloud.tencent.com/document/api/1323/70369#SuccessDeleteStaffData)

### 第 18 次发布

发布时间：2022-09-20 21:03:08

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [VerifyPdf](https://cloud.tencent.com/document/api/1323/80797)

新增数据结构：

* [PdfVerifyResult](https://cloud.tencent.com/document/api/1323/70369#PdfVerifyResult)

### 第 17 次发布

发布时间：2022-09-16 06:24:43

本次发布包含了以下内容：

改善已有的文档。

新增数据结构：

* [RegisterInfo](https://cloud.tencent.com/document/api/1323/70369#RegisterInfo)

修改数据结构：

* [FlowCreateApprover](https://cloud.tencent.com/document/api/1323/70369#FlowCreateApprover)

	* 新增成员：RegisterInfo


### 第 16 次发布

发布时间：2022-09-02 06:31:01

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateFlowApprovers](https://cloud.tencent.com/document/api/1323/80033)
* [DescribeFlowInfo](https://cloud.tencent.com/document/api/1323/80032)

新增数据结构：

* [FillApproverInfo](https://cloud.tencent.com/document/api/1323/70369#FillApproverInfo)
* [FlowApproverDetail](https://cloud.tencent.com/document/api/1323/70369#FlowApproverDetail)
* [FlowDetailInfo](https://cloud.tencent.com/document/api/1323/70369#FlowDetailInfo)

修改数据结构：

* [ApproverInfo](https://cloud.tencent.com/document/api/1323/70369#ApproverInfo)

	* 新增成员：UserId, ApproverSource, CustomApproverTag

* [FlowCreateApprover](https://cloud.tencent.com/document/api/1323/70369#FlowCreateApprover)

	* 新增成员：ApproverSource, CustomApproverTag


### 第 15 次发布

发布时间：2022-08-29 00:06:53

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateFlowEvidenceReport](https://cloud.tencent.com/document/api/1323/79686)

### 第 14 次发布

发布时间：2022-08-11 22:36:30

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateFlowSignReview](https://cloud.tencent.com/document/api/1323/78980)

### 第 13 次发布

发布时间：2022-08-11 07:02:49

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateFlow](https://cloud.tencent.com/document/api/1323/70361)

	* 新增入参：NeedSignReview

* [CreateFlowByFiles](https://cloud.tencent.com/document/api/1323/70360)

	* 新增入参：NeedSignReview


### 第 12 次发布

发布时间：2022-08-03 06:24:12

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateBatchCancelFlowUrl](https://cloud.tencent.com/document/api/1323/78262)

修改接口：

* [CreateMultiFlowSignQRCode](https://cloud.tencent.com/document/api/1323/75450)

	* 新增入参：ApproverRestrictions

	* 新增出参：SignUrls


新增数据结构：

* [ApproverRestriction](https://cloud.tencent.com/document/api/1323/70369#ApproverRestriction)
* [SignUrl](https://cloud.tencent.com/document/api/1323/70369#SignUrl)

### 第 11 次发布

发布时间：2022-07-30 15:12:18

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateConvertTaskApi](https://cloud.tencent.com/document/api/1323/78149)
* [GetTaskResultApi](https://cloud.tencent.com/document/api/1323/78148)

新增数据结构：

* [OrganizationInfo](https://cloud.tencent.com/document/api/1323/70369#OrganizationInfo)

### 第 10 次发布

发布时间：2022-07-05 06:13:29

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [UploadFiles](https://cloud.tencent.com/document/api/1323/73066)

	* <font color="#dd0000">**修改入参**：</font>Caller


### 第 9 次发布

发布时间：2022-06-30 06:06:55

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateFlow](https://cloud.tencent.com/document/api/1323/70361)

	* 新增入参：RelatedFlowId, CustomShowMap

* [CreateFlowByFiles](https://cloud.tencent.com/document/api/1323/70360)

	* 新增入参：CustomShowMap


修改数据结构：

* [Caller](https://cloud.tencent.com/document/api/1323/70369#Caller)

	* <font color="#dd0000">**修改成员**：</font>ApplicationId


### 第 8 次发布

发布时间：2022-06-13 06:11:55

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CancelMultiFlowSignQRCode](https://cloud.tencent.com/document/api/1323/75451)
* [CreateMultiFlowSignQRCode](https://cloud.tencent.com/document/api/1323/75450)

新增数据结构：

* [SignQrCode](https://cloud.tencent.com/document/api/1323/70369#SignQrCode)

### 第 7 次发布

发布时间：2022-06-02 06:08:09

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeFlowTemplates](https://cloud.tencent.com/document/api/1323/74803)

新增数据结构：

* [FileInfo](https://cloud.tencent.com/document/api/1323/70369#FileInfo)
* [Filter](https://cloud.tencent.com/document/api/1323/70369#Filter)
* [Recipient](https://cloud.tencent.com/document/api/1323/70369#Recipient)
* [TemplateInfo](https://cloud.tencent.com/document/api/1323/70369#TemplateInfo)

### 第 6 次发布

发布时间：2022-05-16 06:09:12

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [Component](https://cloud.tencent.com/document/api/1323/70369#Component)

	* 新增成员：OffsetX, OffsetY


### 第 5 次发布

发布时间：2022-04-29 06:07:54

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateSchemeUrl](https://cloud.tencent.com/document/api/1323/70359)

	* 新增入参：OrganizationName, EndPoint, AutoJumpBack


### 第 4 次发布

发布时间：2022-04-25 06:06:57

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [UploadFiles](https://cloud.tencent.com/document/api/1323/73066)

新增数据结构：

* [Caller](https://cloud.tencent.com/document/api/1323/70369#Caller)
* [UploadFile](https://cloud.tencent.com/document/api/1323/70369#UploadFile)

### 第 3 次发布

发布时间：2022-03-18 15:46:35

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CancelFlow](https://cloud.tencent.com/document/api/1323/70362)

	* <font color="#dd0000">**修改入参**：</font>Agent


修改数据结构：

* [FlowCreateApprover](https://cloud.tencent.com/document/api/1323/70369#FlowCreateApprover)

	* 新增成员：VerifyChannel


### 第 2 次发布

发布时间：2022-03-16 08:09:15

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateDocument](https://cloud.tencent.com/document/api/1323/70364)

	* 新增入参：NeedPreview

	* 新增出参：PreviewFileUrl

* [CreateFlowByFiles](https://cloud.tencent.com/document/api/1323/70360)

	* 新增入参：NeedPreview

	* 新增出参：PreviewUrl


### 第 1 次发布

发布时间：2022-02-25 16:43:22

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CancelFlow](https://cloud.tencent.com/document/api/1323/70362)
* [CreateDocument](https://cloud.tencent.com/document/api/1323/70364)
* [CreateFlow](https://cloud.tencent.com/document/api/1323/70361)
* [CreateFlowByFiles](https://cloud.tencent.com/document/api/1323/70360)
* [CreateSchemeUrl](https://cloud.tencent.com/document/api/1323/70359)
* [DescribeFileUrls](https://cloud.tencent.com/document/api/1323/70366)
* [DescribeFlowBriefs](https://cloud.tencent.com/document/api/1323/70358)
* [DescribeThirdPartyAuthCode](https://cloud.tencent.com/document/api/1323/70368)
* [StartFlow](https://cloud.tencent.com/document/api/1323/70357)

新增数据结构：

* [Agent](https://cloud.tencent.com/document/api/1323/70369#Agent)
* [ApproverInfo](https://cloud.tencent.com/document/api/1323/70369#ApproverInfo)
* [CcInfo](https://cloud.tencent.com/document/api/1323/70369#CcInfo)
* [Component](https://cloud.tencent.com/document/api/1323/70369#Component)
* [FileUrl](https://cloud.tencent.com/document/api/1323/70369#FileUrl)
* [FlowBrief](https://cloud.tencent.com/document/api/1323/70369#FlowBrief)
* [FlowCreateApprover](https://cloud.tencent.com/document/api/1323/70369#FlowCreateApprover)
* [FormField](https://cloud.tencent.com/document/api/1323/70369#FormField)
* [UserInfo](https://cloud.tencent.com/document/api/1323/70369#UserInfo)




## 腾讯电子签（基础版）(essbasic) 版本：2020-12-22

### 第 1 次发布

发布时间：2021-09-15 11:54:06

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [ArchiveFlow](https://cloud.tencent.com/document/api/#/#)
* [CancelFlow](https://cloud.tencent.com/document/api/#/#)
* [CheckBankCard2EVerification](https://cloud.tencent.com/document/api/#/#)
* [CheckBankCard3EVerification](https://cloud.tencent.com/document/api/#/#)
* [CheckBankCard4EVerification](https://cloud.tencent.com/document/api/#/#)
* [CheckBankCardVerification](https://cloud.tencent.com/document/api/#/#)
* [CheckFaceIdentify](https://cloud.tencent.com/document/api/#/#)
* [CheckIdCardVerification](https://cloud.tencent.com/document/api/#/#)
* [CheckMobileAndName](https://cloud.tencent.com/document/api/#/#)
* [CheckMobileVerification](https://cloud.tencent.com/document/api/#/#)
* [CheckVerifyCodeMatchFlowId](https://cloud.tencent.com/document/api/#/#)
* [CreateFaceIdSign](https://cloud.tencent.com/document/api/#/#)
* [CreateFlowByFiles](https://cloud.tencent.com/document/api/#/#)
* [CreateH5FaceIdUrl](https://cloud.tencent.com/document/api/#/#)
* [CreatePreviewSignUrl](https://cloud.tencent.com/document/api/#/#)
* [CreateSeal](https://cloud.tencent.com/document/api/#/#)
* [CreateServerFlowSign](https://cloud.tencent.com/document/api/#/#)
* [CreateSignUrl](https://cloud.tencent.com/document/api/#/#)
* [CreateSubOrganization](https://cloud.tencent.com/document/api/#/#)
* [CreateSubOrganizationAndSeal](https://cloud.tencent.com/document/api/#/#)
* [CreateUser](https://cloud.tencent.com/document/api/#/#)
* [CreateUserAndSeal](https://cloud.tencent.com/document/api/#/#)
* [DeleteSeal](https://cloud.tencent.com/document/api/#/#)
* [DescribeCatalogApprovers](https://cloud.tencent.com/document/api/#/#)
* [DescribeCatalogSignComponents](https://cloud.tencent.com/document/api/#/#)
* [DescribeCustomFlowIds](https://cloud.tencent.com/document/api/#/#)
* [DescribeCustomFlowIdsByFlowId](https://cloud.tencent.com/document/api/#/#)
* [DescribeFaceIdPhotos](https://cloud.tencent.com/document/api/#/#)
* [DescribeFaceIdResults](https://cloud.tencent.com/document/api/#/#)
* [DescribeFileIdsByCustomIds](https://cloud.tencent.com/document/api/#/#)
* [DescribeFileUrls](https://cloud.tencent.com/document/api/#/#)
* [DescribeFlow](https://cloud.tencent.com/document/api/#/#)
* [DescribeFlowApprovers](https://cloud.tencent.com/document/api/#/#)
* [DescribeFlowFiles](https://cloud.tencent.com/document/api/#/#)
* [DescribeSeals](https://cloud.tencent.com/document/api/#/#)
* [DescribeSubOrganizations](https://cloud.tencent.com/document/api/#/#)
* [DescribeUsers](https://cloud.tencent.com/document/api/#/#)
* [DestroyFlowFile](https://cloud.tencent.com/document/api/#/#)
* [GenerateOrganizationSeal](https://cloud.tencent.com/document/api/#/#)
* [GenerateUserSeal](https://cloud.tencent.com/document/api/#/#)
* [ModifyOrganizationDefaultSeal](https://cloud.tencent.com/document/api/#/#)
* [ModifySeal](https://cloud.tencent.com/document/api/#/#)
* [ModifySubOrganizationInfo](https://cloud.tencent.com/document/api/#/#)
* [ModifyUser](https://cloud.tencent.com/document/api/#/#)
* [ModifyUserDefaultSeal](https://cloud.tencent.com/document/api/#/#)
* [RejectFlow](https://cloud.tencent.com/document/api/#/#)
* [SendFlow](https://cloud.tencent.com/document/api/#/#)
* [SendFlowUrl](https://cloud.tencent.com/document/api/#/#)
* [SendSignInnerVerifyCode](https://cloud.tencent.com/document/api/#/#)
* [SignFlow](https://cloud.tencent.com/document/api/#/#)
* [UploadFiles](https://cloud.tencent.com/document/api/#/#)
* [VerifySubOrganization](https://cloud.tencent.com/document/api/#/#)
* [VerifyUser](https://cloud.tencent.com/document/api/#/#)

新增数据结构：

* [Address](https://cloud.tencent.com/document/api/#/##Address)
* [Caller](https://cloud.tencent.com/document/api/#/##Caller)
* [CatalogApprovers](https://cloud.tencent.com/document/api/#/##CatalogApprovers)
* [CatalogComponents](https://cloud.tencent.com/document/api/#/##CatalogComponents)
* [Component](https://cloud.tencent.com/document/api/#/##Component)
* [ComponentSeal](https://cloud.tencent.com/document/api/#/##ComponentSeal)
* [CustomFileIdMap](https://cloud.tencent.com/document/api/#/##CustomFileIdMap)
* [CustomFlowIdMap](https://cloud.tencent.com/document/api/#/##CustomFlowIdMap)
* [FaceIdPhoto](https://cloud.tencent.com/document/api/#/##FaceIdPhoto)
* [FaceIdResult](https://cloud.tencent.com/document/api/#/##FaceIdResult)
* [FileUrl](https://cloud.tencent.com/document/api/#/##FileUrl)
* [FlowApproverInfo](https://cloud.tencent.com/document/api/#/##FlowApproverInfo)
* [FlowFileInfo](https://cloud.tencent.com/document/api/#/##FlowFileInfo)
* [FlowInfo](https://cloud.tencent.com/document/api/#/##FlowInfo)
* [Seal](https://cloud.tencent.com/document/api/#/##Seal)
* [SignSeal](https://cloud.tencent.com/document/api/#/##SignSeal)
* [SmsTemplate](https://cloud.tencent.com/document/api/#/##SmsTemplate)
* [SubOrganizationDetail](https://cloud.tencent.com/document/api/#/##SubOrganizationDetail)
* [UploadFile](https://cloud.tencent.com/document/api/#/##UploadFile)
* [UserDescribe](https://cloud.tencent.com/document/api/#/##UserDescribe)



## 腾讯电子签（基础版）(essbasic) 版本：2021-05-26

### 第 177 次发布

发布时间：2024-07-31 01:36:50

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [BaseFlowInfo](https://cloud.tencent.com/document/api/1420/61525#BaseFlowInfo)

	* <font color="#dd0000">**修改成员**：</font>FlowType, FlowDescription


### 第 176 次发布

发布时间：2024-07-29 01:41:10

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreatePartnerAutoSignAuthUrl](https://cloud.tencent.com/document/api/1420/102515)

	* 新增入参：AuthToMe


### 第 175 次发布

发布时间：2024-07-18 01:11:43

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [ChannelCreateBatchSignUrl](https://cloud.tencent.com/document/api/1420/98671)

	* 新增入参：OpenId, OrganizationOpenId


### 第 174 次发布

发布时间：2024-07-12 01:16:22

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateEmployeeQualificationSealQrCode](https://cloud.tencent.com/document/api/1420/108597)

### 第 173 次发布

发布时间：2024-07-09 01:15:08

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateFlowBlockchainEvidenceUrl](https://cloud.tencent.com/document/api/1420/107553)

	* 新增入参：ExpiredOn


### 第 172 次发布

发布时间：2024-06-25 01:15:10

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateLegalSealQrCode](https://cloud.tencent.com/document/api/1420/107552)


### 第 171 次发布

发布时间：2024-06-21 01:42:38

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateFlowBlockchainEvidenceUrl](https://cloud.tencent.com/document/api/1420/107553)
* [CreateLegalSealQrCode](https://cloud.tencent.com/document/api/1420/107552)

### 第 170 次发布

发布时间：2024-06-17 01:42:30

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreatePartnerAutoSignAuthUrl](https://cloud.tencent.com/document/api/1420/102515)

	* 新增入参：SealTypes


### 第 169 次发布

发布时间：2024-06-14 01:52:51

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [ChannelCreateEmbedWebUrl](https://cloud.tencent.com/document/api/1420/87919)

	* 新增入参：Option

* [ChannelDescribeOrganizationSeals](https://cloud.tencent.com/document/api/1420/82455)

	* 新增入参：SealStatuses


新增数据结构：

* [EmbedUrlOption](https://cloud.tencent.com/document/api/1420/61525#EmbedUrlOption)

### 第 168 次发布

发布时间：2024-05-24 01:40:32

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [ChannelCreatePrepareFlow](https://cloud.tencent.com/document/api/1420/87897)

	* 新增出参：FlowId


### 第 167 次发布

发布时间：2024-05-08 01:17:50

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [ReleasedApprover](https://cloud.tencent.com/document/api/1420/61525#ReleasedApprover)

	* 新增成员：ReleasedApproverRecipientId, ApproverSignSealId


### 第 166 次发布

发布时间：2024-04-25 01:16:48

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [ChannelCreateBatchSignUrl](https://cloud.tencent.com/document/api/1420/98671)

	* 新增入参：FlowBatchUrlInfo

	* <font color="#dd0000">**修改入参**：</font>Name, Mobile


新增数据结构：

* [FlowBatchApproverInfo](https://cloud.tencent.com/document/api/1420/61525#FlowBatchApproverInfo)
* [FlowBatchUrlInfo](https://cloud.tencent.com/document/api/1420/61525#FlowBatchUrlInfo)

### 第 165 次发布

发布时间：2024-04-22 01:16:52

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateConsoleLoginUrl](https://cloud.tencent.com/document/api/1420/61524)

	* 新增入参：TopNavigationStatus


### 第 164 次发布

发布时间：2024-04-08 11:27:16

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [ChannelCreateUserAutoSignEnableUrl](https://cloud.tencent.com/document/api/1420/96110)

	* 新增入参：UserData


修改数据结构：

* [AutoSignConfig](https://cloud.tencent.com/document/api/1420/61525#AutoSignConfig)

	* 新增成员：JumpUrl


### 第 163 次发布

发布时间：2024-04-03 11:19:08

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [RegistrationOrganizationInfo](https://cloud.tencent.com/document/api/1420/61525#RegistrationOrganizationInfo)

	* 新增成员：PowerOfAttorneys


### 第 162 次发布

发布时间：2024-03-29 01:17:41

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateConsoleLoginUrl](https://cloud.tencent.com/document/api/1420/61524)

	* 新增入参：ProxyOperatorMobile


### 第 161 次发布

发布时间：2024-03-26 01:16:43

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [ChannelCreateFlowApprovers](https://cloud.tencent.com/document/api/1420/99282)

	* 新增入参：FlowGroupId

	* <font color="#dd0000">**修改入参**：</font>FlowId

* [ChannelCreateFlowGroupByFiles](https://cloud.tencent.com/document/api/1420/80390)

	* 新增出参：Approvers

* [ChannelCreateFlowGroupByTemplates](https://cloud.tencent.com/document/api/1420/94886)

	* 新增出参：Approvers

* [CreateSignUrls](https://cloud.tencent.com/document/api/1420/61522)

	* 新增入参：FlowGroupUrlInfo


新增数据结构：

* [FlowGroupApproverInfo](https://cloud.tencent.com/document/api/1420/61525#FlowGroupApproverInfo)
* [FlowGroupApprovers](https://cloud.tencent.com/document/api/1420/61525#FlowGroupApprovers)
* [FlowGroupUrlInfo](https://cloud.tencent.com/document/api/1420/61525#FlowGroupUrlInfo)

修改数据结构：

* [FillApproverInfo](https://cloud.tencent.com/document/api/1420/61525#FillApproverInfo)

	* 新增成员：FlowId


### 第 160 次发布

发布时间：2024-03-20 01:16:49

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeCancelFlowsTask](https://cloud.tencent.com/document/api/1420/104511)

新增数据结构：

* [CancelFailureFlow](https://cloud.tencent.com/document/api/1420/61525#CancelFailureFlow)

### 第 159 次发布

发布时间：2024-03-19 01:15:14

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [ChannelBatchCancelFlows](https://cloud.tencent.com/document/api/1420/80391)

	* 新增出参：TaskId

* [ChannelCreateBatchCancelFlowUrl](https://cloud.tencent.com/document/api/1420/78264)

	* 新增出参：TaskId


### 第 158 次发布

发布时间：2024-03-15 01:15:07

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [ChannelRenewAutoSignLicense](https://cloud.tencent.com/document/api/1420/104347)

### 第 157 次发布

发布时间：2024-03-13 01:15:56

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreatePartnerAutoSignAuthUrl](https://cloud.tencent.com/document/api/1420/102515)

	* 新增入参：PlatformAppAuthorization


### 第 156 次发布

发布时间：2024-03-11 01:15:31

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [FillApproverInfo](https://cloud.tencent.com/document/api/1420/61525#FillApproverInfo)

	* 新增成员：ApproverIdCardType, ApproverIdCardNumber


### 第 155 次发布

发布时间：2024-03-07 01:16:27

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [ChannelDescribeSignFaceVideo](https://cloud.tencent.com/document/api/1420/104134)

新增数据结构：

* [DetectInfoVideoData](https://cloud.tencent.com/document/api/1420/61525#DetectInfoVideoData)
* [Intention](https://cloud.tencent.com/document/api/1420/61525#Intention)
* [IntentionAction](https://cloud.tencent.com/document/api/1420/61525#IntentionAction)
* [IntentionActionResult](https://cloud.tencent.com/document/api/1420/61525#IntentionActionResult)
* [IntentionActionResultDetail](https://cloud.tencent.com/document/api/1420/61525#IntentionActionResultDetail)
* [IntentionQuestion](https://cloud.tencent.com/document/api/1420/61525#IntentionQuestion)
* [IntentionQuestionResult](https://cloud.tencent.com/document/api/1420/61525#IntentionQuestionResult)

修改数据结构：

* [FlowApproverInfo](https://cloud.tencent.com/document/api/1420/61525#FlowApproverInfo)

	* 新增成员：Intention


### 第 154 次发布

发布时间：2024-02-29 01:16:27

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [FlowApproverInfo](https://cloud.tencent.com/document/api/1420/61525#FlowApproverInfo)

	* 新增成员：Components


### 第 153 次发布

发布时间：2024-02-20 01:16:04

本次发布包含了以下内容：

改善已有的文档。

<font color="#dd0000">**删除接口**：</font>

* DescribeBillUsageDetail

<font color="#dd0000">**删除数据结构**：</font>

* BillUsageDetail

### 第 152 次发布

发布时间：2024-02-02 01:13:44

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [RegistrationOrganizationInfo](https://cloud.tencent.com/document/api/1420/61525#RegistrationOrganizationInfo)

	* 新增成员：BusinessLicense


### 第 151 次发布

发布时间：2024-01-31 11:46:10

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateChannelFlowEvidenceReport](https://cloud.tencent.com/document/api/1420/79688)

	* 新增入参：ReportType

* [DescribeChannelFlowEvidenceReport](https://cloud.tencent.com/document/api/1420/83442)

	* 新增入参：ReportType


### 第 150 次发布

发布时间：2024-01-26 01:13:42

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [WebThemeConfig](https://cloud.tencent.com/document/api/1420/61525#WebThemeConfig)

	* 新增成员：AuthenticateBackground, HideAuthenticateNavigationBar, HideAuthenticateTopLogo


### 第 149 次发布

发布时间：2024-01-25 01:13:43

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [ModifyFlowDeadline](https://cloud.tencent.com/document/api/1420/103374)

### 第 148 次发布

发布时间：2024-01-16 01:15:09

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [ChannelCreateFlowSignUrl](https://cloud.tencent.com/document/api/1420/85819)

	* 新增入参：UrlType

	* <font color="#dd0000">**修改入参**：</font>FlowApproverInfos

* [CreateConsoleLoginUrl](https://cloud.tencent.com/document/api/1420/61524)

	* 新增入参：ProxyOperatorIdCardNumber, AutoJumpUrl


修改数据结构：

* [RegistrationOrganizationInfo](https://cloud.tencent.com/document/api/1420/61525#RegistrationOrganizationInfo)

	* 新增成员：AdminIdCardType, AdminIdCardNumber


### 第 147 次发布

发布时间：2024-01-08 00:10:12

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateChannelOrganizationInfoChangeUrl](https://cloud.tencent.com/document/api/1420/99179)

	* 新增入参：Endpoint


### 第 146 次发布

发布时间：2023-12-27 01:19:26

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateFlowGroupSignReview](https://cloud.tencent.com/document/api/1420/102693)

新增数据结构：

* [NeedReviewApproverInfo](https://cloud.tencent.com/document/api/1420/61525#NeedReviewApproverInfo)

### 第 145 次发布

发布时间：2023-12-21 01:38:43

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [ChannelCreatePrepareFlow](https://cloud.tencent.com/document/api/1420/87897)

	* <font color="#dd0000">**修改入参**：</font>ResourceId


### 第 144 次发布

发布时间：2023-12-15 19:40:36

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreatePartnerAutoSignAuthUrl](https://cloud.tencent.com/document/api/1420/102515)
* [DescribeExtendedServiceAuthDetail](https://cloud.tencent.com/document/api/1420/102514)

修改接口：

* [ChannelCreateBatchQuickSignUrl](https://cloud.tencent.com/document/api/1420/101059)

	* 新增入参：SignTypeSelector


新增数据结构：

* [AuthInfoDetail](https://cloud.tencent.com/document/api/1420/61525#AuthInfoDetail)
* [HasAuthOrganization](https://cloud.tencent.com/document/api/1420/61525#HasAuthOrganization)
* [HasAuthUser](https://cloud.tencent.com/document/api/1420/61525#HasAuthUser)

修改数据结构：

* [FlowApproverInfo](https://cloud.tencent.com/document/api/1420/61525#FlowApproverInfo)

	* 新增成员：SignTypeSelector


### 第 143 次发布

发布时间：2023-12-14 16:39:27

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateBatchOrganizationRegistrationTasks](https://cloud.tencent.com/document/api/1420/102492)
* [DescribeBatchOrganizationRegistrationUrls](https://cloud.tencent.com/document/api/1420/102491)

新增数据结构：

* [OrganizationAuthUrl](https://cloud.tencent.com/document/api/1420/61525#OrganizationAuthUrl)
* [RegistrationOrganizationInfo](https://cloud.tencent.com/document/api/1420/61525#RegistrationOrganizationInfo)

### 第 142 次发布

发布时间：2023-12-14 01:49:14

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateSealByImage](https://cloud.tencent.com/document/api/1420/73067)

	* 新增入参：TaxIdentifyCode


### 第 141 次发布

发布时间：2023-12-12 01:49:27

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [ChannelCreateBatchQuickSignUrl](https://cloud.tencent.com/document/api/1420/101059)

	* 新增入参：FlowGroupId

	* <font color="#dd0000">**修改入参**：</font>FlowIds

* [ChannelCreatePreparedPersonalEsign](https://cloud.tencent.com/document/api/1420/96160)

	* 新增入参：SceneKey


### 第 140 次发布

发布时间：2023-12-11 00:44:01

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeChannelOrganizations](https://cloud.tencent.com/document/api/1420/102360)

新增数据结构：

* [ChannelOrganizationInfo](https://cloud.tencent.com/document/api/1420/61525#ChannelOrganizationInfo)

### 第 139 次发布

发布时间：2023-12-08 01:48:54

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [Recipient](https://cloud.tencent.com/document/api/1420/61525#Recipient)

	* 新增成员：ApproverVerifyTypes, ApproverSignTypes


### 第 138 次发布

发布时间：2023-12-07 01:49:40

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [CreateFlowOption](https://cloud.tencent.com/document/api/1420/61525#CreateFlowOption)

	* <font color="#dd0000">**修改成员**：</font>SkipUploadFile


### 第 137 次发布

发布时间：2023-11-30 16:01:23

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [ChannelCreateEmbedWebUrl](https://cloud.tencent.com/document/api/1420/87919)

	* 新增入参：UserData


修改数据结构：

* [CreateFlowOption](https://cloud.tencent.com/document/api/1420/61525#CreateFlowOption)

	* 新增成员：SkipUploadFile


### 第 136 次发布

发布时间：2023-11-30 04:06:09

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeChannelSealPolicyWorkflowUrl](https://cloud.tencent.com/document/api/1420/102013)

	* 新增入参：Endpoint


### 第 135 次发布

发布时间：2023-11-29 01:55:39

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeChannelSealPolicyWorkflowUrl](https://cloud.tencent.com/document/api/1420/102013)

### 第 134 次发布

发布时间：2023-11-27 00:10:25

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [CommonFlowApprover](https://cloud.tencent.com/document/api/1420/61525#CommonFlowApprover)

	* 新增成员：ApproverIdCardType, ApproverIdCardNumber

* [CreateFlowOption](https://cloud.tencent.com/document/api/1420/61525#CreateFlowOption)

	* 新增成员：ForbidEditFillComponent


### 第 133 次发布

发布时间：2023-11-23 01:19:06

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateSignUrls](https://cloud.tencent.com/document/api/1420/61522)

	* 新增入参：IdCardType, IdCardNumber


修改数据结构：

* [FillApproverInfo](https://cloud.tencent.com/document/api/1420/61525#FillApproverInfo)

	* <font color="#dd0000">**修改成员**：</font>NotChannelOrganization


### 第 132 次发布

发布时间：2023-11-14 01:16:20

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [ApproverOption](https://cloud.tencent.com/document/api/1420/61525#ApproverOption)

	* 新增成员：NoTransfer


### 第 131 次发布

发布时间：2023-11-13 00:13:25

本次发布包含了以下内容：

改善已有的文档。

<font color="#dd0000">**预下线接口**：</font>

* DescribeBillUsageDetail

### 第 130 次发布

发布时间：2023-11-10 01:16:11

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [ChannelDescribeBillUsageDetail](https://cloud.tencent.com/document/api/1420/101456)

新增数据结构：

* [ChannelBillUsageDetail](https://cloud.tencent.com/document/api/1420/61525#ChannelBillUsageDetail)

### 第 129 次发布

发布时间：2023-11-08 14:25:55

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeBillUsageDetail](https://cloud.tencent.com/document/api/1420/101386)

新增数据结构：

* [BillUsageDetail](https://cloud.tencent.com/document/api/1420/61525#BillUsageDetail)

### 第 128 次发布

发布时间：2023-11-08 01:39:50

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [SyncProxyOrganization](https://cloud.tencent.com/document/api/1420/61518)

	* 新增入参：ProxyAddress


### 第 127 次发布

发布时间：2023-11-07 01:42:44

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [FlowApproverUrlInfo](https://cloud.tencent.com/document/api/1420/61525#FlowApproverUrlInfo)

	* <font color="#dd0000">**修改成员**：</font>LongUrl


### 第 126 次发布

发布时间：2023-11-06 00:09:55

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [FlowDetailInfo](https://cloud.tencent.com/document/api/1420/61525#FlowDetailInfo)

	* <font color="#dd0000">**修改成员**：</font>CcInfos, NeedCreateReview

* [ReleasedApprover](https://cloud.tencent.com/document/api/1420/61525#ReleasedApprover)

	* <font color="#dd0000">**修改成员**：</font>OrganizationName


### 第 125 次发布

发布时间：2023-11-03 01:15:04

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [ChannelCreateReleaseFlow](https://cloud.tencent.com/document/api/1420/83461)

	* 新增入参：UserData


### 第 124 次发布

发布时间：2023-11-02 01:45:47

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [ChannelCreateBatchQuickSignUrl](https://cloud.tencent.com/document/api/1420/101059)

修改接口：

* [DescribeTemplates](https://cloud.tencent.com/document/api/1420/61521)

	* 新增入参：TemplateIds


修改数据结构：

* [ApproverOption](https://cloud.tencent.com/document/api/1420/61525#ApproverOption)

	* 新增成员：NoRefuse


### 第 123 次发布

发布时间：2023-10-20 01:15:49

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [ApproverOption](https://cloud.tencent.com/document/api/1420/61525#ApproverOption)

	* 新增成员：FlowReadLimit


### 第 122 次发布

发布时间：2023-10-18 02:03:31

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [ChannelVerifyPdf](https://cloud.tencent.com/document/api/1420/80799)

	* 新增出参：VerifySerialNo, PdfResourceMd5


### 第 121 次发布

发布时间：2023-10-12 01:58:40

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [ExtentServiceAuthInfo](https://cloud.tencent.com/document/api/1420/61525#ExtentServiceAuthInfo)

	* <font color="#dd0000">**修改成员**：</font>Type, Name, Status, OperatorOpenId, OperateOn


### 第 120 次发布

发布时间：2023-10-11 01:49:28

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [ChannelCreateFlowApprovers](https://cloud.tencent.com/document/api/1420/99282)

	* 新增出参：FillError


新增数据结构：

* [FillError](https://cloud.tencent.com/document/api/1420/61525#FillError)

### 第 119 次发布

发布时间：2023-10-09 17:31:01

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [ChannelCreateUserAutoSignSealUrl](https://cloud.tencent.com/document/api/1420/99317)

### 第 118 次发布

发布时间：2023-10-09 07:05:45

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [ChannelCreateFlowApprovers](https://cloud.tencent.com/document/api/1420/99282)

新增数据结构：

* [FillApproverInfo](https://cloud.tencent.com/document/api/1420/61525#FillApproverInfo)

### 第 117 次发布

发布时间：2023-10-09 00:00:55

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [ChannelCreateOrganizationBatchSignUrl](https://cloud.tencent.com/document/api/1420/99258)

### 第 116 次发布

发布时间：2023-10-07 11:30:18

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateChannelOrganizationInfoChangeUrl](https://cloud.tencent.com/document/api/1420/99179)

	* 新增入参：Agent, ChangeType

	* 新增出参：Url, ExpiredTime


### 第 115 次发布

发布时间：2023-09-28 01:14:02

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateChannelOrganizationInfoChangeUrl](https://cloud.tencent.com/document/api/1420/99179)

### 第 114 次发布

发布时间：2023-09-26 16:46:19

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [ChannelCreateFlowByFiles](https://cloud.tencent.com/document/api/1420/73068)

	* 新增出参：Approvers

* [CreateFlowsByTemplates](https://cloud.tencent.com/document/api/1420/61523)

	* 新增出参：FlowApprovers

* [CreateSignUrls](https://cloud.tencent.com/document/api/1420/61522)

	* 新增入参：RecipientIds

* [ModifyExtendedService](https://cloud.tencent.com/document/api/1420/85666)

	* 新增入参：Endpoint


新增数据结构：

* [ApproverItem](https://cloud.tencent.com/document/api/1420/61525#ApproverItem)
* [FlowApproverItem](https://cloud.tencent.com/document/api/1420/61525#FlowApproverItem)

修改数据结构：

* [ApproverOption](https://cloud.tencent.com/document/api/1420/61525#ApproverOption)

	* 新增成员：FillType

* [FlowApproverDetail](https://cloud.tencent.com/document/api/1420/61525#FlowApproverDetail)

	* 新增成员：ApproverRoleName

* [FlowApproverInfo](https://cloud.tencent.com/document/api/1420/61525#FlowApproverInfo)

	* 新增成员：ApproverRoleName

* [SignUrlInfo](https://cloud.tencent.com/document/api/1420/61525#SignUrlInfo)

	* 新增成员：SignQrcodeUrl


### 第 113 次发布

发布时间：2023-09-22 01:50:20

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [ChannelCreateMultiFlowSignQRCode](https://cloud.tencent.com/document/api/1420/75452)

	* 新增入参：ApproverComponentLimitTypes


新增数据结构：

* [ApproverComponentLimitType](https://cloud.tencent.com/document/api/1420/61525#ApproverComponentLimitType)

### 第 112 次发布

发布时间：2023-09-19 01:15:27

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [ChannelCreateBatchSignUrl](https://cloud.tencent.com/document/api/1420/98671)

### 第 111 次发布

发布时间：2023-09-14 11:40:45

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [ChannelCreateRole](https://cloud.tencent.com/document/api/1420/98223)
* [ChannelDeleteRole](https://cloud.tencent.com/document/api/1420/98222)
* [ChannelModifyRole](https://cloud.tencent.com/document/api/1420/98221)

修改接口：

* [ChannelDescribeRoles](https://cloud.tencent.com/document/api/1420/89387)

	* <font color="#dd0000">**修改入参**：</font>Offset


新增数据结构：

* [Permission](https://cloud.tencent.com/document/api/1420/61525#Permission)
* [PermissionGroup](https://cloud.tencent.com/document/api/1420/61525#PermissionGroup)

修改数据结构：

* [ChannelRole](https://cloud.tencent.com/document/api/1420/61525#ChannelRole)

	* 新增成员：PermissionGroups

	* <font color="#dd0000">**修改成员**：</font>RoleId, RoleName, RoleStatus


### 第 110 次发布

发布时间：2023-09-13 01:47:18

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateSealByImage](https://cloud.tencent.com/document/api/1420/73067)

	* 新增入参：GenerateSource, SealType, SealHorizontalText, SealStyle, SealSize

	* <font color="#dd0000">**修改入参**：</font>SealImage

	* 新增出参：ImageUrl


### 第 109 次发布

发布时间：2023-09-12 01:52:56

本次发布包含了以下内容：

改善已有的文档。

新增数据结构：

* [ComponentLimit](https://cloud.tencent.com/document/api/1420/61525#ComponentLimit)

修改数据结构：

* [CommonFlowApprover](https://cloud.tencent.com/document/api/1420/61525#CommonFlowApprover)

	* 新增成员：ApproverVerifyTypes, ApproverSignTypes

* [Component](https://cloud.tencent.com/document/api/1420/61525#Component)

	* 新增成员：LockComponentValue, ForbidMoveAndDelete

* [FlowApproverInfo](https://cloud.tencent.com/document/api/1420/61525#FlowApproverInfo)

	* 新增成员：AddSignComponentsLimits


### 第 108 次发布

发布时间：2023-09-05 17:36:50

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [SignUrlInfo](https://cloud.tencent.com/document/api/1420/61525#SignUrlInfo)

	* <font color="#dd0000">**修改成员**：</font>CustomUserId


### 第 107 次发布

发布时间：2023-08-29 01:15:15

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [ChannelCreateMultiFlowSignQRCode](https://cloud.tencent.com/document/api/1420/75452)


修改数据结构：

* [BaseFlowInfo](https://cloud.tencent.com/document/api/1420/61525#BaseFlowInfo)

	* 新增成员：Components

* [CommonFlowApprover](https://cloud.tencent.com/document/api/1420/61525#CommonFlowApprover)

	* 新增成员：SignComponents


### 第 106 次发布

发布时间：2023-08-22 01:13:29

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [ChannelCreatePreparedPersonalEsign](https://cloud.tencent.com/document/api/1420/96160)

	* 新增入参：LicenseType

* [ChannelDescribeUserAutoSignStatus](https://cloud.tencent.com/document/api/1420/96109)

	* 新增出参：LicenseType


修改数据结构：

* [AutoSignConfig](https://cloud.tencent.com/document/api/1420/61525#AutoSignConfig)

	* 新增成员：LicenseType


### 第 105 次发布

发布时间：2023-08-21 01:13:02

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [SyncProxyOrganization](https://cloud.tencent.com/document/api/1420/61518)

	* 新增入参：ProxyLegalIdCardType, ProxyLegalIdCardNumber


### 第 104 次发布

发布时间：2023-08-18 01:11:57

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [ChannelCreateFlowGroupByFiles](https://cloud.tencent.com/document/api/1420/80390)

	* 新增入参：FlowGroupOptions


新增数据结构：

* [FlowGroupOptions](https://cloud.tencent.com/document/api/1420/61525#FlowGroupOptions)

### 第 103 次发布

发布时间：2023-08-17 03:11:06

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [ChannelCreatePreparedPersonalEsign](https://cloud.tencent.com/document/api/1420/96160)

	* 新增入参：SealImageCompress


### 第 102 次发布

发布时间：2023-08-14 01:23:26

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [ChannelCreatePreparedPersonalEsign](https://cloud.tencent.com/document/api/1420/96160)

### 第 101 次发布

发布时间：2023-08-09 10:50:48

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [ChannelCancelUserAutoSignEnableUrl](https://cloud.tencent.com/document/api/1420/96111)
* [ChannelCreateUserAutoSignEnableUrl](https://cloud.tencent.com/document/api/1420/96110)
* [ChannelDescribeUserAutoSignStatus](https://cloud.tencent.com/document/api/1420/96109)
* [ChannelDisableUserAutoSign](https://cloud.tencent.com/document/api/1420/96108)

新增数据结构：

* [AutoSignConfig](https://cloud.tencent.com/document/api/1420/61525#AutoSignConfig)
* [UserThreeFactor](https://cloud.tencent.com/document/api/1420/61525#UserThreeFactor)

### 第 100 次发布

发布时间：2023-08-08 01:17:36

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [ChannelDescribeEmployees](https://cloud.tencent.com/document/api/1420/81119)

	* <font color="#dd0000">**修改入参**：</font>Agent


### 第 99 次发布

发布时间：2023-08-01 01:24:13

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [TemplateInfo](https://cloud.tencent.com/document/api/1420/61525#TemplateInfo)

	* <font color="#dd0000">**修改成员**：</font>IsPromoter, Available


### 第 98 次发布

发布时间：2023-07-28 17:50:48

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [ChannelCreatePrepareFlow](https://cloud.tencent.com/document/api/1420/87897)

	* <font color="#dd0000">**修改入参**：</font>FlowApproverList


### 第 97 次发布

发布时间：2023-07-26 16:20:45

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [ChannelCreateWebThemeConfig](https://cloud.tencent.com/document/api/1420/95591)

新增数据结构：

* [WebThemeConfig](https://cloud.tencent.com/document/api/1420/61525#WebThemeConfig)

### 第 96 次发布

发布时间：2023-07-21 01:23:53

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateSignUrls](https://cloud.tencent.com/document/api/1420/61522)

	* 新增入参：Hides


### 第 95 次发布

发布时间：2023-07-18 01:30:22

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [ChannelCreateFlowSignUrl](https://cloud.tencent.com/document/api/1420/85819)

	* 新增入参：JumpUrl


### 第 94 次发布

发布时间：2023-07-17 01:19:47

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [ChannelCreateOrganizationModifyQrCode](https://cloud.tencent.com/document/api/1420/95067)

### 第 93 次发布

发布时间：2023-07-13 01:20:20

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [CreateFlowOption](https://cloud.tencent.com/document/api/1420/61525#CreateFlowOption)

	* 新增成员：HideShowFlowName, HideShowFlowType, HideShowDeadline, CanSkipAddApprover, CustomCreateFlowDescription

* [FormField](https://cloud.tencent.com/document/api/1420/61525#FormField)

	* 新增成员：LockComponentValue


### 第 92 次发布

发布时间：2023-07-12 01:24:43

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [FlowApproverInfo](https://cloud.tencent.com/document/api/1420/61525#FlowApproverInfo)

	* 新增成员：NotifyType


### 第 91 次发布

发布时间：2023-07-10 14:50:55

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [ChannelCreateFlowGroupByTemplates](https://cloud.tencent.com/document/api/1420/94886)

### 第 90 次发布

发布时间：2023-07-10 11:31:03

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [FlowFileInfo](https://cloud.tencent.com/document/api/1420/61525#FlowFileInfo)

	* 新增成员：Components


### 第 89 次发布

发布时间：2023-07-10 01:25:48

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [ChannelCreatePrepareFlow](https://cloud.tencent.com/document/api/1420/87897)


### 第 88 次发布

发布时间：2023-07-07 01:34:05

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [OperateChannelTemplate](https://cloud.tencent.com/document/api/1420/66367)

	* 新增入参：Available


### 第 87 次发布

发布时间：2023-06-30 17:26:03

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [ChannelCreateReleaseFlow](https://cloud.tencent.com/document/api/1420/83461)

	* 新增入参：Deadline


修改数据结构：

* [ReleasedApprover](https://cloud.tencent.com/document/api/1420/61525#ReleasedApprover)

	* 新增成员：ApproverSignComponentType, ApproverSignRole


### 第 86 次发布

发布时间：2023-06-29 01:22:07

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [CommonFlowApprover](https://cloud.tencent.com/document/api/1420/61525#CommonFlowApprover)


### 第 85 次发布

发布时间：2023-06-21 01:19:14

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [ChannelDescribeFlowComponents](https://cloud.tencent.com/document/api/1420/94220)

新增数据结构：

* [FilledComponent](https://cloud.tencent.com/document/api/1420/61525#FilledComponent)
* [RecipientComponentInfo](https://cloud.tencent.com/document/api/1420/61525#RecipientComponentInfo)

### 第 84 次发布

发布时间：2023-06-09 01:20:47

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [ChannelCreateUserRoles](https://cloud.tencent.com/document/api/1420/89389)

	* 新增入参：OpenIds

	* <font color="#dd0000">**修改入参**：</font>UserIds

* [ChannelDeleteRoleUsers](https://cloud.tencent.com/document/api/1420/89388)

	* 新增入参：OpenIds

	* <font color="#dd0000">**修改入参**：</font>UserIds


### 第 83 次发布

发布时间：2023-06-08 01:29:22

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [FlowApproverInfo](https://cloud.tencent.com/document/api/1420/61525#FlowApproverInfo)

	* 新增成员：SignId


### 第 82 次发布

发布时间：2023-06-07 17:21:12

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [ChannelBatchCancelFlows](https://cloud.tencent.com/document/api/1420/80391)

* [ChannelCancelFlow](https://cloud.tencent.com/document/api/1420/81869)

* [ChannelCancelMultiFlowSignQRCode](https://cloud.tencent.com/document/api/1420/75453)

* [ChannelCreateBatchCancelFlowUrl](https://cloud.tencent.com/document/api/1420/78264)

* [ChannelCreateBoundFlows](https://cloud.tencent.com/document/api/1420/83118)

* [ChannelCreateConvertTaskApi](https://cloud.tencent.com/document/api/1420/78774)

* [ChannelCreateEmbedWebUrl](https://cloud.tencent.com/document/api/1420/87919)

* [ChannelCreateFlowByFiles](https://cloud.tencent.com/document/api/1420/73068)

* [ChannelCreateFlowGroupByFiles](https://cloud.tencent.com/document/api/1420/80390)

* [ChannelCreateFlowSignUrl](https://cloud.tencent.com/document/api/1420/85819)

* [ChannelCreateMultiFlowSignQRCode](https://cloud.tencent.com/document/api/1420/75452)

* [ChannelCreatePrepareFlow](https://cloud.tencent.com/document/api/1420/87897)

* [ChannelCreateReleaseFlow](https://cloud.tencent.com/document/api/1420/83461)

* [ChannelCreateSealPolicy](https://cloud.tencent.com/document/api/1420/86257)

* [ChannelCreateUserRoles](https://cloud.tencent.com/document/api/1420/89389)

* [ChannelDeleteRoleUsers](https://cloud.tencent.com/document/api/1420/89388)

* [ChannelDeleteSealPolicies](https://cloud.tencent.com/document/api/1420/86256)

* [ChannelDescribeEmployees](https://cloud.tencent.com/document/api/1420/81119)

* [ChannelDescribeRoles](https://cloud.tencent.com/document/api/1420/89387)

* [ChannelGetTaskResultApi](https://cloud.tencent.com/document/api/1420/78773)

* [ChannelUpdateSealStatus](https://cloud.tencent.com/document/api/1420/86605)

* [ChannelVerifyPdf](https://cloud.tencent.com/document/api/1420/80799)

* [CreateChannelFlowEvidenceReport](https://cloud.tencent.com/document/api/1420/79688)

* [CreateConsoleLoginUrl](https://cloud.tencent.com/document/api/1420/61524)

* [CreateFlowsByTemplates](https://cloud.tencent.com/document/api/1420/61523)

* [CreateSealByImage](https://cloud.tencent.com/document/api/1420/73067)

* [CreateSignUrls](https://cloud.tencent.com/document/api/1420/61522)

* [DescribeChannelFlowEvidenceReport](https://cloud.tencent.com/document/api/1420/83442)

* [DescribeFlowDetailInfo](https://cloud.tencent.com/document/api/1420/66683)

* [DescribeResourceUrlsByFlows](https://cloud.tencent.com/document/api/1420/63220)

* [DescribeTemplates](https://cloud.tencent.com/document/api/1420/61521)

* [DescribeUsage](https://cloud.tencent.com/document/api/1420/61520)

* [GetDownloadFlowUrl](https://cloud.tencent.com/document/api/1420/66368)

* [OperateChannelTemplate](https://cloud.tencent.com/document/api/1420/66367)

* [PrepareFlows](https://cloud.tencent.com/document/api/1420/61519)

* [SyncProxyOrganization](https://cloud.tencent.com/document/api/1420/61518)

* [SyncProxyOrganizationOperators](https://cloud.tencent.com/document/api/1420/61517)

* [UploadFiles](https://cloud.tencent.com/document/api/1420/71479)


修改数据结构：

* [Agent](https://cloud.tencent.com/document/api/1420/61525#Agent)


### 第 81 次发布

发布时间：2023-06-07 01:25:09

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [FlowApproverInfo](https://cloud.tencent.com/document/api/1420/61525#FlowApproverInfo)

* [OrganizationInfo](https://cloud.tencent.com/document/api/1420/61525#OrganizationInfo)

	* <font color="#dd0000">**修改成员**：</font>ClientIp, ProxyIp

* [SignUrlInfo](https://cloud.tencent.com/document/api/1420/61525#SignUrlInfo)

	* <font color="#dd0000">**修改成员**：</font>CustomUserId

* [TemplateInfo](https://cloud.tencent.com/document/api/1420/61525#TemplateInfo)

	* <font color="#dd0000">**修改成员**：</font>IsPromoter

* [UserInfo](https://cloud.tencent.com/document/api/1420/61525#UserInfo)


### 第 80 次发布

发布时间：2023-05-26 14:30:59

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [ChannelCreateFlowSignReview](https://cloud.tencent.com/document/api/1420/78953)

	* 新增入参：OperateType


### 第 79 次发布

发布时间：2023-05-25 01:36:12

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [ChannelCreateUserRoles](https://cloud.tencent.com/document/api/1420/89389)

	* <font color="#dd0000">**修改入参**：</font>Operator

* [ChannelDeleteRoleUsers](https://cloud.tencent.com/document/api/1420/89388)

	* <font color="#dd0000">**修改入参**：</font>Operator

* [ChannelDescribeRoles](https://cloud.tencent.com/document/api/1420/89387)

	* <font color="#dd0000">**修改入参**：</font>Operator


修改数据结构：

* [BaseFlowInfo](https://cloud.tencent.com/document/api/1420/61525#BaseFlowInfo)

	* 新增成员：NeedCreateReview

* [FlowDetailInfo](https://cloud.tencent.com/document/api/1420/61525#FlowDetailInfo)

	* 新增成员：NeedCreateReview


### 第 78 次发布

发布时间：2023-05-18 11:50:51

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [ChannelGetTaskResultApi](https://cloud.tencent.com/document/api/1420/78773)


### 第 77 次发布

发布时间：2023-05-18 01:27:06

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [ChannelCreateFlowByFiles](https://cloud.tencent.com/document/api/1420/73068)

	* 新增入参：AutoSignScene


修改数据结构：

* [FlowInfo](https://cloud.tencent.com/document/api/1420/61525#FlowInfo)

	* 新增成员：AutoSignScene


### 第 76 次发布

发布时间：2023-05-15 01:38:51

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [BaseFlowInfo](https://cloud.tencent.com/document/api/1420/61525#BaseFlowInfo)

	* 新增成员：CcInfos


### 第 75 次发布

发布时间：2023-05-08 01:24:18

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [FlowApproverUrlInfo](https://cloud.tencent.com/document/api/1420/61525#FlowApproverUrlInfo)

	* 新增成员：LongUrl


### 第 74 次发布

发布时间：2023-04-24 16:40:52

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [Component](https://cloud.tencent.com/document/api/1420/61525#Component)

	* 新增成员：Placeholder


### 第 73 次发布

发布时间：2023-04-12 01:27:48

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [TemplateInfo](https://cloud.tencent.com/document/api/1420/61525#TemplateInfo)

	* 新增成员：Available


### 第 72 次发布

发布时间：2023-03-31 16:30:48

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [BaseFlowInfo](https://cloud.tencent.com/document/api/1420/61525#BaseFlowInfo)

	* 新增成员：UserData


### 第 71 次发布

发布时间：2023-03-27 01:54:48

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [ChannelCreateUserRoles](https://cloud.tencent.com/document/api/1420/89389)
* [ChannelDeleteRoleUsers](https://cloud.tencent.com/document/api/1420/89388)
* [ChannelDescribeRoles](https://cloud.tencent.com/document/api/1420/89387)

新增数据结构：

* [ChannelRole](https://cloud.tencent.com/document/api/1420/61525#ChannelRole)
* [FailedCreateRoleData](https://cloud.tencent.com/document/api/1420/61525#FailedCreateRoleData)

### 第 70 次发布

发布时间：2023-03-23 01:39:22

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [FlowApproverInfo](https://cloud.tencent.com/document/api/1420/61525#FlowApproverInfo)

	* 新增成员：ApproverVerifyTypes, ApproverSignTypes

* [FlowDetailInfo](https://cloud.tencent.com/document/api/1420/61525#FlowDetailInfo)

	* 新增成员：CcInfos


### 第 69 次发布

发布时间：2023-03-10 01:32:46

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [ChannelCreateFlowByFiles](https://cloud.tencent.com/document/api/1420/73068)

	* 新增入参：CcInfos, CcNotifyType


修改数据结构：

* [CcInfo](https://cloud.tencent.com/document/api/1420/61525#CcInfo)

	* 新增成员：Name, CcType, CcPermission

* [FlowInfo](https://cloud.tencent.com/document/api/1420/61525#FlowInfo)

	* 新增成员：CcNotifyType


### 第 68 次发布

发布时间：2023-03-09 01:25:44

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [ChannelCreateEmbedWebUrl](https://cloud.tencent.com/document/api/1420/87919)

	* 新增入参：HiddenComponents


### 第 67 次发布

发布时间：2023-03-08 14:55:33

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [ChannelCreateEmbedWebUrl](https://cloud.tencent.com/document/api/1420/87919)

### 第 66 次发布

发布时间：2023-03-08 00:25:37

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [ChannelCreatePrepareFlow](https://cloud.tencent.com/document/api/1420/87897)

新增数据结构：

* [BaseFlowInfo](https://cloud.tencent.com/document/api/1420/61525#BaseFlowInfo)
* [CommonApproverOption](https://cloud.tencent.com/document/api/1420/61525#CommonApproverOption)
* [CommonFlowApprover](https://cloud.tencent.com/document/api/1420/61525#CommonFlowApprover)
* [CreateFlowOption](https://cloud.tencent.com/document/api/1420/61525#CreateFlowOption)

### 第 65 次发布

发布时间：2023-03-03 17:35:43

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [ProxyOrganizationOperator](https://cloud.tencent.com/document/api/1420/61525#ProxyOrganizationOperator)

	* 新增成员：DefaultRole


### 第 64 次发布

发布时间：2023-02-15 17:31:06

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [ChannelUpdateSealStatus](https://cloud.tencent.com/document/api/1420/86605)

### 第 63 次发布

发布时间：2023-02-13 01:39:50

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [ChannelDescribeOrganizationSeals](https://cloud.tencent.com/document/api/1420/82455)

	* 新增入参：SealTypes


### 第 62 次发布

发布时间：2023-02-08 01:37:10

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [ChannelCreateSealPolicy](https://cloud.tencent.com/document/api/1420/86257)
* [ChannelDeleteSealPolicies](https://cloud.tencent.com/document/api/1420/86256)

### 第 61 次发布

发布时间：2023-02-01 01:24:43

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [ChannelCreateFlowReminds](https://cloud.tencent.com/document/api/1420/86003)

新增数据结构：

* [RemindFlowRecords](https://cloud.tencent.com/document/api/1420/61525#RemindFlowRecords)

### 第 60 次发布

发布时间：2023-01-13 16:41:14

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [ChannelCreateFlowSignUrl](https://cloud.tencent.com/document/api/1420/85819)

新增数据结构：

* [FlowApproverUrlInfo](https://cloud.tencent.com/document/api/1420/61525#FlowApproverUrlInfo)

### 第 59 次发布

发布时间：2023-01-11 15:01:01

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeExtendedServiceAuthInfo](https://cloud.tencent.com/document/api/1420/85667)
* [ModifyExtendedService](https://cloud.tencent.com/document/api/1420/85666)

新增数据结构：

* [ExtentServiceAuthInfo](https://cloud.tencent.com/document/api/1420/61525#ExtentServiceAuthInfo)

### 第 58 次发布

发布时间：2022-12-29 10:24:56

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeTemplates](https://cloud.tencent.com/document/api/1420/61521)

	* 新增入参：ChannelTemplateId


### 第 57 次发布

发布时间：2022-12-22 01:39:07

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [ChannelCreateFlowGroupByFiles](https://cloud.tencent.com/document/api/1420/80390)

	* 新增入参：ApproverVerifyType


修改数据结构：

* [Component](https://cloud.tencent.com/document/api/1420/61525#Component)

	* 新增成员：KeywordOrder


### 第 56 次发布

发布时间：2022-12-14 01:27:32

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [TemplateInfo](https://cloud.tencent.com/document/api/1420/61525#TemplateInfo)

	* 新增成员：ChannelTemplateName, ChannelAutoSave, TemplateVersion


### 第 55 次发布

发布时间：2022-12-08 17:53:00

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [Staff](https://cloud.tencent.com/document/api/1420/61525#Staff)

	* 新增成员：QuiteJob


### 第 54 次发布

发布时间：2022-11-29 17:04:20

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeTemplates](https://cloud.tencent.com/document/api/1420/61521)

	* 新增入参：WithPdfUrl


修改数据结构：

* [TemplateInfo](https://cloud.tencent.com/document/api/1420/61525#TemplateInfo)

	* 新增成员：PdfUrl


### 第 53 次发布

发布时间：2022-11-28 10:42:34

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [ChannelCreateReleaseFlow](https://cloud.tencent.com/document/api/1420/83461)

新增数据结构：

* [ReleasedApprover](https://cloud.tencent.com/document/api/1420/61525#ReleasedApprover)
* [RelieveInfo](https://cloud.tencent.com/document/api/1420/61525#RelieveInfo)

### 第 52 次发布

发布时间：2022-11-25 18:17:38

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateChannelFlowEvidenceReport](https://cloud.tencent.com/document/api/1420/79688)
* [DescribeChannelFlowEvidenceReport](https://cloud.tencent.com/document/api/1420/83442)

### 第 51 次发布

发布时间：2022-11-24 06:32:35

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateConsoleLoginUrl](https://cloud.tencent.com/document/api/1420/61524)

	* 新增入参：AuthorizationTypes


### 第 50 次发布

发布时间：2022-11-21 19:31:59

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [Component](https://cloud.tencent.com/document/api/1420/61525#Component)

	* 新增成员：ChannelComponentId


### 第 49 次发布

发布时间：2022-11-21 17:22:12

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [TemplateInfo](https://cloud.tencent.com/document/api/1420/61525#TemplateInfo)

	* 新增成员：ChannelTemplateId


### 第 48 次发布

发布时间：2022-11-21 15:12:25

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [ChannelCreateFlowByFiles](https://cloud.tencent.com/document/api/1420/73068)

	* 新增入参：SignBeanTag


### 第 47 次发布

发布时间：2022-11-18 20:21:39

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [ChannelCreateBoundFlows](https://cloud.tencent.com/document/api/1420/83118)

### 第 46 次发布

发布时间：2022-11-17 06:26:33

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [Component](https://cloud.tencent.com/document/api/1420/61525#Component)

	* 新增成员：KeywordPage, RelativeLocation, KeywordIndexes


### 第 45 次发布

发布时间：2022-11-16 16:57:46

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [ChannelCreateFlowSignReview](https://cloud.tencent.com/document/api/1420/78953)

	* 新增入参：RecipientId


### 第 44 次发布

发布时间：2022-11-16 06:23:30

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [UsageDetail](https://cloud.tencent.com/document/api/1420/61525#UsageDetail)

	* 新增成员：FlowChannel


### 第 43 次发布

发布时间：2022-11-15 06:24:31

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateFlowsByTemplates](https://cloud.tencent.com/document/api/1420/61523)

	* 新增入参：PreviewType

* [DescribeTemplates](https://cloud.tencent.com/document/api/1420/61521)

	* 新增入参：WithPreviewUrl


修改数据结构：

* [TemplateInfo](https://cloud.tencent.com/document/api/1420/61525#TemplateInfo)

	* 新增成员：PreviewUrl


### 第 42 次发布

发布时间：2022-11-14 10:16:40

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateConsoleLoginUrl](https://cloud.tencent.com/document/api/1420/61524)

	* 新增入参：Endpoint, AutoJumpBackEvent

	* 新增出参：ProxyOperatorIsVerified

* [SyncProxyOrganization](https://cloud.tencent.com/document/api/1420/61518)

	* 新增入参：ProxyLegalName


### 第 41 次发布

发布时间：2022-11-08 06:25:25

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [ChannelDescribeOrganizationSeals](https://cloud.tencent.com/document/api/1420/82455)

	* 新增入参：SealId


### 第 40 次发布

发布时间：2022-11-07 10:56:44

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [ChannelDescribeOrganizationSeals](https://cloud.tencent.com/document/api/1420/82455)

新增数据结构：

* [AuthorizedUser](https://cloud.tencent.com/document/api/1420/61525#AuthorizedUser)
* [OccupiedSeal](https://cloud.tencent.com/document/api/1420/61525#OccupiedSeal)

### 第 39 次发布

发布时间：2022-11-04 06:23:52

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [ChannelCreateFlowByFiles](https://cloud.tencent.com/document/api/1420/73068)

	* 新增入参：ApproverVerifyType


### 第 38 次发布

发布时间：2022-10-26 06:35:40

本次发布包含了以下内容：

改善已有的文档。

新增数据结构：

* [ApproverOption](https://cloud.tencent.com/document/api/1420/61525#ApproverOption)

修改数据结构：

* [FlowApproverInfo](https://cloud.tencent.com/document/api/1420/61525#FlowApproverInfo)

	* 新增成员：ApproverOption, ApproverNeedSignReview


### 第 37 次发布

发布时间：2022-10-24 15:26:34

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [ChannelCancelFlow](https://cloud.tencent.com/document/api/1420/81869)

### 第 36 次发布

发布时间：2022-10-24 15:11:55

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [ChannelBatchCancelFlows](https://cloud.tencent.com/document/api/1420/80391)

	* 新增入参：CancelMessage, CancelMessageFormat


### 第 35 次发布

发布时间：2022-10-19 20:26:32

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [ChannelCreateMultiFlowSignQRCode](https://cloud.tencent.com/document/api/1420/75452)

	* 新增入参：Restrictions


### 第 34 次发布

发布时间：2022-10-18 16:02:52

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [Component](https://cloud.tencent.com/document/api/1420/61525#Component)

	* 新增成员：ComponentRecipientId


### 第 33 次发布

发布时间：2022-10-14 10:03:19

本次发布包含了以下内容：

改善已有的文档。

<font color="#dd0000">**删除接口**：</font>

* CreateChannelFlowEvidenceReport

### 第 32 次发布

发布时间：2022-09-29 06:30:52

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [ChannelDescribeEmployees](https://cloud.tencent.com/document/api/1420/81119)

新增数据结构：

* [Department](https://cloud.tencent.com/document/api/1420/61525#Department)
* [Filter](https://cloud.tencent.com/document/api/1420/61525#Filter)
* [Staff](https://cloud.tencent.com/document/api/1420/61525#Staff)
* [StaffRole](https://cloud.tencent.com/document/api/1420/61525#StaffRole)

### 第 31 次发布

发布时间：2022-09-20 21:03:25

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [ChannelVerifyPdf](https://cloud.tencent.com/document/api/1420/80799)

新增数据结构：

* [PdfVerifyResult](https://cloud.tencent.com/document/api/1420/61525#PdfVerifyResult)

### 第 30 次发布

发布时间：2022-09-09 18:16:42

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [ChannelBatchCancelFlows](https://cloud.tencent.com/document/api/1420/80391)
* [ChannelCreateFlowGroupByFiles](https://cloud.tencent.com/document/api/1420/80390)

修改接口：

* [CreateSignUrls](https://cloud.tencent.com/document/api/1420/61522)

	* 新增入参：FlowGroupId

	* <font color="#dd0000">**修改入参**：</font>FlowIds

* [DescribeFlowDetailInfo](https://cloud.tencent.com/document/api/1420/66683)

	* 新增入参：FlowGroupId

	* <font color="#dd0000">**修改入参**：</font>FlowIds

	* 新增出参：FlowGroupId, FlowGroupName


新增数据结构：

* [FlowFileInfo](https://cloud.tencent.com/document/api/1420/61525#FlowFileInfo)

修改数据结构：

* [SignUrlInfo](https://cloud.tencent.com/document/api/1420/61525#SignUrlInfo)

	* 新增成员：FlowGroupId


### 第 29 次发布

发布时间：2022-09-07 06:29:24

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeTemplates](https://cloud.tencent.com/document/api/1420/61521)

	* 新增入参：QueryAllComponents, TemplateName


### 第 28 次发布

发布时间：2022-08-29 00:07:08

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateChannelFlowEvidenceReport](https://cloud.tencent.com/document/api/1420/79688)

修改接口：

* [ChannelGetTaskResultApi](https://cloud.tencent.com/document/api/1420/78773)

	* 新增出参：PreviewUrl

* [CreateFlowsByTemplates](https://cloud.tencent.com/document/api/1420/61523)

	* 新增出参：TaskInfos


新增数据结构：

* [TaskInfo](https://cloud.tencent.com/document/api/1420/61525#TaskInfo)

### 第 27 次发布

发布时间：2022-08-11 15:03:00

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [ChannelCreateFlowSignReview](https://cloud.tencent.com/document/api/1420/78953)

### 第 26 次发布

发布时间：2022-08-11 07:03:11

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [ChannelCreateFlowByFiles](https://cloud.tencent.com/document/api/1420/73068)

	* 新增入参：NeedSignReview


修改数据结构：

* [FlowInfo](https://cloud.tencent.com/document/api/1420/61525#FlowInfo)

	* 新增成员：NeedSignReview


### 第 25 次发布

发布时间：2022-08-08 10:31:46

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [ChannelCreateConvertTaskApi](https://cloud.tencent.com/document/api/1420/78774)
* [ChannelGetTaskResultApi](https://cloud.tencent.com/document/api/1420/78773)

新增数据结构：

* [OrganizationInfo](https://cloud.tencent.com/document/api/1420/61525#OrganizationInfo)

### 第 24 次发布

发布时间：2022-08-02 11:36:28

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [ChannelCreateBatchCancelFlowUrl](https://cloud.tencent.com/document/api/1420/78264)

修改接口：

* [ChannelCreateMultiFlowSignQRCode](https://cloud.tencent.com/document/api/1420/75452)

	* 新增入参：ApproverRestrictions

	* 新增出参：SignUrls


新增数据结构：

* [ApproverRestriction](https://cloud.tencent.com/document/api/1420/61525#ApproverRestriction)
* [SignUrl](https://cloud.tencent.com/document/api/1420/61525#SignUrl)

### 第 23 次发布

发布时间：2022-07-28 06:11:47

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [ChannelCreateFlowByFiles](https://cloud.tencent.com/document/api/1420/73068)

	* 新增入参：CustomerData


### 第 22 次发布

发布时间：2022-07-21 06:10:03

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateConsoleLoginUrl](https://cloud.tencent.com/document/api/1420/61524)

	* 新增入参：MenuStatus


### 第 21 次发布

发布时间：2022-07-07 06:10:24

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [UsageDetail](https://cloud.tencent.com/document/api/1420/61525#UsageDetail)

	* 新增成员：Cancel


### 第 20 次发布

发布时间：2022-07-05 17:07:31

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateSignUrls](https://cloud.tencent.com/document/api/1420/61522)

	* 新增入参：GenerateType, OrganizationName, Name, Mobile, OrganizationOpenId, OpenId


### 第 19 次发布

发布时间：2022-06-30 06:07:02

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [ChannelCreateFlowByFiles](https://cloud.tencent.com/document/api/1420/73068)

	* 新增入参：CustomShowMap


修改数据结构：

* [FlowApproverInfo](https://cloud.tencent.com/document/api/1420/61525#FlowApproverInfo)

	* 新增成员：IdCardType

* [FlowInfo](https://cloud.tencent.com/document/api/1420/61525#FlowInfo)

	* 新增成员：CustomShowMap


### 第 18 次发布

发布时间：2022-06-23 06:12:30

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [Component](https://cloud.tencent.com/document/api/1420/61525#Component)

	* 新增成员：OffsetX, OffsetY


### 第 17 次发布

发布时间：2022-06-13 06:12:00

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [ChannelCancelMultiFlowSignQRCode](https://cloud.tencent.com/document/api/1420/75453)
* [ChannelCreateMultiFlowSignQRCode](https://cloud.tencent.com/document/api/1420/75452)

新增数据结构：

* [SignQrCode](https://cloud.tencent.com/document/api/1420/61525#SignQrCode)

### 第 16 次发布

发布时间：2022-06-02 06:08:13

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeTemplates](https://cloud.tencent.com/document/api/1420/61521)

	* 新增入参：ContentType, Limit, Offset

	* 新增出参：TotalCount, Limit, Offset


### 第 15 次发布

发布时间：2022-04-25 06:07:01

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [ChannelCreateFlowByFiles](https://cloud.tencent.com/document/api/1420/73068)
* [CreateSealByImage](https://cloud.tencent.com/document/api/1420/73067)

### 第 14 次发布

发布时间：2022-03-29 08:10:05

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateSignUrls](https://cloud.tencent.com/document/api/1420/61522)

	* 新增入参：AutoJumpBack


修改数据结构：

* [FlowApproverInfo](https://cloud.tencent.com/document/api/1420/61525#FlowApproverInfo)

	* 新增成员：SignComponents


### 第 13 次发布

发布时间：2022-03-22 08:09:17

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [UploadFiles](https://cloud.tencent.com/document/api/1420/71479)

新增数据结构：

* [UploadFile](https://cloud.tencent.com/document/api/1420/61525#UploadFile)

### 第 12 次发布

发布时间：2022-03-16 08:09:18

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateFlowsByTemplates](https://cloud.tencent.com/document/api/1420/61523)

	* 新增入参：NeedPreview

	* 新增出参：PreviewUrls


修改数据结构：

* [FlowApproverInfo](https://cloud.tencent.com/document/api/1420/61525#FlowApproverInfo)

	* 新增成员：NotChannelOrganization


### 第 11 次发布

发布时间：2022-01-11 08:08:55

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [Recipient](https://cloud.tencent.com/document/api/1420/61525#Recipient)

	* 新增成员：IsPromoter


### 第 10 次发布

发布时间：2022-01-07 08:08:29

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [FlowApproverInfo](https://cloud.tencent.com/document/api/1420/61525#FlowApproverInfo)

	* 新增成员：ComponentLimitType, RecipientId, OrganizationOpenId, OrganizationName

	* <font color="#dd0000">**修改成员**：</font>Name, Mobile


### 第 9 次发布

发布时间：2021-12-23 08:10:29

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeFlowDetailInfo](https://cloud.tencent.com/document/api/1420/66683)

新增数据结构：

* [FlowApproverDetail](https://cloud.tencent.com/document/api/1420/61525#FlowApproverDetail)
* [FlowDetailInfo](https://cloud.tencent.com/document/api/1420/61525#FlowDetailInfo)

### 第 8 次发布

发布时间：2021-12-22 08:11:49

本次发布包含了以下内容：

改善已有的文档。

新增数据结构：

* [CcInfo](https://cloud.tencent.com/document/api/1420/61525#CcInfo)

修改数据结构：

* [FlowInfo](https://cloud.tencent.com/document/api/1420/61525#FlowInfo)

	* 新增成员：CcInfos

* [TemplateInfo](https://cloud.tencent.com/document/api/1420/61525#TemplateInfo)

	* 新增成员：IsPromoter


### 第 7 次发布

发布时间：2021-12-21 08:05:51

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [GetDownloadFlowUrl](https://cloud.tencent.com/document/api/1420/66368)
* [OperateChannelTemplate](https://cloud.tencent.com/document/api/1420/66367)

新增数据结构：

* [AuthFailMessage](https://cloud.tencent.com/document/api/1420/61525#AuthFailMessage)
* [DownloadFlowInfo](https://cloud.tencent.com/document/api/1420/61525#DownloadFlowInfo)

修改数据结构：

* [FlowApproverInfo](https://cloud.tencent.com/document/api/1420/61525#FlowApproverInfo)

	* 新增成员：PreReadTime


### 第 6 次发布

发布时间：2021-11-08 08:06:21

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [UsageDetail](https://cloud.tencent.com/document/api/1420/61525#UsageDetail)

	* 新增成员：ProxyOrganizationName


### 第 5 次发布

发布时间：2021-10-22 08:10:34

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeResourceUrlsByFlows](https://cloud.tencent.com/document/api/1420/63220)

新增数据结构：

* [FlowResourceUrlInfo](https://cloud.tencent.com/document/api/1420/61525#FlowResourceUrlInfo)
* [ResourceUrlInfo](https://cloud.tencent.com/document/api/1420/61525#ResourceUrlInfo)

### 第 4 次发布

发布时间：2021-10-12 08:06:14

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateSignUrls](https://cloud.tencent.com/document/api/1420/61522)

	* 新增出参：ErrorMessages


### 第 3 次发布

发布时间：2021-09-30 08:05:19

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [SignUrlInfo](https://cloud.tencent.com/document/api/1420/61525#SignUrlInfo)

	* 新增成员：OpenId


### 第 2 次发布

发布时间：2021-09-17 08:08:31

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateConsoleLoginUrl](https://cloud.tencent.com/document/api/1420/61524)

	* 新增入参：Module, ModuleId

* [DescribeTemplates](https://cloud.tencent.com/document/api/1420/61521)

	* 新增入参：TemplateId

* [SyncProxyOrganizationOperators](https://cloud.tencent.com/document/api/1420/61517)

	* 新增出参：Status, FailedList


新增数据结构：

* [Recipient](https://cloud.tencent.com/document/api/1420/61525#Recipient)
* [SyncFailReason](https://cloud.tencent.com/document/api/1420/61525#SyncFailReason)

修改数据结构：

* [FlowApproverInfo](https://cloud.tencent.com/document/api/1420/61525#FlowApproverInfo)

	* 新增成员：ApproverType, OpenId

* [TemplateInfo](https://cloud.tencent.com/document/api/1420/61525#TemplateInfo)

	* 新增成员：TemplateType, Recipients


### 第 1 次发布

发布时间：2021-09-15 11:54:06

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateConsoleLoginUrl](https://cloud.tencent.com/document/api/1420/61524)
* [CreateFlowsByTemplates](https://cloud.tencent.com/document/api/1420/61523)
* [CreateSignUrls](https://cloud.tencent.com/document/api/1420/61522)
* [DescribeTemplates](https://cloud.tencent.com/document/api/1420/61521)
* [DescribeUsage](https://cloud.tencent.com/document/api/1420/61520)
* [PrepareFlows](https://cloud.tencent.com/document/api/1420/61519)
* [SyncProxyOrganization](https://cloud.tencent.com/document/api/1420/61518)
* [SyncProxyOrganizationOperators](https://cloud.tencent.com/document/api/1420/61517)

新增数据结构：

* [Agent](https://cloud.tencent.com/document/api/1420/61525#Agent)
* [Component](https://cloud.tencent.com/document/api/1420/61525#Component)
* [FlowApproverInfo](https://cloud.tencent.com/document/api/1420/61525#FlowApproverInfo)
* [FlowInfo](https://cloud.tencent.com/document/api/1420/61525#FlowInfo)
* [FormField](https://cloud.tencent.com/document/api/1420/61525#FormField)
* [ProxyOrganizationOperator](https://cloud.tencent.com/document/api/1420/61525#ProxyOrganizationOperator)
* [SignUrlInfo](https://cloud.tencent.com/document/api/1420/61525#SignUrlInfo)
* [TemplateInfo](https://cloud.tencent.com/document/api/1420/61525#TemplateInfo)
* [UsageDetail](https://cloud.tencent.com/document/api/1420/61525#UsageDetail)
* [UserInfo](https://cloud.tencent.com/document/api/1420/61525#UserInfo)




## 人脸融合(facefusion) 版本：2018-12-01

### 第 9 次发布

发布时间：2024-01-23 01:18:48

本次发布包含了以下内容：

改善已有的文档。

<font color="#dd0000">**删除接口**：</font>

* FaceFusionLite

### 第 8 次发布

发布时间：2023-09-08 01:55:19

本次发布包含了以下内容：

改善已有的文档。

<font color="#dd0000">**预下线接口**：</font>

* FaceFusionLite

### 第 7 次发布

发布时间：2023-07-27 01:13:26

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [FaceFusion](https://cloud.tencent.com/document/api/670/31061)

	* 新增入参：FuseParam

* [FuseFace](https://cloud.tencent.com/document/api/670/37736)

	* 新增入参：FuseParam


新增数据结构：

* [FuseParam](https://cloud.tencent.com/document/api/670/31062#FuseParam)
* [ImageCodecParam](https://cloud.tencent.com/document/api/670/31062#ImageCodecParam)
* [MetaData](https://cloud.tencent.com/document/api/670/31062#MetaData)

### 第 6 次发布

发布时间：2021-07-22 08:05:36

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [FaceFusion](https://cloud.tencent.com/document/api/670/31061)

	* 新增入参：Url

	* <font color="#dd0000">**修改入参**：</font>Image


### 第 5 次发布

发布时间：2020-09-24 08:03:28

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [FaceFusionLite](https://cloud.tencent.com/document/api/670/48682)

### 第 4 次发布

发布时间：2020-05-20 08:10:36

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeMaterialList](https://cloud.tencent.com/document/api/670/44746)

新增数据结构：

* [FaceInfo](https://cloud.tencent.com/document/api/670/31062#FaceInfo)
* [MaterialFaceList](https://cloud.tencent.com/document/api/670/31062#MaterialFaceList)
* [PublicMaterialInfos](https://cloud.tencent.com/document/api/670/31062#PublicMaterialInfos)

### 第 3 次发布

发布时间：2019-11-28 22:14:34

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [FuseFace](https://cloud.tencent.com/document/api/670/37736)

	* 新增入参：CelebrityIdentify

	* 新增出参：ReviewResultSet


### 第 2 次发布

发布时间：2019-09-04 16:12:48

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [FuseFace](https://cloud.tencent.com/document/api/670/37736)

新增数据结构：

* [FaceRect](https://cloud.tencent.com/document/api/670/31062#FaceRect)
* [MergeInfo](https://cloud.tencent.com/document/api/670/31062#MergeInfo)

### 第 1 次发布

发布时间：2018-12-03 19:20:13

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [FaceFusion](https://cloud.tencent.com/document/api/670/31061)

新增数据结构：

* [FuseFaceReviewDetail](https://cloud.tencent.com/document/api/670/31062#FuseFaceReviewDetail)
* [FuseFaceReviewResult](https://cloud.tencent.com/document/api/670/31062#FuseFaceReviewResult)



## 人脸融合(facefusion) 版本：2022-09-27

### 第 8 次发布

发布时间：2024-07-16 01:16:45

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [PublicMaterialInfos](https://cloud.tencent.com/document/api/670/85619#PublicMaterialInfos)

	* <font color="#dd0000">**修改成员**：</font>AuditResult


### 第 7 次发布

发布时间：2024-06-05 10:32:35

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [FuseFaceUltra](https://cloud.tencent.com/document/api/670/106891)

新增数据结构：

* [FusionUltraParam](https://cloud.tencent.com/document/api/670/85619#FusionUltraParam)

### 第 6 次发布

发布时间：2023-09-18 01:48:33

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [MergeInfo](https://cloud.tencent.com/document/api/670/85619#MergeInfo)

	* 新增成员：TemplateFaceRect


### 第 5 次发布

发布时间：2023-07-27 01:13:31

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [FuseFace](https://cloud.tencent.com/document/api/670/85618)

	* 新增入参：FuseParam


新增数据结构：

* [FuseParam](https://cloud.tencent.com/document/api/670/85619#FuseParam)
* [ImageCodecParam](https://cloud.tencent.com/document/api/670/85619#ImageCodecParam)
* [MetaData](https://cloud.tencent.com/document/api/670/85619#MetaData)

### 第 4 次发布

发布时间：2023-05-31 01:26:29

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [PublicMaterialInfos](https://cloud.tencent.com/document/api/670/85619#PublicMaterialInfos)

	* 新增成员：AuditResult


### 第 3 次发布

发布时间：2023-02-14 01:27:28

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [MaterialFaces](https://cloud.tencent.com/document/api/670/85619#MaterialFaces)

	* <font color="#dd0000">**修改成员**：</font>FaceId, FaceInfo


### 第 2 次发布

发布时间：2023-01-10 20:30:44

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeMaterialList](https://cloud.tencent.com/document/api/670/85633)

新增数据结构：

* [FaceInfo](https://cloud.tencent.com/document/api/670/85619#FaceInfo)
* [MaterialFaces](https://cloud.tencent.com/document/api/670/85619#MaterialFaces)
* [PublicMaterialInfos](https://cloud.tencent.com/document/api/670/85619#PublicMaterialInfos)

### 第 1 次发布

发布时间：2023-01-10 20:21:04

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [FuseFace](https://cloud.tencent.com/document/api/670/85618)

新增数据结构：

* [FaceRect](https://cloud.tencent.com/document/api/670/85619#FaceRect)
* [LogoParam](https://cloud.tencent.com/document/api/670/85619#LogoParam)
* [MergeInfo](https://cloud.tencent.com/document/api/670/85619#MergeInfo)




## 人脸核身(faceid) 版本：2018-03-01

### 第 76 次发布

发布时间：2024-04-26 01:16:30

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [GetFaceIdResult](https://cloud.tencent.com/document/api/1007/49199)

	* 新增出参：LivenessInfoTag, DeviceInfoLevel


### 第 75 次发布

发布时间：2024-04-22 01:17:05

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [PhoneVerification](https://cloud.tencent.com/document/api/1007/39765)

	* 新增入参：VerifyMode

	* 新增出参：ResultDetail


### 第 74 次发布

发布时间：2024-04-12 01:15:49

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [RuleIdConfig](https://cloud.tencent.com/document/api/1007/41958#RuleIdConfig)

	* 新增成员：MouthOpenRecognition


### 第 73 次发布

发布时间：2024-03-27 01:17:36

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [GetFaceIdToken](https://cloud.tencent.com/document/api/1007/49198)

	* 新增入参：RuleId


### 第 72 次发布

发布时间：2024-03-26 01:17:00

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [GetFaceIdRiskInfo](https://cloud.tencent.com/document/api/1007/104582)
* [GetFaceidRiskInfoToken](https://cloud.tencent.com/document/api/1007/104581)

### 第 71 次发布

发布时间：2024-03-25 01:16:50

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [GetEidTokenConfig](https://cloud.tencent.com/document/api/1007/41958#GetEidTokenConfig)

	* 新增成员：MouthOpenRecognition


### 第 70 次发布

发布时间：2024-01-12 01:15:37

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [GetEidResult](https://cloud.tencent.com/document/api/1007/54090)

	* 新增入参：IsCutIdCardImage, IsNeedIdCardAvatar


### 第 69 次发布

发布时间：2023-12-27 01:19:47

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [IntentionQuestionResult](https://cloud.tencent.com/document/api/1007/41958#IntentionQuestionResult)

	* <font color="#dd0000">**修改成员**：</font>FinalResultDetailCode, FinalResultMessage


### 第 68 次发布

发布时间：2023-12-22 01:16:17

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DetectAIFakeFaces](https://cloud.tencent.com/document/api/1007/101561)

	* 新增出参：ExtraInfo


新增数据结构：

* [ExtraInfo](https://cloud.tencent.com/document/api/1007/41958#ExtraInfo)
* [RetrievalLivenessExtraInfo](https://cloud.tencent.com/document/api/1007/41958#RetrievalLivenessExtraInfo)

### 第 67 次发布

发布时间：2023-12-06 01:49:35

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [ImageRecognitionV2](https://cloud.tencent.com/document/api/1007/102203)

### 第 66 次发布

发布时间：2023-11-14 01:16:39

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DetectAIFakeFaces](https://cloud.tencent.com/document/api/1007/101561)

新增数据结构：

* [AttackRiskDetail](https://cloud.tencent.com/document/api/1007/41958#AttackRiskDetail)

### 第 65 次发布

发布时间：2023-11-13 11:06:52

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [GetDetectInfoEnhanced](https://cloud.tencent.com/document/api/1007/41957)

	* 新增入参：IsEncryptResponse

	* 新增出参：EncryptedBody


### 第 64 次发布

发布时间：2023-11-10 01:16:33

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [DetectInfoText](https://cloud.tencent.com/document/api/1007/41958#DetectInfoText)

	* <font color="#dd0000">**修改成员**：</font>IdInfoFrom, NFCRequestIds, NFCBillingCounts, PassNo, VisaNum


### 第 63 次发布

发布时间：2023-09-06 01:49:13

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [ChargeDetail](https://cloud.tencent.com/document/api/1007/41958#ChargeDetail)

	* 新增成员：IdCard


### 第 62 次发布

发布时间：2023-08-31 01:16:46

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [GetEidResult](https://cloud.tencent.com/document/api/1007/54090)

	* 新增出参：IntentionActionResult


修改数据结构：

* [GetEidTokenConfig](https://cloud.tencent.com/document/api/1007/41958#GetEidTokenConfig)

	* 新增成员：IntentionActions


### 第 61 次发布

发布时间：2023-08-29 01:15:31

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [IntentionVerifyData](https://cloud.tencent.com/document/api/1007/41958#IntentionVerifyData)


### 第 60 次发布

发布时间：2023-08-17 03:11:54

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DetectAuth](https://cloud.tencent.com/document/api/1007/31816)

	* 新增入参：IntentionActions

* [GetDetectInfoEnhanced](https://cloud.tencent.com/document/api/1007/41957)

	* 新增出参：IntentionActionResult


新增数据结构：

* [IntentionActionConfig](https://cloud.tencent.com/document/api/1007/41958#IntentionActionConfig)
* [IntentionActionResult](https://cloud.tencent.com/document/api/1007/41958#IntentionActionResult)
* [IntentionActionResultDetail](https://cloud.tencent.com/document/api/1007/41958#IntentionActionResultDetail)

修改数据结构：

* [RuleIdConfig](https://cloud.tencent.com/document/api/1007/41958#RuleIdConfig)

	* 新增成员：IntentionType


### 第 59 次发布

发布时间：2023-05-29 14:45:51

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [DetectInfoText](https://cloud.tencent.com/document/api/1007/41958#DetectInfoText)

	* 新增成员：UseIDType


### 第 58 次发布

发布时间：2023-05-23 01:21:54

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [GetEidTokenConfig](https://cloud.tencent.com/document/api/1007/41958#GetEidTokenConfig)

	* 新增成员：IsSupportHMTResidentPermitOCR


### 第 57 次发布

发布时间：2023-04-17 01:20:00

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [IntentionQuestionResult](https://cloud.tencent.com/document/api/1007/41958#IntentionQuestionResult)

	* 新增成员：FinalResultDetailCode, FinalResultMessage


### 第 56 次发布

发布时间：2023-04-13 01:17:40

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [DetectInfoText](https://cloud.tencent.com/document/api/1007/41958#DetectInfoText)

	* 新增成员：PassNo, VisaNum


### 第 55 次发布

发布时间：2023-03-15 01:37:54

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [DetectInfoText](https://cloud.tencent.com/document/api/1007/41958#DetectInfoText)

	* 新增成员：NFCRequestIds, NFCBillingCounts


### 第 54 次发布

发布时间：2023-03-01 01:27:36

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [DetectInfoText](https://cloud.tencent.com/document/api/1007/41958#DetectInfoText)

	* 新增成员：IdInfoFrom


### 第 53 次发布

发布时间：2023-01-06 01:23:24

本次发布包含了以下内容：

改善已有的文档。

<font color="#dd0000">**删除接口**：</font>

* GetRealNameAuthResult

### 第 52 次发布

发布时间：2023-01-05 01:23:16

本次发布包含了以下内容：

改善已有的文档。

<font color="#dd0000">**删除接口**：</font>

* GetRealNameAuthToken

### 第 51 次发布

发布时间：2022-11-29 06:46:33

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DetectAuth](https://cloud.tencent.com/document/api/1007/31816)

	* 新增入参：Config


新增数据结构：

* [RuleIdConfig](https://cloud.tencent.com/document/api/1007/41958#RuleIdConfig)

### 第 50 次发布

发布时间：2022-11-16 06:23:45

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [EncryptedPhoneVerification](https://cloud.tencent.com/document/api/1007/55050)

	* 新增出参：ISP

* [GetFaceIdToken](https://cloud.tencent.com/document/api/1007/49198)

	* 新增入参：Encryption


### 第 49 次发布

发布时间：2022-11-11 06:30:28

本次发布包含了以下内容：

改善已有的文档。

<font color="#dd0000">**删除接口**：</font>

* ApplyLivenessToken
* ApplySdkVerificationToken
* ApplyWebVerificationToken
* CreateUploadUrl
* DetectReflectLivenessAndCompare
* GenerateReflectSequence
* GetLivenessResult
* GetSdkVerificationResult
* GetWebVerificationResult
* VideoLivenessCompare

<font color="#dd0000">**删除数据结构**：</font>

* CardVerifyResult
* CompareResult
* FileInfo
* VerificationDetail

### 第 48 次发布

发布时间：2022-10-17 06:26:28

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [ApplyLivenessToken](https://cloud.tencent.com/document/api/1007/81469)
* [ApplySdkVerificationToken](https://cloud.tencent.com/document/api/1007/81474)
* [ApplyWebVerificationToken](https://cloud.tencent.com/document/api/1007/81473)
* [CreateUploadUrl](https://cloud.tencent.com/document/api/1007/81468)
* [DetectReflectLivenessAndCompare](https://cloud.tencent.com/document/api/1007/66076)
* [GenerateReflectSequence](https://cloud.tencent.com/document/api/1007/81476)
* [GetLivenessResult](https://cloud.tencent.com/document/api/1007/81472)
* [GetSdkVerificationResult](https://cloud.tencent.com/document/api/1007/81471)
* [GetWebVerificationResult](https://cloud.tencent.com/document/api/1007/81470)
* [VideoLivenessCompare](https://cloud.tencent.com/document/api/1007/81475)

新增数据结构：

* [CardVerifyResult](https://cloud.tencent.com/document/api/1007/41958#CardVerifyResult)
* [CompareResult](https://cloud.tencent.com/document/api/1007/41958#CompareResult)
* [FileInfo](https://cloud.tencent.com/document/api/1007/41958#FileInfo)
* [VerificationDetail](https://cloud.tencent.com/document/api/1007/41958#VerificationDetail)

### 第 47 次发布

发布时间：2022-09-20 06:29:06

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [DetectDetail](https://cloud.tencent.com/document/api/1007/41958#DetectDetail)

	* 新增成员：LivenessMode

* [DetectInfoText](https://cloud.tencent.com/document/api/1007/41958#DetectInfoText)

	* 新增成员：LivenessMode


### 第 46 次发布

发布时间：2022-09-02 06:31:36

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [GetEidTokenConfig](https://cloud.tencent.com/document/api/1007/41958#GetEidTokenConfig)

	* 新增成员：IntentionRecognition


### 第 45 次发布

发布时间：2022-08-26 06:28:34

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [GetDetectInfoEnhanced](https://cloud.tencent.com/document/api/1007/41957)

	* 新增入参：Encryption


修改数据结构：

* [Encryption](https://cloud.tencent.com/document/api/1007/41958#Encryption)

	* 新增成员：Algorithm, TagList


### 第 44 次发布

发布时间：2022-08-03 18:41:29

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [GetEidResult](https://cloud.tencent.com/document/api/1007/54090)

	* 新增出参：IntentionQuestionResult


修改数据结构：

* [GetEidTokenConfig](https://cloud.tencent.com/document/api/1007/41958#GetEidTokenConfig)

	* 新增成员：IntentionMode, IntentionQuestions


### 第 43 次发布

发布时间：2022-07-30 15:12:30

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DetectAuth](https://cloud.tencent.com/document/api/1007/31816)

	* 新增入参：IntentionQuestions

* [GetDetectInfoEnhanced](https://cloud.tencent.com/document/api/1007/41957)

	* 新增出参：IntentionQuestionResult


新增数据结构：

* [IntentionQuestion](https://cloud.tencent.com/document/api/1007/41958#IntentionQuestion)
* [IntentionQuestionResult](https://cloud.tencent.com/document/api/1007/41958#IntentionQuestionResult)

### 第 42 次发布

发布时间：2022-07-28 06:11:52

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [DetectInfoIdCardData](https://cloud.tencent.com/document/api/1007/41958#DetectInfoIdCardData)

	* 新增成员：BackWarnInfos


### 第 41 次发布

发布时间：2022-07-14 17:47:55

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [GetEidResult](https://cloud.tencent.com/document/api/1007/54090)

	* 新增出参：IntentionVerifyData


修改数据结构：

* [GetEidTokenConfig](https://cloud.tencent.com/document/api/1007/41958#GetEidTokenConfig)

	* 新增成员：UseIntentionVerify, IntentionVerifyText


### 第 40 次发布

发布时间：2022-06-02 06:08:18

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [ParseNfcData](https://cloud.tencent.com/document/api/1007/74804)

### 第 39 次发布

发布时间：2022-04-01 06:09:09

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [IntentionVerifyData](https://cloud.tencent.com/document/api/1007/41958#IntentionVerifyData)

	* 新增成员：AsrResultSimilarity


### 第 38 次发布

发布时间：2022-01-21 08:11:28

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [PhoneVerificationCMCC](https://cloud.tencent.com/document/api/1007/68559)
* [PhoneVerificationCTCC](https://cloud.tencent.com/document/api/1007/68558)
* [PhoneVerificationCUCC](https://cloud.tencent.com/document/api/1007/68557)

### 第 37 次发布

发布时间：2022-01-07 08:08:34

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [GetWeChatBillDetails](https://cloud.tencent.com/document/api/1007/67729)

新增数据结构：

* [ChargeDetail](https://cloud.tencent.com/document/api/1007/41958#ChargeDetail)
* [WeChatBillDetail](https://cloud.tencent.com/document/api/1007/41958#WeChatBillDetail)

### 第 36 次发布

发布时间：2022-01-06 08:09:38

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [PhoneVerification](https://cloud.tencent.com/document/api/1007/39765)

	* 新增出参：Isp


修改数据结构：

* [DetectInfoIdCardData](https://cloud.tencent.com/document/api/1007/41958#DetectInfoIdCardData)

	* 新增成员：WarnInfos


### 第 35 次发布

发布时间：2021-12-16 08:09:22

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DetectReflectLivenessAndCompare](https://cloud.tencent.com/document/api/1007/66076)

### 第 34 次发布

发布时间：2021-12-10 08:06:32

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DetectAuth](https://cloud.tencent.com/document/api/1007/31816)

	* 新增入参：IntentionVerifyText

* [GetDetectInfoEnhanced](https://cloud.tencent.com/document/api/1007/41957)

	* 新增出参：IntentionVerifyData


新增数据结构：

* [IntentionVerifyData](https://cloud.tencent.com/document/api/1007/41958#IntentionVerifyData)

### 第 33 次发布

发布时间：2021-11-23 08:07:49

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [LivenessCompare](https://cloud.tencent.com/document/api/1007/31819)

	* 新增入参：ImageUrl, VideoUrl

	* <font color="#dd0000">**修改入参**：</font>ImageBase64, VideoBase64

* [LivenessRecognition](https://cloud.tencent.com/document/api/1007/31818)

	* 新增入参：VideoUrl

	* <font color="#dd0000">**修改入参**：</font>VideoBase64


### 第 32 次发布

发布时间：2021-10-29 08:05:31

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [GetFaceIdToken](https://cloud.tencent.com/document/api/1007/49198)

	* 新增入参：UseCos


修改数据结构：

* [EidInfo](https://cloud.tencent.com/document/api/1007/41958#EidInfo)

	* 新增成员：DesKey, UserInfo


### 第 31 次发布

发布时间：2021-10-21 11:26:59

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [GetEidToken](https://cloud.tencent.com/document/api/1007/54089)

	* 新增入参：Encryption


### 第 30 次发布

发布时间：2021-08-24 08:06:24

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [GetFaceIdResult](https://cloud.tencent.com/document/api/1007/49199)

	* 新增出参：DeviceInfoTag, RiskInfoTag


### 第 29 次发布

发布时间：2021-08-11 08:05:48

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CheckIdNameDate](https://cloud.tencent.com/document/api/1007/60075)

### 第 28 次发布

发布时间：2021-07-13 08:07:56

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [BankCard2EVerification](https://cloud.tencent.com/document/api/1007/35776)

	* 新增入参：Encryption

* [CheckBankCardInformation](https://cloud.tencent.com/document/api/1007/47837)

	* 新增入参：Encryption

* [CheckIdCardInformation](https://cloud.tencent.com/document/api/1007/47276)

	* 新增入参：IsEncrypt

	* 新增出参：Encryption

* [CheckPhoneAndName](https://cloud.tencent.com/document/api/1007/50364)

	* 新增入参：Encryption

* [IdCardVerification](https://cloud.tencent.com/document/api/1007/33188)

	* 新增入参：Encryption

* [ImageRecognition](https://cloud.tencent.com/document/api/1007/31820)

	* 新增入参：Encryption

* [LivenessRecognition](https://cloud.tencent.com/document/api/1007/31818)

	* 新增入参：Encryption


### 第 27 次发布

发布时间：2021-07-07 10:00:09

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CheckEidTokenStatus](https://cloud.tencent.com/document/api/1007/58231)

修改接口：

* [GetEidToken](https://cloud.tencent.com/document/api/1007/54089)

	* 新增入参：RedirectUrl

	* 新增出参：Url


### 第 26 次发布

发布时间：2021-04-25 10:14:38

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [EncryptedPhoneVerification](https://cloud.tencent.com/document/api/1007/55050)

### 第 25 次发布

发布时间：2021-04-01 08:04:52

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [GetDetectInfoEnhanced](https://cloud.tencent.com/document/api/1007/41957)

	* 新增入参：IsEncrypt

	* 新增出参：Encryption

* [IdCardOCRVerification](https://cloud.tencent.com/document/api/1007/37980)

	* 新增入参：Encryption


### 第 24 次发布

发布时间：2021-03-25 08:04:55

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [GetEidResult](https://cloud.tencent.com/document/api/1007/54090)
* [GetEidToken](https://cloud.tencent.com/document/api/1007/54089)

新增数据结构：

* [EidInfo](https://cloud.tencent.com/document/api/1007/41958#EidInfo)
* [GetEidTokenConfig](https://cloud.tencent.com/document/api/1007/41958#GetEidTokenConfig)

### 第 23 次发布

发布时间：2021-03-24 08:04:57

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [MobileNetworkTimeVerification](https://cloud.tencent.com/document/api/1007/40546)

	* 新增入参：Encryption

* [MobileStatus](https://cloud.tencent.com/document/api/1007/40545)

	* 新增入参：Encryption


### 第 22 次发布

发布时间：2021-03-16 08:05:37

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [BankCard4EVerification](https://cloud.tencent.com/document/api/1007/35775)

	* 新增入参：Encryption

* [BankCardVerification](https://cloud.tencent.com/document/api/1007/33848)

	* 新增入参：Encryption

* [DetectAuth](https://cloud.tencent.com/document/api/1007/31816)

	* 新增入参：Encryption


### 第 21 次发布

发布时间：2021-03-03 08:04:35

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [MinorsVerification](https://cloud.tencent.com/document/api/1007/39766)

	* 新增入参：Encryption


新增数据结构：

* [Encryption](https://cloud.tencent.com/document/api/1007/41958#Encryption)

### 第 20 次发布

发布时间：2020-12-24 08:04:18

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [GetRealNameAuthResult](https://cloud.tencent.com/document/api/1007/51442)
* [GetRealNameAuthToken](https://cloud.tencent.com/document/api/1007/51441)

### 第 19 次发布

发布时间：2020-11-27 08:03:44

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CheckPhoneAndName](https://cloud.tencent.com/document/api/1007/50364)

修改数据结构：

* [DetectDetail](https://cloud.tencent.com/document/api/1007/41958#DetectDetail)

	* 新增成员：CompareLibType

* [DetectInfoText](https://cloud.tencent.com/document/api/1007/41958#DetectInfoText)

	* 新增成员：CompareLibType


### 第 18 次发布

发布时间：2020-10-16 08:04:13

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [GetFaceIdResult](https://cloud.tencent.com/document/api/1007/49199)
* [GetFaceIdToken](https://cloud.tencent.com/document/api/1007/49198)

### 第 17 次发布

发布时间：2020-09-29 08:04:10

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [PhoneVerification](https://cloud.tencent.com/document/api/1007/39765)

	* 新增入参：Iv


### 第 16 次发布

发布时间：2020-08-27 08:03:28

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CheckBankCardInformation](https://cloud.tencent.com/document/api/1007/47837)

### 第 15 次发布

发布时间：2020-08-18 08:12:45

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CheckIdCardInformation](https://cloud.tencent.com/document/api/1007/47276)

	* 新增出参：Quality


### 第 14 次发布

发布时间：2020-08-10 08:11:30

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CheckIdCardInformation](https://cloud.tencent.com/document/api/1007/47276)

### 第 13 次发布

发布时间：2020-08-07 08:11:16

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [PhoneVerification](https://cloud.tencent.com/document/api/1007/39765)

	* 新增入参：CiphertextBlob, EncryptList


### 第 12 次发布

发布时间：2020-06-02 08:10:02

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [GetActionSequence](https://cloud.tencent.com/document/api/1007/31822)

	* 新增入参：ActionType

* [Liveness](https://cloud.tencent.com/document/api/1007/35330)

	* 新增出参：BestFrameList

* [LivenessCompare](https://cloud.tencent.com/document/api/1007/31819)

	* 新增出参：BestFrameList

* [LivenessRecognition](https://cloud.tencent.com/document/api/1007/31818)

	* 新增出参：BestFrameList


### 第 11 次发布

发布时间：2020-03-05 22:50:23

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [GetDetectInfoEnhanced](https://cloud.tencent.com/document/api/1007/41957)

新增数据结构：

* [DetectDetail](https://cloud.tencent.com/document/api/1007/41958#DetectDetail)
* [DetectInfoBestFrame](https://cloud.tencent.com/document/api/1007/41958#DetectInfoBestFrame)
* [DetectInfoIdCardData](https://cloud.tencent.com/document/api/1007/41958#DetectInfoIdCardData)
* [DetectInfoText](https://cloud.tencent.com/document/api/1007/41958#DetectInfoText)
* [DetectInfoVideoData](https://cloud.tencent.com/document/api/1007/41958#DetectInfoVideoData)

### 第 10 次发布

发布时间：2019-12-30 13:35:35

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [MobileNetworkTimeVerification](https://cloud.tencent.com/document/api/1007/40546)
* [MobileStatus](https://cloud.tencent.com/document/api/1007/40545)

### 第 9 次发布

发布时间：2019-11-28 20:30:09

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [MinorsVerification](https://cloud.tencent.com/document/api/1007/39766)
* [PhoneVerification](https://cloud.tencent.com/document/api/1007/39765)

### 第 8 次发布

发布时间：2019-09-12 17:08:04

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [IdCardOCRVerification](https://cloud.tencent.com/document/api/1007/37980)

### 第 7 次发布

发布时间：2019-06-27 16:10:47

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [BankCard2EVerification](https://cloud.tencent.com/document/api/1007/35776)
* [BankCard4EVerification](https://cloud.tencent.com/document/api/1007/35775)

### 第 6 次发布

发布时间：2019-06-06 21:54:47

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [Liveness](https://cloud.tencent.com/document/api/1007/35330)

修改接口：

* [BankCardVerification](https://cloud.tencent.com/document/api/1007/33848)

	* 新增入参：CertType


### 第 5 次发布

发布时间：2019-03-21 19:55:03

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [BankCardVerification](https://cloud.tencent.com/document/api/1007/33848)

### 第 4 次发布

发布时间：2019-02-22 15:15:07

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [IdCardVerification](https://cloud.tencent.com/document/api/1007/33188)

### 第 3 次发布

发布时间：2019-01-17 19:49:49

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [ImageRecognition](https://cloud.tencent.com/document/api/1007/31820)

	* 新增出参：Result, Description

* [LivenessCompare](https://cloud.tencent.com/document/api/1007/31819)

	* 新增出参：Result, Description

* [LivenessRecognition](https://cloud.tencent.com/document/api/1007/31818)

	* 新增出参：Result, Description


### 第 2 次发布

发布时间：2018-12-20 19:44:02

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [GetActionSequence](https://cloud.tencent.com/document/api/1007/31822)
* [GetLiveCode](https://cloud.tencent.com/document/api/1007/31821)
* [ImageRecognition](https://cloud.tencent.com/document/api/1007/31820)
* [LivenessCompare](https://cloud.tencent.com/document/api/1007/31819)
* [LivenessRecognition](https://cloud.tencent.com/document/api/1007/31818)

### 第 1 次发布

发布时间：2018-12-07 16:21:28

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DetectAuth](https://cloud.tencent.com/document/api/1007/31816)
* [GetDetectInfo](https://cloud.tencent.com/document/api/1007/33560)




## 人脸试妆(fmu) 版本：2019-12-13

### 第 8 次发布

发布时间：2024-07-05 01:10:44

本次发布包含了以下内容：

改善已有的文档。

<font color="#dd0000">**预下线接口**：</font>

* BeautifyVideo
* CancelBeautifyVideoJob
* QueryBeautifyVideoJob

### 第 7 次发布

发布时间：2023-07-14 14:55:45

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [QueryBeautifyVideoJob](https://cloud.tencent.com/document/api/1172/47792)

	* 新增出参：JobStatusCode


### 第 6 次发布

发布时间：2020-11-03 08:01:24

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [StyleImage](https://cloud.tencent.com/document/api/1172/49625)
* [StyleImagePro](https://cloud.tencent.com/document/api/1172/49624)

### 第 5 次发布

发布时间：2020-08-25 08:01:12

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [BeautifyVideo](https://cloud.tencent.com/document/api/1172/47794)
* [CancelBeautifyVideoJob](https://cloud.tencent.com/document/api/1172/47793)
* [QueryBeautifyVideoJob](https://cloud.tencent.com/document/api/1172/47792)

新增数据结构：

* [BeautifyVideoOutput](https://cloud.tencent.com/document/api/1172/40710#BeautifyVideoOutput)
* [BeautyParam](https://cloud.tencent.com/document/api/1172/40710#BeautyParam)

### 第 4 次发布

发布时间：2020-07-02 08:02:39

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [BeautifyPic](https://cloud.tencent.com/document/api/1172/40715)

	* 新增入参：RspImgType

	* 新增出参：ResultUrl

* [TryLipstickPic](https://cloud.tencent.com/document/api/1172/40706)

	* 新增入参：RspImgType

	* 新增出参：ResultUrl


### 第 3 次发布

发布时间：2020-04-30 08:02:30

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [LipColorInfo](https://cloud.tencent.com/document/api/1172/40710#LipColorInfo)

	* 新增成员：ModelAlpha


### 第 2 次发布

发布时间：2020-01-02 20:32:27

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [BeautifyPic](https://cloud.tencent.com/document/api/1172/40715)

### 第 1 次发布

发布时间：2020-01-02 17:02:17

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateModel](https://cloud.tencent.com/document/api/1172/40709)
* [DeleteModel](https://cloud.tencent.com/document/api/1172/40708)
* [GetModelList](https://cloud.tencent.com/document/api/1172/40707)
* [TryLipstickPic](https://cloud.tencent.com/document/api/1172/40706)

新增数据结构：

* [FaceRect](https://cloud.tencent.com/document/api/1172/40710#FaceRect)
* [LipColorInfo](https://cloud.tencent.com/document/api/1172/40710#LipColorInfo)
* [ModelInfo](https://cloud.tencent.com/document/api/1172/40710#ModelInfo)
* [RGBAInfo](https://cloud.tencent.com/document/api/1172/40710#RGBAInfo)




## 人像变换(ft) 版本：2020-03-04

### 第 6 次发布

发布时间：2021-12-08 08:10:45

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [QueryFaceMorphJob](https://cloud.tencent.com/document/api/1202/47936)

	* 新增出参：JobStatusCode


### 第 5 次发布

发布时间：2020-09-01 08:00:52

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [FaceCartoonPic](https://cloud.tencent.com/document/api/1202/47891)

	* 新增入参：DisableGlobalEffect


### 第 4 次发布

发布时间：2020-08-31 08:01:02

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CancelFaceMorphJob](https://cloud.tencent.com/document/api/1202/47938)
* [MorphFace](https://cloud.tencent.com/document/api/1202/47937)
* [QueryFaceMorphJob](https://cloud.tencent.com/document/api/1202/47936)

新增数据结构：

* [FaceMorphOutput](https://cloud.tencent.com/document/api/1202/41969#FaceMorphOutput)
* [GradientInfo](https://cloud.tencent.com/document/api/1202/41969#GradientInfo)

### 第 3 次发布

发布时间：2020-08-28 08:00:53

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [FaceCartoonPic](https://cloud.tencent.com/document/api/1202/47891)

### 第 2 次发布

发布时间：2020-07-02 08:02:30

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [ChangeAgePic](https://cloud.tencent.com/document/api/1202/41968)

	* 新增入参：RspImgType

	* 新增出参：ResultUrl

* [SwapGenderPic](https://cloud.tencent.com/document/api/1202/41967)

	* 新增入参：RspImgType

	* 新增出参：ResultUrl


### 第 1 次发布

发布时间：2020-03-05 23:04:05

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [ChangeAgePic](https://cloud.tencent.com/document/api/1202/41968)
* [SwapGenderPic](https://cloud.tencent.com/document/api/1202/41967)

新增数据结构：

* [AgeInfo](https://cloud.tencent.com/document/api/1202/41969#AgeInfo)
* [FaceRect](https://cloud.tencent.com/document/api/1202/41969#FaceRect)
* [GenderInfo](https://cloud.tencent.com/document/api/1202/41969#GenderInfo)




## 全球应用加速(gaap) 版本：2018-05-29

### 第 49 次发布

发布时间：2024-07-17 01:16:44

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeTaskStatus](https://cloud.tencent.com/document/api/608/108598)

	* 新增出参：Status, TaskId


### 第 48 次发布

发布时间：2024-07-15 01:12:05

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeTaskStatus](https://cloud.tencent.com/document/api/608/108598)

	* 新增入参：TaskId


### 第 47 次发布

发布时间：2024-07-12 01:16:49

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeTaskStatus](https://cloud.tencent.com/document/api/608/108598)

### 第 46 次发布

发布时间：2024-07-03 01:16:42

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [SetTlsVersion](https://cloud.tencent.com/document/api/608/107933)

### 第 45 次发布

发布时间：2024-06-19 01:43:58

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [DomainRuleSet](https://cloud.tencent.com/document/api/608/37023#DomainRuleSet)

	* 新增成员：TLSCiphers, TLSSupportVersion


### 第 44 次发布

发布时间：2024-04-17 01:14:36

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateDomain](https://cloud.tencent.com/document/api/608/36991)

	* 新增入参：IsDefaultServer

* [ModifyDomain](https://cloud.tencent.com/document/api/608/36984)

	* 新增入参：IsDefaultServer


修改数据结构：

* [DomainRuleSet](https://cloud.tencent.com/document/api/608/37023#DomainRuleSet)

	* 新增成员：IsDefaultServer


### 第 43 次发布

发布时间：2024-03-25 01:16:59

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [HTTPSListener](https://cloud.tencent.com/document/api/608/37023#HTTPSListener)

	* 新增成员：TLSSupportVersion, TLSCiphers

* [ProxyGroupDetail](https://cloud.tencent.com/document/api/608/37023#ProxyGroupDetail)

	* 新增成员：IsSupportTLSChoice

* [ProxyInfo](https://cloud.tencent.com/document/api/608/37023#ProxyInfo)

	* 新增成员：IsSupportTLSChoice


### 第 42 次发布

发布时间：2023-11-14 01:16:54

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [ProxyInfo](https://cloud.tencent.com/document/api/608/37023#ProxyInfo)

	* 新增成员：IsAutoScaleProxy


### 第 41 次发布

发布时间：2023-09-22 01:52:02

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeCustomHeader](https://cloud.tencent.com/document/api/608/59240)

	* 新增入参：RuleId


### 第 40 次发布

发布时间：2023-04-27 01:21:51

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeAuthSignature](https://cloud.tencent.com/document/api/608/90692)

### 第 39 次发布

发布时间：2023-04-25 01:27:13

本次发布包含了以下内容：

改善已有的文档。

新增数据结构：

* [SupportFeature](https://cloud.tencent.com/document/api/608/37023#SupportFeature)

修改数据结构：

* [RegionDetail](https://cloud.tencent.com/document/api/608/37023#RegionDetail)

	* 新增成员：SupportFeature


### 第 38 次发布

发布时间：2023-04-10 01:32:20

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DeleteProxyGroup](https://cloud.tencent.com/document/api/608/36947)

	* <font color="#dd0000">**修改入参**：</font>GroupId


### 第 37 次发布

发布时间：2022-10-13 06:28:02

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [HTTPListener](https://cloud.tencent.com/document/api/608/37023#HTTPListener)

	* 新增成员：ProxyId, GroupId

* [HTTPSListener](https://cloud.tencent.com/document/api/608/37023#HTTPSListener)

	* 新增成员：ProxyId, GroupId

* [TCPListener](https://cloud.tencent.com/document/api/608/37023#TCPListener)

	* 新增成员：ProxyId, GroupId

* [UDPListener](https://cloud.tencent.com/document/api/608/37023#UDPListener)

	* 新增成员：ProxyId, GroupId


### 第 36 次发布

发布时间：2022-09-01 06:29:26

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [HTTPSListener](https://cloud.tencent.com/document/api/608/37023#HTTPSListener)

	* 新增成员：Http3Supported


### 第 35 次发布

发布时间：2022-08-25 06:30:05

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateGlobalDomain](https://cloud.tencent.com/document/api/608/79567)
* [CreateGlobalDomainDns](https://cloud.tencent.com/document/api/608/79566)
* [DeleteGlobalDomain](https://cloud.tencent.com/document/api/608/79565)
* [DeleteGlobalDomainDns](https://cloud.tencent.com/document/api/608/79564)
* [DescribeGlobalDomainDns](https://cloud.tencent.com/document/api/608/79563)
* [DescribeGlobalDomains](https://cloud.tencent.com/document/api/608/79562)
* [DisableGlobalDomain](https://cloud.tencent.com/document/api/608/79561)
* [EnableGlobalDomain](https://cloud.tencent.com/document/api/608/79560)
* [ModifyGlobalDomainAttribute](https://cloud.tencent.com/document/api/608/79559)
* [ModifyGlobalDomainDns](https://cloud.tencent.com/document/api/608/79558)

新增数据结构：

* [Domain](https://cloud.tencent.com/document/api/608/37023#Domain)
* [GlobalDns](https://cloud.tencent.com/document/api/608/37023#GlobalDns)
* [ProxyAccessInfo](https://cloud.tencent.com/document/api/608/37023#ProxyAccessInfo)

### 第 34 次发布

发布时间：2022-07-29 06:09:17

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [ProxyGroupDetail](https://cloud.tencent.com/document/api/608/37023#ProxyGroupDetail)

	* 新增成员：FeatureBitmap

* [ProxyGroupInfo](https://cloud.tencent.com/document/api/608/37023#ProxyGroupInfo)

	* 新增成员：FeatureBitmap

* [ProxyInfo](https://cloud.tencent.com/document/api/608/37023#ProxyInfo)

	* 新增成员：FeatureBitmap


### 第 33 次发布

发布时间：2022-07-27 06:10:24

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateUDPListeners](https://cloud.tencent.com/document/api/608/37004)

	* 新增入参：DelayLoop, ConnectTimeout, HealthyThreshold, UnhealthyThreshold, FailoverSwitch, HealthCheck, CheckType, CheckPort, ContextType, SendContext, RecvContext

* [ModifyUDPListenerAttribute](https://cloud.tencent.com/document/api/608/36994)

	* 新增入参：DelayLoop, ConnectTimeout, HealthyThreshold, UnhealthyThreshold, FailoverSwitch, HealthCheck, CheckType, CheckPort, ContextType, SendContext, RecvContext


修改数据结构：

* [BindRealServer](https://cloud.tencent.com/document/api/608/37023#BindRealServer)

	* 新增成员：RealServerFailoverRole

* [UDPListener](https://cloud.tencent.com/document/api/608/37023#UDPListener)

	* 新增成员：DelayLoop, ConnectTimeout, HealthyThreshold, UnhealthyThreshold, FailoverSwitch, HealthCheck, CheckType, CheckPort, ContextType, SendContext, RecvContext


### 第 32 次发布

发布时间：2022-07-14 06:10:30

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [BanAndRecoverProxy](https://cloud.tencent.com/document/api/608/77246)
* [DescribeCrossBorderProxies](https://cloud.tencent.com/document/api/608/77245)

### 第 31 次发布

发布时间：2022-07-13 06:11:21

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateRule](https://cloud.tencent.com/document/api/608/36990)

	* 新增入参：ForcedRedirect

* [ModifyRuleAttribute](https://cloud.tencent.com/document/api/608/36983)

	* 新增入参：ForcedRedirect


修改数据结构：

* [RuleInfo](https://cloud.tencent.com/document/api/608/37023#RuleInfo)

	* 新增成员：ForcedRedirect


### 第 30 次发布

发布时间：2022-06-28 06:10:45

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [CountryAreaMap](https://cloud.tencent.com/document/api/608/37023#CountryAreaMap)

	* 新增成员：Remark


### 第 29 次发布

发布时间：2022-05-16 06:09:28

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateFirstLinkSession](https://cloud.tencent.com/document/api/608/73697)
* [DeleteFirstLinkSession](https://cloud.tencent.com/document/api/608/73696)
* [DescribeFirstLinkSession](https://cloud.tencent.com/document/api/608/73695)

新增数据结构：

* [Capacity](https://cloud.tencent.com/document/api/608/37023#Capacity)
* [DestAddressInfo](https://cloud.tencent.com/document/api/608/37023#DestAddressInfo)
* [DeviceInfo](https://cloud.tencent.com/document/api/608/37023#DeviceInfo)
* [SrcAddressInfo](https://cloud.tencent.com/document/api/608/37023#SrcAddressInfo)

### 第 28 次发布

发布时间：2022-02-17 08:10:54

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateRule](https://cloud.tencent.com/document/api/608/36990)

	* 新增入参：ServerNameIndicationSwitch, ServerNameIndication

* [ModifyRuleAttribute](https://cloud.tencent.com/document/api/608/36983)

	* 新增入参：ServerNameIndicationSwitch, ServerNameIndication


修改数据结构：

* [ProxyInfo](https://cloud.tencent.com/document/api/608/37023#ProxyInfo)

	* 新增成员：InBanBlacklist

* [RealServer](https://cloud.tencent.com/document/api/608/37023#RealServer)

	* 新增成员：InBanBlacklist

* [RuleInfo](https://cloud.tencent.com/document/api/608/37023#RuleInfo)

	* 新增成员：ServerNameIndicationSwitch, ServerNameIndication


### 第 27 次发布

发布时间：2022-01-11 08:09:11

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CheckProxyCreate](https://cloud.tencent.com/document/api/608/36974)

	* 新增入参：Http3Supported

* [CreateDomain](https://cloud.tencent.com/document/api/608/36991)

	* 新增入参：Http3Supported

* [CreateHTTPSListener](https://cloud.tencent.com/document/api/608/37006)

	* 新增入参：Http3Supported

* [CreateProxy](https://cloud.tencent.com/document/api/608/36971)

	* 新增入参：Http3Supported

* [CreateProxyGroup](https://cloud.tencent.com/document/api/608/36949)

	* 新增入参：Http3Supported

* [DescribeHTTPSListeners](https://cloud.tencent.com/document/api/608/37001)

	* 新增入参：Http3Supported

* [InquiryPriceCreateProxy](https://cloud.tencent.com/document/api/608/36957)

	* 新增入参：Http3Supported


修改数据结构：

* [AccessRegionDetial](https://cloud.tencent.com/document/api/608/37023#AccessRegionDetial)

	* 新增成员：FeatureBitmap

* [DomainRuleSet](https://cloud.tencent.com/document/api/608/37023#DomainRuleSet)

	* 新增成员：Http3Supported

* [ProxyGroupDetail](https://cloud.tencent.com/document/api/608/37023#ProxyGroupDetail)

	* 新增成员：Http3Supported

* [ProxyGroupInfo](https://cloud.tencent.com/document/api/608/37023#ProxyGroupInfo)

	* 新增成员：Http3Supported

* [ProxyInfo](https://cloud.tencent.com/document/api/608/37023#ProxyInfo)

	* 新增成员：Http3Supported

* [RegionDetail](https://cloud.tencent.com/document/api/608/37023#RegionDetail)

	* 新增成员：FeatureBitmap


### 第 26 次发布

发布时间：2021-12-30 08:09:28

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateProxy](https://cloud.tencent.com/document/api/608/36971)

	* 新增入参：PackageType


### 第 25 次发布

发布时间：2021-12-03 08:06:49

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeProxyStatistics](https://cloud.tencent.com/document/api/608/37019)

	* 新增入参：Isp


### 第 24 次发布

发布时间：2021-10-15 08:10:54

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeProxies](https://cloud.tencent.com/document/api/608/36963)

	* 新增入参：Order, OrderField


新增数据结构：

* [IPDetail](https://cloud.tencent.com/document/api/608/37023#IPDetail)

修改数据结构：

* [AccessRegionDetial](https://cloud.tencent.com/document/api/608/37023#AccessRegionDetial)

	* 新增成员：RegionArea, RegionAreaName, IDCType

* [ProxyInfo](https://cloud.tencent.com/document/api/608/37023#ProxyInfo)

	* 新增成员：IPList

* [RealServerStatus](https://cloud.tencent.com/document/api/608/37023#RealServerStatus)

	* 新增成员：GroupId

* [RegionDetail](https://cloud.tencent.com/document/api/608/37023#RegionDetail)

	* 新增成员：RegionArea, RegionAreaName, IDCType


### 第 23 次发布

发布时间：2021-09-22 08:08:23

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [DomainRuleSet](https://cloud.tencent.com/document/api/608/37023#DomainRuleSet)

	* 新增成员：BanStatus

* [ProxyInfo](https://cloud.tencent.com/document/api/608/37023#ProxyInfo)

	* 新增成员：BanStatus


### 第 22 次发布

发布时间：2021-08-26 08:05:52

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [ProxyInfo](https://cloud.tencent.com/document/api/608/37023#ProxyInfo)

	* 新增成员：PackageType

* [TCPListener](https://cloud.tencent.com/document/api/608/37023#TCPListener)

	* 新增成员：FailoverSwitch, SessionPersist

* [UDPListener](https://cloud.tencent.com/document/api/608/37023#UDPListener)

	* 新增成员：SessionPersist


### 第 21 次发布

发布时间：2021-08-24 08:06:32

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CheckProxyCreate](https://cloud.tencent.com/document/api/608/36974)

	* 新增入参：PackageType

* [CreateProxyGroup](https://cloud.tencent.com/document/api/608/36949)

	* 新增入参：PackageType

* [DescribeAccessRegionsByDestRegion](https://cloud.tencent.com/document/api/608/36965)

	* 新增入参：PackageType

* [DescribeRegionAndPrice](https://cloud.tencent.com/document/api/608/37017)

	* 新增入参：PackageType

* [InquiryPriceCreateProxy](https://cloud.tencent.com/document/api/608/36957)

	* 新增入参：PackageType


修改数据结构：

* [ProxyGroupDetail](https://cloud.tencent.com/document/api/608/37023#ProxyGroupDetail)

	* 新增成员：PackageType


### 第 20 次发布

发布时间：2021-08-12 08:06:22

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CheckProxyCreate](https://cloud.tencent.com/document/api/608/36974)

	* 新增入参：NetworkType

* [CreateProxy](https://cloud.tencent.com/document/api/608/36971)

	* 新增入参：NetworkType

* [InquiryPriceCreateProxy](https://cloud.tencent.com/document/api/608/36957)

	* 新增入参：NetworkType

	* 新增出参：Cn2BandwidthPrice, Cn2BandwidthPriceWithDiscount


修改数据结构：

* [AccessConfiguration](https://cloud.tencent.com/document/api/608/37023#AccessConfiguration)

	* 新增成员：NetworkType

* [ProxyInfo](https://cloud.tencent.com/document/api/608/37023#ProxyInfo)

	* 新增成员：NetworkType


### 第 19 次发布

发布时间：2021-07-28 08:06:03

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateCustomHeader](https://cloud.tencent.com/document/api/608/59242)
* [DescribeBlackHeader](https://cloud.tencent.com/document/api/608/59241)
* [DescribeCustomHeader](https://cloud.tencent.com/document/api/608/59240)

### 第 18 次发布

发布时间：2021-07-01 08:05:20

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CheckProxyCreate](https://cloud.tencent.com/document/api/608/36974)

	* 新增入参：IPAddressVersion

* [CreateProxy](https://cloud.tencent.com/document/api/608/36971)

	* 新增入参：IPAddressVersion

* [CreateProxyGroup](https://cloud.tencent.com/document/api/608/36949)

	* 新增入参：IPAddressVersion

* [CreateTCPListeners](https://cloud.tencent.com/document/api/608/37005)

	* 新增入参：HealthyThreshold, UnhealthyThreshold

* [DescribeAccessRegionsByDestRegion](https://cloud.tencent.com/document/api/608/36965)

	* 新增入参：IPAddressVersion

* [DescribeRegionAndPrice](https://cloud.tencent.com/document/api/608/37017)

	* 新增入参：IPAddressVersion

* [InquiryPriceCreateProxy](https://cloud.tencent.com/document/api/608/36957)

	* 新增入参：IPAddressVersion

* [ModifyTCPListenerAttribute](https://cloud.tencent.com/document/api/608/36995)

	* 新增入参：HealthyThreshold, UnhealthyThreshold


修改数据结构：

* [ProxyGroupDetail](https://cloud.tencent.com/document/api/608/37023#ProxyGroupDetail)

	* 新增成员：IPAddressVersion

* [ProxyInfo](https://cloud.tencent.com/document/api/608/37023#ProxyInfo)

	* 新增成员：IPAddressVersion

* [TCPListener](https://cloud.tencent.com/document/api/608/37023#TCPListener)

	* 新增成员：HealthyThreshold, UnhealthyThreshold


### 第 17 次发布

发布时间：2021-03-24 08:05:04

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateTCPListeners](https://cloud.tencent.com/document/api/608/37005)

	* 新增入参：FailoverSwitch

* [ModifyTCPListenerAttribute](https://cloud.tencent.com/document/api/608/36995)

	* 新增入参：FailoverSwitch


修改数据结构：

* [RealServerBindSetReq](https://cloud.tencent.com/document/api/608/37023#RealServerBindSetReq)

	* 新增成员：RealServerFailoverRole


### 第 16 次发布

发布时间：2021-01-15 08:04:18

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [ModifySecurityRule](https://cloud.tencent.com/document/api/608/36953)

	* 新增入参：RuleAction, SourceCidr, Protocol, DestPortRange


### 第 15 次发布

发布时间：2020-12-29 08:04:44

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeRuleRealServers](https://cloud.tencent.com/document/api/608/36987)

	* 新增入参：Offset, Limit


修改数据结构：

* [DomainRuleSet](https://cloud.tencent.com/document/api/608/37023#DomainRuleSet)

	* 新增成员：DomainStatus

* [RuleCheckParams](https://cloud.tencent.com/document/api/608/37023#RuleCheckParams)

	* 新增成员：FailedCountInter, FailedThreshold, BlockInter


### 第 14 次发布

发布时间：2020-11-17 08:04:34

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateTCPListeners](https://cloud.tencent.com/document/api/608/37005)

	* 新增入参：ClientIPMethod


修改数据结构：

* [ProxyGroupDetail](https://cloud.tencent.com/document/api/608/37023#ProxyGroupDetail)

	* 新增成员：PolicyId, Version, ClientIPMethod

* [ProxyInfo](https://cloud.tencent.com/document/api/608/37023#ProxyInfo)

	* 新增成员：ClientIPMethod

* [TCPListener](https://cloud.tencent.com/document/api/608/37023#TCPListener)

	* 新增成员：ClientIPMethod


### 第 13 次发布

发布时间：2020-09-04 08:03:55

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeRealServerStatistics](https://cloud.tencent.com/document/api/608/37018)

	* 新增入参：StartTime, EndTime, Granularity

	* <font color="#dd0000">**修改入参**：</font>ListenerId, WithinTime

	* 新增出参：RsStatisticsData


修改数据结构：

* [BandwidthPriceGradient](https://cloud.tencent.com/document/api/608/37023#BandwidthPriceGradient)

	* 新增成员：DiscountBandwidthUnitPrice

* [ProxyGroupInfo](https://cloud.tencent.com/document/api/608/37023#ProxyGroupInfo)

	* 新增成员：ProxyType

* [ProxyInfo](https://cloud.tencent.com/document/api/608/37023#ProxyInfo)

	* 新增成员：ProxyType


### 第 12 次发布

发布时间：2020-06-11 08:10:11

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CloseProxyGroup](https://cloud.tencent.com/document/api/608/45481)
* [OpenProxyGroup](https://cloud.tencent.com/document/api/608/45480)

修改接口：

* [CheckProxyCreate](https://cloud.tencent.com/document/api/608/36974)

	* 新增入参：GroupId

* [CloseSecurityPolicy](https://cloud.tencent.com/document/api/608/36972)

	* 新增入参：PolicyId

	* <font color="#dd0000">**修改入参**：</font>ProxyId

* [CreateHTTPListener](https://cloud.tencent.com/document/api/608/37007)

	* 新增入参：GroupId

* [CreateHTTPSListener](https://cloud.tencent.com/document/api/608/37006)

	* 新增入参：GroupId

* [CreateProxyGroup](https://cloud.tencent.com/document/api/608/36949)

	* 新增入参：AccessRegionSet

* [CreateSecurityPolicy](https://cloud.tencent.com/document/api/608/36970)

	* 新增入参：GroupId

	* <font color="#dd0000">**修改入参**：</font>ProxyId

* [DeleteProxyGroup](https://cloud.tencent.com/document/api/608/36947)

	* 新增入参：Force

* [DescribeHTTPListeners](https://cloud.tencent.com/document/api/608/37002)

	* 新增入参：GroupId

* [DescribeHTTPSListeners](https://cloud.tencent.com/document/api/608/37001)

	* 新增入参：GroupId

* [ModifyProxyGroupAttribute](https://cloud.tencent.com/document/api/608/36941)

	* 新增入参：ProjectId

* [OpenSecurityPolicy](https://cloud.tencent.com/document/api/608/36951)

	* 新增入参：PolicyId

	* <font color="#dd0000">**修改入参**：</font>ProxyId


新增数据结构：

* [AccessConfiguration](https://cloud.tencent.com/document/api/608/37023#AccessConfiguration)

修改数据结构：

* [ProxyGroupInfo](https://cloud.tencent.com/document/api/608/37023#ProxyGroupInfo)

	* 新增成员：Version, CreateTime

* [ProxyInfo](https://cloud.tencent.com/document/api/608/37023#ProxyInfo)

	* 新增成员：RelatedGlobalDomains, ModifyConfigTime


### 第 11 次发布

发布时间：2020-04-20 08:09:26

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateProxy](https://cloud.tencent.com/document/api/608/36971)

	* 新增入参：BillingType

* [InquiryPriceCreateProxy](https://cloud.tencent.com/document/api/608/36957)

	* 新增入参：BillingType

	* 新增出参：FlowUnitPrice, DiscountFlowUnitPrice

* [ModifyProxyConfiguration](https://cloud.tencent.com/document/api/608/36954)

	* 新增入参：BillingType


### 第 10 次发布

发布时间：2020-03-31 08:07:50

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [ProxyInfo](https://cloud.tencent.com/document/api/608/37023#ProxyInfo)

	* 新增成员：BillingType


### 第 9 次发布

发布时间：2019-12-27 11:54:41

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [DomainErrorPageInfo](https://cloud.tencent.com/document/api/608/37023#DomainErrorPageInfo)

	* 新增成员：Status


### 第 8 次发布

发布时间：2019-12-26 19:51:22

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeDomainErrorPageInfoByIds](https://cloud.tencent.com/document/api/608/40489)

### 第 7 次发布

发布时间：2019-12-15 20:56:38

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [SetAuthentication](https://cloud.tencent.com/document/api/608/36982)

	* 新增入参：PolyRealServerCertificateIds


### 第 6 次发布

发布时间：2019-12-05 17:38:02

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [DomainRuleSet](https://cloud.tencent.com/document/api/608/37023#DomainRuleSet)

	* 新增成员：PolyRealServerCertificateAliasInfo


### 第 5 次发布

发布时间：2019-11-28 19:49:39

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeRulesByRuleIds](https://cloud.tencent.com/document/api/608/39750)
* [DescribeSecurityRules](https://cloud.tencent.com/document/api/608/39749)

修改数据结构：

* [SecurityPolicyRuleOut](https://cloud.tencent.com/document/api/608/37023#SecurityPolicyRuleOut)

	* 新增成员：PolicyId


### 第 4 次发布

发布时间：2019-11-19 16:54:03

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateDomainErrorPageInfo](https://cloud.tencent.com/document/api/608/39347)
* [DeleteDomainErrorPageInfo](https://cloud.tencent.com/document/api/608/39346)
* [DescribeDomainErrorPageInfo](https://cloud.tencent.com/document/api/608/39345)

修改接口：

* [CreateDomain](https://cloud.tencent.com/document/api/608/36991)

	* 新增入参：PolyClientCertificateIds

* [CreateHTTPSListener](https://cloud.tencent.com/document/api/608/37006)

	* 新增入参：PolyClientCertificateIds

* [ModifyCertificate](https://cloud.tencent.com/document/api/608/36985)

	* 新增入参：PolyClientCertificateIds

* [ModifyDomain](https://cloud.tencent.com/document/api/608/36984)

	* 新增入参：PolyClientCertificateIds

* [ModifyHTTPSListenerAttribute](https://cloud.tencent.com/document/api/608/36996)

	* 新增入参：PolyClientCertificateIds


新增数据结构：

* [CertificateAliasInfo](https://cloud.tencent.com/document/api/608/37023#CertificateAliasInfo)
* [DomainErrorPageInfo](https://cloud.tencent.com/document/api/608/37023#DomainErrorPageInfo)
* [HttpHeaderParam](https://cloud.tencent.com/document/api/608/37023#HttpHeaderParam)

修改数据结构：

* [DomainRuleSet](https://cloud.tencent.com/document/api/608/37023#DomainRuleSet)

	* 新增成员：PolyClientCertificateAliasInfo

* [HTTPSListener](https://cloud.tencent.com/document/api/608/37023#HTTPSListener)

	* 新增成员：PolyClientCertificateAliasInfo

* [ProxyInfo](https://cloud.tencent.com/document/api/608/37023#ProxyInfo)

	* 新增成员：SupportSecurity


### 第 3 次发布

发布时间：2019-09-26 22:02:49

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateProxy](https://cloud.tencent.com/document/api/608/36971)

	* 新增入参：ClonedProxyId

* [CreateRule](https://cloud.tencent.com/document/api/608/36990)

	* 新增入参：ForwardHost


### 第 2 次发布

发布时间：2019-08-16 16:52:58

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [RealServerBindSetReq](https://cloud.tencent.com/document/api/608/37023#RealServerBindSetReq)

	* <font color="#dd0000">**修改成员**：</font>RealServerWeight


### 第 1 次发布

发布时间：2019-08-09 18:50:11

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [AddRealServers](https://cloud.tencent.com/document/api/608/37014)
* [BindListenerRealServers](https://cloud.tencent.com/document/api/608/37008)
* [BindRuleRealServers](https://cloud.tencent.com/document/api/608/36992)
* [CheckProxyCreate](https://cloud.tencent.com/document/api/608/36974)
* [CloseProxies](https://cloud.tencent.com/document/api/608/36973)
* [CloseSecurityPolicy](https://cloud.tencent.com/document/api/608/36972)
* [CreateCertificate](https://cloud.tencent.com/document/api/608/36980)
* [CreateDomain](https://cloud.tencent.com/document/api/608/36991)
* [CreateHTTPListener](https://cloud.tencent.com/document/api/608/37007)
* [CreateHTTPSListener](https://cloud.tencent.com/document/api/608/37006)
* [CreateProxy](https://cloud.tencent.com/document/api/608/36971)
* [CreateProxyGroup](https://cloud.tencent.com/document/api/608/36949)
* [CreateProxyGroupDomain](https://cloud.tencent.com/document/api/608/36948)
* [CreateRule](https://cloud.tencent.com/document/api/608/36990)
* [CreateSecurityPolicy](https://cloud.tencent.com/document/api/608/36970)
* [CreateSecurityRules](https://cloud.tencent.com/document/api/608/36969)
* [CreateTCPListeners](https://cloud.tencent.com/document/api/608/37005)
* [CreateUDPListeners](https://cloud.tencent.com/document/api/608/37004)
* [DeleteCertificate](https://cloud.tencent.com/document/api/608/36979)
* [DeleteDomain](https://cloud.tencent.com/document/api/608/36989)
* [DeleteListeners](https://cloud.tencent.com/document/api/608/37003)
* [DeleteProxyGroup](https://cloud.tencent.com/document/api/608/36947)
* [DeleteRule](https://cloud.tencent.com/document/api/608/36988)
* [DeleteSecurityPolicy](https://cloud.tencent.com/document/api/608/36968)
* [DeleteSecurityRules](https://cloud.tencent.com/document/api/608/36967)
* [DescribeAccessRegions](https://cloud.tencent.com/document/api/608/36966)
* [DescribeAccessRegionsByDestRegion](https://cloud.tencent.com/document/api/608/36965)
* [DescribeCertificateDetail](https://cloud.tencent.com/document/api/608/36978)
* [DescribeCertificates](https://cloud.tencent.com/document/api/608/36977)
* [DescribeCountryAreaMapping](https://cloud.tencent.com/document/api/608/36946)
* [DescribeDestRegions](https://cloud.tencent.com/document/api/608/36964)
* [DescribeGroupAndStatisticsProxy](https://cloud.tencent.com/document/api/608/37022)
* [DescribeGroupDomainConfig](https://cloud.tencent.com/document/api/608/36945)
* [DescribeHTTPListeners](https://cloud.tencent.com/document/api/608/37002)
* [DescribeHTTPSListeners](https://cloud.tencent.com/document/api/608/37001)
* [DescribeListenerRealServers](https://cloud.tencent.com/document/api/608/37000)
* [DescribeListenerStatistics](https://cloud.tencent.com/document/api/608/37021)
* [DescribeProxies](https://cloud.tencent.com/document/api/608/36963)
* [DescribeProxiesStatus](https://cloud.tencent.com/document/api/608/36962)
* [DescribeProxyAndStatisticsListeners](https://cloud.tencent.com/document/api/608/36961)
* [DescribeProxyDetail](https://cloud.tencent.com/document/api/608/36960)
* [DescribeProxyGroupDetails](https://cloud.tencent.com/document/api/608/36944)
* [DescribeProxyGroupList](https://cloud.tencent.com/document/api/608/36943)
* [DescribeProxyGroupStatistics](https://cloud.tencent.com/document/api/608/37020)
* [DescribeProxyStatistics](https://cloud.tencent.com/document/api/608/37019)
* [DescribeRealServerStatistics](https://cloud.tencent.com/document/api/608/37018)
* [DescribeRealServers](https://cloud.tencent.com/document/api/608/37013)
* [DescribeRealServersStatus](https://cloud.tencent.com/document/api/608/37012)
* [DescribeRegionAndPrice](https://cloud.tencent.com/document/api/608/37017)
* [DescribeResourcesByTag](https://cloud.tencent.com/document/api/608/37016)
* [DescribeRuleRealServers](https://cloud.tencent.com/document/api/608/36987)
* [DescribeRules](https://cloud.tencent.com/document/api/608/36986)
* [DescribeSecurityPolicyDetail](https://cloud.tencent.com/document/api/608/36959)
* [DescribeTCPListeners](https://cloud.tencent.com/document/api/608/36999)
* [DescribeUDPListeners](https://cloud.tencent.com/document/api/608/36998)
* [DestroyProxies](https://cloud.tencent.com/document/api/608/36958)
* [InquiryPriceCreateProxy](https://cloud.tencent.com/document/api/608/36957)
* [ModifyCertificate](https://cloud.tencent.com/document/api/608/36985)
* [ModifyCertificateAttributes](https://cloud.tencent.com/document/api/608/36976)
* [ModifyDomain](https://cloud.tencent.com/document/api/608/36984)
* [ModifyGroupDomainConfig](https://cloud.tencent.com/document/api/608/36942)
* [ModifyHTTPListenerAttribute](https://cloud.tencent.com/document/api/608/36997)
* [ModifyHTTPSListenerAttribute](https://cloud.tencent.com/document/api/608/36996)
* [ModifyProxiesAttribute](https://cloud.tencent.com/document/api/608/36956)
* [ModifyProxiesProject](https://cloud.tencent.com/document/api/608/36955)
* [ModifyProxyConfiguration](https://cloud.tencent.com/document/api/608/36954)
* [ModifyProxyGroupAttribute](https://cloud.tencent.com/document/api/608/36941)
* [ModifyRealServerName](https://cloud.tencent.com/document/api/608/37011)
* [ModifyRuleAttribute](https://cloud.tencent.com/document/api/608/36983)
* [ModifySecurityRule](https://cloud.tencent.com/document/api/608/36953)
* [ModifyTCPListenerAttribute](https://cloud.tencent.com/document/api/608/36995)
* [ModifyUDPListenerAttribute](https://cloud.tencent.com/document/api/608/36994)
* [OpenProxies](https://cloud.tencent.com/document/api/608/36952)
* [OpenSecurityPolicy](https://cloud.tencent.com/document/api/608/36951)
* [RemoveRealServers](https://cloud.tencent.com/document/api/608/37010)
* [SetAuthentication](https://cloud.tencent.com/document/api/608/36982)

新增数据结构：

* [AccessRegionDetial](https://cloud.tencent.com/document/api/608/37023#AccessRegionDetial)
* [AccessRegionDomainConf](https://cloud.tencent.com/document/api/608/37023#AccessRegionDomainConf)
* [BandwidthPriceGradient](https://cloud.tencent.com/document/api/608/37023#BandwidthPriceGradient)
* [BindRealServer](https://cloud.tencent.com/document/api/608/37023#BindRealServer)
* [BindRealServerInfo](https://cloud.tencent.com/document/api/608/37023#BindRealServerInfo)
* [Certificate](https://cloud.tencent.com/document/api/608/37023#Certificate)
* [CertificateDetail](https://cloud.tencent.com/document/api/608/37023#CertificateDetail)
* [CountryAreaMap](https://cloud.tencent.com/document/api/608/37023#CountryAreaMap)
* [DomainAccessRegionDict](https://cloud.tencent.com/document/api/608/37023#DomainAccessRegionDict)
* [DomainRuleSet](https://cloud.tencent.com/document/api/608/37023#DomainRuleSet)
* [Filter](https://cloud.tencent.com/document/api/608/37023#Filter)
* [GroupStatisticsInfo](https://cloud.tencent.com/document/api/608/37023#GroupStatisticsInfo)
* [HTTPListener](https://cloud.tencent.com/document/api/608/37023#HTTPListener)
* [HTTPSListener](https://cloud.tencent.com/document/api/608/37023#HTTPSListener)
* [ListenerInfo](https://cloud.tencent.com/document/api/608/37023#ListenerInfo)
* [MetricStatisticsInfo](https://cloud.tencent.com/document/api/608/37023#MetricStatisticsInfo)
* [NationCountryInnerInfo](https://cloud.tencent.com/document/api/608/37023#NationCountryInnerInfo)
* [NewRealServer](https://cloud.tencent.com/document/api/608/37023#NewRealServer)
* [ProxyGroupDetail](https://cloud.tencent.com/document/api/608/37023#ProxyGroupDetail)
* [ProxyGroupInfo](https://cloud.tencent.com/document/api/608/37023#ProxyGroupInfo)
* [ProxyIdDict](https://cloud.tencent.com/document/api/608/37023#ProxyIdDict)
* [ProxyInfo](https://cloud.tencent.com/document/api/608/37023#ProxyInfo)
* [ProxySimpleInfo](https://cloud.tencent.com/document/api/608/37023#ProxySimpleInfo)
* [ProxyStatus](https://cloud.tencent.com/document/api/608/37023#ProxyStatus)
* [RealServer](https://cloud.tencent.com/document/api/608/37023#RealServer)
* [RealServerBindSetReq](https://cloud.tencent.com/document/api/608/37023#RealServerBindSetReq)
* [RealServerStatus](https://cloud.tencent.com/document/api/608/37023#RealServerStatus)
* [RegionDetail](https://cloud.tencent.com/document/api/608/37023#RegionDetail)
* [RuleCheckParams](https://cloud.tencent.com/document/api/608/37023#RuleCheckParams)
* [RuleInfo](https://cloud.tencent.com/document/api/608/37023#RuleInfo)
* [SecurityPolicyRuleIn](https://cloud.tencent.com/document/api/608/37023#SecurityPolicyRuleIn)
* [SecurityPolicyRuleOut](https://cloud.tencent.com/document/api/608/37023#SecurityPolicyRuleOut)
* [StatisticsDataInfo](https://cloud.tencent.com/document/api/608/37023#StatisticsDataInfo)
* [TCPListener](https://cloud.tencent.com/document/api/608/37023#TCPListener)
* [TagPair](https://cloud.tencent.com/document/api/608/37023#TagPair)
* [TagResourceInfo](https://cloud.tencent.com/document/api/608/37023#TagResourceInfo)
* [UDPListener](https://cloud.tencent.com/document/api/608/37023#UDPListener)




## 游戏多媒体引擎(gme) 版本：2018-07-11

### 第 36 次发布

发布时间：2023-12-06 01:51:28

本次发布包含了以下内容：

改善已有的文档。

<font color="#dd0000">**预下线接口**：</font>

* CreateAgeDetectTask
* DescribeAgeDetectTask

### 第 35 次发布

发布时间：2023-08-24 01:19:31

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateScanUser](https://cloud.tencent.com/document/api/607/71481)

	* 新增入参：UserIdString, ExpirationTime

* [DeleteScanUser](https://cloud.tencent.com/document/api/607/71480)

	* 新增入参：UserIdString


### 第 34 次发布

发布时间：2023-06-14 01:25:30

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [ServiceStatus](https://cloud.tencent.com/document/api/607/35375#ServiceStatus)

	* 新增成员：TextTranslate


### 第 33 次发布

发布时间：2023-04-21 01:25:14

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateApp](https://cloud.tencent.com/document/api/607/38692)

	* 新增入参：AsrConf


### 第 32 次发布

发布时间：2023-04-20 01:22:55

本次发布包含了以下内容：

改善已有的文档。

新增数据结构：

* [AsrConf](https://cloud.tencent.com/document/api/607/35375#AsrConf)
* [SceneInfo](https://cloud.tencent.com/document/api/607/35375#SceneInfo)

修改数据结构：

* [CreateAppResp](https://cloud.tencent.com/document/api/607/35375#CreateAppResp)

	* 新增成员：AsrConf

* [VoiceFilterConf](https://cloud.tencent.com/document/api/607/35375#VoiceFilterConf)

	* 新增成员：SceneInfos


### 第 31 次发布

发布时间：2023-03-06 01:22:24

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeRecordInfo](https://cloud.tencent.com/document/api/607/87793)
* [DescribeTaskInfo](https://cloud.tencent.com/document/api/607/87792)
* [ModifyRecordInfo](https://cloud.tencent.com/document/api/607/87791)
* [StartRecord](https://cloud.tencent.com/document/api/607/87790)
* [StopRecord](https://cloud.tencent.com/document/api/607/87789)

新增数据结构：

* [RecordInfo](https://cloud.tencent.com/document/api/607/35375#RecordInfo)
* [SubscribeRecordUserIds](https://cloud.tencent.com/document/api/607/35375#SubscribeRecordUserIds)

### 第 30 次发布

发布时间：2023-02-02 01:29:27

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DeleteRoomMember](https://cloud.tencent.com/document/api/607/80403)

	* <font color="#dd0000">**修改入参**：</font>Uids


修改数据结构：

* [UserMicStatus](https://cloud.tencent.com/document/api/607/35375#UserMicStatus)

	* 新增成员：StrUid

	* <font color="#dd0000">**修改成员**：</font>Uid


### 第 29 次发布

发布时间：2023-01-12 01:21:12

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [RoomUser](https://cloud.tencent.com/document/api/607/35375#RoomUser)

	* 新增成员：StrUins


### 第 28 次发布

发布时间：2022-11-24 06:34:16

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeApplicationList](https://cloud.tencent.com/document/api/607/83252)

新增数据结构：

* [ApplicationList](https://cloud.tencent.com/document/api/607/35375#ApplicationList)
* [Filter](https://cloud.tencent.com/document/api/607/35375#Filter)
* [ServiceStatus](https://cloud.tencent.com/document/api/607/35375#ServiceStatus)
* [StatusInfo](https://cloud.tencent.com/document/api/607/35375#StatusInfo)

### 第 27 次发布

发布时间：2022-11-17 06:27:50

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateCustomization](https://cloud.tencent.com/document/api/607/78906)

	* 新增入参：ModelName


修改数据结构：

* [CustomizationConfigs](https://cloud.tencent.com/document/api/607/35375#CustomizationConfigs)

	* 新增成员：ModelName, TextUrl, UpdateTime


### 第 26 次发布

发布时间：2022-11-03 06:25:18

本次发布包含了以下内容：

改善已有的文档。

<font color="#dd0000">**删除接口**：</font>

* ModifyRoomInfo

### 第 25 次发布

发布时间：2022-10-28 06:29:04

本次发布包含了以下内容：

改善已有的文档。

新增数据结构：

* [AudioTextStatisticsItem](https://cloud.tencent.com/document/api/607/35375#AudioTextStatisticsItem)
* [OverseaTextStatisticsItem](https://cloud.tencent.com/document/api/607/35375#OverseaTextStatisticsItem)
* [RealtimeTextStatisticsItem](https://cloud.tencent.com/document/api/607/35375#RealtimeTextStatisticsItem)
* [StreamTextStatisticsItem](https://cloud.tencent.com/document/api/607/35375#StreamTextStatisticsItem)

修改数据结构：

* [AppStatisticsItem](https://cloud.tencent.com/document/api/607/35375#AppStatisticsItem)

	* 新增成员：AudioTextStatisticsItem, StreamTextStatisticsItem, OverseaTextStatisticsItem, RealtimeTextStatisticsItem


### 第 24 次发布

发布时间：2022-09-12 06:26:19

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DeleteRoomMember](https://cloud.tencent.com/document/api/607/80403)

新增数据结构：

* [DeleteResult](https://cloud.tencent.com/document/api/607/35375#DeleteResult)

### 第 23 次发布

发布时间：2022-09-06 06:33:02

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeUserInAndOutTime](https://cloud.tencent.com/document/api/607/50480)

	* 新增入参：UserIdStr, RoomIdStr


### 第 22 次发布

发布时间：2022-08-17 06:24:51

本次发布包含了以下内容：

改善已有的文档。

<font color="#dd0000">**删除接口**：</font>

* DescribeFilterResult
* DescribeFilterResultList
* VoiceFilter

<font color="#dd0000">**删除数据结构**：</font>

* VoiceFilter
* VoiceFilterInfo

### 第 21 次发布

发布时间：2022-08-11 06:32:55

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateCustomization](https://cloud.tencent.com/document/api/607/78906)
* [DeleteCustomization](https://cloud.tencent.com/document/api/607/78905)
* [GetCustomizationList](https://cloud.tencent.com/document/api/607/78904)
* [ModifyCustomization](https://cloud.tencent.com/document/api/607/78903)
* [ModifyCustomizationState](https://cloud.tencent.com/document/api/607/78902)

新增数据结构：

* [CustomizationConfigs](https://cloud.tencent.com/document/api/607/35375#CustomizationConfigs)

### 第 20 次发布

发布时间：2022-08-09 12:11:50

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [ModifyUserMicStatus](https://cloud.tencent.com/document/api/607/78798)

新增数据结构：

* [UserMicStatus](https://cloud.tencent.com/document/api/607/35375#UserMicStatus)

### 第 19 次发布

发布时间：2022-03-22 08:09:44

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateScanUser](https://cloud.tencent.com/document/api/607/71481)
* [DeleteScanUser](https://cloud.tencent.com/document/api/607/71480)

### 第 18 次发布

发布时间：2022-03-01 08:07:22

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeRealtimeScanConfig](https://cloud.tencent.com/document/api/607/70424)
* [UpdateScanRooms](https://cloud.tencent.com/document/api/607/70423)
* [UpdateScanUsers](https://cloud.tencent.com/document/api/607/70422)

### 第 17 次发布

发布时间：2022-01-17 08:08:32

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeRoomInfo](https://cloud.tencent.com/document/api/607/54789)

	* 新增入参：StrRoomIds

	* <font color="#dd0000">**修改入参**：</font>RoomIds


修改数据结构：

* [RoomUser](https://cloud.tencent.com/document/api/607/35375#RoomUser)

	* 新增成员：StrRoomId


### 第 16 次发布

发布时间：2021-12-23 08:10:54

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [ScanVoice](https://cloud.tencent.com/document/api/607/37622)

	* 新增入参：Lang


### 第 15 次发布

发布时间：2021-09-16 08:07:34

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [DescribeScanResult](https://cloud.tencent.com/document/api/607/35375#DescribeScanResult)

	* 新增成员：BizId


### 第 14 次发布

发布时间：2021-08-31 15:20:17

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeAppStatistics](https://cloud.tencent.com/document/api/607/38690)
* [ModifyAppStatus](https://cloud.tencent.com/document/api/607/38691)

新增数据结构：

* [AppStatisticsItem](https://cloud.tencent.com/document/api/607/35375#AppStatisticsItem)
* [DescribeAppStatisticsResp](https://cloud.tencent.com/document/api/607/35375#DescribeAppStatisticsResp)
* [ModifyAppStatusResp](https://cloud.tencent.com/document/api/607/35375#ModifyAppStatusResp)
* [RealTimeSpeechStatisticsItem](https://cloud.tencent.com/document/api/607/35375#RealTimeSpeechStatisticsItem)
* [VoiceFilterStatisticsItem](https://cloud.tencent.com/document/api/607/35375#VoiceFilterStatisticsItem)
* [VoiceMessageStatisticsItem](https://cloud.tencent.com/document/api/607/35375#VoiceMessageStatisticsItem)

### 第 13 次发布

发布时间：2021-08-31 14:37:25

本次发布包含了以下内容：

改善已有的文档。

<font color="#dd0000">**删除接口**：</font>

* DescribeAppStatistics
* ModifyAppStatus

修改接口：

* [CreateApp](https://cloud.tencent.com/document/api/607/38692)

	* 新增出参：Data, RequestId

	* <font color="#dd0000">**删除出参**：</font>BizId, AppName, ProjectId, SecretKey, CreateTime, RealtimeSpeechConf, VoiceMessageConf, VoiceFilterConf


新增数据结构：

* [CreateAppResp](https://cloud.tencent.com/document/api/607/35375#CreateAppResp)

<font color="#dd0000">**删除数据结构**：</font>

* AppStatisticsItem
* RealTimeSpeechStatisticsItem
* VoiceFilterStatisticsItem
* VoiceMessageStatisticsItem

### 第 12 次发布

发布时间：2021-08-24 08:06:51

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateAgeDetectTask](https://cloud.tencent.com/document/api/607/60620)
* [DescribeAgeDetectTask](https://cloud.tencent.com/document/api/607/60619)

新增数据结构：

* [AgeDetectTask](https://cloud.tencent.com/document/api/607/35375#AgeDetectTask)
* [AgeDetectTaskResult](https://cloud.tencent.com/document/api/607/35375#AgeDetectTaskResult)

### 第 11 次发布

发布时间：2021-04-19 08:04:50

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeRoomInfo](https://cloud.tencent.com/document/api/607/54789)

新增数据结构：

* [RoomUser](https://cloud.tencent.com/document/api/607/35375#RoomUser)

### 第 10 次发布

发布时间：2021-04-15 08:05:08

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [ModifyRoomInfo](https://cloud.tencent.com/document/api/607/54730)

### 第 9 次发布

发布时间：2021-01-25 08:04:43

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeApplicationData](https://cloud.tencent.com/document/api/607/52409)

新增数据结构：

* [ApplicationDataStatistics](https://cloud.tencent.com/document/api/607/35375#ApplicationDataStatistics)
* [StatisticsItem](https://cloud.tencent.com/document/api/607/35375#StatisticsItem)

### 第 8 次发布

发布时间：2020-12-01 08:03:50

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeUserInAndOutTime](https://cloud.tencent.com/document/api/607/50480)

新增数据结构：

* [InOutTimeInfo](https://cloud.tencent.com/document/api/607/35375#InOutTimeInfo)

### 第 7 次发布

发布时间：2019-11-28 22:12:22

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeScanResultList](https://cloud.tencent.com/document/api/607/37623)

	* 新增入参：Limit


修改数据结构：

* [ScanPiece](https://cloud.tencent.com/document/api/607/35375#ScanPiece)

	* 新增成员：PieceStartTime


### 第 6 次发布

发布时间：2019-11-21 19:32:13

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [ScanPiece](https://cloud.tencent.com/document/api/607/35375#ScanPiece)

	* 新增成员：Offset, Duration


### 第 5 次发布

发布时间：2019-10-24 20:33:56

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateApp](https://cloud.tencent.com/document/api/607/38692)
* [DescribeAppStatistics](https://cloud.tencent.com/document/api/607/38690)
* [ModifyAppStatus](https://cloud.tencent.com/document/api/607/38691)

新增数据结构：

* [AppStatisticsItem](https://cloud.tencent.com/document/api/607/35375#AppStatisticsItem)
* [RealTimeSpeechStatisticsItem](https://cloud.tencent.com/document/api/607/35375#RealTimeSpeechStatisticsItem)
* [RealtimeSpeechConf](https://cloud.tencent.com/document/api/607/35375#RealtimeSpeechConf)
* [Tag](https://cloud.tencent.com/document/api/607/35375#Tag)
* [VoiceFilterConf](https://cloud.tencent.com/document/api/607/35375#VoiceFilterConf)
* [VoiceFilterStatisticsItem](https://cloud.tencent.com/document/api/607/35375#VoiceFilterStatisticsItem)
* [VoiceMessageConf](https://cloud.tencent.com/document/api/607/35375#VoiceMessageConf)
* [VoiceMessageStatisticsItem](https://cloud.tencent.com/document/api/607/35375#VoiceMessageStatisticsItem)

修改数据结构：

* [ScanPiece](https://cloud.tencent.com/document/api/607/35375#ScanPiece)

	* 新增成员：Info


### 第 4 次发布

发布时间：2019-09-06 10:39:25

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [ScanPiece](https://cloud.tencent.com/document/api/607/35375#ScanPiece)

	* 新增成员：RoomId, OpenId

* [Task](https://cloud.tencent.com/document/api/607/35375#Task)

	* 新增成员：RoomId, OpenId


### 第 3 次发布

发布时间：2019-08-28 13:36:39

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeScanResultList](https://cloud.tencent.com/document/api/607/37623)
* [ScanVoice](https://cloud.tencent.com/document/api/607/37622)

新增数据结构：

* [DescribeScanResult](https://cloud.tencent.com/document/api/607/35375#DescribeScanResult)
* [ScanDetail](https://cloud.tencent.com/document/api/607/35375#ScanDetail)
* [ScanPiece](https://cloud.tencent.com/document/api/607/35375#ScanPiece)
* [ScanVoiceResult](https://cloud.tencent.com/document/api/607/35375#ScanVoiceResult)
* [Task](https://cloud.tencent.com/document/api/607/35375#Task)

### 第 2 次发布

发布时间：2019-07-12 11:02:06

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeFilterResult](https://cloud.tencent.com/document/api/607/36188)

### 第 1 次发布

发布时间：2019-06-10 16:19:26

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeFilterResultList](https://cloud.tencent.com/document/api/607/35374)
* [VoiceFilter](https://cloud.tencent.com/document/api/607/35373)

新增数据结构：

* [VoiceFilter](https://cloud.tencent.com/document/api/607/35375#VoiceFilter)
* [VoiceFilterInfo](https://cloud.tencent.com/document/api/607/35375#VoiceFilterInfo)




## 数据加速器 GooseFS(goosefs) 版本：2022-05-19

### 第 9 次发布

发布时间：2024-07-10 01:17:00

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [ExpandCapacity](https://cloud.tencent.com/document/api/1424/95787)

	* 新增入参：ModifyType


新增数据结构：

* [ChargeAttribute](https://cloud.tencent.com/document/api/1424/95076#ChargeAttribute)

修改数据结构：

* [FSAttribute](https://cloud.tencent.com/document/api/1424/95076#FSAttribute)

	* 新增成员：ChargeAttribute

* [MappedBucket](https://cloud.tencent.com/document/api/1424/95076#MappedBucket)

	* 新增成员：Endpoint


### 第 8 次发布

发布时间：2024-03-08 01:16:56

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateFileSystem](https://cloud.tencent.com/document/api/1424/95792)

	* 新增入参：SecurityGroupId


### 第 7 次发布

发布时间：2023-09-25 01:15:41

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [MappedBucket](https://cloud.tencent.com/document/api/1424/95076#MappedBucket)

	* 新增成员：Status, AccelerateFlag, BucketRegion


### 第 6 次发布

发布时间：2023-08-02 01:16:12

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [AddCrossVpcSubnetSupportForClientNode](https://cloud.tencent.com/document/api/1424/95800)
* [AttachFileSystemBucket](https://cloud.tencent.com/document/api/1424/95793)
* [BatchAddClientNodes](https://cloud.tencent.com/document/api/1424/95799)
* [BatchDeleteClientNodes](https://cloud.tencent.com/document/api/1424/95798)
* [CreateFileSystem](https://cloud.tencent.com/document/api/1424/95792)
* [DeleteCrossVpcSubnetSupportForClientNode](https://cloud.tencent.com/document/api/1424/95797)
* [DeleteFileSystem](https://cloud.tencent.com/document/api/1424/95791)
* [DescribeClientNodes](https://cloud.tencent.com/document/api/1424/95796)
* [DescribeFileSystemBuckets](https://cloud.tencent.com/document/api/1424/95790)
* [DescribeFileSystems](https://cloud.tencent.com/document/api/1424/95789)
* [DetachFileSystemBucket](https://cloud.tencent.com/document/api/1424/95788)
* [ExpandCapacity](https://cloud.tencent.com/document/api/1424/95787)
* [ModifyDataRepositoryBandwidth](https://cloud.tencent.com/document/api/1424/95786)
* [QueryCrossVpcSubnetSupportForClientNode](https://cloud.tencent.com/document/api/1424/95795)
* [QueryDataRepositoryBandwidth](https://cloud.tencent.com/document/api/1424/95785)

新增数据结构：

* [ClientClusterManagerNodeInfo](https://cloud.tencent.com/document/api/1424/95076#ClientClusterManagerNodeInfo)
* [ClientNodeAttribute](https://cloud.tencent.com/document/api/1424/95076#ClientNodeAttribute)
* [FSAttribute](https://cloud.tencent.com/document/api/1424/95076#FSAttribute)
* [GooseFSxAttribute](https://cloud.tencent.com/document/api/1424/95076#GooseFSxAttribute)
* [GooseFSxBuildElement](https://cloud.tencent.com/document/api/1424/95076#GooseFSxBuildElement)
* [LinuxNodeAttribute](https://cloud.tencent.com/document/api/1424/95076#LinuxNodeAttribute)
* [MappedBucket](https://cloud.tencent.com/document/api/1424/95076#MappedBucket)
* [SubnetInfo](https://cloud.tencent.com/document/api/1424/95076#SubnetInfo)
* [Tag](https://cloud.tencent.com/document/api/1424/95076#Tag)

### 第 5 次发布

发布时间：2023-07-19 01:25:47

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeClusterRoles](https://cloud.tencent.com/document/api/1424/95073)

	* 新增入参：RoleName


修改数据结构：

* [ClientToken](https://cloud.tencent.com/document/api/1424/95076#ClientToken)

	* 新增成员：NodeIp, GooseFSDirectory, Token

	* <font color="#dd0000">**修改成员**：</font>LocalDirectory


### 第 4 次发布

发布时间：2023-07-18 01:31:45

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeClusterClientToken](https://cloud.tencent.com/document/api/1424/95075)
* [DescribeClusterRoleToken](https://cloud.tencent.com/document/api/1424/95074)
* [DescribeClusterRoles](https://cloud.tencent.com/document/api/1424/95073)

新增数据结构：

* [ClientToken](https://cloud.tencent.com/document/api/1424/95076#ClientToken)
* [ClusterRole](https://cloud.tencent.com/document/api/1424/95076#ClusterRole)
* [RoleToken](https://cloud.tencent.com/document/api/1424/95076#RoleToken)

### 第 3 次发布

发布时间：2023-04-20 01:23:06

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeDataRepositoryTaskStatus](https://cloud.tencent.com/document/api/1424/86083)

	* 新增出参：FinishedFileNumber, FinishedCapacity


### 第 2 次发布

发布时间：2023-02-02 16:45:50

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeDataRepositoryTaskStatus](https://cloud.tencent.com/document/api/1424/86083)

修改接口：

* [CreateDataRepositoryTask](https://cloud.tencent.com/document/api/1424/85978)

	* 新增入参：RepositoryType, TextLocation


### 第 1 次发布

发布时间：2023-01-31 17:01:22

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateDataRepositoryTask](https://cloud.tencent.com/document/api/1424/85978)




## 游戏玩家匹配(gpm) 版本：2020-08-20

### 第 4 次发布

发布时间：2021-04-28 08:00:58

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [StartMatchingBackfill](https://cloud.tencent.com/document/api/1294/55243)

### 第 3 次发布

发布时间：2021-01-26 15:39:09

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeMatchCodes](https://cloud.tencent.com/document/api/1294/49483)

	* 新增入参：MatchCode


### 第 2 次发布

发布时间：2020-11-03 08:00:03

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeToken](https://cloud.tencent.com/document/api/1294/49622)
* [ModifyToken](https://cloud.tencent.com/document/api/1294/49621)

### 第 1 次发布

发布时间：2020-10-28 16:03:13

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CancelMatching](https://cloud.tencent.com/document/api/1294/49493)
* [CreateMatch](https://cloud.tencent.com/document/api/1294/49489)
* [CreateRule](https://cloud.tencent.com/document/api/1294/49488)
* [DeleteMatch](https://cloud.tencent.com/document/api/1294/49487)
* [DeleteRule](https://cloud.tencent.com/document/api/1294/49486)
* [DescribeData](https://cloud.tencent.com/document/api/1294/49485)
* [DescribeMatch](https://cloud.tencent.com/document/api/1294/49484)
* [DescribeMatchCodes](https://cloud.tencent.com/document/api/1294/49483)
* [DescribeMatches](https://cloud.tencent.com/document/api/1294/49482)
* [DescribeMatchingProgress](https://cloud.tencent.com/document/api/1294/49492)
* [DescribeRule](https://cloud.tencent.com/document/api/1294/49481)
* [DescribeRules](https://cloud.tencent.com/document/api/1294/49480)
* [ModifyMatch](https://cloud.tencent.com/document/api/1294/49479)
* [ModifyRule](https://cloud.tencent.com/document/api/1294/49478)
* [StartMatching](https://cloud.tencent.com/document/api/1294/49491)

新增数据结构：

* [AttributeMap](https://cloud.tencent.com/document/api/1294/49494#AttributeMap)
* [MTicket](https://cloud.tencent.com/document/api/1294/49494#MTicket)
* [MatchAttribute](https://cloud.tencent.com/document/api/1294/49494#MatchAttribute)
* [MatchCodeAttr](https://cloud.tencent.com/document/api/1294/49494#MatchCodeAttr)
* [MatchInfo](https://cloud.tencent.com/document/api/1294/49494#MatchInfo)
* [MatchTicket](https://cloud.tencent.com/document/api/1294/49494#MatchTicket)
* [Player](https://cloud.tencent.com/document/api/1294/49494#Player)
* [RegionLatency](https://cloud.tencent.com/document/api/1294/49494#RegionLatency)
* [ReportOverviewData](https://cloud.tencent.com/document/api/1294/49494#ReportOverviewData)
* [ReportTrendData](https://cloud.tencent.com/document/api/1294/49494#ReportTrendData)
* [RuleBriefInfo](https://cloud.tencent.com/document/api/1294/49494#RuleBriefInfo)
* [RuleInfo](https://cloud.tencent.com/document/api/1294/49494#RuleInfo)
* [StringKV](https://cloud.tencent.com/document/api/1294/49494#StringKV)
* [Tag](https://cloud.tencent.com/document/api/1294/49494#Tag)




## 云游戏(gs) 版本：2019-11-18

### 第 21 次发布

发布时间：2024-04-10 01:16:17

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [StartPublishStreamToCSS](https://cloud.tencent.com/document/api/1162/104965)

### 第 20 次发布

发布时间：2023-02-27 01:27:19

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateSession](https://cloud.tencent.com/document/api/1162/40740)

	* <font color="#dd0000">**修改入参**：</font>ClientSession


### 第 19 次发布

发布时间：2022-12-21 15:17:42

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeInstancesCount](https://cloud.tencent.com/document/api/1162/52717)

	* 新增入参：GameType


### 第 18 次发布

发布时间：2022-08-19 06:23:23

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeInstancesCount](https://cloud.tencent.com/document/api/1162/52717)

	* 新增入参：GameRegion


### 第 17 次发布

发布时间：2022-04-08 06:07:59

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateSession](https://cloud.tencent.com/document/api/1162/40740)

	* 新增入参：RunMode


### 第 16 次发布

发布时间：2022-01-11 08:09:37

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [StartPublishStream](https://cloud.tencent.com/document/api/1162/67868)
* [StopPublishStream](https://cloud.tencent.com/document/api/1162/67867)

### 第 15 次发布

发布时间：2021-02-03 08:01:53

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeInstancesCount](https://cloud.tencent.com/document/api/1162/52717)

### 第 14 次发布

发布时间：2021-01-08 08:01:28

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateSession](https://cloud.tencent.com/document/api/1162/40740)

	* 新增入参：GameContext


### 第 13 次发布

发布时间：2021-01-07 08:01:45

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [SaveGameArchive](https://cloud.tencent.com/document/api/1162/51776)
* [SwitchGameArchive](https://cloud.tencent.com/document/api/1162/51775)

### 第 12 次发布

发布时间：2020-12-23 08:01:30

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateSession](https://cloud.tencent.com/document/api/1162/40740)

	* 新增出参：Role


### 第 11 次发布

发布时间：2020-09-04 08:01:20

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateSession](https://cloud.tencent.com/document/api/1162/40740)

	* 新增入参：Role

	* 新增出参：RoleNumber


### 第 10 次发布

发布时间：2020-08-18 08:04:14

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateSession](https://cloud.tencent.com/document/api/1162/40740)

	* 新增入参：HostUserId

* [StopGame](https://cloud.tencent.com/document/api/1162/40739)

	* 新增入参：HostUserId


### 第 9 次发布

发布时间：2020-07-15 08:03:05

本次发布包含了以下内容：

改善已有的文档。

<font color="#dd0000">**删除接口**：</font>

* DescribeWorkers
* DescribeWorkersInfo
* EnterQueue
* ModifyWorkers
* QuitQueue

<font color="#dd0000">**删除数据结构**：</font>

* WorkerDetail
* WorkerRegionInfo

### 第 8 次发布

发布时间：2020-07-13 08:06:32

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [TrylockWorker](https://cloud.tencent.com/document/api/1162/40738)

	* 新增入参：GroupId


### 第 7 次发布

发布时间：2020-06-22 08:03:54

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [EnterQueue](https://cloud.tencent.com/document/api/1162/43837)

	* 新增入参：UserIp


### 第 6 次发布

发布时间：2020-04-27 08:02:18

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [EnterQueue](https://cloud.tencent.com/document/api/1162/43837)
* [QuitQueue](https://cloud.tencent.com/document/api/1162/43836)

### 第 5 次发布

发布时间：2020-04-24 08:02:17

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [WorkerDetail](https://cloud.tencent.com/document/api/1162/40743#WorkerDetail)

	* 新增成员：UserId, GameId


### 第 4 次发布

发布时间：2020-03-17 08:00:26

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateSession](https://cloud.tencent.com/document/api/1162/40740)

	* 新增入参：Optimization


### 第 3 次发布

发布时间：2020-03-16 08:00:52

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeWorkersInfo](https://cloud.tencent.com/document/api/1162/42275)
* [ModifyWorkers](https://cloud.tencent.com/document/api/1162/42274)

新增数据结构：

* [WorkerDetail](https://cloud.tencent.com/document/api/1162/40743#WorkerDetail)

### 第 2 次发布

发布时间：2020-01-13 16:53:58

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateSession](https://cloud.tencent.com/document/api/1162/40740)

	* 新增入参：Bitrate, MaxBitrate, MinBitrate, Fps, UserIp

* [TrylockWorker](https://cloud.tencent.com/document/api/1162/40738)

	* 新增入参：UserIp


### 第 1 次发布

发布时间：2020-01-03 14:32:39

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateSession](https://cloud.tencent.com/document/api/1162/40740)
* [DescribeWorkers](https://cloud.tencent.com/document/api/1162/40742)
* [StopGame](https://cloud.tencent.com/document/api/1162/40739)
* [TrylockWorker](https://cloud.tencent.com/document/api/1162/40738)

新增数据结构：

* [WorkerRegionInfo](https://cloud.tencent.com/document/api/1162/40743#WorkerRegionInfo)




## 游戏服务器伸缩(gse) 版本：2019-11-12

### 第 22 次发布

发布时间：2021-06-03 08:02:10

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [EndGameServerSessionAndProcess](https://cloud.tencent.com/document/api/1165/56618)

### 第 21 次发布

发布时间：2021-05-13 08:01:51

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [Instance](https://cloud.tencent.com/document/api/1165/42074#Instance)

	* 新增成员：PrivateIpAddress


### 第 20 次发布

发布时间：2021-05-08 15:20:44

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CopyFleet](https://cloud.tencent.com/document/api/1165/50917)

	* 新增入参：InternetMaxBandwidthOut

* [CreateFleet](https://cloud.tencent.com/document/api/1165/48938)

	* 新增入参：InternetMaxBandwidthOut

* [DescribeFleetEvents](https://cloud.tencent.com/document/api/1165/48749)

	* 新增入参：EventCode, StartTime, EndTime


修改数据结构：

* [FleetAttributes](https://cloud.tencent.com/document/api/1165/42074#FleetAttributes)

	* 新增成员：InternetMaxBandwidthOut


### 第 19 次发布

发布时间：2021-03-25 08:01:36

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeFleetRelatedResources](https://cloud.tencent.com/document/api/1165/54086)
* [GetGameServerInstanceLogUrl](https://cloud.tencent.com/document/api/1165/54088)

修改接口：

* [CopyFleet](https://cloud.tencent.com/document/api/1165/50917)

	* 新增入参：CcnInfos

* [CreateFleet](https://cloud.tencent.com/document/api/1165/48938)

	* 新增入参：CcnInfos


新增数据结构：

* [CcnInfo](https://cloud.tencent.com/document/api/1165/42074#CcnInfo)
* [FleetRelatedResource](https://cloud.tencent.com/document/api/1165/42074#FleetRelatedResource)
* [RelatedCcnInfo](https://cloud.tencent.com/document/api/1165/42074#RelatedCcnInfo)

修改数据结构：

* [FleetAttributes](https://cloud.tencent.com/document/api/1165/42074#FleetAttributes)

	* 新增成员：RelatedCcnInfos


### 第 18 次发布

发布时间：2021-03-22 08:01:39

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeInstances](https://cloud.tencent.com/document/api/1165/42604)

	* 新增入参：IpAddress

* [DescribeInstancesExtend](https://cloud.tencent.com/document/api/1165/48936)

	* 新增入参：IpAddress


### 第 17 次发布

发布时间：2021-02-02 08:01:29

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DeleteTimerScalingPolicy](https://cloud.tencent.com/document/api/1165/52668)
* [DescribeTimerScalingPolicies](https://cloud.tencent.com/document/api/1165/52667)
* [PutTimerScalingPolicy](https://cloud.tencent.com/document/api/1165/52666)
* [SetServerReserved](https://cloud.tencent.com/document/api/1165/52665)

修改接口：

* [CopyFleet](https://cloud.tencent.com/document/api/1165/50917)

	* 新增入参：SystemDiskInfo, DataDiskInfo, SelectedTimerType

* [CreateFleet](https://cloud.tencent.com/document/api/1165/48938)

	* 新增入参：SystemDiskInfo, DataDiskInfo


新增数据结构：

* [DiskInfo](https://cloud.tencent.com/document/api/1165/42074#DiskInfo)
* [TimerConfiguration](https://cloud.tencent.com/document/api/1165/42074#TimerConfiguration)
* [TimerFleetCapacity](https://cloud.tencent.com/document/api/1165/42074#TimerFleetCapacity)
* [TimerScalingPolicy](https://cloud.tencent.com/document/api/1165/42074#TimerScalingPolicy)
* [TimerValue](https://cloud.tencent.com/document/api/1165/42074#TimerValue)

修改数据结构：

* [FleetAttributes](https://cloud.tencent.com/document/api/1165/42074#FleetAttributes)

	* 新增成员：DataDiskInfo, SystemDiskInfo

* [Instance](https://cloud.tencent.com/document/api/1165/42074#Instance)

	* 新增成员：Weight, ReserveValue

* [TargetConfiguration](https://cloud.tencent.com/document/api/1165/42074#TargetConfiguration)

	* <font color="#dd0000">**修改成员**：</font>TargetValue


### 第 16 次发布

发布时间：2021-02-01 08:01:19

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [UpdateBucketAccelerateOpt](https://cloud.tencent.com/document/api/1165/52648)
* [UpdateBucketCORSOpt](https://cloud.tencent.com/document/api/1165/52647)

### 第 15 次发布

发布时间：2021-01-19 08:01:32

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CopyFleet](https://cloud.tencent.com/document/api/1165/50917)

	* 新增入参：Tags

* [CreateAlias](https://cloud.tencent.com/document/api/1165/48755)

	* 新增入参：Tags

* [CreateAsset](https://cloud.tencent.com/document/api/1165/48731)

	* 新增入参：Tags

* [CreateFleet](https://cloud.tencent.com/document/api/1165/48938)

	* 新增入参：Tags

* [CreateGameServerSessionQueue](https://cloud.tencent.com/document/api/1165/48937)

	* 新增入参：Tags


新增数据结构：

* [Tag](https://cloud.tencent.com/document/api/1165/42074#Tag)

修改数据结构：

* [Alias](https://cloud.tencent.com/document/api/1165/42074#Alias)

	* 新增成员：Tags

* [Asset](https://cloud.tencent.com/document/api/1165/42074#Asset)

	* 新增成员：Tags

* [FleetAttributes](https://cloud.tencent.com/document/api/1165/42074#FleetAttributes)

	* 新增成员：Tags

* [GameServerSessionQueue](https://cloud.tencent.com/document/api/1165/42074#GameServerSessionQueue)

	* 新增成员：Tags


### 第 14 次发布

发布时间：2020-12-14 08:01:08

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CopyFleet](https://cloud.tencent.com/document/api/1165/50917)

修改数据结构：

* [Asset](https://cloud.tencent.com/document/api/1165/42074#Asset)

	* <font color="#dd0000">**修改成员**：</font>CreateTime


### 第 13 次发布

发布时间：2020-11-17 08:01:20

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [Asset](https://cloud.tencent.com/document/api/1165/42074#Asset)

	* 新增成员：ResourceType, SharingStatus


### 第 12 次发布

发布时间：2020-11-06 08:01:10

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateAssetWithImage](https://cloud.tencent.com/document/api/1165/49738)

### 第 11 次发布

发布时间：2020-10-27 08:01:14

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeAssets](https://cloud.tencent.com/document/api/1165/48728)

	* 新增入参：Filters

* [DescribeGameServerSessionQueues](https://cloud.tencent.com/document/api/1165/44552)

	* 新增入参：Filters

* [ListAliases](https://cloud.tencent.com/document/api/1165/48741)

	* 新增入参：Filters

* [ListFleets](https://cloud.tencent.com/document/api/1165/48740)

	* 新增入参：Filters


新增数据结构：

* [Filter](https://cloud.tencent.com/document/api/1165/42074#Filter)

### 第 10 次发布

发布时间：2020-10-16 17:46:44

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeAssetSystems](https://cloud.tencent.com/document/api/1165/49191)
* [UpdateFleetName](https://cloud.tencent.com/document/api/1165/49204)

新增数据结构：

* [AssetSupportSys](https://cloud.tencent.com/document/api/1165/42074#AssetSupportSys)

### 第 9 次发布

发布时间：2020-10-13 08:00:55

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateAsset](https://cloud.tencent.com/document/api/1165/48731)

	* 新增入参：ImageId

	* 新增出参：AssetArn


修改数据结构：

* [Asset](https://cloud.tencent.com/document/api/1165/42074#Asset)

	* 新增成员：AssetArn, ImageId, OsType


### 第 8 次发布

发布时间：2020-09-30 08:00:48

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateFleet](https://cloud.tencent.com/document/api/1165/48938)
* [CreateGameServerSessionQueue](https://cloud.tencent.com/document/api/1165/48937)
* [DeleteGameServerSessionQueue](https://cloud.tencent.com/document/api/1165/48935)
* [DescribeFleetCapacity](https://cloud.tencent.com/document/api/1165/42072)
* [DescribeFleetStatisticDetails](https://cloud.tencent.com/document/api/1165/48934)
* [DescribeFleetStatisticFlows](https://cloud.tencent.com/document/api/1165/48933)
* [DescribeFleetStatisticSummary](https://cloud.tencent.com/document/api/1165/48932)
* [DescribeInstanceLimit](https://cloud.tencent.com/document/api/1165/48931)
* [DescribeInstancesExtend](https://cloud.tencent.com/document/api/1165/48936)
* [JoinGameServerSessionBatch](https://cloud.tencent.com/document/api/1165/42061)
* [UpdateFleetCapacity](https://cloud.tencent.com/document/api/1165/42069)
* [UpdateGameServerSessionQueue](https://cloud.tencent.com/document/api/1165/48930)

<font color="#dd0000">**删除接口**：</font>

* StartMatchPlacement

新增数据结构：

* [ExtraInfos](https://cloud.tencent.com/document/api/1165/42074#ExtraInfos)
* [FleetCapacity](https://cloud.tencent.com/document/api/1165/42074#FleetCapacity)
* [FleetStatisticDetail](https://cloud.tencent.com/document/api/1165/42074#FleetStatisticDetail)
* [FleetStatisticFlows](https://cloud.tencent.com/document/api/1165/42074#FleetStatisticFlows)
* [FleetStatisticTimes](https://cloud.tencent.com/document/api/1165/42074#FleetStatisticTimes)
* [InstanceCounts](https://cloud.tencent.com/document/api/1165/42074#InstanceCounts)
* [InstanceExtend](https://cloud.tencent.com/document/api/1165/42074#InstanceExtend)
* [PlayerDataMap](https://cloud.tencent.com/document/api/1165/42074#PlayerDataMap)

### 第 7 次发布

发布时间：2020-09-25 08:00:48

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [AttachCcnInstances](https://cloud.tencent.com/document/api/1165/48756)
* [CreateAlias](https://cloud.tencent.com/document/api/1165/48755)
* [CreateAsset](https://cloud.tencent.com/document/api/1165/48731)
* [DeleteAlias](https://cloud.tencent.com/document/api/1165/48754)
* [DeleteAsset](https://cloud.tencent.com/document/api/1165/48730)
* [DeleteFleet](https://cloud.tencent.com/document/api/1165/48753)
* [DescribeAlias](https://cloud.tencent.com/document/api/1165/48752)
* [DescribeAsset](https://cloud.tencent.com/document/api/1165/48729)
* [DescribeAssets](https://cloud.tencent.com/document/api/1165/48728)
* [DescribeCcnInstances](https://cloud.tencent.com/document/api/1165/48751)
* [DescribeFleetAttributes](https://cloud.tencent.com/document/api/1165/48750)
* [DescribeFleetEvents](https://cloud.tencent.com/document/api/1165/48749)
* [DescribeFleetPortSettings](https://cloud.tencent.com/document/api/1165/48748)
* [DescribeFleetUtilization](https://cloud.tencent.com/document/api/1165/48747)
* [DescribeInstanceTypes](https://cloud.tencent.com/document/api/1165/48732)
* [DescribeRuntimeConfiguration](https://cloud.tencent.com/document/api/1165/48746)
* [DescribeUserQuota](https://cloud.tencent.com/document/api/1165/48745)
* [DescribeUserQuotas](https://cloud.tencent.com/document/api/1165/48744)
* [DetachCcnInstances](https://cloud.tencent.com/document/api/1165/48743)
* [GetUploadCredentials](https://cloud.tencent.com/document/api/1165/48727)
* [GetUploadFederationToken](https://cloud.tencent.com/document/api/1165/48742)
* [ListAliases](https://cloud.tencent.com/document/api/1165/48741)
* [ListFleets](https://cloud.tencent.com/document/api/1165/48740)
* [ResolveAlias](https://cloud.tencent.com/document/api/1165/48739)
* [StartFleetActions](https://cloud.tencent.com/document/api/1165/48738)
* [StopFleetActions](https://cloud.tencent.com/document/api/1165/48737)
* [UpdateAlias](https://cloud.tencent.com/document/api/1165/48736)
* [UpdateAsset](https://cloud.tencent.com/document/api/1165/48726)
* [UpdateFleetAttributes](https://cloud.tencent.com/document/api/1165/48735)
* [UpdateFleetPortSettings](https://cloud.tencent.com/document/api/1165/48734)
* [UpdateRuntimeConfiguration](https://cloud.tencent.com/document/api/1165/48733)

新增数据结构：

* [Alias](https://cloud.tencent.com/document/api/1165/42074#Alias)
* [Asset](https://cloud.tencent.com/document/api/1165/42074#Asset)
* [AssetCredentials](https://cloud.tencent.com/document/api/1165/42074#AssetCredentials)
* [CcnInstanceSets](https://cloud.tencent.com/document/api/1165/42074#CcnInstanceSets)
* [Event](https://cloud.tencent.com/document/api/1165/42074#Event)
* [FleetAttributes](https://cloud.tencent.com/document/api/1165/42074#FleetAttributes)
* [FleetUtilization](https://cloud.tencent.com/document/api/1165/42074#FleetUtilization)
* [InboundPermission](https://cloud.tencent.com/document/api/1165/42074#InboundPermission)
* [InboundPermissionAuthorization](https://cloud.tencent.com/document/api/1165/42074#InboundPermissionAuthorization)
* [InboundPermissionRevocations](https://cloud.tencent.com/document/api/1165/42074#InboundPermissionRevocations)
* [InstanceTypeInfo](https://cloud.tencent.com/document/api/1165/42074#InstanceTypeInfo)
* [QuotaResource](https://cloud.tencent.com/document/api/1165/42074#QuotaResource)
* [ResourceCreationLimitPolicy](https://cloud.tencent.com/document/api/1165/42074#ResourceCreationLimitPolicy)
* [RoutingStrategy](https://cloud.tencent.com/document/api/1165/42074#RoutingStrategy)
* [RuntimeConfiguration](https://cloud.tencent.com/document/api/1165/42074#RuntimeConfiguration)
* [ServerProcesse](https://cloud.tencent.com/document/api/1165/42074#ServerProcesse)

修改数据结构：

* [GameServerSessionQueueDestination](https://cloud.tencent.com/document/api/1165/42074#GameServerSessionQueueDestination)

	* 新增成员：FleetStatus


### 第 6 次发布

发布时间：2020-06-29 08:02:16

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [StartMatchPlacement](https://cloud.tencent.com/document/api/1165/45804)

### 第 5 次发布

发布时间：2020-05-18 08:02:15

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DeleteScalingPolicy](https://cloud.tencent.com/document/api/1165/42073)
* [DescribeGameServerSessionQueues](https://cloud.tencent.com/document/api/1165/44552)
* [DescribeScalingPolicies](https://cloud.tencent.com/document/api/1165/42071)
* [PutScalingPolicy](https://cloud.tencent.com/document/api/1165/42070)
* [SetServerWeight](https://cloud.tencent.com/document/api/1165/44551)

新增数据结构：

* [GameServerSessionQueue](https://cloud.tencent.com/document/api/1165/42074#GameServerSessionQueue)
* [GameServerSessionQueueDestination](https://cloud.tencent.com/document/api/1165/42074#GameServerSessionQueueDestination)
* [PlayerLatencyPolicy](https://cloud.tencent.com/document/api/1165/42074#PlayerLatencyPolicy)
* [ScalingPolicy](https://cloud.tencent.com/document/api/1165/42074#ScalingPolicy)
* [TargetConfiguration](https://cloud.tencent.com/document/api/1165/42074#TargetConfiguration)

### 第 4 次发布

发布时间：2020-04-23 08:01:55

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [SearchGameServerSessions](https://cloud.tencent.com/document/api/1165/43708)

### 第 3 次发布

发布时间：2020-04-14 08:01:44

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [GameServerSession](https://cloud.tencent.com/document/api/1165/42074#GameServerSession)

	* 新增成员：CurrentCustomCount, MaxCustomCount, Weight, AvailabilityStatus


### 第 2 次发布

发布时间：2020-03-19 08:01:38

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeInstances](https://cloud.tencent.com/document/api/1165/42604)
* [GetInstanceAccess](https://cloud.tencent.com/document/api/1165/42603)

<font color="#dd0000">**删除接口**：</font>

* DeleteScalingPolicy
* DescribeFleetCapacity
* DescribeScalingPolicies
* PutScalingPolicy
* UpdateFleetCapacity

新增数据结构：

* [Credentials](https://cloud.tencent.com/document/api/1165/42074#Credentials)
* [Instance](https://cloud.tencent.com/document/api/1165/42074#Instance)
* [InstanceAccess](https://cloud.tencent.com/document/api/1165/42074#InstanceAccess)

<font color="#dd0000">**删除数据结构**：</font>

* FleetCapacity
* InstanceCounts
* ScalingPolicy
* TargetConfiguration

### 第 1 次发布

发布时间：2020-03-06 17:34:37

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateGameServerSession](https://cloud.tencent.com/document/api/1165/42067)
* [DeleteScalingPolicy](https://cloud.tencent.com/document/api/1165/42073)
* [DescribeFleetCapacity](https://cloud.tencent.com/document/api/1165/42072)
* [DescribeGameServerSessionDetails](https://cloud.tencent.com/document/api/1165/42066)
* [DescribeGameServerSessionPlacement](https://cloud.tencent.com/document/api/1165/42065)
* [DescribeGameServerSessions](https://cloud.tencent.com/document/api/1165/42064)
* [DescribePlayerSessions](https://cloud.tencent.com/document/api/1165/42063)
* [DescribeScalingPolicies](https://cloud.tencent.com/document/api/1165/42071)
* [GetGameServerSessionLogUrl](https://cloud.tencent.com/document/api/1165/42062)
* [JoinGameServerSession](https://cloud.tencent.com/document/api/1165/49192)
* [PutScalingPolicy](https://cloud.tencent.com/document/api/1165/42070)
* [StartGameServerSessionPlacement](https://cloud.tencent.com/document/api/1165/42060)
* [StopGameServerSessionPlacement](https://cloud.tencent.com/document/api/1165/42059)
* [UpdateFleetCapacity](https://cloud.tencent.com/document/api/1165/42069)
* [UpdateGameServerSession](https://cloud.tencent.com/document/api/1165/42058)

新增数据结构：

* [DesiredPlayerSession](https://cloud.tencent.com/document/api/1165/42074#DesiredPlayerSession)
* [FleetCapacity](https://cloud.tencent.com/document/api/1165/42074#FleetCapacity)
* [GameProperty](https://cloud.tencent.com/document/api/1165/42074#GameProperty)
* [GameServerSession](https://cloud.tencent.com/document/api/1165/42074#GameServerSession)
* [GameServerSessionDetail](https://cloud.tencent.com/document/api/1165/42074#GameServerSessionDetail)
* [GameServerSessionPlacement](https://cloud.tencent.com/document/api/1165/42074#GameServerSessionPlacement)
* [InstanceCounts](https://cloud.tencent.com/document/api/1165/42074#InstanceCounts)
* [PlacedPlayerSession](https://cloud.tencent.com/document/api/1165/42074#PlacedPlayerSession)
* [PlayerLatency](https://cloud.tencent.com/document/api/1165/42074#PlayerLatency)
* [PlayerSession](https://cloud.tencent.com/document/api/1165/42074#PlayerSession)
* [ScalingPolicy](https://cloud.tencent.com/document/api/1165/42074#ScalingPolicy)
* [TargetConfiguration](https://cloud.tencent.com/document/api/1165/42074#TargetConfiguration)




## (habo) 版本：2018-12-03

### 第 1 次发布

发布时间：2018-12-18 17:18:35

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeStatus](https://cloud.tencent.com/document/api/1012/31730)
* [StartAnalyse](https://cloud.tencent.com/document/api/1012/31729)




## 高性能应用服务(hai) 版本：2023-08-12

### 第 7 次发布

发布时间：2024-03-22 01:16:13

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [Instance](https://cloud.tencent.com/document/api/1721/101518#Instance)

	* 新增成员：OSType


### 第 6 次发布

发布时间：2024-01-03 01:16:14

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeApplications](https://cloud.tencent.com/document/api/1721/101609)

	* 新增入参：OrderField, Order


修改数据结构：

* [ApplicationInfo](https://cloud.tencent.com/document/api/1721/101518#ApplicationInfo)

	* 新增成员：ApplicationType, ApplicationState, CreateTime, ApplicationSize


### 第 5 次发布

发布时间：2023-12-13 01:52:48

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [StartInstance](https://cloud.tencent.com/document/api/1721/102449)
* [StopInstance](https://cloud.tencent.com/document/api/1721/102448)

### 第 4 次发布

发布时间：2023-11-22 04:14:20

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [SystemDisk](https://cloud.tencent.com/document/api/1721/101518#SystemDisk)

	* 新增成员：DiskName


### 第 3 次发布

发布时间：2023-11-16 01:20:06

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeApplications](https://cloud.tencent.com/document/api/1721/101609)
* [DescribeInstanceNetworkStatus](https://cloud.tencent.com/document/api/1721/101613)
* [DescribeInstances](https://cloud.tencent.com/document/api/1721/101612)
* [DescribeRegions](https://cloud.tencent.com/document/api/1721/101615)
* [DescribeScenes](https://cloud.tencent.com/document/api/1721/101608)
* [DescribeServiceLoginSettings](https://cloud.tencent.com/document/api/1721/101611)
* [InquirePriceRunInstances](https://cloud.tencent.com/document/api/1721/101610)

新增数据结构：

* [ApplicationInfo](https://cloud.tencent.com/document/api/1721/101518#ApplicationInfo)
* [Filter](https://cloud.tencent.com/document/api/1721/101518#Filter)
* [Instance](https://cloud.tencent.com/document/api/1721/101518#Instance)
* [ItemPrice](https://cloud.tencent.com/document/api/1721/101518#ItemPrice)
* [LoginService](https://cloud.tencent.com/document/api/1721/101518#LoginService)
* [LoginSetting](https://cloud.tencent.com/document/api/1721/101518#LoginSetting)
* [NetworkStatus](https://cloud.tencent.com/document/api/1721/101518#NetworkStatus)
* [Price](https://cloud.tencent.com/document/api/1721/101518#Price)
* [RegionInfo](https://cloud.tencent.com/document/api/1721/101518#RegionInfo)
* [SceneInfo](https://cloud.tencent.com/document/api/1721/101518#SceneInfo)

### 第 2 次发布

发布时间：2023-11-15 01:43:11

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [TerminateInstances](https://cloud.tencent.com/document/api/1721/101581)

### 第 1 次发布

发布时间：2023-11-10 16:10:58

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [RunInstances](https://cloud.tencent.com/document/api/1721/101517)

新增数据结构：

* [SystemDisk](https://cloud.tencent.com/document/api/1721/101518#SystemDisk)




## 高可用物联网卡(hasim) 版本：2021-07-16

### 第 2 次发布

发布时间：2023-03-15 01:39:36

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeLinks](https://cloud.tencent.com/document/api/1482/85099)

	* 新增入参：Limit, Offset


### 第 1 次发布

发布时间：2023-01-04 16:41:04

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateRule](https://cloud.tencent.com/document/api/1482/85109)
* [CreateTactic](https://cloud.tencent.com/document/api/1482/85115)
* [CreateTag](https://cloud.tencent.com/document/api/1482/85120)
* [DeleteRule](https://cloud.tencent.com/document/api/1482/85108)
* [DeleteTactic](https://cloud.tencent.com/document/api/1482/85114)
* [DeleteTag](https://cloud.tencent.com/document/api/1482/85119)
* [DescribeLink](https://cloud.tencent.com/document/api/1482/85100)
* [DescribeLinks](https://cloud.tencent.com/document/api/1482/85099)
* [DescribeOrders](https://cloud.tencent.com/document/api/1482/85102)
* [DescribeRule](https://cloud.tencent.com/document/api/1482/85107)
* [DescribeRules](https://cloud.tencent.com/document/api/1482/85106)
* [DescribeTactic](https://cloud.tencent.com/document/api/1482/85113)
* [DescribeTactics](https://cloud.tencent.com/document/api/1482/85112)
* [DescribeTags](https://cloud.tencent.com/document/api/1482/85118)
* [ModifyLinkAdvancedLog](https://cloud.tencent.com/document/api/1482/85098)
* [ModifyLinkTactic](https://cloud.tencent.com/document/api/1482/85097)
* [ModifyLinkTele](https://cloud.tencent.com/document/api/1482/85096)
* [ModifyRule](https://cloud.tencent.com/document/api/1482/85105)
* [ModifyRuleStatus](https://cloud.tencent.com/document/api/1482/85104)
* [ModifyTactic](https://cloud.tencent.com/document/api/1482/85111)
* [ModifyTag](https://cloud.tencent.com/document/api/1482/85117)
* [RenewLinkInfo](https://cloud.tencent.com/document/api/1482/85095)

新增数据结构：

* [DeviceReport](https://cloud.tencent.com/document/api/1482/85121#DeviceReport)
* [LinkDetailInfo](https://cloud.tencent.com/document/api/1482/85121#LinkDetailInfo)
* [LinkInfo](https://cloud.tencent.com/document/api/1482/85121#LinkInfo)
* [LinkInfos](https://cloud.tencent.com/document/api/1482/85121#LinkInfos)
* [OrderInfo](https://cloud.tencent.com/document/api/1482/85121#OrderInfo)
* [Orders](https://cloud.tencent.com/document/api/1482/85121#Orders)
* [Rule](https://cloud.tencent.com/document/api/1482/85121#Rule)
* [RuleDetail](https://cloud.tencent.com/document/api/1482/85121#RuleDetail)
* [RuleInfos](https://cloud.tencent.com/document/api/1482/85121#RuleInfos)
* [Tactic](https://cloud.tencent.com/document/api/1482/85121#Tactic)
* [TacticInfos](https://cloud.tencent.com/document/api/1482/85121#TacticInfos)
* [Tag](https://cloud.tencent.com/document/api/1482/85121#Tag)
* [TagInfos](https://cloud.tencent.com/document/api/1482/85121#TagInfos)
* [TeleOperatorCard](https://cloud.tencent.com/document/api/1482/85121#TeleOperatorCard)




## 数学作业批改(hcm) 版本：2018-11-06

### 第 9 次发布

发布时间：2023-09-25 01:15:46

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [Evaluation](https://cloud.tencent.com/document/api/1004/30616)


### 第 8 次发布

发布时间：2021-02-03 08:05:01

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [Evaluation](https://cloud.tencent.com/document/api/1004/30616)

	* 新增入参：RejectVagueArithmetic


修改数据结构：

* [Item](https://cloud.tencent.com/document/api/1004/30617#Item)

	* 新增成员：QuestionId


### 第 7 次发布

发布时间：2020-08-14 08:12:12

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [Evaluation](https://cloud.tencent.com/document/api/1004/30616)

	* 新增入参：LaTex


修改数据结构：

* [Item](https://cloud.tencent.com/document/api/1004/30617#Item)

	* 新增成员：ItemConf


### 第 6 次发布

发布时间：2020-07-06 08:10:58

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [Evaluation](https://cloud.tencent.com/document/api/1004/30616)

	* 新增入参：EnableDispRelatedVertical, EnableDispMidresult, EnablePdfRecognize, PdfPageIndex


### 第 5 次发布

发布时间：2020-03-16 08:11:31

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [Evaluation](https://cloud.tencent.com/document/api/1004/30616)

	* 新增入参：IsAsync

	* 新增出参：TaskId


### 第 4 次发布

发布时间：2019-05-30 20:16:33

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [Evaluation](https://cloud.tencent.com/document/api/1004/30616)

	* 新增入参：SupportHorizontalImage, RejectNonArithmeticImage


修改数据结构：

* [Item](https://cloud.tencent.com/document/api/1004/30617#Item)

	* 新增成员：ExpressionType


### 第 3 次发布

发布时间：2019-03-21 19:45:30

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [Item](https://cloud.tencent.com/document/api/1004/30617#Item)

	* 新增成员：Answer


### 第 2 次发布

发布时间：2019-01-17 16:39:37

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [Evaluation](https://cloud.tencent.com/document/api/1004/30616)

	* 新增入参：HcmAppid, Url

	* <font color="#dd0000">**修改入参**：</font>Image


### 第 1 次发布

发布时间：2018-11-22 20:07:40

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [Evaluation](https://cloud.tencent.com/document/api/1004/30616)

新增数据结构：

* [Item](https://cloud.tencent.com/document/api/1004/30617#Item)
* [ItemCoord](https://cloud.tencent.com/document/api/1004/30617#ItemCoord)




## 腾讯混元大模型(hunyuan) 版本：2023-09-01

### 第 15 次发布

发布时间：2024-08-02 01:40:08

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [ChatCompletions](https://cloud.tencent.com/document/api/1729/105701)

	* 新增入参：Citation


### 第 14 次发布

发布时间：2024-07-26 01:44:41

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [SubmitHunyuanImageJob](https://cloud.tencent.com/document/api/1729/105969)

	* 新增入参：Num, Seed, LogoParam

* [TextToImageLite](https://cloud.tencent.com/document/api/1729/108738)

	* 新增入参：LogoParam


新增数据结构：

* [LogoParam](https://cloud.tencent.com/document/api/1729/101838#LogoParam)
* [LogoRect](https://cloud.tencent.com/document/api/1729/101838#LogoRect)

### 第 13 次发布

发布时间：2024-07-23 01:37:38

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [SearchResult](https://cloud.tencent.com/document/api/1729/101838#SearchResult)

	* <font color="#dd0000">**修改成员**：</font>Index


### 第 12 次发布

发布时间：2024-07-22 01:43:41

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [ChatCompletions](https://cloud.tencent.com/document/api/1729/105701)

	* 新增入参：SearchInfo

	* 新增出参：SearchInfo


新增数据结构：

* [SearchInfo](https://cloud.tencent.com/document/api/1729/101838#SearchInfo)
* [SearchResult](https://cloud.tencent.com/document/api/1729/101838#SearchResult)

### 第 11 次发布

发布时间：2024-07-17 01:17:08

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [ChatCompletions](https://cloud.tencent.com/document/api/1729/105701)

	* 新增出参：ModerationLevel


### 第 10 次发布

发布时间：2024-07-16 01:17:20

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [TextToImageLite](https://cloud.tencent.com/document/api/1729/108738)

### 第 9 次发布

发布时间：2024-07-05 01:11:07

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [ChatCompletions](https://cloud.tencent.com/document/api/1729/105701)

	* 新增入参：Tools, ToolChoice, CustomTool


新增数据结构：

* [Content](https://cloud.tencent.com/document/api/1729/101838#Content)
* [ImageUrl](https://cloud.tencent.com/document/api/1729/101838#ImageUrl)
* [Tool](https://cloud.tencent.com/document/api/1729/101838#Tool)
* [ToolCall](https://cloud.tencent.com/document/api/1729/101838#ToolCall)
* [ToolCallFunction](https://cloud.tencent.com/document/api/1729/101838#ToolCallFunction)
* [ToolFunction](https://cloud.tencent.com/document/api/1729/101838#ToolFunction)

修改数据结构：

* [Delta](https://cloud.tencent.com/document/api/1729/101838#Delta)

	* 新增成员：ToolCalls

* [Message](https://cloud.tencent.com/document/api/1729/101838#Message)

	* 新增成员：Contents, ToolCallId, ToolCalls


### 第 8 次发布

发布时间：2024-06-12 11:48:37

本次发布包含了以下内容：

改善已有的文档。

<font color="#dd0000">**删除接口**：</font>

* ChatPro
* ChatStd

### 第 7 次发布

发布时间：2024-05-20 01:43:12

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [ChatCompletions](https://cloud.tencent.com/document/api/1729/105701)

	* 新增入参：EnableEnhancement


### 第 6 次发布

发布时间：2024-05-10 10:17:15

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [QueryHunyuanImageJob](https://cloud.tencent.com/document/api/1729/105970)
* [SubmitHunyuanImageJob](https://cloud.tencent.com/document/api/1729/105969)

### 第 5 次发布

发布时间：2024-05-08 01:18:38

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [Message](https://cloud.tencent.com/document/api/1729/101838#Message)

	* <font color="#dd0000">**修改成员**：</font>Content


### 第 4 次发布

发布时间：2024-04-25 21:22:22

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [ChatCompletions](https://cloud.tencent.com/document/api/1729/105701)

### 第 3 次发布

发布时间：2024-04-11 20:37:23

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [ChatPro](https://cloud.tencent.com/document/api/#/#)

	* 新增入参：Stream, StreamModeration

* [ChatStd](https://cloud.tencent.com/document/api/#/#)

	* 新增入参：Stream, StreamModeration


修改数据结构：

* [Choice](https://cloud.tencent.com/document/api/1729/101838#Choice)

	* 新增成员：Message


### 第 2 次发布

发布时间：2024-01-05 01:17:08

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [GetEmbedding](https://cloud.tencent.com/document/api/1729/102832)

新增数据结构：

* [EmbeddingData](https://cloud.tencent.com/document/api/1729/101838#EmbeddingData)
* [EmbeddingUsage](https://cloud.tencent.com/document/api/1729/101838#EmbeddingUsage)

### 第 1 次发布

发布时间：2023-11-23 11:01:12

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [ChatPro](https://cloud.tencent.com/document/api/#/#)
* [ChatStd](https://cloud.tencent.com/document/api/#/#)
* [GetTokenCount](https://cloud.tencent.com/document/api/1729/101835)

新增数据结构：

* [Choice](https://cloud.tencent.com/document/api/1729/101838#Choice)
* [Delta](https://cloud.tencent.com/document/api/1729/101838#Delta)
* [ErrorMsg](https://cloud.tencent.com/document/api/1729/101838#ErrorMsg)
* [Message](https://cloud.tencent.com/document/api/1729/101838#Message)
* [Usage](https://cloud.tencent.com/document/api/1729/101838#Usage)




## 人脸识别(iai) 版本：2018-03-01

### 第 20 次发布

发布时间：2022-04-22 18:43:48

本次发布包含了以下内容：

改善已有的文档。

<font color="#dd0000">**删除接口**：</font>

* CheckSimilarPerson
* EstimateCheckSimilarPersonCostTime
* GetCheckSimilarPersonJobIdList
* GetSimilarPersonResult

<font color="#dd0000">**删除数据结构**：</font>

* JobIdInfo

### 第 19 次发布

发布时间：2020-11-05 08:04:14

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [VerifyPerson](https://cloud.tencent.com/document/api/867/38879)

	* 新增出参：Score, IsMatch, FaceModelVersion


### 第 18 次发布

发布时间：2020-11-02 08:04:13

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [VerifyPerson](https://cloud.tencent.com/document/api/867/38879)

	* <font color="#dd0000">**修改入参**：</font>PersonId

	* <font color="#dd0000">**删除出参**：</font>Score, IsMatch, FaceModelVersion


### 第 17 次发布

发布时间：2020-08-13 08:12:05

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [AnalyzeDenseLandmarks](https://cloud.tencent.com/document/api/867/71634)
* [DetectFaceAttributes](https://cloud.tencent.com/document/api/867/71629)

新增数据结构：

* [AttributeItem](https://cloud.tencent.com/document/api/867/32807#AttributeItem)
* [DenseFaceShape](https://cloud.tencent.com/document/api/867/32807#DenseFaceShape)
* [Eye](https://cloud.tencent.com/document/api/867/32807#Eye)
* [Eyebrow](https://cloud.tencent.com/document/api/867/32807#Eyebrow)
* [FaceDetailAttributesInfo](https://cloud.tencent.com/document/api/867/32807#FaceDetailAttributesInfo)
* [FaceDetailInfo](https://cloud.tencent.com/document/api/867/32807#FaceDetailInfo)
* [Hair](https://cloud.tencent.com/document/api/867/32807#Hair)
* [Hat](https://cloud.tencent.com/document/api/867/32807#Hat)
* [HeadPose](https://cloud.tencent.com/document/api/867/32807#HeadPose)
* [Mouth](https://cloud.tencent.com/document/api/867/32807#Mouth)

### 第 16 次发布

发布时间：2020-08-06 08:11:55

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [GetUpgradeGroupFaceModelVersionJobList](https://cloud.tencent.com/document/api/867/71633)
* [GetUpgradeGroupFaceModelVersionResult](https://cloud.tencent.com/document/api/867/71632)
* [RevertGroupFaceModelVersion](https://cloud.tencent.com/document/api/867/71631)
* [UpgradeGroupFaceModelVersion](https://cloud.tencent.com/document/api/867/71630)

新增数据结构：

* [UpgradeJobInfo](https://cloud.tencent.com/document/api/867/32807#UpgradeJobInfo)

### 第 15 次发布

发布时间：2020-04-21 08:10:37

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [AnalyzeFace](https://cloud.tencent.com/document/api/867/32779)

	* 新增入参：NeedRotateDetection

* [CompareFace](https://cloud.tencent.com/document/api/867/32802)

	* 新增入参：NeedRotateDetection

* [CreateFace](https://cloud.tencent.com/document/api/867/32795)

	* 新增入参：NeedRotateDetection

* [CreatePerson](https://cloud.tencent.com/document/api/867/32793)

	* 新增入参：NeedRotateDetection

* [DetectFace](https://cloud.tencent.com/document/api/867/32800)

	* 新增入参：NeedRotateDetection

* [SearchFaces](https://cloud.tencent.com/document/api/867/32798)

	* 新增入参：NeedRotateDetection

* [SearchFacesReturnsByGroup](https://cloud.tencent.com/document/api/867/38882)

	* 新增入参：NeedRotateDetection

* [SearchPersons](https://cloud.tencent.com/document/api/867/38881)

	* 新增入参：NeedRotateDetection

* [SearchPersonsReturnsByGroup](https://cloud.tencent.com/document/api/867/38880)

	* 新增入参：NeedRotateDetection

* [VerifyFace](https://cloud.tencent.com/document/api/867/32806)

	* 新增入参：NeedRotateDetection

* [VerifyPerson](https://cloud.tencent.com/document/api/867/38879)

	* 新增入参：NeedRotateDetection


### 第 14 次发布

发布时间：2020-01-09 17:29:23

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [GetCheckSimilarPersonJobIdList](https://cloud.tencent.com/document/api/867/40962)
* [GetGroupInfo](https://cloud.tencent.com/document/api/867/40963)

新增数据结构：

* [JobIdInfo](https://cloud.tencent.com/document/api/867/32807#JobIdInfo)

### 第 13 次发布

发布时间：2019-12-05 17:47:15

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CheckSimilarPerson](https://cloud.tencent.com/document/api/867/40083)
* [EstimateCheckSimilarPersonCostTime](https://cloud.tencent.com/document/api/867/40082)
* [GetSimilarPersonResult](https://cloud.tencent.com/document/api/867/40081)

修改接口：

* [SearchPersons](https://cloud.tencent.com/document/api/867/38881)

	* 新增入参：NeedPersonInfo

* [SearchPersonsReturnsByGroup](https://cloud.tencent.com/document/api/867/38880)

	* 新增入参：NeedPersonInfo


### 第 12 次发布

发布时间：2019-11-14 18:07:33

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DetectLiveFace](https://cloud.tencent.com/document/api/867/32804)

	* 新增入参：FaceModelVersion

	* 新增出参：FaceModelVersion, IsLiveness


### 第 11 次发布

发布时间：2019-11-01 10:51:30

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [SearchFacesReturnsByGroup](https://cloud.tencent.com/document/api/867/38882)
* [SearchPersons](https://cloud.tencent.com/document/api/867/38881)
* [SearchPersonsReturnsByGroup](https://cloud.tencent.com/document/api/867/38880)
* [VerifyPerson](https://cloud.tencent.com/document/api/867/38879)

修改接口：

* [CompareFace](https://cloud.tencent.com/document/api/867/32802)

	* 新增入参：QualityControl

* [CreateFace](https://cloud.tencent.com/document/api/867/32795)

	* 新增入参：FaceMatchThreshold, QualityControl

	* 新增出参：SucIndexes, SucFaceRects, FaceModelVersion

* [CreateGroup](https://cloud.tencent.com/document/api/867/32794)

	* 新增入参：FaceModelVersion

	* 新增出参：FaceModelVersion

* [CreatePerson](https://cloud.tencent.com/document/api/867/32793)

	* 新增入参：UniquePersonControl, QualityControl

	* 新增出参：FaceRect, SimilarPersonId, FaceModelVersion

* [GetPersonGroupInfo](https://cloud.tencent.com/document/api/867/32786)

	* 新增出参：FaceModelVersion

* [GetPersonList](https://cloud.tencent.com/document/api/867/32785)

	* 新增出参：FaceModelVersion

* [SearchFaces](https://cloud.tencent.com/document/api/867/32798)

	* 新增入参：QualityControl, FaceMatchThreshold

	* 新增出参：FaceModelVersion

* [VerifyFace](https://cloud.tencent.com/document/api/867/32806)

	* 新增入参：QualityControl

	* 新增出参：FaceModelVersion


新增数据结构：

* [GroupCandidate](https://cloud.tencent.com/document/api/867/32807#GroupCandidate)
* [ResultsReturnsByGroup](https://cloud.tencent.com/document/api/867/32807#ResultsReturnsByGroup)

修改数据结构：

* [PersonInfo](https://cloud.tencent.com/document/api/867/32807#PersonInfo)

	* 新增成员：CreationTimestamp

* [Result](https://cloud.tencent.com/document/api/867/32807#Result)

	* 新增成员：RetCode


### 第 10 次发布

发布时间：2019-10-11 14:13:28

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [GroupInfo](https://cloud.tencent.com/document/api/867/32807#GroupInfo)

	* <font color="#dd0000">**修改成员**：</font>CreationTimestamp


### 第 9 次发布

发布时间：2019-09-19 19:46:00

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CompareFace](https://cloud.tencent.com/document/api/867/32802)

	* 新增入参：FaceModelVersion

	* 新增出参：FaceModelVersion


### 第 8 次发布

发布时间：2019-08-22 19:37:04

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [AnalyzeFace](https://cloud.tencent.com/document/api/867/32779)

	* 新增出参：FaceModelVersion

* [DetectFace](https://cloud.tencent.com/document/api/867/32800)

	* 新增入参：FaceModelVersion

	* 新增出参：FaceModelVersion


### 第 7 次发布

发布时间：2019-08-01 17:27:49

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [AnalyzeFace](https://cloud.tencent.com/document/api/867/32779)

	* 新增入参：FaceModelVersion

* [SearchFaces](https://cloud.tencent.com/document/api/867/32798)

	* 新增入参：NeedPersonInfo


修改数据结构：

* [Candidate](https://cloud.tencent.com/document/api/867/32807#Candidate)

	* 新增成员：PersonName, Gender, PersonGroupInfos


### 第 6 次发布

发布时间：2019-07-04 16:08:02

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [GroupInfo](https://cloud.tencent.com/document/api/867/32807#GroupInfo)

	* 新增成员：FaceModelVersion, CreationTimestamp


### 第 5 次发布

发布时间：2019-06-27 17:24:44

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [GroupInfo](https://cloud.tencent.com/document/api/867/32807#GroupInfo)

	* <font color="#dd0000">**删除成员**：</font>FaceModelVersion, CreationTimestamp


### 第 4 次发布

发布时间：2019-06-06 20:17:29

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [GroupInfo](https://cloud.tencent.com/document/api/867/32807#GroupInfo)

	* 新增成员：FaceModelVersion, CreationTimestamp


### 第 3 次发布

发布时间：2019-04-12 10:44:26

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [FaceAttributesInfo](https://cloud.tencent.com/document/api/867/32807#FaceAttributesInfo)

	* 新增成员：EyeOpen


### 第 2 次发布

发布时间：2019-02-22 11:28:36

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [FaceRect](https://cloud.tencent.com/document/api/867/32807#FaceRect)

	* <font color="#dd0000">**修改成员**：</font>X, Y


### 第 1 次发布

发布时间：2019-01-23 16:53:11

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [AnalyzeFace](https://cloud.tencent.com/document/api/867/32779)
* [CompareFace](https://cloud.tencent.com/document/api/867/32802)
* [CopyPerson](https://cloud.tencent.com/document/api/867/32796)
* [CreateFace](https://cloud.tencent.com/document/api/867/32795)
* [CreateGroup](https://cloud.tencent.com/document/api/867/32794)
* [CreatePerson](https://cloud.tencent.com/document/api/867/32793)
* [DeleteFace](https://cloud.tencent.com/document/api/867/32792)
* [DeleteGroup](https://cloud.tencent.com/document/api/867/32791)
* [DeletePerson](https://cloud.tencent.com/document/api/867/32790)
* [DeletePersonFromGroup](https://cloud.tencent.com/document/api/867/32789)
* [DetectFace](https://cloud.tencent.com/document/api/867/32800)
* [DetectLiveFace](https://cloud.tencent.com/document/api/867/32804)
* [GetGroupList](https://cloud.tencent.com/document/api/867/32788)
* [GetPersonBaseInfo](https://cloud.tencent.com/document/api/867/32787)
* [GetPersonGroupInfo](https://cloud.tencent.com/document/api/867/32786)
* [GetPersonList](https://cloud.tencent.com/document/api/867/32785)
* [GetPersonListNum](https://cloud.tencent.com/document/api/867/32784)
* [ModifyGroup](https://cloud.tencent.com/document/api/867/32783)
* [ModifyPersonBaseInfo](https://cloud.tencent.com/document/api/867/32782)
* [ModifyPersonGroupInfo](https://cloud.tencent.com/document/api/867/32781)
* [SearchFaces](https://cloud.tencent.com/document/api/867/32798)
* [VerifyFace](https://cloud.tencent.com/document/api/867/32806)

新增数据结构：

* [Candidate](https://cloud.tencent.com/document/api/867/32807#Candidate)
* [FaceAttributesInfo](https://cloud.tencent.com/document/api/867/32807#FaceAttributesInfo)
* [FaceHairAttributesInfo](https://cloud.tencent.com/document/api/867/32807#FaceHairAttributesInfo)
* [FaceInfo](https://cloud.tencent.com/document/api/867/32807#FaceInfo)
* [FaceQualityCompleteness](https://cloud.tencent.com/document/api/867/32807#FaceQualityCompleteness)
* [FaceQualityInfo](https://cloud.tencent.com/document/api/867/32807#FaceQualityInfo)
* [FaceRect](https://cloud.tencent.com/document/api/867/32807#FaceRect)
* [FaceShape](https://cloud.tencent.com/document/api/867/32807#FaceShape)
* [GroupExDescriptionInfo](https://cloud.tencent.com/document/api/867/32807#GroupExDescriptionInfo)
* [GroupInfo](https://cloud.tencent.com/document/api/867/32807#GroupInfo)
* [PersonExDescriptionInfo](https://cloud.tencent.com/document/api/867/32807#PersonExDescriptionInfo)
* [PersonGroupInfo](https://cloud.tencent.com/document/api/867/32807#PersonGroupInfo)
* [PersonInfo](https://cloud.tencent.com/document/api/867/32807#PersonInfo)
* [Point](https://cloud.tencent.com/document/api/867/32807#Point)
* [Result](https://cloud.tencent.com/document/api/867/32807#Result)



## 人脸识别(iai) 版本：2020-03-03

### 第 9 次发布

发布时间：2022-04-25 06:07:47

本次发布包含了以下内容：

改善已有的文档。

<font color="#dd0000">**删除接口**：</font>

* CheckSimilarPerson
* EstimateCheckSimilarPersonCostTime
* GetCheckSimilarPersonJobIdList
* GetSimilarPersonResult

<font color="#dd0000">**删除数据结构**：</font>

* JobIdInfo

### 第 8 次发布

发布时间：2020-11-30 08:19:25

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CompareMaskFace](https://cloud.tencent.com/document/api/867/50425)

### 第 7 次发布

发布时间：2020-11-05 08:04:14

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [VerifyPerson](https://cloud.tencent.com/document/api/867/44982)

	* 新增出参：Score, IsMatch, FaceModelVersion


### 第 6 次发布

发布时间：2020-11-02 08:04:13

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [VerifyPerson](https://cloud.tencent.com/document/api/867/44982)

	* <font color="#dd0000">**修改入参**：</font>PersonId

	* <font color="#dd0000">**删除出参**：</font>Score, IsMatch, FaceModelVersion


### 第 5 次发布

发布时间：2020-09-18 08:03:48

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DetectLiveFaceAccurate](https://cloud.tencent.com/document/api/867/48501)

### 第 4 次发布

发布时间：2020-08-13 08:12:05

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [AnalyzeDenseLandmarks](https://cloud.tencent.com/document/api/867/47397)
* [DetectFaceAttributes](https://cloud.tencent.com/document/api/867/47396)

新增数据结构：

* [AttributeItem](https://cloud.tencent.com/document/api/867/45020#AttributeItem)
* [DenseFaceShape](https://cloud.tencent.com/document/api/867/45020#DenseFaceShape)
* [Eye](https://cloud.tencent.com/document/api/867/45020#Eye)
* [Eyebrow](https://cloud.tencent.com/document/api/867/45020#Eyebrow)
* [FaceDetailAttributesInfo](https://cloud.tencent.com/document/api/867/45020#FaceDetailAttributesInfo)
* [FaceDetailInfo](https://cloud.tencent.com/document/api/867/45020#FaceDetailInfo)
* [Hair](https://cloud.tencent.com/document/api/867/45020#Hair)
* [Hat](https://cloud.tencent.com/document/api/867/45020#Hat)
* [HeadPose](https://cloud.tencent.com/document/api/867/45020#HeadPose)
* [Mouth](https://cloud.tencent.com/document/api/867/45020#Mouth)

### 第 3 次发布

发布时间：2020-08-06 08:11:55

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [RevertGroupFaceModelVersion](https://cloud.tencent.com/document/api/867/47164)

### 第 2 次发布

发布时间：2020-08-05 08:12:13

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [GetUpgradeGroupFaceModelVersionJobList](https://cloud.tencent.com/document/api/867/47146)
* [GetUpgradeGroupFaceModelVersionResult](https://cloud.tencent.com/document/api/867/47145)
* [UpgradeGroupFaceModelVersion](https://cloud.tencent.com/document/api/867/47144)

新增数据结构：

* [UpgradeJobInfo](https://cloud.tencent.com/document/api/867/45020#UpgradeJobInfo)

### 第 1 次发布

发布时间：2020-05-29 14:24:56

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [AnalyzeFace](https://cloud.tencent.com/document/api/867/45019)
* [CheckSimilarPerson](https://cloud.tencent.com/document/api/867/44999)
* [CompareFace](https://cloud.tencent.com/document/api/867/44987)
* [CopyPerson](https://cloud.tencent.com/document/api/867/45017)
* [CreateFace](https://cloud.tencent.com/document/api/867/45016)
* [CreateGroup](https://cloud.tencent.com/document/api/867/45015)
* [CreatePerson](https://cloud.tencent.com/document/api/867/45014)
* [DeleteFace](https://cloud.tencent.com/document/api/867/45013)
* [DeleteGroup](https://cloud.tencent.com/document/api/867/45012)
* [DeletePerson](https://cloud.tencent.com/document/api/867/45011)
* [DeletePersonFromGroup](https://cloud.tencent.com/document/api/867/45010)
* [DetectFace](https://cloud.tencent.com/document/api/867/44989)
* [DetectLiveFace](https://cloud.tencent.com/document/api/867/44985)
* [EstimateCheckSimilarPersonCostTime](https://cloud.tencent.com/document/api/867/44998)
* [GetCheckSimilarPersonJobIdList](https://cloud.tencent.com/document/api/867/44997)
* [GetGroupInfo](https://cloud.tencent.com/document/api/867/45009)
* [GetGroupList](https://cloud.tencent.com/document/api/867/45008)
* [GetPersonBaseInfo](https://cloud.tencent.com/document/api/867/45007)
* [GetPersonGroupInfo](https://cloud.tencent.com/document/api/867/45006)
* [GetPersonList](https://cloud.tencent.com/document/api/867/45005)
* [GetPersonListNum](https://cloud.tencent.com/document/api/867/45004)
* [GetSimilarPersonResult](https://cloud.tencent.com/document/api/867/44996)
* [ModifyGroup](https://cloud.tencent.com/document/api/867/45003)
* [ModifyPersonBaseInfo](https://cloud.tencent.com/document/api/867/45002)
* [ModifyPersonGroupInfo](https://cloud.tencent.com/document/api/867/45001)
* [SearchFaces](https://cloud.tencent.com/document/api/867/44994)
* [SearchFacesReturnsByGroup](https://cloud.tencent.com/document/api/867/44993)
* [SearchPersons](https://cloud.tencent.com/document/api/867/44992)
* [SearchPersonsReturnsByGroup](https://cloud.tencent.com/document/api/867/44991)
* [VerifyFace](https://cloud.tencent.com/document/api/867/44983)
* [VerifyPerson](https://cloud.tencent.com/document/api/867/44982)

新增数据结构：

* [Candidate](https://cloud.tencent.com/document/api/867/45020#Candidate)
* [FaceAttributesInfo](https://cloud.tencent.com/document/api/867/45020#FaceAttributesInfo)
* [FaceHairAttributesInfo](https://cloud.tencent.com/document/api/867/45020#FaceHairAttributesInfo)
* [FaceInfo](https://cloud.tencent.com/document/api/867/45020#FaceInfo)
* [FaceQualityCompleteness](https://cloud.tencent.com/document/api/867/45020#FaceQualityCompleteness)
* [FaceQualityInfo](https://cloud.tencent.com/document/api/867/45020#FaceQualityInfo)
* [FaceRect](https://cloud.tencent.com/document/api/867/45020#FaceRect)
* [FaceShape](https://cloud.tencent.com/document/api/867/45020#FaceShape)
* [GroupCandidate](https://cloud.tencent.com/document/api/867/45020#GroupCandidate)
* [GroupExDescriptionInfo](https://cloud.tencent.com/document/api/867/45020#GroupExDescriptionInfo)
* [GroupInfo](https://cloud.tencent.com/document/api/867/45020#GroupInfo)
* [JobIdInfo](https://cloud.tencent.com/document/api/867/45020#JobIdInfo)
* [PersonExDescriptionInfo](https://cloud.tencent.com/document/api/867/45020#PersonExDescriptionInfo)
* [PersonGroupInfo](https://cloud.tencent.com/document/api/867/45020#PersonGroupInfo)
* [PersonInfo](https://cloud.tencent.com/document/api/867/45020#PersonInfo)
* [Point](https://cloud.tencent.com/document/api/867/45020#Point)
* [Result](https://cloud.tencent.com/document/api/867/45020#Result)
* [ResultsReturnsByGroup](https://cloud.tencent.com/document/api/867/45020#ResultsReturnsByGroup)




## 图片瘦身(ic) 版本：2019-03-07

### 第 7 次发布

发布时间：2022-08-30 06:33:17

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [PayForExtendData](https://cloud.tencent.com/document/api/636/79719)

新增数据结构：

* [ResOrderIds](https://cloud.tencent.com/document/api/636/33881#ResOrderIds)

### 第 6 次发布

发布时间：2022-08-05 06:23:27

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeSms](https://cloud.tencent.com/document/api/636/78654)

新增数据结构：

* [ResSms](https://cloud.tencent.com/document/api/636/33881#ResSms)

### 第 5 次发布

发布时间：2021-08-09 08:00:38

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [CardInfo](https://cloud.tencent.com/document/api/636/33881#CardInfo)

	* 新增成员：OtherData


### 第 4 次发布

发布时间：2021-05-11 20:09:52

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [ModifyUserCardRemark](https://cloud.tencent.com/document/api/636/55674)

### 第 3 次发布

发布时间：2020-07-02 08:11:27

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [RenewCards](https://cloud.tencent.com/document/api/636/45922)

新增数据结构：

* [ResRenew](https://cloud.tencent.com/document/api/636/33881#ResRenew)

### 第 2 次发布

发布时间：2020-05-21 08:10:52

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [CardInfo](https://cloud.tencent.com/document/api/636/33881#CardInfo)

	* 新增成员：CertificationState


### 第 1 次发布

发布时间：2019-03-21 20:18:02

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeApp](https://cloud.tencent.com/document/api/636/33875)
* [DescribeCard](https://cloud.tencent.com/document/api/636/33878)
* [DescribeCards](https://cloud.tencent.com/document/api/636/33877)
* [SendMultiSms](https://cloud.tencent.com/document/api/636/33873)
* [SendSms](https://cloud.tencent.com/document/api/636/33880)

新增数据结构：

* [AppInfo](https://cloud.tencent.com/document/api/636/33881#AppInfo)
* [CardInfo](https://cloud.tencent.com/document/api/636/33881#CardInfo)
* [CardList](https://cloud.tencent.com/document/api/636/33881#CardList)
* [SmsRet](https://cloud.tencent.com/document/api/636/33881#SmsRet)
* [SmsSid](https://cloud.tencent.com/document/api/636/33881#SmsSid)




## 对话机器人(icr) 版本：2021-10-14

### 第 1 次发布

发布时间：2022-04-11 21:23:35

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [GetIndustryV1HomeMembers](https://cloud.tencent.com/document/api/1268/72392)

新增数据结构：

* [GetIndustryV1HomeMembersReqPayload](https://cloud.tencent.com/document/api/1268/72393#GetIndustryV1HomeMembersReqPayload)
* [GetIndustryV1HomeMembersRespData](https://cloud.tencent.com/document/api/1268/72393#GetIndustryV1HomeMembersRespData)
* [GetIndustryV1HomeMembersRespFeature](https://cloud.tencent.com/document/api/1268/72393#GetIndustryV1HomeMembersRespFeature)
* [GetIndustryV1HomeMembersRespIndustry](https://cloud.tencent.com/document/api/1268/72393#GetIndustryV1HomeMembersRespIndustry)
* [GetIndustryV1HomeMembersRespPayload](https://cloud.tencent.com/document/api/1268/72393#GetIndustryV1HomeMembersRespPayload)
* [GetIndustryV1HomeMembersRespProduct](https://cloud.tencent.com/document/api/1268/72393#GetIndustryV1HomeMembersRespProduct)
* [GetIndustryV1HomeMembersRespType](https://cloud.tencent.com/document/api/1268/72393#GetIndustryV1HomeMembersRespType)
* [ReqMetadata](https://cloud.tencent.com/document/api/1268/72393#ReqMetadata)
* [ReqMetadataLBS](https://cloud.tencent.com/document/api/1268/72393#ReqMetadataLBS)
* [ReqMetadataVagrant](https://cloud.tencent.com/document/api/1268/72393#ReqMetadataVagrant)
* [RspMetadata](https://cloud.tencent.com/document/api/1268/72393#RspMetadata)




## 智能编辑(ie) 版本：2020-03-04

### 第 13 次发布

发布时间：2022-10-25 06:37:05

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateMediaQualityRestorationTask](https://cloud.tencent.com/document/api/1186/48451)

	* 新增入参：TopSpeedCodecChannel


### 第 12 次发布

发布时间：2022-07-05 06:14:24

本次发布包含了以下内容：

改善已有的文档。

新增数据结构：

* [DynamicImageInfo](https://cloud.tencent.com/document/api/1186/42824#DynamicImageInfo)
* [MediaCuttingWatermark](https://cloud.tencent.com/document/api/1186/42824#MediaCuttingWatermark)
* [MediaCuttingWatermarkImage](https://cloud.tencent.com/document/api/1186/42824#MediaCuttingWatermarkImage)
* [MediaCuttingWatermarkText](https://cloud.tencent.com/document/api/1186/42824#MediaCuttingWatermarkText)
* [SpriteImageInfo](https://cloud.tencent.com/document/api/1186/42824#SpriteImageInfo)

修改数据结构：

* [MediaCuttingInfo](https://cloud.tencent.com/document/api/1186/42824#MediaCuttingInfo)

	* 新增成员：WatermarkInfoSet, DropPureColor

* [MediaCuttingOutForm](https://cloud.tencent.com/document/api/1186/42824#MediaCuttingOutForm)

	* 新增成员：SpriteInfo, DynamicInfo

* [MediaCuttingTaskResult](https://cloud.tencent.com/document/api/1186/42824#MediaCuttingTaskResult)

	* 新增成员：ImageCount

* [MediaJoiningInfo](https://cloud.tencent.com/document/api/1186/42824#MediaJoiningInfo)

	* 新增成员：Mode

* [SaveInfo](https://cloud.tencent.com/document/api/1186/42824#SaveInfo)

	* 新增成员：Id

* [TaskResultFile](https://cloud.tencent.com/document/api/1186/42824#TaskResultFile)

	* 新增成员：Md5


### 第 11 次发布

发布时间：2021-07-23 08:01:48

本次发布包含了以下内容：

改善已有的文档。

新增数据结构：

* [TextMarkInfoItem](https://cloud.tencent.com/document/api/1186/42824#TextMarkInfoItem)

修改数据结构：

* [VideoInfo](https://cloud.tencent.com/document/api/1186/42824#VideoInfo)

	* 新增成员：TextMarkInfo


### 第 10 次发布

发布时间：2021-06-09 08:01:32

本次发布包含了以下内容：

改善已有的文档。

新增数据结构：

* [VideoRepair](https://cloud.tencent.com/document/api/1186/42824#VideoRepair)
* [VideoSuperResolution](https://cloud.tencent.com/document/api/1186/42824#VideoSuperResolution)

修改数据结构：

* [VideoEnhance](https://cloud.tencent.com/document/api/1186/42824#VideoEnhance)

	* 新增成员：VideoSuperResolution, VideoRepair


### 第 9 次发布

发布时间：2021-05-13 08:01:13

本次发布包含了以下内容：

改善已有的文档。

新增数据结构：

* [AudioEnhance](https://cloud.tencent.com/document/api/1186/42824#AudioEnhance)
* [LoudnessInfo](https://cloud.tencent.com/document/api/1186/42824#LoudnessInfo)
* [RemoveReverb](https://cloud.tencent.com/document/api/1186/42824#RemoveReverb)

修改数据结构：

* [AudioInfo](https://cloud.tencent.com/document/api/1186/42824#AudioInfo)

	* 新增成员：LoudnessInfo, AudioEnhance, RemoveReverb


### 第 8 次发布

发布时间：2021-04-12 08:01:01

本次发布包含了以下内容：

改善已有的文档。

新增数据结构：

* [MediaResultInfo](https://cloud.tencent.com/document/api/1186/42824#MediaResultInfo)
* [ResultAudioInfo](https://cloud.tencent.com/document/api/1186/42824#ResultAudioInfo)
* [ResultVideoInfo](https://cloud.tencent.com/document/api/1186/42824#ResultVideoInfo)

修改数据结构：

* [TaskResultFile](https://cloud.tencent.com/document/api/1186/42824#TaskResultFile)

	* 新增成员：FileSize, MediaInfo


### 第 7 次发布

发布时间：2021-04-01 08:00:55

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [AudioInfo](https://cloud.tencent.com/document/api/1186/42824#AudioInfo)

	* 新增成员：EnableMuteAudio

* [MuxInfo](https://cloud.tencent.com/document/api/1186/42824#MuxInfo)

	* 新增成员：FlvFlags


### 第 6 次发布

发布时间：2021-03-01 08:00:57

本次发布包含了以下内容：

改善已有的文档。

新增数据结构：

* [HiddenMarkInfo](https://cloud.tencent.com/document/api/1186/42824#HiddenMarkInfo)

修改数据结构：

* [VideoInfo](https://cloud.tencent.com/document/api/1186/42824#VideoInfo)

	* 新增成员：HiddenMarkInfo


### 第 5 次发布

发布时间：2021-01-07 08:00:44

本次发布包含了以下内容：

改善已有的文档。

新增数据结构：

* [FrameTagItem](https://cloud.tencent.com/document/api/1186/42824#FrameTagItem)
* [FrameTagRec](https://cloud.tencent.com/document/api/1186/42824#FrameTagRec)
* [FrameTagResult](https://cloud.tencent.com/document/api/1186/42824#FrameTagResult)
* [MediaRecognitionInfo](https://cloud.tencent.com/document/api/1186/42824#MediaRecognitionInfo)
* [MediaRecognitionTaskResult](https://cloud.tencent.com/document/api/1186/42824#MediaRecognitionTaskResult)
* [SubtitleItem](https://cloud.tencent.com/document/api/1186/42824#SubtitleItem)
* [SubtitleRec](https://cloud.tencent.com/document/api/1186/42824#SubtitleRec)
* [SubtitleResult](https://cloud.tencent.com/document/api/1186/42824#SubtitleResult)
* [TagItem](https://cloud.tencent.com/document/api/1186/42824#TagItem)

修改数据结构：

* [MediaProcessInfo](https://cloud.tencent.com/document/api/1186/42824#MediaProcessInfo)

	* 新增成员：MediaRecognitionInfo

* [MediaProcessTaskResult](https://cloud.tencent.com/document/api/1186/42824#MediaProcessTaskResult)

	* 新增成员：MediaRecognitionTaskResult


### 第 4 次发布

发布时间：2020-12-24 08:00:54

本次发布包含了以下内容：

改善已有的文档。

新增数据结构：

* [Denoise](https://cloud.tencent.com/document/api/1186/42824#Denoise)

修改数据结构：

* [AudioInfo](https://cloud.tencent.com/document/api/1186/42824#AudioInfo)

	* 新增成员：Denoise


### 第 3 次发布

发布时间：2020-12-21 08:01:10

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateMediaProcessTask](https://cloud.tencent.com/document/api/1186/51243)
* [DescribeMediaProcessTaskResult](https://cloud.tencent.com/document/api/1186/51242)
* [StopMediaProcessTask](https://cloud.tencent.com/document/api/1186/51241)

新增数据结构：

* [IntervalTime](https://cloud.tencent.com/document/api/1186/42824#IntervalTime)
* [MediaCuttingInfo](https://cloud.tencent.com/document/api/1186/42824#MediaCuttingInfo)
* [MediaCuttingOutForm](https://cloud.tencent.com/document/api/1186/42824#MediaCuttingOutForm)
* [MediaCuttingTaskResult](https://cloud.tencent.com/document/api/1186/42824#MediaCuttingTaskResult)
* [MediaCuttingTimeInfo](https://cloud.tencent.com/document/api/1186/42824#MediaCuttingTimeInfo)
* [MediaJoiningInfo](https://cloud.tencent.com/document/api/1186/42824#MediaJoiningInfo)
* [MediaJoiningTaskResult](https://cloud.tencent.com/document/api/1186/42824#MediaJoiningTaskResult)
* [MediaProcessInfo](https://cloud.tencent.com/document/api/1186/42824#MediaProcessInfo)
* [MediaProcessTaskResult](https://cloud.tencent.com/document/api/1186/42824#MediaProcessTaskResult)
* [MediaSourceInfo](https://cloud.tencent.com/document/api/1186/42824#MediaSourceInfo)
* [MediaTargetInfo](https://cloud.tencent.com/document/api/1186/42824#MediaTargetInfo)
* [SectionTime](https://cloud.tencent.com/document/api/1186/42824#SectionTime)
* [TargetVideoInfo](https://cloud.tencent.com/document/api/1186/42824#TargetVideoInfo)
* [TaskResultFile](https://cloud.tencent.com/document/api/1186/42824#TaskResultFile)

### 第 2 次发布

发布时间：2020-09-17 08:00:24

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateMediaQualityRestorationTask](https://cloud.tencent.com/document/api/1186/48451)
* [CreateQualityControlTask](https://cloud.tencent.com/document/api/1186/48450)
* [DescribeMediaQualityRestorationTaskRusult](https://cloud.tencent.com/document/api/1186/48449)
* [DescribeQualityControlTaskResult](https://cloud.tencent.com/document/api/1186/48448)
* [StopMediaQualityRestorationTask](https://cloud.tencent.com/document/api/1186/48447)

新增数据结构：

* [ArtifactReduction](https://cloud.tencent.com/document/api/1186/42824#ArtifactReduction)
* [AudioInfo](https://cloud.tencent.com/document/api/1186/42824#AudioInfo)
* [AudioInfoResultItem](https://cloud.tencent.com/document/api/1186/42824#AudioInfoResultItem)
* [ColorEnhance](https://cloud.tencent.com/document/api/1186/42824#ColorEnhance)
* [DarInfo](https://cloud.tencent.com/document/api/1186/42824#DarInfo)
* [Denoising](https://cloud.tencent.com/document/api/1186/42824#Denoising)
* [EditInfo](https://cloud.tencent.com/document/api/1186/42824#EditInfo)
* [FaceProtect](https://cloud.tencent.com/document/api/1186/42824#FaceProtect)
* [FileInfo](https://cloud.tencent.com/document/api/1186/42824#FileInfo)
* [LowLightEnhance](https://cloud.tencent.com/document/api/1186/42824#LowLightEnhance)
* [MediaQualityRestorationTaskResult](https://cloud.tencent.com/document/api/1186/42824#MediaQualityRestorationTaskResult)
* [MuxInfo](https://cloud.tencent.com/document/api/1186/42824#MuxInfo)
* [PicMarkInfoItem](https://cloud.tencent.com/document/api/1186/42824#PicMarkInfoItem)
* [QualityControlInfo](https://cloud.tencent.com/document/api/1186/42824#QualityControlInfo)
* [QualityControlInfoTaskResult](https://cloud.tencent.com/document/api/1186/42824#QualityControlInfoTaskResult)
* [QualityControlItem](https://cloud.tencent.com/document/api/1186/42824#QualityControlItem)
* [QualityControlResultItems](https://cloud.tencent.com/document/api/1186/42824#QualityControlResultItems)
* [ScratchRepair](https://cloud.tencent.com/document/api/1186/42824#ScratchRepair)
* [SegmentInfo](https://cloud.tencent.com/document/api/1186/42824#SegmentInfo)
* [Sharp](https://cloud.tencent.com/document/api/1186/42824#Sharp)
* [SubTaskResultItem](https://cloud.tencent.com/document/api/1186/42824#SubTaskResultItem)
* [SubTaskTranscodeInfo](https://cloud.tencent.com/document/api/1186/42824#SubTaskTranscodeInfo)
* [TargetInfo](https://cloud.tencent.com/document/api/1186/42824#TargetInfo)
* [VideoEnhance](https://cloud.tencent.com/document/api/1186/42824#VideoEnhance)
* [VideoInfo](https://cloud.tencent.com/document/api/1186/42824#VideoInfo)
* [VideoInfoResultItem](https://cloud.tencent.com/document/api/1186/42824#VideoInfoResultItem)

### 第 1 次发布

发布时间：2020-03-23 16:46:34

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateEditingTask](https://cloud.tencent.com/document/api/1186/42823)
* [DescribeEditingTaskResult](https://cloud.tencent.com/document/api/1186/42822)

新增数据结构：

* [CallbackInfo](https://cloud.tencent.com/document/api/1186/42824#CallbackInfo)
* [ClassificationEditingInfo](https://cloud.tencent.com/document/api/1186/42824#ClassificationEditingInfo)
* [ClassificationTaskResult](https://cloud.tencent.com/document/api/1186/42824#ClassificationTaskResult)
* [ClassificationTaskResultItem](https://cloud.tencent.com/document/api/1186/42824#ClassificationTaskResultItem)
* [CosAuthMode](https://cloud.tencent.com/document/api/1186/42824#CosAuthMode)
* [CosInfo](https://cloud.tencent.com/document/api/1186/42824#CosInfo)
* [CoverEditingInfo](https://cloud.tencent.com/document/api/1186/42824#CoverEditingInfo)
* [CoverTaskResult](https://cloud.tencent.com/document/api/1186/42824#CoverTaskResult)
* [CoverTaskResultItem](https://cloud.tencent.com/document/api/1186/42824#CoverTaskResultItem)
* [DownInfo](https://cloud.tencent.com/document/api/1186/42824#DownInfo)
* [EditingInfo](https://cloud.tencent.com/document/api/1186/42824#EditingInfo)
* [EditingTaskResult](https://cloud.tencent.com/document/api/1186/42824#EditingTaskResult)
* [HighlightsEditingInfo](https://cloud.tencent.com/document/api/1186/42824#HighlightsEditingInfo)
* [HighlightsTaskResult](https://cloud.tencent.com/document/api/1186/42824#HighlightsTaskResult)
* [HighlightsTaskResultItem](https://cloud.tencent.com/document/api/1186/42824#HighlightsTaskResultItem)
* [HighlightsTaskResultItemSegment](https://cloud.tencent.com/document/api/1186/42824#HighlightsTaskResultItemSegment)
* [OpeningEndingEditingInfo](https://cloud.tencent.com/document/api/1186/42824#OpeningEndingEditingInfo)
* [OpeningEndingTaskResult](https://cloud.tencent.com/document/api/1186/42824#OpeningEndingTaskResult)
* [OpeningEndingTaskResultItem](https://cloud.tencent.com/document/api/1186/42824#OpeningEndingTaskResultItem)
* [SaveInfo](https://cloud.tencent.com/document/api/1186/42824#SaveInfo)
* [StripEditingInfo](https://cloud.tencent.com/document/api/1186/42824#StripEditingInfo)
* [StripTaskResult](https://cloud.tencent.com/document/api/1186/42824#StripTaskResult)
* [StripTaskResultItem](https://cloud.tencent.com/document/api/1186/42824#StripTaskResultItem)
* [TagEditingInfo](https://cloud.tencent.com/document/api/1186/42824#TagEditingInfo)
* [TagTaskResult](https://cloud.tencent.com/document/api/1186/42824#TagTaskResult)
* [TagTaskResultItem](https://cloud.tencent.com/document/api/1186/42824#TagTaskResultItem)
* [UrlInfo](https://cloud.tencent.com/document/api/1186/42824#UrlInfo)




## 物联网边缘计算平台(iecp) 版本：2021-09-14

### 第 8 次发布

发布时间：2024-06-20 01:46:44

本次发布包含了以下内容：

改善已有的文档。

<font color="#dd0000">**预下线接口**：</font>

* ApplyMarketComponent
* CreateApplicationVisualization
* CreateEdgeUnitApplicationVisualization
* CreateEdgeUnitApplicationYaml
* DeleteApplications
* DeleteEdgeUnitApplications
* DescribeApplicationVisualization
* DescribeApplicationYaml
* DescribeApplicationYamlError
* DescribeApplications
* DescribeEdgeUnitApplicationEvents
* DescribeEdgeUnitApplicationLogs
* DescribeEdgeUnitApplicationPodContainers
* DescribeEdgeUnitApplicationPods
* DescribeEdgeUnitApplicationVisualization
* DescribeEdgeUnitApplicationYaml
* DescribeEdgeUnitApplicationYamlError
* DescribeEdgeUnitCloud
* ModifyApplicationBasicInfo
* ModifyApplicationVisualization

### 第 7 次发布

发布时间：2022-04-08 06:08:23

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [BuildMessageRoute](https://cloud.tencent.com/document/api/1118/72274)
* [CreateEdgeUnitDevices](https://cloud.tencent.com/document/api/1118/72273)
* [CreateIotDevice](https://cloud.tencent.com/document/api/1118/72272)
* [CreateMessageRoute](https://cloud.tencent.com/document/api/1118/72271)
* [DeleteEdgeUnitDevices](https://cloud.tencent.com/document/api/1118/72270)
* [DeleteIotDevice](https://cloud.tencent.com/document/api/1118/72269)
* [DeleteMessageRoute](https://cloud.tencent.com/document/api/1118/72268)
* [DescribeIotDevice](https://cloud.tencent.com/document/api/1118/72267)
* [DescribeIotDevices](https://cloud.tencent.com/document/api/1118/72266)
* [DescribeMessageRouteList](https://cloud.tencent.com/document/api/1118/72265)
* [ModifyIotDevice](https://cloud.tencent.com/document/api/1118/72264)
* [SetRouteOnOff](https://cloud.tencent.com/document/api/1118/72263)

新增数据结构：

* [DeleteEdgeUnitDevicesDevice](https://cloud.tencent.com/document/api/1118/66797#DeleteEdgeUnitDevicesDevice)
* [IotDevicesInfo](https://cloud.tencent.com/document/api/1118/66797#IotDevicesInfo)
* [RouteInfo](https://cloud.tencent.com/document/api/1118/66797#RouteInfo)

### 第 6 次发布

发布时间：2022-03-23 08:07:34

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DeleteIotDeviceBatch](https://cloud.tencent.com/document/api/1118/71553)
* [DescribeDracoEdgeNodeInstaller](https://cloud.tencent.com/document/api/1118/71552)

### 第 5 次发布

发布时间：2022-03-17 08:08:16

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateEdgeNodeBatch](https://cloud.tencent.com/document/api/1118/71317)
* [CreateUserToken](https://cloud.tencent.com/document/api/1118/71319)
* [DescribeEdgeNodeRemarkList](https://cloud.tencent.com/document/api/1118/71316)
* [DescribeEdgeSnNodes](https://cloud.tencent.com/document/api/1118/71315)
* [DescribeYeheResourceLimit](https://cloud.tencent.com/document/api/1118/71314)
* [ModifyEdgeDracoNode](https://cloud.tencent.com/document/api/1118/71313)
* [ModifyEdgeUnitCloudApi](https://cloud.tencent.com/document/api/1118/71312)

新增数据结构：

* [DracoNodeInfo](https://cloud.tencent.com/document/api/1118/66797#DracoNodeInfo)
* [EdgeDracoNodeInfo](https://cloud.tencent.com/document/api/1118/66797#EdgeDracoNodeInfo)

### 第 4 次发布

发布时间：2022-03-15 08:10:42

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateEdgeUnitCloud](https://cloud.tencent.com/document/api/1118/66764)

	* 新增入参：OpenCloudMonitor


### 第 3 次发布

发布时间：2022-02-23 08:08:30

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateEdgeUnitApplicationYaml](https://cloud.tencent.com/document/api/1118/66785)

	* <font color="#dd0000">**修改入参**：</font>BasicInfo


修改数据结构：

* [MarketComponentInfo](https://cloud.tencent.com/document/api/1118/66797#MarketComponentInfo)

	* 新增成员：DetailUrl, Installed


### 第 2 次发布

发布时间：2022-02-15 08:09:12

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [ApplicationBasicInfo](https://cloud.tencent.com/document/api/1118/66797#ApplicationBasicInfo)

	* 新增成员：AllowVisualModify


### 第 1 次发布

发布时间：2021-12-23 14:56:48

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [ApplyMarketComponent](https://cloud.tencent.com/document/api/1118/66787)
* [CreateApplicationVisualization](https://cloud.tencent.com/document/api/1118/66796)
* [CreateConfigMap](https://cloud.tencent.com/document/api/1118/66729)
* [CreateEdgeNode](https://cloud.tencent.com/document/api/1118/66767)
* [CreateEdgeNodeGroup](https://cloud.tencent.com/document/api/1118/66766)
* [CreateEdgeNodeUnitTemplate](https://cloud.tencent.com/document/api/1118/66765)
* [CreateEdgeUnitApplicationVisualization](https://cloud.tencent.com/document/api/1118/66786)
* [CreateEdgeUnitApplicationYaml](https://cloud.tencent.com/document/api/1118/66785)
* [CreateEdgeUnitCloud](https://cloud.tencent.com/document/api/1118/66764)
* [CreateNamespace](https://cloud.tencent.com/document/api/1118/66728)
* [CreateSecret](https://cloud.tencent.com/document/api/1118/66727)
* [CreateUpdateNodeUnit](https://cloud.tencent.com/document/api/1118/66763)
* [DeleteApplications](https://cloud.tencent.com/document/api/1118/66795)
* [DeleteConfigMap](https://cloud.tencent.com/document/api/1118/66726)
* [DeleteEdgeNodeGroup](https://cloud.tencent.com/document/api/1118/66762)
* [DeleteEdgeNodeUnitTemplates](https://cloud.tencent.com/document/api/1118/66761)
* [DeleteEdgeNodes](https://cloud.tencent.com/document/api/1118/66760)
* [DeleteEdgeUnitApplications](https://cloud.tencent.com/document/api/1118/66784)
* [DeleteEdgeUnitCloud](https://cloud.tencent.com/document/api/1118/66759)
* [DeleteEdgeUnitDeployGridItem](https://cloud.tencent.com/document/api/1118/66758)
* [DeleteEdgeUnitPod](https://cloud.tencent.com/document/api/1118/66757)
* [DeleteNamespace](https://cloud.tencent.com/document/api/1118/66725)
* [DeleteNodeUnit](https://cloud.tencent.com/document/api/1118/66756)
* [DeleteSecret](https://cloud.tencent.com/document/api/1118/66724)
* [DescribeApplicationVisualization](https://cloud.tencent.com/document/api/1118/66794)
* [DescribeApplicationYaml](https://cloud.tencent.com/document/api/1118/66793)
* [DescribeApplicationYamlError](https://cloud.tencent.com/document/api/1118/66792)
* [DescribeApplications](https://cloud.tencent.com/document/api/1118/66791)
* [DescribeConfigMap](https://cloud.tencent.com/document/api/1118/66723)
* [DescribeConfigMapYamlError](https://cloud.tencent.com/document/api/1118/66722)
* [DescribeConfigMaps](https://cloud.tencent.com/document/api/1118/66721)
* [DescribeEdgeAgentNodeInstaller](https://cloud.tencent.com/document/api/1118/66755)
* [DescribeEdgeDefaultVpc](https://cloud.tencent.com/document/api/1118/66754)
* [DescribeEdgeNode](https://cloud.tencent.com/document/api/1118/66753)
* [DescribeEdgeNodePodContainers](https://cloud.tencent.com/document/api/1118/66752)
* [DescribeEdgeNodePods](https://cloud.tencent.com/document/api/1118/66751)
* [DescribeEdgeNodes](https://cloud.tencent.com/document/api/1118/66750)
* [DescribeEdgeOperationLogs](https://cloud.tencent.com/document/api/1118/66720)
* [DescribeEdgePod](https://cloud.tencent.com/document/api/1118/66749)
* [DescribeEdgeUnitApplicationEvents](https://cloud.tencent.com/document/api/1118/66783)
* [DescribeEdgeUnitApplicationLogs](https://cloud.tencent.com/document/api/1118/66782)
* [DescribeEdgeUnitApplicationPodContainers](https://cloud.tencent.com/document/api/1118/66781)
* [DescribeEdgeUnitApplicationPods](https://cloud.tencent.com/document/api/1118/66780)
* [DescribeEdgeUnitApplicationVisualization](https://cloud.tencent.com/document/api/1118/66779)
* [DescribeEdgeUnitApplicationYaml](https://cloud.tencent.com/document/api/1118/66778)
* [DescribeEdgeUnitApplicationYamlError](https://cloud.tencent.com/document/api/1118/66777)
* [DescribeEdgeUnitApplications](https://cloud.tencent.com/document/api/1118/66776)
* [DescribeEdgeUnitCloud](https://cloud.tencent.com/document/api/1118/66748)
* [DescribeEdgeUnitDeployGrid](https://cloud.tencent.com/document/api/1118/66747)
* [DescribeEdgeUnitDeployGridItem](https://cloud.tencent.com/document/api/1118/66746)
* [DescribeEdgeUnitDeployGridItemYaml](https://cloud.tencent.com/document/api/1118/66745)
* [DescribeEdgeUnitExtra](https://cloud.tencent.com/document/api/1118/66744)
* [DescribeEdgeUnitGridEvents](https://cloud.tencent.com/document/api/1118/66743)
* [DescribeEdgeUnitGridPods](https://cloud.tencent.com/document/api/1118/66742)
* [DescribeEdgeUnitMonitorStatus](https://cloud.tencent.com/document/api/1118/66741)
* [DescribeEdgeUnitNodeGroup](https://cloud.tencent.com/document/api/1118/66775)
* [DescribeEdgeUnitNodeUnitTemplates](https://cloud.tencent.com/document/api/1118/66740)
* [DescribeEdgeUnitsCloud](https://cloud.tencent.com/document/api/1118/66739)
* [DescribeMonitorMetrics](https://cloud.tencent.com/document/api/1118/66738)
* [DescribeNamespace](https://cloud.tencent.com/document/api/1118/66719)
* [DescribeNamespaceResources](https://cloud.tencent.com/document/api/1118/66737)
* [DescribeNamespaces](https://cloud.tencent.com/document/api/1118/66718)
* [DescribeNodeUnit](https://cloud.tencent.com/document/api/1118/66736)
* [DescribeNodeUnitTemplateOnNodeGroup](https://cloud.tencent.com/document/api/1118/66735)
* [DescribeSecret](https://cloud.tencent.com/document/api/1118/66717)
* [DescribeSecretYamlError](https://cloud.tencent.com/document/api/1118/66716)
* [DescribeSecrets](https://cloud.tencent.com/document/api/1118/66715)
* [GetMarketComponent](https://cloud.tencent.com/document/api/1118/66774)
* [GetMarketComponentList](https://cloud.tencent.com/document/api/1118/66773)
* [ModifyApplicationBasicInfo](https://cloud.tencent.com/document/api/1118/66790)
* [ModifyApplicationVisualization](https://cloud.tencent.com/document/api/1118/66789)
* [ModifyConfigMap](https://cloud.tencent.com/document/api/1118/66714)
* [ModifyEdgeNodeLabels](https://cloud.tencent.com/document/api/1118/66734)
* [ModifyEdgeUnit](https://cloud.tencent.com/document/api/1118/66733)
* [ModifyEdgeUnitApplicationBasicInfo](https://cloud.tencent.com/document/api/1118/66772)
* [ModifyEdgeUnitApplicationVisualization](https://cloud.tencent.com/document/api/1118/66771)
* [ModifyEdgeUnitApplicationYaml](https://cloud.tencent.com/document/api/1118/66770)
* [ModifyEdgeUnitDeployGridItem](https://cloud.tencent.com/document/api/1118/66732)
* [ModifyNodeUnitTemplate](https://cloud.tencent.com/document/api/1118/66731)
* [ModifySecret](https://cloud.tencent.com/document/api/1118/66713)
* [RedeployEdgeUnitApplication](https://cloud.tencent.com/document/api/1118/66769)

新增数据结构：

* [ApplicationBasicConfig](https://cloud.tencent.com/document/api/1118/66797#ApplicationBasicConfig)
* [ApplicationBasicInfo](https://cloud.tencent.com/document/api/1118/66797#ApplicationBasicInfo)
* [ApplicationDeployMode](https://cloud.tencent.com/document/api/1118/66797#ApplicationDeployMode)
* [ApplicationStatusInfo](https://cloud.tencent.com/document/api/1118/66797#ApplicationStatusInfo)
* [ApplicationTemplate](https://cloud.tencent.com/document/api/1118/66797#ApplicationTemplate)
* [ConfigMapBasicInfo](https://cloud.tencent.com/document/api/1118/66797#ConfigMapBasicInfo)
* [Container](https://cloud.tencent.com/document/api/1118/66797#Container)
* [ContainerStatus](https://cloud.tencent.com/document/api/1118/66797#ContainerStatus)
* [CronJob](https://cloud.tencent.com/document/api/1118/66797#CronJob)
* [DockerConfig](https://cloud.tencent.com/document/api/1118/66797#DockerConfig)
* [EdgeCloudCluster](https://cloud.tencent.com/document/api/1118/66797#EdgeCloudCluster)
* [EdgeNodeInfo](https://cloud.tencent.com/document/api/1118/66797#EdgeNodeInfo)
* [EdgeNodeInstallerOnline](https://cloud.tencent.com/document/api/1118/66797#EdgeNodeInstallerOnline)
* [EdgeNodeLabel](https://cloud.tencent.com/document/api/1118/66797#EdgeNodeLabel)
* [EdgeNodePodContainerInfo](https://cloud.tencent.com/document/api/1118/66797#EdgeNodePodContainerInfo)
* [EdgeNodePodInfo](https://cloud.tencent.com/document/api/1118/66797#EdgeNodePodInfo)
* [EdgeNodeResourceInfo](https://cloud.tencent.com/document/api/1118/66797#EdgeNodeResourceInfo)
* [EdgeUnitStatisticItem](https://cloud.tencent.com/document/api/1118/66797#EdgeUnitStatisticItem)
* [Env](https://cloud.tencent.com/document/api/1118/66797#Env)
* [EnvValueSelector](https://cloud.tencent.com/document/api/1118/66797#EnvValueSelector)
* [Event](https://cloud.tencent.com/document/api/1118/66797#Event)
* [FieldSort](https://cloud.tencent.com/document/api/1118/66797#FieldSort)
* [GridDetail](https://cloud.tencent.com/document/api/1118/66797#GridDetail)
* [GridEventInfo](https://cloud.tencent.com/document/api/1118/66797#GridEventInfo)
* [GridInfo](https://cloud.tencent.com/document/api/1118/66797#GridInfo)
* [GridItemInfo](https://cloud.tencent.com/document/api/1118/66797#GridItemInfo)
* [GridPodInfo](https://cloud.tencent.com/document/api/1118/66797#GridPodInfo)
* [HorizontalPodAutoscaler](https://cloud.tencent.com/document/api/1118/66797#HorizontalPodAutoscaler)
* [HttpHeader](https://cloud.tencent.com/document/api/1118/66797#HttpHeader)
* [HttpProbe](https://cloud.tencent.com/document/api/1118/66797#HttpProbe)
* [Job](https://cloud.tencent.com/document/api/1118/66797#Job)
* [KeyValueObj](https://cloud.tencent.com/document/api/1118/66797#KeyValueObj)
* [Label](https://cloud.tencent.com/document/api/1118/66797#Label)
* [MarketComponentInfo](https://cloud.tencent.com/document/api/1118/66797#MarketComponentInfo)
* [MonitorMetricsColumn](https://cloud.tencent.com/document/api/1118/66797#MonitorMetricsColumn)
* [NamespaceInfo](https://cloud.tencent.com/document/api/1118/66797#NamespaceInfo)
* [NamespaceResource](https://cloud.tencent.com/document/api/1118/66797#NamespaceResource)
* [NodeGroupInfo](https://cloud.tencent.com/document/api/1118/66797#NodeGroupInfo)
* [NodeGroupNodeUnitTemplateInfo](https://cloud.tencent.com/document/api/1118/66797#NodeGroupNodeUnitTemplateInfo)
* [NodeSimpleInfo](https://cloud.tencent.com/document/api/1118/66797#NodeSimpleInfo)
* [NodeUnitInfo](https://cloud.tencent.com/document/api/1118/66797#NodeUnitInfo)
* [NodeUnitNodeInfo](https://cloud.tencent.com/document/api/1118/66797#NodeUnitNodeInfo)
* [NodeUnitTemplate](https://cloud.tencent.com/document/api/1118/66797#NodeUnitTemplate)
* [OperationLog](https://cloud.tencent.com/document/api/1118/66797#OperationLog)
* [OperationLogsCondition](https://cloud.tencent.com/document/api/1118/66797#OperationLogsCondition)
* [PodStatus](https://cloud.tencent.com/document/api/1118/66797#PodStatus)
* [PortConfig](https://cloud.tencent.com/document/api/1118/66797#PortConfig)
* [Probe](https://cloud.tencent.com/document/api/1118/66797#Probe)
* [ResourceMetricTarget](https://cloud.tencent.com/document/api/1118/66797#ResourceMetricTarget)
* [SecretItem](https://cloud.tencent.com/document/api/1118/66797#SecretItem)
* [SecurityCapabilities](https://cloud.tencent.com/document/api/1118/66797#SecurityCapabilities)
* [SecurityContext](https://cloud.tencent.com/document/api/1118/66797#SecurityContext)
* [Service](https://cloud.tencent.com/document/api/1118/66797#Service)
* [Sort](https://cloud.tencent.com/document/api/1118/66797#Sort)
* [TcpProbe](https://cloud.tencent.com/document/api/1118/66797#TcpProbe)
* [Volume](https://cloud.tencent.com/document/api/1118/66797#Volume)
* [VolumeConfigMap](https://cloud.tencent.com/document/api/1118/66797#VolumeConfigMap)
* [VolumeConfigMapKeyToPath](https://cloud.tencent.com/document/api/1118/66797#VolumeConfigMapKeyToPath)
* [VolumeHostPath](https://cloud.tencent.com/document/api/1118/66797#VolumeHostPath)
* [VolumeMount](https://cloud.tencent.com/document/api/1118/66797#VolumeMount)
* [VolumeNFS](https://cloud.tencent.com/document/api/1118/66797#VolumeNFS)




## 智能识图(iir) 版本：2020-04-17

### 第 1 次发布

发布时间：2020-04-28 14:58:11

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [RecognizeProduct](https://cloud.tencent.com/document/api/1217/43952)

新增数据结构：

* [Location](https://cloud.tencent.com/document/api/1217/43953#Location)
* [ProductInfo](https://cloud.tencent.com/document/api/1217/43953#ProductInfo)
* [RegionDetected](https://cloud.tencent.com/document/api/1217/43953#RegionDetected)




## 图片内容安全(ims) 版本：2020-07-13

### 第 6 次发布

发布时间：2023-05-09 01:22:32

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [ImageModeration](https://cloud.tencent.com/document/api/1125/49656)

	* 新增出参：RecognitionResults


新增数据结构：

* [RecognitionResult](https://cloud.tencent.com/document/api/1125/49657#RecognitionResult)
* [RecognitionTag](https://cloud.tencent.com/document/api/1125/49657#RecognitionTag)

修改数据结构：

* [ObjectDetail](https://cloud.tencent.com/document/api/1125/49657#ObjectDetail)

	* 新增成员：GroupId, ObjectId


### 第 5 次发布

发布时间：2023-01-11 11:56:07

本次发布包含了以下内容：

改善已有的文档。

<font color="#dd0000">**删除接口**：</font>

* DescribeImageStat
* DescribeImsList

<font color="#dd0000">**删除数据结构**：</font>

* EvilCount
* Filter
* Filters
* ImsDetail
* Overview
* TrendCount

修改数据结构：

* [ObjectDetail](https://cloud.tencent.com/document/api/1125/49657#ObjectDetail)

	* 新增成员：SubLabel

* [OcrResult](https://cloud.tencent.com/document/api/1125/49657#OcrResult)

	* 新增成员：HitFlag

* [OcrTextDetail](https://cloud.tencent.com/document/api/1125/49657#OcrTextDetail)

	* 新增成员：SubLabel


### 第 4 次发布

发布时间：2021-03-09 08:00:19

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [OcrTextDetail](https://cloud.tencent.com/document/api/1125/49657#OcrTextDetail)

	* 新增成员：Rate


### 第 3 次发布

发布时间：2020-12-18 08:00:10

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [OcrResult](https://cloud.tencent.com/document/api/1125/49657#OcrResult)

	* 新增成员：Text


### 第 2 次发布

发布时间：2020-12-16 08:00:40

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeImageStat](https://cloud.tencent.com/document/api/1125/51002)
* [DescribeImsList](https://cloud.tencent.com/document/api/1125/51001)

新增数据结构：

* [EvilCount](https://cloud.tencent.com/document/api/1125/49657#EvilCount)
* [Filter](https://cloud.tencent.com/document/api/1125/49657#Filter)
* [Filters](https://cloud.tencent.com/document/api/1125/49657#Filters)
* [ImsDetail](https://cloud.tencent.com/document/api/1125/49657#ImsDetail)
* [Overview](https://cloud.tencent.com/document/api/1125/49657#Overview)
* [TrendCount](https://cloud.tencent.com/document/api/1125/49657#TrendCount)

### 第 1 次发布

发布时间：2020-11-04 15:52:22

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [ImageModeration](https://cloud.tencent.com/document/api/1125/49656)

新增数据结构：

* [Device](https://cloud.tencent.com/document/api/1125/49657#Device)
* [LabelDetailItem](https://cloud.tencent.com/document/api/1125/49657#LabelDetailItem)
* [LabelResult](https://cloud.tencent.com/document/api/1125/49657#LabelResult)
* [LibDetail](https://cloud.tencent.com/document/api/1125/49657#LibDetail)
* [LibResult](https://cloud.tencent.com/document/api/1125/49657#LibResult)
* [Location](https://cloud.tencent.com/document/api/1125/49657#Location)
* [ObjectDetail](https://cloud.tencent.com/document/api/1125/49657#ObjectDetail)
* [ObjectResult](https://cloud.tencent.com/document/api/1125/49657#ObjectResult)
* [OcrResult](https://cloud.tencent.com/document/api/1125/49657#OcrResult)
* [OcrTextDetail](https://cloud.tencent.com/document/api/1125/49657#OcrTextDetail)
* [User](https://cloud.tencent.com/document/api/1125/49657#User)



## 图片内容安全(ims) 版本：2020-12-29

### 第 6 次发布

发布时间：2023-05-09 01:22:37

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [ObjectDetail](https://cloud.tencent.com/document/api/1125/53274#ObjectDetail)

	* 新增成员：ObjectId


### 第 5 次发布

发布时间：2023-03-01 01:30:09

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateImageModerationAsyncTask](https://cloud.tencent.com/document/api/1125/87021)

### 第 4 次发布

发布时间：2023-01-31 01:31:04

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [ImageModeration](https://cloud.tencent.com/document/api/1125/53273)

	* 新增出参：RecognitionResults


新增数据结构：

* [RecognitionResult](https://cloud.tencent.com/document/api/1125/53274#RecognitionResult)
* [RecognitionTag](https://cloud.tencent.com/document/api/1125/53274#RecognitionTag)

### 第 3 次发布

发布时间：2021-10-29 08:06:21

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [ObjectDetail](https://cloud.tencent.com/document/api/1125/53274#ObjectDetail)

	* 新增成员：SubLabel

* [OcrTextDetail](https://cloud.tencent.com/document/api/1125/53274#OcrTextDetail)

	* 新增成员：SubLabel


### 第 2 次发布

发布时间：2021-09-14 08:01:18

本次发布包含了以下内容：

改善已有的文档。

<font color="#dd0000">**删除接口**：</font>

* ImageRecognition

### 第 1 次发布

发布时间：2021-02-01 10:50:49

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [ImageModeration](https://cloud.tencent.com/document/api/1125/53273)
* [ImageRecognition](https://cloud.tencent.com/document/api/1125/53272)

新增数据结构：

* [Device](https://cloud.tencent.com/document/api/1125/53274#Device)
* [LabelDetailItem](https://cloud.tencent.com/document/api/1125/53274#LabelDetailItem)
* [LabelResult](https://cloud.tencent.com/document/api/1125/53274#LabelResult)
* [LibDetail](https://cloud.tencent.com/document/api/1125/53274#LibDetail)
* [LibResult](https://cloud.tencent.com/document/api/1125/53274#LibResult)
* [Location](https://cloud.tencent.com/document/api/1125/53274#Location)
* [ObjectDetail](https://cloud.tencent.com/document/api/1125/53274#ObjectDetail)
* [ObjectResult](https://cloud.tencent.com/document/api/1125/53274#ObjectResult)
* [OcrResult](https://cloud.tencent.com/document/api/1125/53274#OcrResult)
* [OcrTextDetail](https://cloud.tencent.com/document/api/1125/53274#OcrTextDetail)
* [User](https://cloud.tencent.com/document/api/1125/53274#User)




## iOA 零信任安全管理系统(ioa) 版本：2022-06-01

### 第 6 次发布

发布时间：2024-06-28 01:12:56

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [DescribeAccountGroupsData](https://cloud.tencent.com/document/api/1092/102488#DescribeAccountGroupsData)

	* 新增成员：LatestSyncResult, LatestSyncTime


### 第 5 次发布

发布时间：2024-06-25 16:17:19

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeAccountGroups](https://cloud.tencent.com/document/api/1092/107711)
* [DescribeLocalAccounts](https://cloud.tencent.com/document/api/1092/107710)

新增数据结构：

* [DescribeAccountGroupsData](https://cloud.tencent.com/document/api/1092/102488#DescribeAccountGroupsData)
* [DescribeAccountGroupsPageResp](https://cloud.tencent.com/document/api/1092/102488#DescribeAccountGroupsPageResp)
* [DescribeLocalAccountAccountGroupsData](https://cloud.tencent.com/document/api/1092/102488#DescribeLocalAccountAccountGroupsData)
* [DescribeLocalAccountsData](https://cloud.tencent.com/document/api/1092/102488#DescribeLocalAccountsData)
* [DescribeLocalAccountsPage](https://cloud.tencent.com/document/api/1092/102488#DescribeLocalAccountsPage)

### 第 4 次发布

发布时间：2024-06-25 16:07:22

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeRootAccountGroup](https://cloud.tencent.com/document/api/1092/107709)

新增数据结构：

* [GetAccountGroupData](https://cloud.tencent.com/document/api/1092/102488#GetAccountGroupData)

### 第 3 次发布

发布时间：2023-12-15 19:46:46

本次发布包含了以下内容：

改善已有的文档。

新增数据结构：

* [DeviceDetail](https://cloud.tencent.com/document/api/1092/102488#DeviceDetail)

修改数据结构：

* [DescribeDevicesPageRsp](https://cloud.tencent.com/document/api/1092/102488#DescribeDevicesPageRsp)

	* 新增成员：Items


### 第 2 次发布

发布时间：2023-12-14 12:16:14

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeDevices](https://cloud.tencent.com/document/api/1092/102467)

	* 新增入参：Condition, GroupId, OsType, OnlineStatus, Filters, Sort, PageNum, PageSize, Status

	* 新增出参：Data


新增数据结构：

* [Condition](https://cloud.tencent.com/document/api/1092/102488#Condition)
* [DescribeDevicesPageRsp](https://cloud.tencent.com/document/api/1092/102488#DescribeDevicesPageRsp)
* [Filter](https://cloud.tencent.com/document/api/1092/102488#Filter)
* [FilterGroup](https://cloud.tencent.com/document/api/1092/102488#FilterGroup)
* [Paging](https://cloud.tencent.com/document/api/1092/102488#Paging)
* [Sort](https://cloud.tencent.com/document/api/1092/102488#Sort)

### 第 1 次发布

发布时间：2023-12-13 17:22:42

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeDevices](https://cloud.tencent.com/document/api/1092/102467)




## 加速物联网套件(iot) 版本：2018-01-23

### 第 7 次发布

发布时间：2023-07-17 01:22:28

本次发布包含了以下内容：

改善已有的文档。

<font color="#dd0000">**预下线接口**：</font>

* UnassociateSubDeviceFromGatewayProduct

### 第 6 次发布

发布时间：2020-03-16 08:11:55

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [GetDataHistory](https://cloud.tencent.com/document/api/568/30087)

	* <font color="#dd0000">**修改入参**：</font>Size


### 第 5 次发布

发布时间：2018-10-19 17:42:33

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [AssociateSubDeviceToGatewayProduct](https://cloud.tencent.com/document/api/568/30065)
* [UnassociateSubDeviceFromGatewayProduct](https://cloud.tencent.com/document/api/568/30061)

<font color="#dd0000">**删除接口**：</font>

* AddFirmware
* AddOtaTask
* DeleteFirmware
* GetFirmwares
* GetInstalledFirmwares
* GetOtaRecords
* GetOtaTask
* GetOtaTasks
* AddUser
* AppAddDevice
* GetUser

修改接口：

* [AddProduct](https://cloud.tencent.com/document/api/568/16448)

	* 新增入参：DeviceType


<font color="#dd0000">**删除数据结构**：</font>

* Firmware
* FirmwareEntry
* InstalledFirmware
* OtaRecord
* OtaTask
* OtaTaskEntry
* User

### 第 4 次发布

发布时间：2018-10-19 13:23:40

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [AddFirmware](https://cloud.tencent.com/document/api/#/#)
* [AddOtaTask](https://cloud.tencent.com/document/api/#/#)
* [AppAddDevice](https://cloud.tencent.com/document/api/#/#)
* [AppDeleteDevice](https://cloud.tencent.com/document/api/568/30082)
* [AppGetDevice](https://cloud.tencent.com/document/api/568/30081)
* [AppGetDeviceData](https://cloud.tencent.com/document/api/568/30080)
* [AppGetDeviceStatuses](https://cloud.tencent.com/document/api/568/30079)
* [AppGetDevices](https://cloud.tencent.com/document/api/568/30078)
* [AppGetToken](https://cloud.tencent.com/document/api/568/30071)
* [AppGetUser](https://cloud.tencent.com/document/api/568/30070)
* [AppIssueDeviceControl](https://cloud.tencent.com/document/api/568/30077)
* [AppResetPassword](https://cloud.tencent.com/document/api/568/30069)
* [AppSecureAddDevice](https://cloud.tencent.com/document/api/568/30076)
* [AppUpdateDevice](https://cloud.tencent.com/document/api/568/30075)
* [AppUpdateUser](https://cloud.tencent.com/document/api/568/30068)
* [DeleteFirmware](https://cloud.tencent.com/document/api/#/#)
* [GetDebugLog](https://cloud.tencent.com/document/api/568/30086)
* [GetDeviceSignatures](https://cloud.tencent.com/document/api/568/30074)
* [GetDeviceStatistics](https://cloud.tencent.com/document/api/568/30084)
* [GetFirmwares](https://cloud.tencent.com/document/api/#/#)
* [GetInstalledFirmwares](https://cloud.tencent.com/document/api/#/#)
* [GetOtaRecords](https://cloud.tencent.com/document/api/#/#)
* [GetOtaTask](https://cloud.tencent.com/document/api/#/#)
* [GetOtaTasks](https://cloud.tencent.com/document/api/#/#)

修改接口：

* [AddProduct](https://cloud.tencent.com/document/api/568/16448)

	* 新增入参：CommProtocol

	* <font color="#dd0000">**修改入参**：</font>DataTemplate

* [AddRule](https://cloud.tencent.com/document/api/568/16458)

	* 新增入参：DataType

	* <font color="#dd0000">**修改入参**：</font>Actions

* [GetDataHistory](https://cloud.tencent.com/document/api/568/30087)

	* 新增出参：ScrollTimeout

	* <font color="#dd0000">**修改出参**：</font>DataHistory

* [GetDeviceData](https://cloud.tencent.com/document/api/568/16522)

	* <font color="#dd0000">**修改出参**：</font>DeviceData

* [GetDeviceLog](https://cloud.tencent.com/document/api/568/30085)

	* 新增出参：ScrollTimeout

	* <font color="#dd0000">**修改出参**：</font>DeviceLog, ScrollId

* [GetDevices](https://cloud.tencent.com/document/api/568/16468)

	* 新增入参：Keyword

	* <font color="#dd0000">**修改出参**：</font>Devices

* [GetProducts](https://cloud.tencent.com/document/api/568/16450)

	* <font color="#dd0000">**修改出参**：</font>Products

* [GetRules](https://cloud.tencent.com/document/api/568/16462)

	* 新增出参：Total

* [IssueDeviceControl](https://cloud.tencent.com/document/api/568/16525)

	* 新增入参：Metadata

* [ResetDevice](https://cloud.tencent.com/document/api/568/16526)

	* 新增出参：Device

* [UpdateProduct](https://cloud.tencent.com/document/api/568/16451)

	* <font color="#dd0000">**修改入参**：</font>DataTemplate

* [UpdateRule](https://cloud.tencent.com/document/api/568/16463)

	* 新增入参：DataType

	* <font color="#dd0000">**修改入参**：</font>Actions

	* 新增出参：Rule


新增数据结构：

* [Action](https://cloud.tencent.com/document/api/568/16469#Action)
* [AppDevice](https://cloud.tencent.com/document/api/568/16469#AppDevice)
* [AppDeviceDetail](https://cloud.tencent.com/document/api/568/16469#AppDeviceDetail)
* [BoolData](https://cloud.tencent.com/document/api/568/16469#BoolData)
* [CkafkaAction](https://cloud.tencent.com/document/api/568/16469#CkafkaAction)
* [DataHistoryEntry](https://cloud.tencent.com/document/api/568/16469#DataHistoryEntry)
* [DataTemplate](https://cloud.tencent.com/document/api/568/16469#DataTemplate)
* [DebugLogEntry](https://cloud.tencent.com/document/api/568/16469#DebugLogEntry)
* [DeviceEntry](https://cloud.tencent.com/document/api/568/16469#DeviceEntry)
* [DeviceLogEntry](https://cloud.tencent.com/document/api/568/16469#DeviceLogEntry)
* [DeviceSignature](https://cloud.tencent.com/document/api/568/16469#DeviceSignature)
* [DeviceStatData](https://cloud.tencent.com/document/api/568/16469#DeviceStatData)
* [EnumData](https://cloud.tencent.com/document/api/568/16469#EnumData)
* [Firmware](https://cloud.tencent.com/document/api/568/16469#Firmware)
* [FirmwareEntry](https://cloud.tencent.com/document/api/568/16469#FirmwareEntry)
* [InstalledFirmware](https://cloud.tencent.com/document/api/568/16469#InstalledFirmware)
* [NumberData](https://cloud.tencent.com/document/api/568/16469#NumberData)
* [OtaRecord](https://cloud.tencent.com/document/api/568/16469#OtaRecord)
* [OtaTask](https://cloud.tencent.com/document/api/568/16469#OtaTask)
* [OtaTaskEntry](https://cloud.tencent.com/document/api/568/16469#OtaTaskEntry)
* [ProductEntry](https://cloud.tencent.com/document/api/568/16469#ProductEntry)
* [ServiceAction](https://cloud.tencent.com/document/api/568/16469#ServiceAction)
* [StringData](https://cloud.tencent.com/document/api/568/16469#StringData)
* [TopicAction](https://cloud.tencent.com/document/api/568/16469#TopicAction)

<font color="#dd0000">**删除数据结构**：</font>

* Object

修改数据结构：

* [AppUser](https://cloud.tencent.com/document/api/568/16469#AppUser)

	* <font color="#dd0000">**删除成员**：</font>Devices

* [Device](https://cloud.tencent.com/document/api/568/16469#Device)

	* <font color="#dd0000">**修改成员**：</font>DeviceInfo

* [DeviceStatus](https://cloud.tencent.com/document/api/568/16469#DeviceStatus)

	* 新增成员：FirstOnline, LastOnline, OnlineTimes

* [Product](https://cloud.tencent.com/document/api/568/16469#Product)

	* 新增成员：DataProtocol, Username, Password, CommProtocol, Qps, Region, DeviceType, AssociatedProducts

	* <font color="#dd0000">**删除成员**：</font>ProductSecret

	* <font color="#dd0000">**修改成员**：</font>DataTemplate

* [Rule](https://cloud.tencent.com/document/api/568/16469#Rule)

	* 新增成员：MsgOrder, DataType

	* <font color="#dd0000">**修改成员**：</font>Actions

* [RuleQuery](https://cloud.tencent.com/document/api/568/16469#RuleQuery)

	* 新增成员：ProductId

	* <font color="#dd0000">**修改成员**：</font>Topic

* [Topic](https://cloud.tencent.com/document/api/568/16469#Topic)

	* <font color="#dd0000">**修改成员**：</font>UpdateTime


### 第 3 次发布

发布时间：2018-05-24 17:08:50

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [AddProduct](https://cloud.tencent.com/document/api/568/16448)

	* 新增入参：DataProtocol

* [GetDeviceLog](https://cloud.tencent.com/document/api/568/30085)

	* 新增入参：Type


### 第 2 次发布

发布时间：2018-05-11 11:24:43

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [AddUser](https://cloud.tencent.com/document/api/568/17133)
* [AppAddUser](https://cloud.tencent.com/document/api/568/30072)

修改接口：

* [UpdateProduct](https://cloud.tencent.com/document/api/568/16451)

	* 新增入参：DataTemplate


新增数据结构：

* [AppUser](https://cloud.tencent.com/document/api/568/16469#AppUser)

### 第 1 次发布

发布时间：2018-04-24

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [ActivateRule](https://cloud.tencent.com/document/api/568/16457)
* [AddDevice](https://cloud.tencent.com/document/api/568/16465)
* [AddProduct](https://cloud.tencent.com/document/api/568/16448)
* [AddRule](https://cloud.tencent.com/document/api/568/16458)
* [AddTopic](https://cloud.tencent.com/document/api/568/30066)
* [DeactivateRule](https://cloud.tencent.com/document/api/568/16459)
* [DeleteDevice](https://cloud.tencent.com/document/api/568/16466)
* [DeleteProduct](https://cloud.tencent.com/document/api/568/16449)
* [DeleteRule](https://cloud.tencent.com/document/api/568/16460)
* [DeleteTopic](https://cloud.tencent.com/document/api/568/30064)
* [GetDataHistory](https://cloud.tencent.com/document/api/568/30087)
* [GetDevice](https://cloud.tencent.com/document/api/568/16467)
* [GetDeviceData](https://cloud.tencent.com/document/api/568/16522)
* [GetDeviceLog](https://cloud.tencent.com/document/api/568/30085)
* [GetDeviceStatuses](https://cloud.tencent.com/document/api/568/16524)
* [GetDevices](https://cloud.tencent.com/document/api/568/16468)
* [GetProduct](https://cloud.tencent.com/document/api/568/16380)
* [GetProducts](https://cloud.tencent.com/document/api/568/16450)
* [GetRule](https://cloud.tencent.com/document/api/568/16461)
* [GetRules](https://cloud.tencent.com/document/api/568/16462)
* [GetTopic](https://cloud.tencent.com/document/api/568/30063)
* [GetTopics](https://cloud.tencent.com/document/api/568/30062)
* [GetUser](https://cloud.tencent.com/document/api/568/16589)
* [IssueDeviceControl](https://cloud.tencent.com/document/api/568/16525)
* [PublishMsg](https://cloud.tencent.com/document/api/568/30088)
* [ResetDevice](https://cloud.tencent.com/document/api/568/16526)
* [UpdateProduct](https://cloud.tencent.com/document/api/568/16451)
* [UpdateRule](https://cloud.tencent.com/document/api/568/16463)

新增数据结构：

* [Device](https://cloud.tencent.com/document/api/568/16469#Device)
* [DeviceStatus](https://cloud.tencent.com/document/api/568/16469#DeviceStatus)
* [Object](https://cloud.tencent.com/document/api/568/16469#Object)
* [Product](https://cloud.tencent.com/document/api/568/16469#Product)
* [Rule](https://cloud.tencent.com/document/api/568/16469#Rule)
* [RuleQuery](https://cloud.tencent.com/document/api/568/16469#RuleQuery)
* [Topic](https://cloud.tencent.com/document/api/568/16469#Topic)
* [User](https://cloud.tencent.com/document/api/568/16469#User)




## 物联网通信(iotcloud) 版本：2018-06-14

### 第 27 次发布

发布时间：2022-04-01 15:19:16

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeProduct](https://cloud.tencent.com/document/api/634/73313)
* [UpdateProductDynamicRegister](https://cloud.tencent.com/document/api/634/73310)

### 第 26 次发布

发布时间：2022-02-22 08:08:24

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DeleteDeviceResource](https://cloud.tencent.com/document/api/634/73298)
* [DownloadDeviceResource](https://cloud.tencent.com/document/api/634/73296)

### 第 25 次发布

发布时间：2022-01-13 08:43:07

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [ListLog](https://cloud.tencent.com/document/api/634/73294)
* [ListLogPayload](https://cloud.tencent.com/document/api/634/73293)
* [ListSDKLog](https://cloud.tencent.com/document/api/634/73292)

新增数据结构：

* [CLSLogItem](https://cloud.tencent.com/document/api/634/19497#CLSLogItem)
* [PayloadLogItem](https://cloud.tencent.com/document/api/634/19497#PayloadLogItem)
* [SDKLogItem](https://cloud.tencent.com/document/api/634/19497#SDKLogItem)

### 第 24 次发布

发布时间：2021-09-27 08:12:57

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [SetProductsForbiddenStatus](https://cloud.tencent.com/document/api/634/73311)
* [UpdateDevicesEnableState](https://cloud.tencent.com/document/api/634/72186)

### 第 23 次发布

发布时间：2021-06-04 08:05:53

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [PublishBroadcastMessage](https://cloud.tencent.com/document/api/634/73275)

	* 新增入参：PayloadEncoding


### 第 22 次发布

发布时间：2021-05-31 08:05:42

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeFirmware](https://cloud.tencent.com/document/api/634/73288)

	* 新增出参：FwType

* [EditFirmware](https://cloud.tencent.com/document/api/634/73281)

	* 新增入参：FwType

* [UploadFirmware](https://cloud.tencent.com/document/api/634/73278)

	* 新增入参：FwType


### 第 21 次发布

发布时间：2021-05-18 08:06:17

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [BatchUpdateFirmware](https://cloud.tencent.com/document/api/634/73290)
* [GetCOSURL](https://cloud.tencent.com/document/api/634/73280)

### 第 20 次发布

发布时间：2021-04-05 08:05:16

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeDeviceResource](https://cloud.tencent.com/document/api/634/73252)
* [DescribeDeviceResources](https://cloud.tencent.com/document/api/634/73251)
* [DescribeProductResource](https://cloud.tencent.com/document/api/634/73246)
* [DescribeProductResources](https://cloud.tencent.com/document/api/634/73245)
* [DescribePushResourceTaskStatistics](https://cloud.tencent.com/document/api/634/73297)
* [DescribeResourceTasks](https://cloud.tencent.com/document/api/634/73282)
* [GetUserResourceInfo](https://cloud.tencent.com/document/api/634/73295)

新增数据结构：

* [DeviceResourceInfo](https://cloud.tencent.com/document/api/634/19497#DeviceResourceInfo)
* [ProductResourceInfo](https://cloud.tencent.com/document/api/634/19497#ProductResourceInfo)

### 第 19 次发布

发布时间：2021-02-02 08:05:53

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeDevices](https://cloud.tencent.com/document/api/634/19493)

	* 新增入参：EnableState


### 第 18 次发布

发布时间：2021-01-07 08:05:28

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [PublishMessage](https://cloud.tencent.com/document/api/634/73274)

	* 新增入参：PayloadEncoding


### 第 17 次发布

发布时间：2020-09-15 08:04:44

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CancelDeviceFirmwareTask](https://cloud.tencent.com/document/api/634/73289)
* [DescribeFirmware](https://cloud.tencent.com/document/api/634/73288)
* [DescribeFirmwareTask](https://cloud.tencent.com/document/api/634/73287)
* [DescribeFirmwareTaskDevices](https://cloud.tencent.com/document/api/634/73286)
* [DescribeFirmwareTaskDistribution](https://cloud.tencent.com/document/api/634/73285)
* [DescribeFirmwareTaskStatistics](https://cloud.tencent.com/document/api/634/73284)
* [DescribeFirmwareTasks](https://cloud.tencent.com/document/api/634/73283)
* [EditFirmware](https://cloud.tencent.com/document/api/634/73281)
* [RetryDeviceFirmwareTask](https://cloud.tencent.com/document/api/634/73279)
* [UploadFirmware](https://cloud.tencent.com/document/api/634/73278)

新增数据结构：

* [DeviceUpdateStatus](https://cloud.tencent.com/document/api/634/19497#DeviceUpdateStatus)
* [FirmwareTaskInfo](https://cloud.tencent.com/document/api/634/19497#FirmwareTaskInfo)
* [SearchKeyword](https://cloud.tencent.com/document/api/634/19497#SearchKeyword)
* [StatusStatistic](https://cloud.tencent.com/document/api/634/19497#StatusStatistic)

### 第 16 次发布

发布时间：2020-08-18 08:14:33

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeAllDevices](https://cloud.tencent.com/document/api/634/73255)

新增数据结构：

* [DeviceProperty](https://cloud.tencent.com/document/api/634/19497#DeviceProperty)

### 第 15 次发布

发布时间：2020-08-03 08:13:35

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [PublishBroadcastMessage](https://cloud.tencent.com/document/api/634/73275)
* [PublishRRPCMessage](https://cloud.tencent.com/document/api/634/73273)

### 第 14 次发布

发布时间：2020-06-30 08:13:45

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeDevice](https://cloud.tencent.com/document/api/634/73254)

	* 新增出参：FirmwareUpdateTime

* [DescribeDevices](https://cloud.tencent.com/document/api/634/19493)

	* 新增入参：DeviceName


修改数据结构：

* [DeviceInfo](https://cloud.tencent.com/document/api/634/19497#DeviceInfo)

	* 新增成员：ClientIP, FirmwareUpdateTime


### 第 13 次发布

发布时间：2020-06-05 08:11:21

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateMultiDevicesTask](https://cloud.tencent.com/document/api/634/73306)
* [CreateTaskFileUrl](https://cloud.tencent.com/document/api/634/73304)
* [DescribeProductTask](https://cloud.tencent.com/document/api/634/73303)
* [DescribeProductTasks](https://cloud.tencent.com/document/api/634/73302)

修改接口：

* [DescribeDevice](https://cloud.tencent.com/document/api/634/73254)

	* 新增出参：ClientIP

* [ResetDeviceState](https://cloud.tencent.com/document/api/634/73244)

	* 新增出参：SuccessCount, ResetDeviceResults


新增数据结构：

* [ProductTaskInfo](https://cloud.tencent.com/document/api/634/19497#ProductTaskInfo)
* [ResetDeviceResult](https://cloud.tencent.com/document/api/634/19497#ResetDeviceResult)

修改数据结构：

* [DeviceTag](https://cloud.tencent.com/document/api/634/19497#DeviceTag)

	* 新增成员：Name


### 第 12 次发布

发布时间：2019-12-26 10:30:36

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeDevice](https://cloud.tencent.com/document/api/634/73254)

	* 新增出参：Labels

* [DescribeProducts](https://cloud.tencent.com/document/api/634/73312)

	* <font color="#dd0000">**删除入参**：</font>Filters

* [UpdateDeviceShadow](https://cloud.tencent.com/document/api/634/73263)

	* 新增入参：Prefix


新增数据结构：

* [DeviceLabel](https://cloud.tencent.com/document/api/634/19497#DeviceLabel)

<font color="#dd0000">**删除数据结构**：</font>

* Filter

修改数据结构：

* [DeviceInfo](https://cloud.tencent.com/document/api/634/19497#DeviceInfo)

	* 新增成员：Labels


### 第 11 次发布

发布时间：2019-09-05 21:07:11

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [BindDevices](https://cloud.tencent.com/document/api/634/73261)
* [UnbindDevices](https://cloud.tencent.com/document/api/634/73243)
* [UpdateDeviceAvailableState](https://cloud.tencent.com/document/api/634/73232)

修改数据结构：

* [TopicRulePayload](https://cloud.tencent.com/document/api/634/19497#TopicRulePayload)

	* <font color="#dd0000">**修改成员**：</font>Sql


### 第 10 次发布

发布时间：2019-06-20 17:05:25

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeDevice](https://cloud.tencent.com/document/api/634/73254)

	* 新增出参：FirstOnlineTime, LastOfflineTime, CreateTime, CertState, EnableState


修改数据结构：

* [DeviceInfo](https://cloud.tencent.com/document/api/634/19497#DeviceInfo)

	* 新增成员：EnableState


### 第 9 次发布

发布时间：2019-05-30 19:55:09

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeDeviceClientKey](https://cloud.tencent.com/document/api/634/73253)
* [ResetDeviceState](https://cloud.tencent.com/document/api/634/73244)

修改数据结构：

* [DeviceInfo](https://cloud.tencent.com/document/api/634/19497#DeviceInfo)

	* 新增成员：CertState


### 第 8 次发布

发布时间：2019-05-09 19:46:47

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateLoraDevice](https://cloud.tencent.com/document/api/634/73259)
* [DeleteLoraDevice](https://cloud.tencent.com/document/api/634/73256)
* [DescribeLoraDevice](https://cloud.tencent.com/document/api/634/73249)
* [PublishAsDevice](https://cloud.tencent.com/document/api/634/73276)
* [PublishToDevice](https://cloud.tencent.com/document/api/634/73272)

修改接口：

* [CreateDevice](https://cloud.tencent.com/document/api/634/73260)

	* 新增入参：LoraAppKey

* [DescribeDevice](https://cloud.tencent.com/document/api/634/73254)

	* 新增出参：LogLevel


修改数据结构：

* [ProductProperties](https://cloud.tencent.com/document/api/634/19497#ProductProperties)

	* 新增成员：RegisterType, ProductSecret, RegisterLimit


### 第 7 次发布

发布时间：2019-03-08 17:35:38

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [DeviceInfo](https://cloud.tencent.com/document/api/634/19497#DeviceInfo)

	* 新增成员：FirstOnlineTime, LastOfflineTime, CreateTime, LogLevel


### 第 6 次发布

发布时间：2019-02-22 14:51:50

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [ProductProperties](https://cloud.tencent.com/document/api/634/19497#ProductProperties)

	* 新增成员：ProductKey


### 第 5 次发布

发布时间：2018-12-20 19:07:04

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateTopicPolicy](https://cloud.tencent.com/document/api/634/73315)
* [UpdateTopicPolicy](https://cloud.tencent.com/document/api/634/73309)

新增数据结构：

* [BrokerSubscribe](https://cloud.tencent.com/document/api/634/19497#BrokerSubscribe)

### 第 4 次发布

发布时间：2018-12-13 14:55:15

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateTopicRule](https://cloud.tencent.com/document/api/634/73270)
* [DeleteTopicRule](https://cloud.tencent.com/document/api/634/73269)
* [DescribeDevice](https://cloud.tencent.com/document/api/634/73254)
* [DisableTopicRule](https://cloud.tencent.com/document/api/634/73268)
* [EnableTopicRule](https://cloud.tencent.com/document/api/634/73267)
* [ReplaceTopicRule](https://cloud.tencent.com/document/api/634/73266)

修改接口：

* [CreateDevice](https://cloud.tencent.com/document/api/634/73260)

	* 新增入参：LoraMoteType, Skey

	* 新增出参：LoraMoteType, LoraAppKey, LoraNwkKey

* [CreateProduct](https://cloud.tencent.com/document/api/634/73316)

	* 新增入参：Skey

* [DeleteDevice](https://cloud.tencent.com/document/api/634/73257)

	* 新增入参：Skey

* [DeleteProduct](https://cloud.tencent.com/document/api/634/73314)

	* 新增入参：Skey


新增数据结构：

* [TopicRulePayload](https://cloud.tencent.com/document/api/634/19497#TopicRulePayload)

修改数据结构：

* [ProductProperties](https://cloud.tencent.com/document/api/634/19497#ProductProperties)

	* 新增成员：ModelId, ModelName


### 第 3 次发布

发布时间：2018-10-11 15:26:45

本次发布包含了以下内容：

改善已有的文档。

<font color="#dd0000">**删除接口**：</font>

* GetDeviceShadow

修改数据结构：

* [DeviceInfo](https://cloud.tencent.com/document/api/634/19497#DeviceInfo)

	* 新增成员：LoraMoteType


### 第 2 次发布

发布时间：2018-09-27 17:06:25

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateDevice](https://cloud.tencent.com/document/api/634/73260)

	* 新增入参：LoraDevEui

	* 新增出参：LoraDevEui

* [CreateProduct](https://cloud.tencent.com/document/api/634/73316)

	* 新增出参：ProductProperties

* [DescribeProducts](https://cloud.tencent.com/document/api/634/73312)

	* 新增入参：Filters


新增数据结构：

* [Filter](https://cloud.tencent.com/document/api/634/19497#Filter)

修改数据结构：

* [DeviceInfo](https://cloud.tencent.com/document/api/634/19497#DeviceInfo)

	* 新增成员：LoraDevEui

* [ProductProperties](https://cloud.tencent.com/document/api/634/19497#ProductProperties)

	* 新增成员：Platform, Appeui


### 第 1 次发布

发布时间：2018-08-30 16:03:13

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CancelTask](https://cloud.tencent.com/document/api/634/73307)
* [CreateDevice](https://cloud.tencent.com/document/api/634/73260)
* [CreateMultiDevice](https://cloud.tencent.com/document/api/634/73258)
* [CreateProduct](https://cloud.tencent.com/document/api/634/73316)
* [CreateTask](https://cloud.tencent.com/document/api/634/73305)
* [DeleteDevice](https://cloud.tencent.com/document/api/634/73257)
* [DeleteProduct](https://cloud.tencent.com/document/api/634/73314)
* [DescribeDeviceShadow](https://cloud.tencent.com/document/api/634/73264)
* [DescribeDevices](https://cloud.tencent.com/document/api/634/19493)
* [DescribeMultiDevTask](https://cloud.tencent.com/document/api/634/73248)
* [DescribeMultiDevices](https://cloud.tencent.com/document/api/634/73247)
* [DescribeProducts](https://cloud.tencent.com/document/api/634/73312)
* [DescribeTask](https://cloud.tencent.com/document/api/634/73301)
* [DescribeTasks](https://cloud.tencent.com/document/api/634/73300)
* [GetDeviceShadow](https://cloud.tencent.com/document/api/634/19489)
* [PublishMessage](https://cloud.tencent.com/document/api/634/73274)
* [UpdateDeviceShadow](https://cloud.tencent.com/document/api/634/73263)

新增数据结构：

* [Attribute](https://cloud.tencent.com/document/api/634/19497#Attribute)
* [BatchPublishMessage](https://cloud.tencent.com/document/api/634/19497#BatchPublishMessage)
* [BatchUpdateShadow](https://cloud.tencent.com/document/api/634/19497#BatchUpdateShadow)
* [DeviceInfo](https://cloud.tencent.com/document/api/634/19497#DeviceInfo)
* [DeviceTag](https://cloud.tencent.com/document/api/634/19497#DeviceTag)
* [MultiDevicesInfo](https://cloud.tencent.com/document/api/634/19497#MultiDevicesInfo)
* [ProductInfo](https://cloud.tencent.com/document/api/634/19497#ProductInfo)
* [ProductMetadata](https://cloud.tencent.com/document/api/634/19497#ProductMetadata)
* [ProductProperties](https://cloud.tencent.com/document/api/634/19497#ProductProperties)
* [Task](https://cloud.tencent.com/document/api/634/19497#Task)
* [TaskInfo](https://cloud.tencent.com/document/api/634/19497#TaskInfo)



## 物联网通信(iotcloud) 版本：2021-04-08

### 第 11 次发布

发布时间：2024-06-05 01:47:50

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeFirmware](https://cloud.tencent.com/document/api/634/73630)

	* 新增出参：UserDefined


修改数据结构：

* [FirmwareInfo](https://cloud.tencent.com/document/api/634/71973#FirmwareInfo)

	* 新增成员：UserDefined


### 第 10 次发布

发布时间：2024-01-31 01:16:26

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [UpdateOtaTaskStatus](https://cloud.tencent.com/document/api/634/103653)

修改接口：

* [BatchUpdateFirmware](https://cloud.tencent.com/document/api/634/73637)

	* 新增入参：Type

* [EditFirmware](https://cloud.tencent.com/document/api/634/73623)

	* 新增入参：FirmwareUserDefined

* [UploadFirmware](https://cloud.tencent.com/document/api/634/73621)

	* 新增入参：FirmwareUserDefined


### 第 9 次发布

发布时间：2023-08-09 01:29:39

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeDevice](https://cloud.tencent.com/document/api/634/71948)

	* 新增出参：NBIoTDeviceID


修改数据结构：

* [CLSLogItem](https://cloud.tencent.com/document/api/634/71973#CLSLogItem)

	* 新增成员：UserId

* [DeviceInfo](https://cloud.tencent.com/document/api/634/71973#DeviceInfo)

	* 新增成员：NBIoTDeviceID

* [ProductProperties](https://cloud.tencent.com/document/api/634/71973#ProductProperties)

	* 新增成员：AppEUI


### 第 8 次发布

发布时间：2023-06-14 01:27:08

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [DeviceInfo](https://cloud.tencent.com/document/api/634/71973#DeviceInfo)

	* 新增成员：CreateUserId

* [FirmwareInfo](https://cloud.tencent.com/document/api/634/71973#FirmwareInfo)

	* 新增成员：FwType, CreateUserId


### 第 7 次发布

发布时间：2023-06-12 01:24:01

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [ProductMetadata](https://cloud.tencent.com/document/api/634/71973#ProductMetadata)

	* 新增成员：CreateUserId, UserId

* [ProductProperties](https://cloud.tencent.com/document/api/634/71973#ProductProperties)

	* 新增成员：DeviceLimit, ForbiddenStatus


### 第 6 次发布

发布时间：2022-08-16 06:27:22

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DeleteDeviceShadow](https://cloud.tencent.com/document/api/634/79109)

### 第 5 次发布

发布时间：2022-05-27 06:10:42

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [ListTopicRules](https://cloud.tencent.com/document/api/634/74542)

新增数据结构：

* [TopicRuleInfo](https://cloud.tencent.com/document/api/634/71973#TopicRuleInfo)

### 第 4 次发布

发布时间：2022-05-20 06:13:13

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [GetAllVersion](https://cloud.tencent.com/document/api/634/74072)
* [ListFirmwares](https://cloud.tencent.com/document/api/634/74071)

新增数据结构：

* [FirmwareInfo](https://cloud.tencent.com/document/api/634/71973#FirmwareInfo)

### 第 3 次发布

发布时间：2022-05-11 10:24:44

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [BatchUpdateFirmware](https://cloud.tencent.com/document/api/634/73637)
* [BindDevices](https://cloud.tencent.com/document/api/634/73608)
* [CancelDeviceFirmwareTask](https://cloud.tencent.com/document/api/634/73631)
* [CreateMultiDevicesTask](https://cloud.tencent.com/document/api/634/73642)
* [CreateProduct](https://cloud.tencent.com/document/api/634/73646)
* [CreateTaskFileUrl](https://cloud.tencent.com/document/api/634/73641)
* [CreateTopicPolicy](https://cloud.tencent.com/document/api/634/73645)
* [CreateTopicRule](https://cloud.tencent.com/document/api/634/73617)
* [DeleteDeviceResource](https://cloud.tencent.com/document/api/634/73636)
* [DeleteTopicRule](https://cloud.tencent.com/document/api/634/73616)
* [DescribeDeviceClientKey](https://cloud.tencent.com/document/api/634/73607)
* [DescribeDeviceResource](https://cloud.tencent.com/document/api/634/73606)
* [DescribeDeviceResources](https://cloud.tencent.com/document/api/634/73605)
* [DescribeDeviceShadow](https://cloud.tencent.com/document/api/634/73611)
* [DescribeFirmware](https://cloud.tencent.com/document/api/634/73630)
* [DescribeFirmwareTask](https://cloud.tencent.com/document/api/634/73629)
* [DescribeFirmwareTaskDevices](https://cloud.tencent.com/document/api/634/73628)
* [DescribeFirmwareTaskDistribution](https://cloud.tencent.com/document/api/634/73627)
* [DescribeFirmwareTaskStatistics](https://cloud.tencent.com/document/api/634/73626)
* [DescribeFirmwareTasks](https://cloud.tencent.com/document/api/634/73625)
* [DescribeGatewayBindDevices](https://cloud.tencent.com/document/api/634/73604)
* [DescribeProductResource](https://cloud.tencent.com/document/api/634/73603)
* [DescribeProductResources](https://cloud.tencent.com/document/api/634/73602)
* [DescribeProductTask](https://cloud.tencent.com/document/api/634/73640)
* [DescribeProductTasks](https://cloud.tencent.com/document/api/634/73639)
* [DescribeProducts](https://cloud.tencent.com/document/api/634/73644)
* [DescribePushResourceTaskStatistics](https://cloud.tencent.com/document/api/634/73635)
* [DescribeResourceTasks](https://cloud.tencent.com/document/api/634/73624)
* [DisableTopicRule](https://cloud.tencent.com/document/api/634/73615)
* [DownloadDeviceResource](https://cloud.tencent.com/document/api/634/73634)
* [EditFirmware](https://cloud.tencent.com/document/api/634/73623)
* [EnableTopicRule](https://cloud.tencent.com/document/api/634/73614)
* [GetCOSURL](https://cloud.tencent.com/document/api/634/73633)
* [GetUserResourceInfo](https://cloud.tencent.com/document/api/634/73632)
* [PublishMessage](https://cloud.tencent.com/document/api/634/73619)
* [PublishRRPCMessage](https://cloud.tencent.com/document/api/634/73618)
* [ReplaceTopicRule](https://cloud.tencent.com/document/api/634/73613)
* [ResetDeviceState](https://cloud.tencent.com/document/api/634/73601)
* [RetryDeviceFirmwareTask](https://cloud.tencent.com/document/api/634/73622)
* [UnbindDevices](https://cloud.tencent.com/document/api/634/73600)
* [UpdateDeviceAvailableState](https://cloud.tencent.com/document/api/634/73599)
* [UpdateDeviceShadow](https://cloud.tencent.com/document/api/634/73610)
* [UpdateTopicPolicy](https://cloud.tencent.com/document/api/634/73643)
* [UploadFirmware](https://cloud.tencent.com/document/api/634/73621)

新增数据结构：

* [BindDeviceInfo](https://cloud.tencent.com/document/api/634/71973#BindDeviceInfo)
* [BrokerSubscribe](https://cloud.tencent.com/document/api/634/71973#BrokerSubscribe)
* [DeviceResourceInfo](https://cloud.tencent.com/document/api/634/71973#DeviceResourceInfo)
* [DeviceUpdateStatus](https://cloud.tencent.com/document/api/634/71973#DeviceUpdateStatus)
* [FirmwareTaskInfo](https://cloud.tencent.com/document/api/634/71973#FirmwareTaskInfo)
* [ProductInfo](https://cloud.tencent.com/document/api/634/71973#ProductInfo)
* [ProductResourceInfo](https://cloud.tencent.com/document/api/634/71973#ProductResourceInfo)
* [ProductTaskInfo](https://cloud.tencent.com/document/api/634/71973#ProductTaskInfo)
* [ResetDeviceResult](https://cloud.tencent.com/document/api/634/71973#ResetDeviceResult)
* [SearchKeyword](https://cloud.tencent.com/document/api/634/71973#SearchKeyword)
* [StatusStatistic](https://cloud.tencent.com/document/api/634/71973#StatusStatistic)
* [TopicRulePayload](https://cloud.tencent.com/document/api/634/71973#TopicRulePayload)

### 第 2 次发布

发布时间：2022-04-01 15:20:13

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DeleteProductPrivateCA](https://cloud.tencent.com/document/api/634/71963)
* [ListLog](https://cloud.tencent.com/document/api/634/71956)
* [ListLogPayload](https://cloud.tencent.com/document/api/634/71955)
* [ListSDKLog](https://cloud.tencent.com/document/api/634/71954)
* [PublishBroadcastMessage](https://cloud.tencent.com/document/api/634/71952)
* [SetProductsForbiddenStatus](https://cloud.tencent.com/document/api/634/71960)
* [UpdateDevicePSK](https://cloud.tencent.com/document/api/634/71945)
* [UpdateProductDynamicRegister](https://cloud.tencent.com/document/api/634/71959)
* [UpdateProductPrivateCA](https://cloud.tencent.com/document/api/634/71958)

修改接口：

* [DescribeDevice](https://cloud.tencent.com/document/api/634/71948)

	* 新增出参：CreateUserId


新增数据结构：

* [CLSLogItem](https://cloud.tencent.com/document/api/634/71973#CLSLogItem)
* [PayloadLogItem](https://cloud.tencent.com/document/api/634/71973#PayloadLogItem)
* [SDKLogItem](https://cloud.tencent.com/document/api/634/71973#SDKLogItem)

### 第 1 次发布

发布时间：2021-07-21 08:06:35

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateDevice](https://cloud.tencent.com/document/api/634/71950)
* [CreatePrivateCA](https://cloud.tencent.com/document/api/634/71972)
* [DeleteDevice](https://cloud.tencent.com/document/api/634/71949)
* [DeletePrivateCA](https://cloud.tencent.com/document/api/634/71970)
* [DeleteProduct](https://cloud.tencent.com/document/api/634/71964)
* [DescribeDevice](https://cloud.tencent.com/document/api/634/71948)
* [DescribeDevices](https://cloud.tencent.com/document/api/634/71947)
* [DescribePrivateCA](https://cloud.tencent.com/document/api/634/71969)
* [DescribePrivateCABindedProducts](https://cloud.tencent.com/document/api/634/71968)
* [DescribePrivateCAs](https://cloud.tencent.com/document/api/634/71967)
* [DescribeProduct](https://cloud.tencent.com/document/api/634/71962)
* [DescribeProductCA](https://cloud.tencent.com/document/api/634/71961)
* [UpdateDeviceLogLevel](https://cloud.tencent.com/document/api/634/71946)
* [UpdateDevicesEnableState](https://cloud.tencent.com/document/api/634/71944)
* [UpdatePrivateCA](https://cloud.tencent.com/document/api/634/71966)

新增数据结构：

* [Attribute](https://cloud.tencent.com/document/api/634/71973#Attribute)
* [BindProductInfo](https://cloud.tencent.com/document/api/634/71973#BindProductInfo)
* [CertInfo](https://cloud.tencent.com/document/api/634/71973#CertInfo)
* [DeviceInfo](https://cloud.tencent.com/document/api/634/71973#DeviceInfo)
* [DeviceLabel](https://cloud.tencent.com/document/api/634/71973#DeviceLabel)
* [DeviceTag](https://cloud.tencent.com/document/api/634/71973#DeviceTag)
* [ProductMetadata](https://cloud.tencent.com/document/api/634/71973#ProductMetadata)
* [ProductProperties](https://cloud.tencent.com/document/api/634/71973#ProductProperties)




## 物联网开发平台(iotexplorer) 版本：2019-04-23

### 第 75 次发布

发布时间：2024-08-02 01:42:30

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateCloudStorageAIService](https://cloud.tencent.com/document/api/1081/109627)
* [ResetCloudStorageAIService](https://cloud.tencent.com/document/api/1081/109626)

修改接口：

* [DescribeCloudStorageAIService](https://cloud.tencent.com/document/api/1081/105303)

	* 新增出参：Type, Status, ExpireTime, UserId


### 第 74 次发布

发布时间：2024-07-15 01:13:08

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeTopicRule](https://cloud.tencent.com/document/api/1081/50231)

	* 新增出参：CamTag

* [GetDeviceList](https://cloud.tencent.com/document/api/1081/37653)

	* 新增入参：Filters

* [SearchStudioProduct](https://cloud.tencent.com/document/api/1081/34981)

	* 新增入参：Filters


新增数据结构：

* [CamTag](https://cloud.tencent.com/document/api/1081/34988#CamTag)
* [Filter](https://cloud.tencent.com/document/api/1081/34988#Filter)

### 第 73 次发布

发布时间：2024-07-08 01:16:17

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [CloudStorageEvent](https://cloud.tencent.com/document/api/1081/34988#CloudStorageEvent)

	* 新增成员：Data


### 第 72 次发布

发布时间：2024-07-05 01:11:41

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [ActivateTWeCallLicense](https://cloud.tencent.com/document/api/1081/106587)

	* 新增出参：DeviceList


新增数据结构：

* [DeviceActiveResult](https://cloud.tencent.com/document/api/1081/34988#DeviceActiveResult)

### 第 71 次发布

发布时间：2024-07-01 01:17:32

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [GetTWeCallPkgList](https://cloud.tencent.com/document/api/1081/106582)

	* 新增出参：TWeCallCategoryPkgList


新增数据结构：

* [TWeCallCategoryPkgInfo](https://cloud.tencent.com/document/api/1081/34988#TWeCallCategoryPkgInfo)

### 第 70 次发布

发布时间：2024-06-27 01:13:47

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [CloudStorageEvent](https://cloud.tencent.com/document/api/1081/34988#CloudStorageEvent)

	* 新增成员：UploadStatus


### 第 69 次发布

发布时间：2024-06-26 01:17:47

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CheckFirmwareUpdate](https://cloud.tencent.com/document/api/1081/107736)
* [DescribeFirmwareUpdateStatus](https://cloud.tencent.com/document/api/1081/107735)
* [PublishFirmwareUpdateMessage](https://cloud.tencent.com/document/api/1081/107734)

### 第 68 次发布

发布时间：2024-06-25 01:16:25

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeFirmware](https://cloud.tencent.com/document/api/1081/107671)

### 第 67 次发布

发布时间：2024-06-13 01:52:49

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [GetWechatDeviceTicket](https://cloud.tencent.com/document/api/1081/106915)

	* 新增入参：MiniProgramAppId


### 第 66 次发布

发布时间：2024-06-06 01:57:24

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [GetWechatDeviceTicket](https://cloud.tencent.com/document/api/1081/106915)

新增数据结构：

* [WXDeviceInfo](https://cloud.tencent.com/document/api/1081/34988#WXDeviceInfo)
* [WXIoTDeviceInfo](https://cloud.tencent.com/document/api/1081/34988#WXIoTDeviceInfo)

### 第 65 次发布

发布时间：2024-06-05 01:48:26

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [FirmwareInfo](https://cloud.tencent.com/document/api/1081/34988#FirmwareInfo)

	* 新增成员：UserDefined


### 第 64 次发布

发布时间：2024-05-27 01:45:34

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [ActivateTWeCallLicense](https://cloud.tencent.com/document/api/1081/106587)
* [AssignTWeCallLicense](https://cloud.tencent.com/document/api/1081/106586)
* [CancelAssignTWeCallLicense](https://cloud.tencent.com/document/api/1081/106585)
* [GetAuthMiniProgramAppList](https://cloud.tencent.com/document/api/1081/106584)
* [GetTWeCallActiveStatus](https://cloud.tencent.com/document/api/1081/106583)
* [GetTWeCallPkgList](https://cloud.tencent.com/document/api/1081/106582)

新增数据结构：

* [AuthMiniProgramAppInfo](https://cloud.tencent.com/document/api/1081/34988#AuthMiniProgramAppInfo)
* [TWeCallActiveInfo](https://cloud.tencent.com/document/api/1081/34988#TWeCallActiveInfo)
* [TWeCallInfo](https://cloud.tencent.com/document/api/1081/34988#TWeCallInfo)
* [TWeCallPkgInfo](https://cloud.tencent.com/document/api/1081/34988#TWeCallPkgInfo)

### 第 63 次发布

发布时间：2024-05-23 01:45:19

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [UpdateDeviceTWeCallAuthorizeStatus](https://cloud.tencent.com/document/api/1081/106531)

### 第 62 次发布

发布时间：2024-05-22 01:45:12

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateStudioProduct](https://cloud.tencent.com/document/api/1081/34987)

	* 新增入参：Rate, Period


修改数据结构：

* [ProductEntry](https://cloud.tencent.com/document/api/1081/34988#ProductEntry)

	* 新增成员：Rate, Period


### 第 61 次发布

发布时间：2024-05-09 01:17:01

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateTRTCSignaturesWithRoomId](https://cloud.tencent.com/document/api/1081/105920)
* [DescribeCloudStorageAIServiceTask](https://cloud.tencent.com/document/api/1081/105917)
* [DismissRoomByStrRoomIdFromTRTC](https://cloud.tencent.com/document/api/1081/105919)
* [GenerateCloudStorageAIServiceTaskFileURL](https://cloud.tencent.com/document/api/1081/105916)
* [RemoveUserByRoomIdFromTRTC](https://cloud.tencent.com/document/api/1081/105918)

修改接口：

* [DescribeCloudStorageAIServiceTasks](https://cloud.tencent.com/document/api/1081/105301)

	* 新增入参：UserId, ChannelId

* [ModifyCloudStorageAIService](https://cloud.tencent.com/document/api/1081/105299)

	* 新增入参：Config


新增数据结构：

* [TRTCParams](https://cloud.tencent.com/document/api/1081/34988#TRTCParams)

修改数据结构：

* [CloudStorageAIServiceTask](https://cloud.tencent.com/document/api/1081/34988#CloudStorageAIServiceTask)

	* 新增成员：Files


### 第 60 次发布

发布时间：2024-04-25 01:18:05

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeDeviceFirmwares](https://cloud.tencent.com/document/api/1081/105649)

新增数据结构：

* [DeviceFirmwareInfo](https://cloud.tencent.com/document/api/1081/34988#DeviceFirmwareInfo)

### 第 59 次发布

发布时间：2024-04-17 01:15:33

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeCloudStorageAIService](https://cloud.tencent.com/document/api/1081/105303)
* [DescribeCloudStorageAIServiceCallback](https://cloud.tencent.com/document/api/1081/105302)
* [DescribeCloudStorageAIServiceTasks](https://cloud.tencent.com/document/api/1081/105301)
* [DescribeProductCloudStorageAIService](https://cloud.tencent.com/document/api/1081/105300)
* [ModifyCloudStorageAIService](https://cloud.tencent.com/document/api/1081/105299)
* [ModifyCloudStorageAIServiceCallback](https://cloud.tencent.com/document/api/1081/105298)
* [ModifyProductCloudStorageAIService](https://cloud.tencent.com/document/api/1081/105297)

新增数据结构：

* [CloudStorageAIServiceTask](https://cloud.tencent.com/document/api/1081/34988#CloudStorageAIServiceTask)

### 第 58 次发布

发布时间：2024-03-28 01:18:46

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [BindCloudStorageUser](https://cloud.tencent.com/document/api/1081/104655)
* [CreateIotVideoCloudStorage](https://cloud.tencent.com/document/api/1081/104654)
* [DeleteCloudStorageEvent](https://cloud.tencent.com/document/api/1081/104653)
* [DescribeCloudStorage](https://cloud.tencent.com/document/api/1081/104652)
* [DescribeCloudStorageDate](https://cloud.tencent.com/document/api/1081/104651)
* [DescribeCloudStorageEvents](https://cloud.tencent.com/document/api/1081/104650)
* [DescribeCloudStorageMultiThumbnail](https://cloud.tencent.com/document/api/1081/104649)
* [DescribeCloudStorageOrder](https://cloud.tencent.com/document/api/1081/104648)
* [DescribeCloudStoragePackageConsumeDetails](https://cloud.tencent.com/document/api/1081/104647)
* [DescribeCloudStoragePackageConsumeStats](https://cloud.tencent.com/document/api/1081/104646)
* [DescribeCloudStorageStreamData](https://cloud.tencent.com/document/api/1081/104645)
* [DescribeCloudStorageThumbnail](https://cloud.tencent.com/document/api/1081/104644)
* [DescribeCloudStorageThumbnailList](https://cloud.tencent.com/document/api/1081/104643)
* [DescribeCloudStorageTime](https://cloud.tencent.com/document/api/1081/104642)
* [DescribeCloudStorageUsers](https://cloud.tencent.com/document/api/1081/104641)
* [DescribeDevicePackages](https://cloud.tencent.com/document/api/1081/104640)
* [DescribePackageConsumeTask](https://cloud.tencent.com/document/api/1081/104639)
* [DescribePackageConsumeTasks](https://cloud.tencent.com/document/api/1081/104638)
* [GenerateSignedVideoURL](https://cloud.tencent.com/document/api/1081/104637)
* [InheritCloudStorageUser](https://cloud.tencent.com/document/api/1081/104636)
* [ResetCloudStorage](https://cloud.tencent.com/document/api/1081/104635)
* [ResetCloudStorageEvent](https://cloud.tencent.com/document/api/1081/104634)
* [TransferCloudStorage](https://cloud.tencent.com/document/api/1081/104633)

新增数据结构：

* [CloudStorageEvent](https://cloud.tencent.com/document/api/1081/34988#CloudStorageEvent)
* [CloudStorageTimeData](https://cloud.tencent.com/document/api/1081/34988#CloudStorageTimeData)
* [CloudStorageTimeInfo](https://cloud.tencent.com/document/api/1081/34988#CloudStorageTimeInfo)
* [CloudStorageUserInfo](https://cloud.tencent.com/document/api/1081/34988#CloudStorageUserInfo)
* [PackageConsumeStat](https://cloud.tencent.com/document/api/1081/34988#PackageConsumeStat)
* [PackageConsumeTask](https://cloud.tencent.com/document/api/1081/34988#PackageConsumeTask)
* [PackageInfo](https://cloud.tencent.com/document/api/1081/34988#PackageInfo)
* [ThumbnailURLInfoList](https://cloud.tencent.com/document/api/1081/34988#ThumbnailURLInfoList)

### 第 57 次发布

发布时间：2024-03-14 01:17:47

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [InstanceDetail](https://cloud.tencent.com/document/api/1081/34988#InstanceDetail)

	* 新增成员：UpDownTPS, UpDownCurrentTPS, ForwardTPS, ForwardCurrentTPS, CellNum, BillingTag, EverydayFreeMessageCount, MaxDeviceOnlineCount


### 第 56 次发布

发布时间：2024-02-26 01:17:19

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeDeviceFirmWare](https://cloud.tencent.com/document/api/1081/103935)

### 第 55 次发布

发布时间：2024-02-02 01:15:04

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [UploadFirmware](https://cloud.tencent.com/document/api/1081/53872)

	* 新增入参：FirmwareUserDefined


修改数据结构：

* [InstanceDetail](https://cloud.tencent.com/document/api/1081/34988#InstanceDetail)

	* 新增成员：Description, Status

* [ProductEntry](https://cloud.tencent.com/document/api/1081/34988#ProductEntry)

	* 新增成员：DeviceCount


### 第 54 次发布

发布时间：2023-10-16 01:17:51

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [GetDeviceSumStatistics](https://cloud.tencent.com/document/api/1081/100249)

### 第 53 次发布

发布时间：2023-08-22 01:14:25

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeInstance](https://cloud.tencent.com/document/api/1081/96827)

新增数据结构：

* [InstanceDetail](https://cloud.tencent.com/document/api/1081/34988#InstanceDetail)

### 第 52 次发布

发布时间：2023-07-17 01:23:02

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeFirmwareTask](https://cloud.tencent.com/document/api/1081/53875)

	* 新增出参：CreateUserId, CreatorNickName


### 第 51 次发布

发布时间：2023-05-08 01:28:02

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [DeviceUser](https://cloud.tencent.com/document/api/1081/34988#DeviceUser)

	* 新增成员：FamilyId, FamilyName


### 第 50 次发布

发布时间：2023-04-25 01:30:43

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [ProjectEntryEx](https://cloud.tencent.com/document/api/1081/34988#ProjectEntryEx)

	* 新增成员：EnableOpenState


### 第 49 次发布

发布时间：2023-03-28 01:38:25

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [ModifyStudioProduct](https://cloud.tencent.com/document/api/1081/34983)

	* 新增入参：BindStrategy


修改数据结构：

* [ProductEntry](https://cloud.tencent.com/document/api/1081/34988#ProductEntry)

	* 新增成员：BindStrategy


### 第 48 次发布

发布时间：2022-11-29 06:52:35

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [DeviceInfo](https://cloud.tencent.com/document/api/1081/34988#DeviceInfo)

	* 新增成员：IsLora


### 第 47 次发布

发布时间：2022-11-21 06:32:42

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeDeviceLocationSolve](https://cloud.tencent.com/document/api/1081/83128)

新增数据结构：

* [WifiInfo](https://cloud.tencent.com/document/api/1081/34988#WifiInfo)

### 第 46 次发布

发布时间：2022-10-25 06:38:53

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeBindedProducts](https://cloud.tencent.com/document/api/1081/67876)

	* 新增入参：ProductSource

* [DescribeDeviceBindGateway](https://cloud.tencent.com/document/api/1081/67872)

	* 新增出参：GatewayProductOwnerName, GatewayProductOwnerUin

* [DescribeGatewaySubProducts](https://cloud.tencent.com/document/api/1081/67875)

	* 新增入参：ProductSource


修改数据结构：

* [BindProductInfo](https://cloud.tencent.com/document/api/1081/34988#BindProductInfo)

	* 新增成员：ProductOwnerName


### 第 45 次发布

发布时间：2022-05-25 06:10:34

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [PositionItem](https://cloud.tencent.com/document/api/1081/34988#PositionItem)

	* 新增成员：LocationType, Accuracy


### 第 44 次发布

发布时间：2022-04-18 06:13:51

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [PublishBroadcastMessage](https://cloud.tencent.com/document/api/1081/72633)

### 第 43 次发布

发布时间：2022-04-12 06:15:29

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeDeviceBindGateway](https://cloud.tencent.com/document/api/1081/67872)

	* 新增出参：GatewayName


### 第 42 次发布

发布时间：2022-04-11 06:13:21

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [LoRaGatewayLocation](https://cloud.tencent.com/document/api/1081/34988#LoRaGatewayLocation)

	* <font color="#dd0000">**修改成员**：</font>Accuracy, Altitude


### 第 41 次发布

发布时间：2022-02-15 08:09:38

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeGatewaySubDeviceList](https://cloud.tencent.com/document/api/1081/69291)

### 第 40 次发布

发布时间：2022-01-11 08:10:29

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [BindDevices](https://cloud.tencent.com/document/api/1081/67873)
* [BindProducts](https://cloud.tencent.com/document/api/1081/67877)
* [DescribeBindedProducts](https://cloud.tencent.com/document/api/1081/67876)
* [DescribeDeviceBindGateway](https://cloud.tencent.com/document/api/1081/67872)
* [DescribeGatewayBindDevices](https://cloud.tencent.com/document/api/1081/67871)
* [DescribeGatewaySubProducts](https://cloud.tencent.com/document/api/1081/67875)
* [GetGatewaySubDeviceList](https://cloud.tencent.com/document/api/1081/67870)
* [UnbindDevices](https://cloud.tencent.com/document/api/1081/67869)
* [UnbindProducts](https://cloud.tencent.com/document/api/1081/67874)

新增数据结构：

* [BindDeviceInfo](https://cloud.tencent.com/document/api/1081/34988#BindDeviceInfo)
* [BindProductInfo](https://cloud.tencent.com/document/api/1081/34988#BindProductInfo)
* [FamilySubDevice](https://cloud.tencent.com/document/api/1081/34988#FamilySubDevice)

### 第 39 次发布

发布时间：2021-12-10 08:07:35

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [GetFamilyDeviceUserList](https://cloud.tencent.com/document/api/1081/65807)

新增数据结构：

* [DeviceUser](https://cloud.tencent.com/document/api/1081/34988#DeviceUser)

### 第 38 次发布

发布时间：2021-12-09 08:07:14

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [PublishRRPCMessage](https://cloud.tencent.com/document/api/1081/65767)

### 第 37 次发布

发布时间：2021-12-06 08:07:14

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [GenSingleDeviceSignatureOfPublic](https://cloud.tencent.com/document/api/1081/65438)

新增数据结构：

* [DeviceSignatureInfo](https://cloud.tencent.com/document/api/1081/34988#DeviceSignatureInfo)

### 第 36 次发布

发布时间：2021-11-10 08:08:03

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateBatchProduction](https://cloud.tencent.com/document/api/1081/63809)
* [DescribeBatchProduction](https://cloud.tencent.com/document/api/1081/63808)
* [GetBatchProductionsList](https://cloud.tencent.com/document/api/1081/63807)

新增数据结构：

* [BatchProductionInfo](https://cloud.tencent.com/document/api/1081/34988#BatchProductionInfo)

### 第 35 次发布

发布时间：2021-10-27 08:08:37

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [DeviceInfo](https://cloud.tencent.com/document/api/1081/34988#DeviceInfo)

	* 新增成员：EnableState, ProductId, ProductName, DeviceType


### 第 34 次发布

发布时间：2021-10-19 08:09:21

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeDevicePositionList](https://cloud.tencent.com/document/api/1081/62451)

	* 新增入参：ProductIdList, CoordinateType, Offset, Limit

	* 新增出参：Positions, Total


新增数据结构：

* [DevicePositionItem](https://cloud.tencent.com/document/api/1081/34988#DevicePositionItem)
* [ProductDevicesPositionItem](https://cloud.tencent.com/document/api/1081/34988#ProductDevicesPositionItem)

### 第 33 次发布

发布时间：2021-10-14 08:10:09

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DeleteTopicPolicy](https://cloud.tencent.com/document/api/1081/62673)
* [DescribeTopicPolicy](https://cloud.tencent.com/document/api/1081/62672)
* [ListTopicPolicy](https://cloud.tencent.com/document/api/1081/62671)
* [ModifyTopicPolicy](https://cloud.tencent.com/document/api/1081/62670)

新增数据结构：

* [TopicItem](https://cloud.tencent.com/document/api/1081/34988#TopicItem)

### 第 32 次发布

发布时间：2021-10-11 08:06:10

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateFenceBind](https://cloud.tencent.com/document/api/1081/62457)
* [CreatePositionFence](https://cloud.tencent.com/document/api/1081/62456)
* [CreatePositionSpace](https://cloud.tencent.com/document/api/1081/62455)
* [DeleteFenceBind](https://cloud.tencent.com/document/api/1081/62454)
* [DeletePositionFence](https://cloud.tencent.com/document/api/1081/62453)
* [DeletePositionSpace](https://cloud.tencent.com/document/api/1081/62452)
* [DescribeDevicePositionList](https://cloud.tencent.com/document/api/1081/62451)
* [DescribeFenceBindList](https://cloud.tencent.com/document/api/1081/62450)
* [DescribeFenceEventList](https://cloud.tencent.com/document/api/1081/62449)
* [DescribePositionFenceList](https://cloud.tencent.com/document/api/1081/62448)
* [DescribeSpaceFenceEventList](https://cloud.tencent.com/document/api/1081/62447)
* [GetDeviceLocationHistory](https://cloud.tencent.com/document/api/1081/62446)
* [GetPositionSpaceList](https://cloud.tencent.com/document/api/1081/62445)
* [ModifyFenceBind](https://cloud.tencent.com/document/api/1081/62444)
* [ModifyPositionFence](https://cloud.tencent.com/document/api/1081/62443)
* [ModifyPositionSpace](https://cloud.tencent.com/document/api/1081/62442)
* [ModifySpaceProperty](https://cloud.tencent.com/document/api/1081/62441)
* [SearchPositionSpace](https://cloud.tencent.com/document/api/1081/62440)

新增数据结构：

* [FenceAlarmPoint](https://cloud.tencent.com/document/api/1081/34988#FenceAlarmPoint)
* [FenceBindDeviceItem](https://cloud.tencent.com/document/api/1081/34988#FenceBindDeviceItem)
* [FenceBindProductItem](https://cloud.tencent.com/document/api/1081/34988#FenceBindProductItem)
* [FenceEventItem](https://cloud.tencent.com/document/api/1081/34988#FenceEventItem)
* [PositionFenceInfo](https://cloud.tencent.com/document/api/1081/34988#PositionFenceInfo)
* [PositionFenceItem](https://cloud.tencent.com/document/api/1081/34988#PositionFenceItem)
* [PositionItem](https://cloud.tencent.com/document/api/1081/34988#PositionItem)
* [PositionSpaceInfo](https://cloud.tencent.com/document/api/1081/34988#PositionSpaceInfo)

### 第 31 次发布

发布时间：2021-10-01 08:11:47

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateTopicPolicy](https://cloud.tencent.com/document/api/1081/62259)

### 第 30 次发布

发布时间：2021-09-02 08:05:31

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DirectBindDeviceInFamily](https://cloud.tencent.com/document/api/1081/61081)

新增数据结构：

* [AppDeviceInfo](https://cloud.tencent.com/document/api/1081/34988#AppDeviceInfo)

### 第 29 次发布

发布时间：2021-08-27 08:06:16

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DeleteDevices](https://cloud.tencent.com/document/api/1081/60780)
* [UpdateDevicesEnableState](https://cloud.tencent.com/document/api/1081/60779)

修改接口：

* [GetDeviceList](https://cloud.tencent.com/document/api/1081/37653)

	* 新增入参：ProjectId


新增数据结构：

* [DevicesItem](https://cloud.tencent.com/document/api/1081/34988#DevicesItem)

### 第 28 次发布

发布时间：2021-08-18 08:06:21

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateDevice](https://cloud.tencent.com/document/api/1081/37178)

	* 新增入参：DefinedPsk


### 第 27 次发布

发布时间：2021-08-04 08:06:18

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DeleteDevice](https://cloud.tencent.com/document/api/1081/37177)

	* 新增入参：ForceDelete


### 第 26 次发布

发布时间：2021-07-07 10:01:07

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [DeviceInfo](https://cloud.tencent.com/document/api/1081/34988#DeviceInfo)

	* 新增成员：CreateUserId, CreatorNickName

* [FirmwareInfo](https://cloud.tencent.com/document/api/1081/34988#FirmwareInfo)

	* 新增成员：CreateUserId, CreatorNickName

* [ProductEntry](https://cloud.tencent.com/document/api/1081/34988#ProductEntry)

	* 新增成员：CreateUserId, CreatorNickName


### 第 25 次发布

发布时间：2021-06-17 08:06:06

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [GetProjectList](https://cloud.tencent.com/document/api/1081/34968)

	* 新增入参：ProjectId, ProductId, Includes, ProjectName

* [SearchStudioProduct](https://cloud.tencent.com/document/api/1081/34981)

	* 新增入参：ProductId


修改数据结构：

* [ProjectEntryEx](https://cloud.tencent.com/document/api/1081/34988#ProjectEntryEx)

	* 新增成员：ApplicationCount, DeviceCount


### 第 24 次发布

发布时间：2021-05-31 08:05:55

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [UploadFirmware](https://cloud.tencent.com/document/api/1081/53872)

	* 新增入参：FwType


修改数据结构：

* [FirmwareInfo](https://cloud.tencent.com/document/api/1081/34988#FirmwareInfo)

	* 新增成员：FwType


### 第 23 次发布

发布时间：2021-04-22 08:05:46

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [GetCOSURL](https://cloud.tencent.com/document/api/1081/54944)

### 第 22 次发布

发布时间：2021-03-19 08:05:27

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeFirmwareTask](https://cloud.tencent.com/document/api/1081/53875)
* [ListFirmwares](https://cloud.tencent.com/document/api/1081/53874)
* [UpdateFirmware](https://cloud.tencent.com/document/api/1081/53873)
* [UploadFirmware](https://cloud.tencent.com/document/api/1081/53872)

新增数据结构：

* [FirmwareInfo](https://cloud.tencent.com/document/api/1081/34988#FirmwareInfo)
* [SearchKeyword](https://cloud.tencent.com/document/api/1081/34988#SearchKeyword)

### 第 21 次发布

发布时间：2021-03-11 08:05:04

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [ProductModelDefinition](https://cloud.tencent.com/document/api/1081/34988#ProductModelDefinition)

	* 新增成员：NetTypeModel


### 第 20 次发布

发布时间：2021-02-05 08:05:15

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateLoRaFrequency](https://cloud.tencent.com/document/api/1081/52872)
* [DeleteLoRaFrequency](https://cloud.tencent.com/document/api/1081/52871)
* [DescribeLoRaFrequency](https://cloud.tencent.com/document/api/1081/52870)
* [ModifyLoRaFrequency](https://cloud.tencent.com/document/api/1081/52869)

新增数据结构：

* [LoRaFrequencyEntry](https://cloud.tencent.com/document/api/1081/34988#LoRaFrequencyEntry)

### 第 19 次发布

发布时间：2021-01-27 08:05:09

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [ProjectEntryEx](https://cloud.tencent.com/document/api/1081/34988#ProjectEntryEx)

	* 新增成员：InstanceId


### 第 18 次发布

发布时间：2021-01-07 08:05:39

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateProject](https://cloud.tencent.com/document/api/1081/34971)

	* 新增入参：InstanceId

* [GetProjectList](https://cloud.tencent.com/document/api/1081/34968)

	* 新增入参：InstanceId


### 第 17 次发布

发布时间：2020-12-18 08:05:18

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateLoRaGateway](https://cloud.tencent.com/document/api/1081/45745)

	* 新增入参：FrequencyId

* [ModifyLoRaGateway](https://cloud.tencent.com/document/api/1081/46010)

	* 新增入参：FrequencyId


修改数据结构：

* [LoRaGatewayItem](https://cloud.tencent.com/document/api/1081/34988#LoRaGatewayItem)

	* 新增成员：FrequencyId


### 第 16 次发布

发布时间：2020-12-15 08:07:25

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [PublishMessage](https://cloud.tencent.com/document/api/1081/50983)

### 第 15 次发布

发布时间：2020-11-24 08:05:27

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateTopicRule](https://cloud.tencent.com/document/api/1081/50233)
* [DeleteTopicRule](https://cloud.tencent.com/document/api/1081/50232)
* [DescribeTopicRule](https://cloud.tencent.com/document/api/1081/50231)
* [DisableTopicRule](https://cloud.tencent.com/document/api/1081/50230)
* [EnableTopicRule](https://cloud.tencent.com/document/api/1081/50229)
* [GetTopicRuleList](https://cloud.tencent.com/document/api/1081/50228)
* [ModifyTopicRule](https://cloud.tencent.com/document/api/1081/50227)
* [SearchTopicRule](https://cloud.tencent.com/document/api/1081/50226)

新增数据结构：

* [TopicRule](https://cloud.tencent.com/document/api/1081/34988#TopicRule)
* [TopicRuleInfo](https://cloud.tencent.com/document/api/1081/34988#TopicRuleInfo)
* [TopicRulePayload](https://cloud.tencent.com/document/api/1081/34988#TopicRulePayload)

### 第 14 次发布

发布时间：2020-10-21 08:04:34

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [ListEventHistory](https://cloud.tencent.com/document/api/1081/37655)

	* <font color="#dd0000">**修改入参**：</font>Type


### 第 13 次发布

发布时间：2020-10-20 08:04:47

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [ListEventHistory](https://cloud.tencent.com/document/api/1081/37655)

	* 新增入参：EventId


### 第 12 次发布

发布时间：2020-09-25 08:04:27

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [GetDeviceList](https://cloud.tencent.com/document/api/1081/37653)

	* 新增入参：FirmwareVersion, DeviceName


### 第 11 次发布

发布时间：2020-08-11 08:15:57

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DeleteDevice](https://cloud.tencent.com/document/api/1081/37177)

	* 新增出参：ResultCode, ResultMessage


### 第 10 次发布

发布时间：2020-07-07 08:12:01

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DeleteLoRaGateway](https://cloud.tencent.com/document/api/1081/46011)
* [ModifyLoRaGateway](https://cloud.tencent.com/document/api/1081/46010)

### 第 9 次发布

发布时间：2020-06-24 08:12:41

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateLoRaGateway](https://cloud.tencent.com/document/api/1081/45745)
* [GetLoRaGatewayList](https://cloud.tencent.com/document/api/1081/45744)

新增数据结构：

* [LoRaGatewayItem](https://cloud.tencent.com/document/api/1081/34988#LoRaGatewayItem)
* [LoRaGatewayLocation](https://cloud.tencent.com/document/api/1081/34988#LoRaGatewayLocation)

### 第 8 次发布

发布时间：2020-03-19 08:09:46

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [ControlDeviceData](https://cloud.tencent.com/document/api/1081/34973)

	* 新增入参：DataTimestamp


### 第 7 次发布

发布时间：2020-03-16 08:12:36

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [ModifyStudioProduct](https://cloud.tencent.com/document/api/1081/34983)

	* 新增入参：EnableProductScript


修改数据结构：

* [ProductEntry](https://cloud.tencent.com/document/api/1081/34988#ProductEntry)

	* 新增成员：EnableProductScript


### 第 6 次发布

发布时间：2020-01-02 10:19:49

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateDevice](https://cloud.tencent.com/document/api/1081/37178)

	* 新增入参：DevAddr, AppKey, DevEUI, AppSKey, NwkSKey


修改数据结构：

* [DeviceInfo](https://cloud.tencent.com/document/api/1081/34988#DeviceInfo)

	* 新增成员：DevAddr, AppKey, DevEUI, AppSKey, NwkSKey


### 第 5 次发布

发布时间：2019-12-05 19:39:47

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeDeviceData](https://cloud.tencent.com/document/api/1081/34979)

	* 新增入参：DeviceId


修改数据结构：

* [DeviceInfo](https://cloud.tencent.com/document/api/1081/34988#DeviceInfo)

	* 新增成员：LogLevel


### 第 4 次发布

发布时间：2019-11-01 20:11:41

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CallDeviceActionAsync](https://cloud.tencent.com/document/api/1081/38941)
* [CallDeviceActionSync](https://cloud.tencent.com/document/api/1081/38940)

修改接口：

* [DescribeDevice](https://cloud.tencent.com/document/api/1081/37654)

	* 新增入参：DeviceId


### 第 3 次发布

发布时间：2019-08-29 20:31:45

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeDevice](https://cloud.tencent.com/document/api/1081/37654)
* [GetDeviceList](https://cloud.tencent.com/document/api/1081/37653)
* [ListEventHistory](https://cloud.tencent.com/document/api/1081/37655)

新增数据结构：

* [DeviceInfo](https://cloud.tencent.com/document/api/1081/34988#DeviceInfo)
* [EventHistoryItem](https://cloud.tencent.com/document/api/1081/34988#EventHistoryItem)

### 第 2 次发布

发布时间：2019-08-15 20:41:15

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateDevice](https://cloud.tencent.com/document/api/1081/37178)
* [DeleteDevice](https://cloud.tencent.com/document/api/1081/37177)

修改接口：

* [ControlDeviceData](https://cloud.tencent.com/document/api/1081/34973)

	* 新增入参：Method, DeviceId

	* 新增出参：Result

* [DeleteProject](https://cloud.tencent.com/document/api/1081/34970)

	* <font color="#dd0000">**修改入参**：</font>ProjectId

* [DescribeProject](https://cloud.tencent.com/document/api/1081/34969)

	* <font color="#dd0000">**修改入参**：</font>ProjectId

* [GetProjectList](https://cloud.tencent.com/document/api/1081/34968)

	* <font color="#dd0000">**修改入参**：</font>Offset, Limit

* [GetStudioProductList](https://cloud.tencent.com/document/api/1081/34984)

	* <font color="#dd0000">**修改入参**：</font>ProjectId, DevStatus, Offset, Limit

* [ModifyProject](https://cloud.tencent.com/document/api/1081/34967)

	* <font color="#dd0000">**修改入参**：</font>ProjectId

* [SearchStudioProduct](https://cloud.tencent.com/document/api/1081/34981)

	* 新增入参：DevStatus

	* <font color="#dd0000">**修改入参**：</font>ProjectId, ProductName, Limit, Offset


新增数据结构：

* [DeviceData](https://cloud.tencent.com/document/api/1081/34988#DeviceData)

修改数据结构：

* [ProductModelDefinition](https://cloud.tencent.com/document/api/1081/34988#ProductModelDefinition)

	* 新增成员：CategoryModel

* [ProjectEntry](https://cloud.tencent.com/document/api/1081/34988#ProjectEntry)

	* <font color="#dd0000">**修改成员**：</font>ProjectId

* [ProjectEntryEx](https://cloud.tencent.com/document/api/1081/34988#ProjectEntryEx)

	* <font color="#dd0000">**修改成员**：</font>ProjectId


### 第 1 次发布

发布时间：2019-05-16 15:18:14

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [ControlDeviceData](https://cloud.tencent.com/document/api/1081/34973)
* [CreateProject](https://cloud.tencent.com/document/api/1081/34971)
* [CreateStudioProduct](https://cloud.tencent.com/document/api/1081/34987)
* [DeleteProject](https://cloud.tencent.com/document/api/1081/34970)
* [DeleteStudioProduct](https://cloud.tencent.com/document/api/1081/34986)
* [DescribeDeviceData](https://cloud.tencent.com/document/api/1081/34979)
* [DescribeDeviceDataHistory](https://cloud.tencent.com/document/api/1081/34978)
* [DescribeModelDefinition](https://cloud.tencent.com/document/api/1081/34976)
* [DescribeProject](https://cloud.tencent.com/document/api/1081/34969)
* [DescribeStudioProduct](https://cloud.tencent.com/document/api/1081/34985)
* [GetProjectList](https://cloud.tencent.com/document/api/1081/34968)
* [GetStudioProductList](https://cloud.tencent.com/document/api/1081/34984)
* [ModifyModelDefinition](https://cloud.tencent.com/document/api/1081/34975)
* [ModifyProject](https://cloud.tencent.com/document/api/1081/34967)
* [ModifyStudioProduct](https://cloud.tencent.com/document/api/1081/34983)
* [ReleaseStudioProduct](https://cloud.tencent.com/document/api/1081/34982)
* [SearchStudioProduct](https://cloud.tencent.com/document/api/1081/34981)

新增数据结构：

* [DeviceDataHistoryItem](https://cloud.tencent.com/document/api/1081/34988#DeviceDataHistoryItem)
* [ProductEntry](https://cloud.tencent.com/document/api/1081/34988#ProductEntry)
* [ProductModelDefinition](https://cloud.tencent.com/document/api/1081/34988#ProductModelDefinition)
* [ProjectEntry](https://cloud.tencent.com/document/api/1081/34988#ProjectEntry)
* [ProjectEntryEx](https://cloud.tencent.com/document/api/1081/34988#ProjectEntryEx)




## 物联网设备身份认证(iottid) 版本：2019-04-11

### 第 4 次发布

发布时间：2019-10-18 10:27:35

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [UploadDeviceUniqueCode](https://cloud.tencent.com/document/api/1086/38510)

### 第 3 次发布

发布时间：2019-09-12 11:44:34

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeAvailableLibCount](https://cloud.tencent.com/document/api/1086/37968)

修改接口：

* [VerifyChipBurnInfo](https://cloud.tencent.com/document/api/1086/36305)

	* 新增出参：VerifiedTimes, LeftTimes


修改数据结构：

* [TidKeysInfo](https://cloud.tencent.com/document/api/1086/35616#TidKeysInfo)

	* 新增成员：DownloadUrl, DeviceCode


### 第 2 次发布

发布时间：2019-07-18 21:54:49

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [AuthTestTid](https://cloud.tencent.com/document/api/1086/36306)
* [VerifyChipBurnInfo](https://cloud.tencent.com/document/api/1086/36305)

### 第 1 次发布

发布时间：2019-06-21 15:53:53

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [BurnTidNotify](https://cloud.tencent.com/document/api/1086/35615)
* [DeliverTidNotify](https://cloud.tencent.com/document/api/1086/35614)
* [DeliverTids](https://cloud.tencent.com/document/api/1086/35613)
* [DescribePermission](https://cloud.tencent.com/document/api/1086/35612)
* [DownloadTids](https://cloud.tencent.com/document/api/1086/35611)

新增数据结构：

* [TidKeysInfo](https://cloud.tencent.com/document/api/1086/35616#TidKeysInfo)




## 物联网智能视频服务(iotvideo) 版本：2019-11-26

### 第 24 次发布

发布时间：2021-06-09 08:01:59

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateBinding](https://cloud.tencent.com/document/api/1131/42367)

	* 新增入参：BindToken


### 第 23 次发布

发布时间：2021-04-22 08:01:40

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateBinding](https://cloud.tencent.com/document/api/1131/42367)

	* 新增入参：Nick

* [CreateUsrToken](https://cloud.tencent.com/document/api/1131/42365)

	* 新增入参：OldAccessToken


### 第 22 次发布

发布时间：2021-04-13 08:01:35

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [ModifyDevice](https://cloud.tencent.com/document/api/1131/54741)

### 第 21 次发布

发布时间：2021-02-24 20:40:37

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeStream](https://cloud.tencent.com/document/api/1131/53079)

新增数据结构：

* [Data](https://cloud.tencent.com/document/api/1131/42400#Data)

### 第 20 次发布

发布时间：2020-12-24 08:01:22

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [VersionData](https://cloud.tencent.com/document/api/1131/42400#VersionData)

	* 新增成员：AliveInMonthCnt


### 第 19 次发布

发布时间：2020-12-16 08:01:40

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeAccountBalance](https://cloud.tencent.com/document/api/1131/51009)
* [DescribeRechargeRecords](https://cloud.tencent.com/document/api/1131/51008)

新增数据结构：

* [RechargeRecord](https://cloud.tencent.com/document/api/1131/42400#RechargeRecord)

### 第 18 次发布

发布时间：2020-11-24 08:01:29

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateProduct](https://cloud.tencent.com/document/api/1131/42382)

	* 新增入参：ChipArch

* [ModifyVerContent](https://cloud.tencent.com/document/api/1131/49512)

	* <font color="#dd0000">**修改入参**：</font>ProductId


### 第 17 次发布

发布时间：2020-11-23 08:01:31

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [Contents](https://cloud.tencent.com/document/api/1131/42400#Contents)

	* 新增成员：Default


### 第 16 次发布

发布时间：2020-11-09 08:00:52

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [UploadOtaVersion](https://cloud.tencent.com/document/api/1131/42391)

	* 新增入参：Remark, Contents


### 第 15 次发布

发布时间：2020-10-30 08:00:58

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateAppUsr](https://cloud.tencent.com/document/api/1131/42370)

	* 新增入参：Mobile


### 第 14 次发布

发布时间：2020-10-29 08:00:46

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeOsList](https://cloud.tencent.com/document/api/1131/49511)
* [ModifyVerContent](https://cloud.tencent.com/document/api/1131/49512)

新增数据结构：

* [OsData](https://cloud.tencent.com/document/api/1131/42400#OsData)
* [SystemType](https://cloud.tencent.com/document/api/1131/42400#SystemType)

### 第 13 次发布

发布时间：2020-10-27 08:01:01

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [RunOtaVersion](https://cloud.tencent.com/document/api/1131/42394)

	* 新增入参：Remark, Contents

* [RunTestOtaVersion](https://cloud.tencent.com/document/api/1131/42393)

	* 新增入参：Remark


新增数据结构：

* [Contents](https://cloud.tencent.com/document/api/1131/42400#Contents)

修改数据结构：

* [VersionData](https://cloud.tencent.com/document/api/1131/42400#VersionData)

	* 新增成员：Remark, Contents


### 第 12 次发布

发布时间：2020-10-23 08:01:19

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateProduct](https://cloud.tencent.com/document/api/1131/42382)

	* 新增入参：AccessMode, Os


### 第 11 次发布

发布时间：2020-10-22 08:00:44

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [ProductData](https://cloud.tencent.com/document/api/1131/42400#ProductData)

	* 新增成员：Os


### 第 10 次发布

发布时间：2020-10-21 08:00:47

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [ProductData](https://cloud.tencent.com/document/api/1131/42400#ProductData)

	* 新增成员：AccessMode


### 第 9 次发布

发布时间：2020-10-16 08:00:46

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [ClearDeviceActiveCode](https://cloud.tencent.com/document/api/1131/49190)
* [CreateAnonymousAccessToken](https://cloud.tencent.com/document/api/1131/49189)
* [CreateStorageService](https://cloud.tencent.com/document/api/1131/49188)
* [DeliverStorageService](https://cloud.tencent.com/document/api/1131/49187)
* [DescribeStorageService](https://cloud.tencent.com/document/api/1131/49186)
* [RefundStorageService](https://cloud.tencent.com/document/api/1131/49185)

新增数据结构：

* [StorageOrder](https://cloud.tencent.com/document/api/1131/42400#StorageOrder)

### 第 8 次发布

发布时间：2020-08-17 08:02:47

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateProduct](https://cloud.tencent.com/document/api/1131/42382)

	* 新增入参：ProductRegion, ProductCate

	* <font color="#dd0000">**修改入参**：</font>Features


修改数据结构：

* [ProductBase](https://cloud.tencent.com/document/api/1131/42400#ProductBase)

	* 新增成员：FuncCode, ProductCate, ProductRegion

* [ProductData](https://cloud.tencent.com/document/api/1131/42400#ProductData)

	* 新增成员：ProductCate, ProductRegion


### 第 7 次发布

发布时间：2020-04-15 08:02:12

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeRegistrationStatus](https://cloud.tencent.com/document/api/1131/43425)

修改接口：

* [ModifyProduct](https://cloud.tencent.com/document/api/1131/42374)

	* 新增入参：ChipManufactureId, ChipId


新增数据结构：

* [RegisteredStatus](https://cloud.tencent.com/document/api/1131/42400#RegisteredStatus)

### 第 6 次发布

发布时间：2020-04-10 08:01:14

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateStorage](https://cloud.tencent.com/document/api/1131/43350)

### 第 5 次发布

发布时间：2020-04-09 08:01:08

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeBindUsr](https://cloud.tencent.com/document/api/1131/42362)

	* <font color="#dd0000">**修改入参**：</font>AccessId


### 第 4 次发布

发布时间：2020-04-08 08:01:03

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DeleteAppUsr](https://cloud.tencent.com/document/api/1131/43184)

### 第 3 次发布

发布时间：2020-03-25 08:00:56

本次发布包含了以下内容：

改善已有的文档。

<font color="#dd0000">**删除接口**：</font>

* CreateUploadTest
* RenewUploadTest

<font color="#dd0000">**删除数据结构**：</font>

* CertificateInfo
* CosCertificate
* RenewCertificate

### 第 2 次发布

发布时间：2020-03-20 08:00:53

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [ModifyDeviceProperty](https://cloud.tencent.com/document/api/1131/42705)

### 第 1 次发布

发布时间：2020-03-16 18:44:17

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateAppUsr](https://cloud.tencent.com/document/api/1131/42370)
* [CreateBinding](https://cloud.tencent.com/document/api/1131/42367)
* [CreateDevToken](https://cloud.tencent.com/document/api/1131/42366)
* [CreateDevices](https://cloud.tencent.com/document/api/1131/42348)
* [CreateGencode](https://cloud.tencent.com/document/api/1131/42389)
* [CreateIotDataType](https://cloud.tencent.com/document/api/1131/42388)
* [CreateIotModel](https://cloud.tencent.com/document/api/1131/42387)
* [CreateProduct](https://cloud.tencent.com/document/api/1131/42382)
* [CreateTraceIds](https://cloud.tencent.com/document/api/1131/42360)
* [CreateUploadPath](https://cloud.tencent.com/document/api/1131/42399)
* [CreateUploadTest](https://cloud.tencent.com/document/api/1131/42381)
* [CreateUsrToken](https://cloud.tencent.com/document/api/1131/42365)
* [DeleteBinding](https://cloud.tencent.com/document/api/1131/42364)
* [DeleteDevice](https://cloud.tencent.com/document/api/1131/42347)
* [DeleteIotDataType](https://cloud.tencent.com/document/api/1131/42386)
* [DeleteMessageQueue](https://cloud.tencent.com/document/api/1131/42380)
* [DeleteOtaVersion](https://cloud.tencent.com/document/api/1131/42398)
* [DeleteProduct](https://cloud.tencent.com/document/api/1131/42379)
* [DeleteTraceIds](https://cloud.tencent.com/document/api/1131/42359)
* [DescribeBindDev](https://cloud.tencent.com/document/api/1131/42363)
* [DescribeBindUsr](https://cloud.tencent.com/document/api/1131/42362)
* [DescribeDevice](https://cloud.tencent.com/document/api/1131/42346)
* [DescribeDeviceModel](https://cloud.tencent.com/document/api/1131/42353)
* [DescribeDevices](https://cloud.tencent.com/document/api/1131/42345)
* [DescribeIotDataType](https://cloud.tencent.com/document/api/1131/42378)
* [DescribeIotModel](https://cloud.tencent.com/document/api/1131/42385)
* [DescribeIotModels](https://cloud.tencent.com/document/api/1131/42384)
* [DescribeLogs](https://cloud.tencent.com/document/api/1131/42358)
* [DescribeMessageQueue](https://cloud.tencent.com/document/api/1131/42377)
* [DescribeModelDataRet](https://cloud.tencent.com/document/api/1131/42352)
* [DescribeOtaVersions](https://cloud.tencent.com/document/api/1131/42397)
* [DescribeProduct](https://cloud.tencent.com/document/api/1131/42376)
* [DescribeProducts](https://cloud.tencent.com/document/api/1131/42375)
* [DescribePubVersions](https://cloud.tencent.com/document/api/1131/42396)
* [DescribeRunLog](https://cloud.tencent.com/document/api/1131/42357)
* [DescribeTraceIds](https://cloud.tencent.com/document/api/1131/42356)
* [DescribeTraceStatus](https://cloud.tencent.com/document/api/1131/42355)
* [DisableDevice](https://cloud.tencent.com/document/api/1131/42344)
* [DisableDeviceStream](https://cloud.tencent.com/document/api/1131/42343)
* [DisableOtaVersion](https://cloud.tencent.com/document/api/1131/42395)
* [ModifyDeviceAction](https://cloud.tencent.com/document/api/1131/42351)
* [ModifyProduct](https://cloud.tencent.com/document/api/1131/42374)
* [RenewUploadTest](https://cloud.tencent.com/document/api/1131/42373)
* [RunDevice](https://cloud.tencent.com/document/api/1131/42342)
* [RunDeviceStream](https://cloud.tencent.com/document/api/1131/42341)
* [RunIotModel](https://cloud.tencent.com/document/api/1131/42369)
* [RunOtaVersion](https://cloud.tencent.com/document/api/1131/42394)
* [RunTestOtaVersion](https://cloud.tencent.com/document/api/1131/42393)
* [SendOnlineMsg](https://cloud.tencent.com/document/api/1131/42350)
* [SetMessageQueue](https://cloud.tencent.com/document/api/1131/42372)
* [UpgradeDevice](https://cloud.tencent.com/document/api/1131/42392)
* [UploadOtaVersion](https://cloud.tencent.com/document/api/1131/42391)

新增数据结构：

* [BindDevInfo](https://cloud.tencent.com/document/api/1131/42400#BindDevInfo)
* [BindUsrInfo](https://cloud.tencent.com/document/api/1131/42400#BindUsrInfo)
* [CertificateInfo](https://cloud.tencent.com/document/api/1131/42400#CertificateInfo)
* [CosCertificate](https://cloud.tencent.com/document/api/1131/42400#CosCertificate)
* [DevTokenInfo](https://cloud.tencent.com/document/api/1131/42400#DevTokenInfo)
* [DeviceCertificate](https://cloud.tencent.com/document/api/1131/42400#DeviceCertificate)
* [DeviceData](https://cloud.tencent.com/document/api/1131/42400#DeviceData)
* [DeviceModelData](https://cloud.tencent.com/document/api/1131/42400#DeviceModelData)
* [DevicesData](https://cloud.tencent.com/document/api/1131/42400#DevicesData)
* [IotModelData](https://cloud.tencent.com/document/api/1131/42400#IotModelData)
* [LogData](https://cloud.tencent.com/document/api/1131/42400#LogData)
* [MsgQueueData](https://cloud.tencent.com/document/api/1131/42400#MsgQueueData)
* [OtaPubHistory](https://cloud.tencent.com/document/api/1131/42400#OtaPubHistory)
* [ProductBase](https://cloud.tencent.com/document/api/1131/42400#ProductBase)
* [ProductData](https://cloud.tencent.com/document/api/1131/42400#ProductData)
* [RenewCertificate](https://cloud.tencent.com/document/api/1131/42400#RenewCertificate)
* [TraceStatus](https://cloud.tencent.com/document/api/1131/42400#TraceStatus)
* [VersionData](https://cloud.tencent.com/document/api/1131/42400#VersionData)



## 物联网智能视频服务(iotvideo) 版本：2020-12-15

### 第 17 次发布

发布时间：2023-08-30 01:16:44

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeCloudStorage](https://cloud.tencent.com/document/api/1131/53635)

	* 新增入参：ChannelId


### 第 16 次发布

发布时间：2023-05-12 01:31:21

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [DeviceInfo](https://cloud.tencent.com/document/api/1131/53113#DeviceInfo)

	* 新增成员：LogLevel


### 第 15 次发布

发布时间：2021-12-03 08:07:55

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateProduct](https://cloud.tencent.com/document/api/1131/53112)

	* 新增入参：NetType


修改数据结构：

* [VideoProduct](https://cloud.tencent.com/document/api/1131/53113#VideoProduct)

	* 新增成员：NetType


### 第 14 次发布

发布时间：2021-11-23 08:09:04

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [ResetCloudStorage](https://cloud.tencent.com/document/api/1131/53958)

	* 新增入参：ChannelId, UserId


### 第 13 次发布

发布时间：2021-11-19 08:11:51

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeProductDynamicRegister](https://cloud.tencent.com/document/api/1131/64445)
* [ModifyProductDynamicRegister](https://cloud.tencent.com/document/api/1131/64444)

### 第 12 次发布

发布时间：2021-11-10 08:08:18

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeCloudStorageEvents](https://cloud.tencent.com/document/api/1131/53633)

	* 新增入参：ChannelId


### 第 11 次发布

发布时间：2021-07-30 08:02:18

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [BindCloudStorageUser](https://cloud.tencent.com/document/api/1131/59323)
* [CreateDataForward](https://cloud.tencent.com/document/api/1131/59317)
* [DescribeCloudStorageUsers](https://cloud.tencent.com/document/api/1131/59322)
* [DescribeDataForwardList](https://cloud.tencent.com/document/api/1131/59316)
* [DescribeDeviceStatusLog](https://cloud.tencent.com/document/api/1131/59320)
* [DescribeSDKLog](https://cloud.tencent.com/document/api/1131/59319)
* [InheritCloudStorageUser](https://cloud.tencent.com/document/api/1131/59321)
* [ModifyDataForward](https://cloud.tencent.com/document/api/1131/59315)
* [ModifyDataForwardStatus](https://cloud.tencent.com/document/api/1131/59314)
* [ModifyDeviceLogLevel](https://cloud.tencent.com/document/api/1131/59318)
* [WakeUpDevice](https://cloud.tencent.com/document/api/1131/59313)

修改接口：

* [DescribeCloudStorage](https://cloud.tencent.com/document/api/1131/53635)

	* 新增入参：UserId

	* 新增出参：UserId

* [DescribeCloudStorageDate](https://cloud.tencent.com/document/api/1131/53634)

	* 新增入参：UserId

* [DescribeCloudStorageEvents](https://cloud.tencent.com/document/api/1131/53633)

	* 新增入参：UserId

* [DescribeCloudStorageTime](https://cloud.tencent.com/document/api/1131/53631)

	* 新增入参：StartTime, EndTime, UserId

* [DescribeDevice](https://cloud.tencent.com/document/api/1131/53083)

	* 新增出参：LogLevel


新增数据结构：

* [CloudStorageUserInfo](https://cloud.tencent.com/document/api/1131/53113#CloudStorageUserInfo)
* [DataForward](https://cloud.tencent.com/document/api/1131/53113#DataForward)
* [DeviceStatusLogItem](https://cloud.tencent.com/document/api/1131/53113#DeviceStatusLogItem)
* [SDKLogItem](https://cloud.tencent.com/document/api/1131/53113#SDKLogItem)

### 第 10 次发布

发布时间：2021-07-07 09:56:32

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [ApplyAIModel](https://cloud.tencent.com/document/api/1131/58228)
* [CancelAIModelApplication](https://cloud.tencent.com/document/api/1131/58227)
* [CreateAIDetection](https://cloud.tencent.com/document/api/1131/58226)
* [CreateCOSCredentials](https://cloud.tencent.com/document/api/1131/58225)
* [DescribeAIModelApplications](https://cloud.tencent.com/document/api/1131/58224)
* [DescribeAIModelChannel](https://cloud.tencent.com/document/api/1131/58223)
* [DescribeAIModelUsage](https://cloud.tencent.com/document/api/1131/58222)
* [DescribeAIModels](https://cloud.tencent.com/document/api/1131/58221)
* [ReportAliveDevice](https://cloud.tencent.com/document/api/1131/58220)
* [UpdateAIModelChannel](https://cloud.tencent.com/document/api/1131/58219)

新增数据结构：

* [AIModelApplication](https://cloud.tencent.com/document/api/1131/53113#AIModelApplication)
* [AIModelInfo](https://cloud.tencent.com/document/api/1131/53113#AIModelInfo)
* [AIModelUsageInfo](https://cloud.tencent.com/document/api/1131/53113#AIModelUsageInfo)

### 第 9 次发布

发布时间：2021-06-16 08:02:12

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [ControlDeviceData](https://cloud.tencent.com/document/api/1131/57369)
* [PublishMessage](https://cloud.tencent.com/document/api/1131/57368)

### 第 8 次发布

发布时间：2021-06-01 08:02:14

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateCloudStorage](https://cloud.tencent.com/document/api/1131/53636)

	* 新增入参：Override


### 第 7 次发布

发布时间：2021-05-18 08:01:52

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeBalance](https://cloud.tencent.com/document/api/1131/55896)
* [DescribeBalanceTransactions](https://cloud.tencent.com/document/api/1131/55895)

新增数据结构：

* [BalanceTransaction](https://cloud.tencent.com/document/api/1131/53113#BalanceTransaction)

### 第 6 次发布

发布时间：2021-04-26 08:01:26

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [GenerateSignedVideoURL](https://cloud.tencent.com/document/api/1131/55135)

### 第 5 次发布

发布时间：2021-04-25 10:11:19

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeCloudStorageEvents](https://cloud.tencent.com/document/api/1131/53633)

	* 新增出参：VideoURL


### 第 4 次发布

发布时间：2021-03-24 08:01:29

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [ResetCloudStorage](https://cloud.tencent.com/document/api/1131/53958)
* [TransferCloudStorage](https://cloud.tencent.com/document/api/1131/53957)

### 第 3 次发布

发布时间：2021-03-17 08:01:23

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [BatchUpdateFirmware](https://cloud.tencent.com/document/api/1131/53699)
* [CancelDeviceFirmwareTask](https://cloud.tencent.com/document/api/1131/53698)
* [CreateTaskFileUrl](https://cloud.tencent.com/document/api/1131/53697)
* [DeleteFirmware](https://cloud.tencent.com/document/api/1131/53696)
* [DescribeFirmware](https://cloud.tencent.com/document/api/1131/53695)
* [DescribeFirmwareTask](https://cloud.tencent.com/document/api/1131/53694)
* [DescribeFirmwareTaskDevices](https://cloud.tencent.com/document/api/1131/53693)
* [DescribeFirmwareTaskDistribution](https://cloud.tencent.com/document/api/1131/53692)
* [DescribeFirmwareTaskStatistics](https://cloud.tencent.com/document/api/1131/53691)
* [DescribeFirmwareTasks](https://cloud.tencent.com/document/api/1131/53690)
* [EditFirmware](https://cloud.tencent.com/document/api/1131/53689)
* [GetAllFirmwareVersion](https://cloud.tencent.com/document/api/1131/53688)
* [GetFirmwareURL](https://cloud.tencent.com/document/api/1131/53687)
* [ListFirmwares](https://cloud.tencent.com/document/api/1131/53686)
* [RetryDeviceFirmwareTask](https://cloud.tencent.com/document/api/1131/53685)
* [UploadFirmware](https://cloud.tencent.com/document/api/1131/53684)

新增数据结构：

* [DeviceUpdateStatus](https://cloud.tencent.com/document/api/1131/53113#DeviceUpdateStatus)
* [FirmwareInfo](https://cloud.tencent.com/document/api/1131/53113#FirmwareInfo)
* [FirmwareTaskInfo](https://cloud.tencent.com/document/api/1131/53113#FirmwareTaskInfo)
* [SearchKeyword](https://cloud.tencent.com/document/api/1131/53113#SearchKeyword)
* [StatusStatistic](https://cloud.tencent.com/document/api/1131/53113#StatusStatistic)

### 第 2 次发布

发布时间：2021-03-16 08:01:33

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateCloudStorage](https://cloud.tencent.com/document/api/1131/53636)
* [DescribeCloudStorage](https://cloud.tencent.com/document/api/1131/53635)
* [DescribeCloudStorageDate](https://cloud.tencent.com/document/api/1131/53634)
* [DescribeCloudStorageEvents](https://cloud.tencent.com/document/api/1131/53633)
* [DescribeCloudStorageThumbnail](https://cloud.tencent.com/document/api/1131/53632)
* [DescribeCloudStorageTime](https://cloud.tencent.com/document/api/1131/53631)

新增数据结构：

* [CloudStorageEvent](https://cloud.tencent.com/document/api/1131/53113#CloudStorageEvent)
* [CloudStorageTimeData](https://cloud.tencent.com/document/api/1131/53113#CloudStorageTimeData)
* [CloudStorageTimeInfo](https://cloud.tencent.com/document/api/1131/53113#CloudStorageTimeInfo)

### 第 1 次发布

发布时间：2021-02-23 08:01:19

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CheckForwardAuth](https://cloud.tencent.com/document/api/1131/53096)
* [CreateBatch](https://cloud.tencent.com/document/api/1131/53106)
* [CreateForwardRule](https://cloud.tencent.com/document/api/1131/53095)
* [CreateProduct](https://cloud.tencent.com/document/api/1131/53112)
* [DeleteDevice](https://cloud.tencent.com/document/api/1131/53084)
* [DeleteForwardRule](https://cloud.tencent.com/document/api/1131/53094)
* [DeleteProduct](https://cloud.tencent.com/document/api/1131/53111)
* [DescribeBatch](https://cloud.tencent.com/document/api/1131/53105)
* [DescribeBatchs](https://cloud.tencent.com/document/api/1131/53104)
* [DescribeCategory](https://cloud.tencent.com/document/api/1131/53089)
* [DescribeDevice](https://cloud.tencent.com/document/api/1131/53083)
* [DescribeDeviceActionHistory](https://cloud.tencent.com/document/api/1131/53102)
* [DescribeDeviceCommLog](https://cloud.tencent.com/document/api/1131/53101)
* [DescribeDeviceData](https://cloud.tencent.com/document/api/1131/53100)
* [DescribeDeviceDataHistory](https://cloud.tencent.com/document/api/1131/53099)
* [DescribeDeviceEventHistory](https://cloud.tencent.com/document/api/1131/53098)
* [DescribeDevices](https://cloud.tencent.com/document/api/1131/53082)
* [DescribeForwardRule](https://cloud.tencent.com/document/api/1131/53093)
* [DescribeModelDefinition](https://cloud.tencent.com/document/api/1131/53088)
* [DescribeProduct](https://cloud.tencent.com/document/api/1131/53110)
* [DescribeProducts](https://cloud.tencent.com/document/api/1131/53109)
* [ImportModelDefinition](https://cloud.tencent.com/document/api/1131/53087)
* [ModifyDevice](https://cloud.tencent.com/document/api/1131/53081)
* [ModifyForwardRule](https://cloud.tencent.com/document/api/1131/53092)
* [ModifyModelDefinition](https://cloud.tencent.com/document/api/1131/53086)
* [ModifyProduct](https://cloud.tencent.com/document/api/1131/53108)
* [SetForwardAuth](https://cloud.tencent.com/document/api/1131/53091)

新增数据结构：

* [ActionHistory](https://cloud.tencent.com/document/api/1131/53113#ActionHistory)
* [DeviceCommLogItem](https://cloud.tencent.com/document/api/1131/53113#DeviceCommLogItem)
* [DeviceDataHistoryItem](https://cloud.tencent.com/document/api/1131/53113#DeviceDataHistoryItem)
* [DeviceInfo](https://cloud.tencent.com/document/api/1131/53113#DeviceInfo)
* [EventHistoryItem](https://cloud.tencent.com/document/api/1131/53113#EventHistoryItem)
* [ProductModelDefinition](https://cloud.tencent.com/document/api/1131/53113#ProductModelDefinition)
* [ProductTemplate](https://cloud.tencent.com/document/api/1131/53113#ProductTemplate)
* [VideoBatch](https://cloud.tencent.com/document/api/1131/53113#VideoBatch)
* [VideoProduct](https://cloud.tencent.com/document/api/1131/53113#VideoProduct)



## 物联网智能视频服务(iotvideo) 版本：2021-11-25

### 第 31 次发布

发布时间：2024-07-08 01:16:48

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [CloudStorageEvent](https://cloud.tencent.com/document/api/1131/76635#CloudStorageEvent)

	* 新增成员：Data


### 第 30 次发布

发布时间：2024-04-29 01:18:23

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [CloudStorageEvent](https://cloud.tencent.com/document/api/1131/76635#CloudStorageEvent)

	* 新增成员：UploadStatus


### 第 29 次发布

发布时间：2024-03-06 01:17:55

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeP2PInfo](https://cloud.tencent.com/document/api/1131/104107)

### 第 28 次发布

发布时间：2024-02-29 01:18:16

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateCloudStorage](https://cloud.tencent.com/document/api/1131/77505)

	* 新增入参：StorageRegion


### 第 27 次发布

发布时间：2024-02-22 01:17:49

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeDevicePackages](https://cloud.tencent.com/document/api/1131/95522)

	* 新增入参：CSUserId


修改数据结构：

* [PackageInfo](https://cloud.tencent.com/document/api/1131/76635#PackageInfo)

	* 新增成员：CSUserId


### 第 26 次发布

发布时间：2024-01-30 01:16:52

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeDevicePackages](https://cloud.tencent.com/document/api/1131/95522)

	* 新增入参：ChannelId


修改数据结构：

* [PackageInfo](https://cloud.tencent.com/document/api/1131/76635#PackageInfo)

	* 新增成员：ChannelId


### 第 25 次发布

发布时间：2024-01-23 01:20:20

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeCloudStorageMultiThumbnail](https://cloud.tencent.com/document/api/1131/103174)

### 第 24 次发布

发布时间：2024-01-18 01:17:58

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DeleteCloudStorageEvent](https://cloud.tencent.com/document/api/1131/95523)

	* 新增入参：ChannelId

* [DescribeCloudStorageOrder](https://cloud.tencent.com/document/api/1131/96706)

	* 新增出参：ChannelId

* [ResetCloudStorageEvent](https://cloud.tencent.com/document/api/1131/96104)

	* 新增入参：ChannelId


### 第 23 次发布

发布时间：2023-11-29 01:57:28

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeCloudStorageThumbnailList](https://cloud.tencent.com/document/api/1131/102014)

新增数据结构：

* [ThumbnailURLInfoList](https://cloud.tencent.com/document/api/1131/76635#ThumbnailURLInfoList)

### 第 22 次发布

发布时间：2023-10-31 01:58:13

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [GenerateSignedVideoURL](https://cloud.tencent.com/document/api/1131/77494)

	* 新增入参：ChannelId


### 第 21 次发布

发布时间：2023-10-25 01:19:12

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeCloudStorage](https://cloud.tencent.com/document/api/1131/77504)

	* 新增入参：ChannelId


### 第 20 次发布

发布时间：2023-08-30 01:17:01

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateCloudStorage](https://cloud.tencent.com/document/api/1131/77505)

	* 新增入参：ChannelId

* [DescribeCloudStorageDate](https://cloud.tencent.com/document/api/1131/77503)

	* 新增入参：ChannelId

* [DescribeCloudStorageTime](https://cloud.tencent.com/document/api/1131/77498)

	* 新增入参：ChannelId


### 第 19 次发布

发布时间：2023-08-18 01:13:17

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeCloudStorageOrder](https://cloud.tencent.com/document/api/1131/96706)

### 第 18 次发布

发布时间：2023-08-17 03:37:09

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateCloudStorage](https://cloud.tencent.com/document/api/1131/77505)

	* 新增入参：OrderId


修改数据结构：

* [PackageInfo](https://cloud.tencent.com/document/api/1131/76635#PackageInfo)

	* 新增成员：PackageId, OrderId


### 第 17 次发布

发布时间：2023-08-09 01:31:19

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [ResetCloudStorageEvent](https://cloud.tencent.com/document/api/1131/96104)

### 第 16 次发布

发布时间：2023-07-27 01:14:43

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [PackageInfo](https://cloud.tencent.com/document/api/1131/76635#PackageInfo)

	* 新增成员：CreatedAt, UpdatedAt


### 第 15 次发布

发布时间：2023-07-26 01:24:02

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DeleteCloudStorageEvent](https://cloud.tencent.com/document/api/1131/95523)
* [DescribeDevicePackages](https://cloud.tencent.com/document/api/1131/95522)

修改接口：

* [DescribeCloudStorageThumbnail](https://cloud.tencent.com/document/api/1131/77499)

	* 新增出参：ExpireTime


新增数据结构：

* [PackageInfo](https://cloud.tencent.com/document/api/1131/76635#PackageInfo)

### 第 14 次发布

发布时间：2023-05-12 01:31:53

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [DeviceInfo](https://cloud.tencent.com/document/api/1131/76635#DeviceInfo)

	* 新增成员：LogLevel


### 第 13 次发布

发布时间：2023-03-22 01:49:36

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CallTRTCDevice](https://cloud.tencent.com/document/api/1131/89113)

新增数据结构：

* [TRTCParams](https://cloud.tencent.com/document/api/1131/76635#TRTCParams)

### 第 12 次发布

发布时间：2023-02-15 01:37:52

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [BonusInfo](https://cloud.tencent.com/document/api/1131/76635#BonusInfo)

	* 新增成员：Status


### 第 11 次发布

发布时间：2023-02-06 15:45:46

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [TransferCloudStorage](https://cloud.tencent.com/document/api/1131/77491)

	* 新增入参：ToProductId


### 第 10 次发布

发布时间：2022-12-05 06:57:57

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [FirmwareInfo](https://cloud.tencent.com/document/api/1131/76635#FirmwareInfo)

	* 新增成员：FwType


### 第 9 次发布

发布时间：2022-12-02 11:32:35

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [BatchUpdateFirmware](https://cloud.tencent.com/document/api/1131/77483)

	* 新增入参：TimeoutInterval

* [DescribeFirmware](https://cloud.tencent.com/document/api/1131/77479)

	* 新增出参：FwType

* [UploadFirmware](https://cloud.tencent.com/document/api/1131/77468)

	* 新增入参：FwType


### 第 8 次发布

发布时间：2022-11-03 06:28:16

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateCloudStorage](https://cloud.tencent.com/document/api/1131/77505)

	* 新增入参：PackageQueue


### 第 7 次发布

发布时间：2022-09-21 06:33:00

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateProduct](https://cloud.tencent.com/document/api/1131/77008)

	* 新增入参：CategoryId


修改数据结构：

* [VideoProduct](https://cloud.tencent.com/document/api/1131/76635#VideoProduct)

	* 新增成员：ProductVaildYears


### 第 6 次发布

发布时间：2022-08-30 06:36:25

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeCloudStorageStreamData](https://cloud.tencent.com/document/api/1131/79720)

### 第 5 次发布

发布时间：2022-08-22 06:33:46

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [VideoProduct](https://cloud.tencent.com/document/api/1131/76635#VideoProduct)

	* 新增成员：CategoryId


### 第 4 次发布

发布时间：2022-07-19 16:17:21

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [ApplyAIModel](https://cloud.tencent.com/document/api/1131/77517)
* [BatchUpdateFirmware](https://cloud.tencent.com/document/api/1131/77483)
* [BindCloudStorageUser](https://cloud.tencent.com/document/api/1131/77506)
* [CancelAIModelApplication](https://cloud.tencent.com/document/api/1131/77516)
* [CancelDeviceFirmwareTask](https://cloud.tencent.com/document/api/1131/77482)
* [CheckForwardAuth](https://cloud.tencent.com/document/api/1131/77453)
* [ControlDeviceData](https://cloud.tencent.com/document/api/1131/77431)
* [CreateAIDetection](https://cloud.tencent.com/document/api/1131/77515)
* [CreateBatch](https://cloud.tencent.com/document/api/1131/77466)
* [CreateCOSCredentials](https://cloud.tencent.com/document/api/1131/77514)
* [CreateCloudStorage](https://cloud.tencent.com/document/api/1131/77505)
* [CreateDataForward](https://cloud.tencent.com/document/api/1131/77452)
* [CreateForwardRule](https://cloud.tencent.com/document/api/1131/77451)
* [CreateTaskFileUrl](https://cloud.tencent.com/document/api/1131/77481)
* [DeleteDevice](https://cloud.tencent.com/document/api/1131/77430)
* [DeleteFirmware](https://cloud.tencent.com/document/api/1131/77480)
* [DeleteForwardRule](https://cloud.tencent.com/document/api/1131/77450)
* [DeleteProduct](https://cloud.tencent.com/document/api/1131/77489)
* [DescribeAIModelApplications](https://cloud.tencent.com/document/api/1131/77513)
* [DescribeAIModelChannel](https://cloud.tencent.com/document/api/1131/77512)
* [DescribeAIModelUsage](https://cloud.tencent.com/document/api/1131/77511)
* [DescribeAIModels](https://cloud.tencent.com/document/api/1131/77510)
* [DescribeAccount](https://cloud.tencent.com/document/api/1131/77435)
* [DescribeBalance](https://cloud.tencent.com/document/api/1131/77434)
* [DescribeBalanceTransactions](https://cloud.tencent.com/document/api/1131/77433)
* [DescribeBatch](https://cloud.tencent.com/document/api/1131/77465)
* [DescribeBatchs](https://cloud.tencent.com/document/api/1131/77464)
* [DescribeBonuses](https://cloud.tencent.com/document/api/1131/77429)
* [DescribeCategory](https://cloud.tencent.com/document/api/1131/77440)
* [DescribeCloudStorage](https://cloud.tencent.com/document/api/1131/77504)
* [DescribeCloudStorageDate](https://cloud.tencent.com/document/api/1131/77503)
* [DescribeCloudStorageEvents](https://cloud.tencent.com/document/api/1131/77502)
* [DescribeCloudStoragePackageConsumeDetails](https://cloud.tencent.com/document/api/1131/77501)
* [DescribeCloudStoragePackageConsumeStats](https://cloud.tencent.com/document/api/1131/77500)
* [DescribeCloudStorageThumbnail](https://cloud.tencent.com/document/api/1131/77499)
* [DescribeCloudStorageTime](https://cloud.tencent.com/document/api/1131/77498)
* [DescribeCloudStorageUsers](https://cloud.tencent.com/document/api/1131/77497)
* [DescribeDataForwardList](https://cloud.tencent.com/document/api/1131/77449)
* [DescribeDevice](https://cloud.tencent.com/document/api/1131/77428)
* [DescribeDeviceActionHistory](https://cloud.tencent.com/document/api/1131/77462)
* [DescribeDeviceCommLog](https://cloud.tencent.com/document/api/1131/77461)
* [DescribeDeviceData](https://cloud.tencent.com/document/api/1131/77460)
* [DescribeDeviceDataHistory](https://cloud.tencent.com/document/api/1131/77459)
* [DescribeDeviceEventHistory](https://cloud.tencent.com/document/api/1131/77458)
* [DescribeDeviceStatusLog](https://cloud.tencent.com/document/api/1131/77457)
* [DescribeDevices](https://cloud.tencent.com/document/api/1131/77427)
* [DescribeFirmware](https://cloud.tencent.com/document/api/1131/77479)
* [DescribeFirmwareTask](https://cloud.tencent.com/document/api/1131/77478)
* [DescribeFirmwareTaskDevices](https://cloud.tencent.com/document/api/1131/77477)
* [DescribeFirmwareTaskDistribution](https://cloud.tencent.com/document/api/1131/77476)
* [DescribeFirmwareTaskStatistics](https://cloud.tencent.com/document/api/1131/77475)
* [DescribeFirmwareTasks](https://cloud.tencent.com/document/api/1131/77474)
* [DescribeForwardRule](https://cloud.tencent.com/document/api/1131/77448)
* [DescribeModelDefinition](https://cloud.tencent.com/document/api/1131/77439)
* [DescribePackageConsumeTask](https://cloud.tencent.com/document/api/1131/77496)
* [DescribePackageConsumeTasks](https://cloud.tencent.com/document/api/1131/77495)
* [DescribeProduct](https://cloud.tencent.com/document/api/1131/77488)
* [DescribeProductDynamicRegister](https://cloud.tencent.com/document/api/1131/77487)
* [DescribeProducts](https://cloud.tencent.com/document/api/1131/77486)
* [DescribePushChannel](https://cloud.tencent.com/document/api/1131/77447)
* [DescribeSDKLog](https://cloud.tencent.com/document/api/1131/77456)
* [DescribeUser](https://cloud.tencent.com/document/api/1131/77432)
* [EditFirmware](https://cloud.tencent.com/document/api/1131/77473)
* [GenerateSignedVideoURL](https://cloud.tencent.com/document/api/1131/77494)
* [GetAllFirmwareVersion](https://cloud.tencent.com/document/api/1131/77472)
* [GetFirmwareURL](https://cloud.tencent.com/document/api/1131/77471)
* [ImportModelDefinition](https://cloud.tencent.com/document/api/1131/77438)
* [InheritCloudStorageUser](https://cloud.tencent.com/document/api/1131/77493)
* [ListFirmwares](https://cloud.tencent.com/document/api/1131/77470)
* [ModifyDataForward](https://cloud.tencent.com/document/api/1131/77446)
* [ModifyDataForwardStatus](https://cloud.tencent.com/document/api/1131/77445)
* [ModifyDevice](https://cloud.tencent.com/document/api/1131/77426)
* [ModifyDeviceLogLevel](https://cloud.tencent.com/document/api/1131/77455)
* [ModifyForwardRule](https://cloud.tencent.com/document/api/1131/77444)
* [ModifyModelDefinition](https://cloud.tencent.com/document/api/1131/77437)
* [ModifyProduct](https://cloud.tencent.com/document/api/1131/77485)
* [ModifyProductDynamicRegister](https://cloud.tencent.com/document/api/1131/77484)
* [ModifyPushChannel](https://cloud.tencent.com/document/api/1131/77443)
* [PublishMessage](https://cloud.tencent.com/document/api/1131/77425)
* [ReportAliveDevice](https://cloud.tencent.com/document/api/1131/77509)
* [ResetCloudStorage](https://cloud.tencent.com/document/api/1131/77492)
* [RetryDeviceFirmwareTask](https://cloud.tencent.com/document/api/1131/77469)
* [SetForwardAuth](https://cloud.tencent.com/document/api/1131/77442)
* [TransferCloudStorage](https://cloud.tencent.com/document/api/1131/77491)
* [UpdateAIModelChannel](https://cloud.tencent.com/document/api/1131/77508)
* [UploadFirmware](https://cloud.tencent.com/document/api/1131/77468)
* [WakeUpDevice](https://cloud.tencent.com/document/api/1131/77424)

新增数据结构：

* [AIModelApplication](https://cloud.tencent.com/document/api/1131/76635#AIModelApplication)
* [AIModelInfo](https://cloud.tencent.com/document/api/1131/76635#AIModelInfo)
* [AIModelUsageInfo](https://cloud.tencent.com/document/api/1131/76635#AIModelUsageInfo)
* [ActionHistory](https://cloud.tencent.com/document/api/1131/76635#ActionHistory)
* [BalanceTransaction](https://cloud.tencent.com/document/api/1131/76635#BalanceTransaction)
* [BonusInfo](https://cloud.tencent.com/document/api/1131/76635#BonusInfo)
* [CloudStorageEvent](https://cloud.tencent.com/document/api/1131/76635#CloudStorageEvent)
* [CloudStorageTimeData](https://cloud.tencent.com/document/api/1131/76635#CloudStorageTimeData)
* [CloudStorageTimeInfo](https://cloud.tencent.com/document/api/1131/76635#CloudStorageTimeInfo)
* [CloudStorageUserInfo](https://cloud.tencent.com/document/api/1131/76635#CloudStorageUserInfo)
* [DataForward](https://cloud.tencent.com/document/api/1131/76635#DataForward)
* [DeviceCommLogItem](https://cloud.tencent.com/document/api/1131/76635#DeviceCommLogItem)
* [DeviceDataHistoryItem](https://cloud.tencent.com/document/api/1131/76635#DeviceDataHistoryItem)
* [DeviceInfo](https://cloud.tencent.com/document/api/1131/76635#DeviceInfo)
* [DeviceStatusLogItem](https://cloud.tencent.com/document/api/1131/76635#DeviceStatusLogItem)
* [DeviceUpdateStatus](https://cloud.tencent.com/document/api/1131/76635#DeviceUpdateStatus)
* [EventHistoryItem](https://cloud.tencent.com/document/api/1131/76635#EventHistoryItem)
* [FirmwareInfo](https://cloud.tencent.com/document/api/1131/76635#FirmwareInfo)
* [FirmwareTaskInfo](https://cloud.tencent.com/document/api/1131/76635#FirmwareTaskInfo)
* [PackageConsumeStat](https://cloud.tencent.com/document/api/1131/76635#PackageConsumeStat)
* [PackageConsumeTask](https://cloud.tencent.com/document/api/1131/76635#PackageConsumeTask)
* [ProductModelDefinition](https://cloud.tencent.com/document/api/1131/76635#ProductModelDefinition)
* [ProductTemplate](https://cloud.tencent.com/document/api/1131/76635#ProductTemplate)
* [SDKLogItem](https://cloud.tencent.com/document/api/1131/76635#SDKLogItem)
* [SearchKeyword](https://cloud.tencent.com/document/api/1131/76635#SearchKeyword)
* [StatusStatistic](https://cloud.tencent.com/document/api/1131/76635#StatusStatistic)
* [VideoBatch](https://cloud.tencent.com/document/api/1131/76635#VideoBatch)

### 第 3 次发布

发布时间：2022-07-13 11:20:10

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateProduct](https://cloud.tencent.com/document/api/1131/77008)

新增数据结构：

* [VideoProduct](https://cloud.tencent.com/document/api/1131/76635#VideoProduct)

### 第 2 次发布

发布时间：2022-07-13 10:17:38

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [GenSingleDeviceSignatureOfPublic](https://cloud.tencent.com/document/api/1131/76866)

新增数据结构：

* [DeviceSignatureInfo](https://cloud.tencent.com/document/api/1131/76635#DeviceSignatureInfo)

### 第 1 次发布

发布时间：2022-07-07 20:28:12

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CallDeviceActionAsync](https://cloud.tencent.com/document/api/1131/76631)
* [CallDeviceActionSync](https://cloud.tencent.com/document/api/1131/76630)
* [DescribeDeviceDataStats](https://cloud.tencent.com/document/api/1131/76634)
* [DescribeMessageDataStats](https://cloud.tencent.com/document/api/1131/76633)

新增数据结构：

* [DeviceCntStats](https://cloud.tencent.com/document/api/1131/76635#DeviceCntStats)
* [MessageCntStats](https://cloud.tencent.com/document/api/1131/76635#MessageCntStats)




## 物联网智能视频服务（行业版）(iotvideoindustry) 版本：2020-12-01

### 第 18 次发布

发布时间：2023-04-26 01:30:49

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [RecordPlanItem](https://cloud.tencent.com/document/api/1361/53754#RecordPlanItem)

	* 新增成员：RecordStorageTime


### 第 17 次发布

发布时间：2022-01-17 10:23:19

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeChannelLiveStreamURL](https://cloud.tencent.com/document/api/1361/68272)

修改接口：

* [DescribeChannelLocalRecordURL](https://cloud.tencent.com/document/api/1361/67424)

	* 新增入参：ExpireTime


### 第 16 次发布

发布时间：2022-01-07 08:10:07

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeChannelStreamURL](https://cloud.tencent.com/document/api/1361/67426)

	* 新增入参：ExpireTime


### 第 15 次发布

发布时间：2022-01-06 08:11:12

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [ControlChannelLocalRecord](https://cloud.tencent.com/document/api/1361/67425)
* [ControlChannelPTZ](https://cloud.tencent.com/document/api/1361/67403)
* [ControlHomePosition](https://cloud.tencent.com/document/api/1361/67396)
* [ControlPreset](https://cloud.tencent.com/document/api/1361/67402)
* [CreateRecordingPlan](https://cloud.tencent.com/document/api/1361/68271)
* [DeleteRecordingPlan](https://cloud.tencent.com/document/api/1361/68268)
* [DeleteWarning](https://cloud.tencent.com/document/api/1361/67401)
* [DescribeAbnormalEvents](https://cloud.tencent.com/document/api/1361/67411)
* [DescribeBindSceneChannels](https://cloud.tencent.com/document/api/1361/67404)
* [DescribeChannelLocalRecordURL](https://cloud.tencent.com/document/api/1361/67424)
* [DescribeChannelStreamURL](https://cloud.tencent.com/document/api/1361/67426)
* [DescribeChannels](https://cloud.tencent.com/document/api/1361/67429)
* [DescribeCurrentDeviceData](https://cloud.tencent.com/document/api/1361/67410)
* [DescribeDevice](https://cloud.tencent.com/document/api/1361/67395)
* [DescribeDeviceEvent](https://cloud.tencent.com/document/api/1361/67409)
* [DescribeDeviceList](https://cloud.tencent.com/document/api/1361/68115)
* [DescribeDeviceMonitorData](https://cloud.tencent.com/document/api/1361/67408)
* [DescribeMonitorDataByDate](https://cloud.tencent.com/document/api/1361/67407)
* [DescribePresetList](https://cloud.tencent.com/document/api/1361/67400)
* [DescribeRecordDatesByChannel](https://cloud.tencent.com/document/api/1361/67423)
* [DescribeRecordingPlanById](https://cloud.tencent.com/document/api/1361/67419)
* [DescribeRecordingPlans](https://cloud.tencent.com/document/api/1361/67418)
* [DescribeScene](https://cloud.tencent.com/document/api/1361/67417)
* [DescribeVideoListByChannel](https://cloud.tencent.com/document/api/1361/67422)
* [DescribeWarnMod](https://cloud.tencent.com/document/api/1361/67399)
* [DescribeWarnings](https://cloud.tencent.com/document/api/1361/67398)
* [DescribeXP2PData](https://cloud.tencent.com/document/api/1361/67431)
* [ModifyBindRecordingPlan](https://cloud.tencent.com/document/api/1361/67416)
* [ModifyBindSceneChannels](https://cloud.tencent.com/document/api/1361/67415)
* [ModifyBindSceneDevice](https://cloud.tencent.com/document/api/1361/67414)
* [ModifyPreset](https://cloud.tencent.com/document/api/1361/67394)
* [ModifyRecordingPlan](https://cloud.tencent.com/document/api/1361/67413)
* [ModifyScene](https://cloud.tencent.com/document/api/1361/67412)
* [ResetWarning](https://cloud.tencent.com/document/api/1361/67397)

修改接口：

* [CreateScene](https://cloud.tencent.com/document/api/1361/65989)

	* 新增入参：Channels


新增数据结构：

* [AbnormalEvents](https://cloud.tencent.com/document/api/1361/53754#AbnormalEvents)
* [AbnormalEventsInfo](https://cloud.tencent.com/document/api/1361/53754#AbnormalEventsInfo)
* [ChannelDetail](https://cloud.tencent.com/document/api/1361/53754#ChannelDetail)
* [ChannelItem](https://cloud.tencent.com/document/api/1361/53754#ChannelItem)
* [DeviceMonitorValue](https://cloud.tencent.com/document/api/1361/53754#DeviceMonitorValue)
* [Events](https://cloud.tencent.com/document/api/1361/53754#Events)
* [PresetItem](https://cloud.tencent.com/document/api/1361/53754#PresetItem)
* [RecordPlanDetail](https://cloud.tencent.com/document/api/1361/53754#RecordPlanDetail)
* [RecordStatistic](https://cloud.tencent.com/document/api/1361/53754#RecordStatistic)
* [RecordStatisticValue](https://cloud.tencent.com/document/api/1361/53754#RecordStatisticValue)
* [WarningsData](https://cloud.tencent.com/document/api/1361/53754#WarningsData)

修改数据结构：

* [GroupDeviceItem](https://cloud.tencent.com/document/api/1361/53754#GroupDeviceItem)

	* 新增成员：CreateTime, ChannelNum, VideoChannelNum


### 第 14 次发布

发布时间：2021-12-16 08:10:46

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateMessageForward](https://cloud.tencent.com/document/api/1361/66081)
* [DeleteMessageForward](https://cloud.tencent.com/document/api/1361/66080)
* [DescribeMessageForward](https://cloud.tencent.com/document/api/1361/66079)
* [DescribeMessageForwards](https://cloud.tencent.com/document/api/1361/66082)
* [ModifyMessageForward](https://cloud.tencent.com/document/api/1361/66078)

新增数据结构：

* [MessageForward](https://cloud.tencent.com/document/api/1361/53754#MessageForward)

### 第 13 次发布

发布时间：2021-12-15 08:09:30

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateLiveChannel](https://cloud.tencent.com/document/api/1361/65979)
* [CreateLiveRecordPlan](https://cloud.tencent.com/document/api/1361/65972)
* [CreateScene](https://cloud.tencent.com/document/api/1361/65989)
* [DeleteChannel](https://cloud.tencent.com/document/api/1361/65961)
* [DeleteLiveChannel](https://cloud.tencent.com/document/api/1361/65978)
* [DeleteLiveRecordPlan](https://cloud.tencent.com/document/api/1361/65971)
* [DeleteLiveVideoList](https://cloud.tencent.com/document/api/1361/65984)
* [DeleteScene](https://cloud.tencent.com/document/api/1361/65988)
* [DeleteVideoList](https://cloud.tencent.com/document/api/1361/65987)
* [DescribeBindSceneDevices](https://cloud.tencent.com/document/api/1361/65970)
* [DescribeChannelsByLiveRecordPlan](https://cloud.tencent.com/document/api/1361/65969)
* [DescribeLiveChannel](https://cloud.tencent.com/document/api/1361/65977)
* [DescribeLiveChannelList](https://cloud.tencent.com/document/api/1361/65976)
* [DescribeLiveRecordPlanById](https://cloud.tencent.com/document/api/1361/65968)
* [DescribeLiveRecordPlanIds](https://cloud.tencent.com/document/api/1361/65967)
* [DescribeLiveStream](https://cloud.tencent.com/document/api/1361/65975)
* [DescribeLiveVideoList](https://cloud.tencent.com/document/api/1361/65983)
* [DescribeRecordDatesByLive](https://cloud.tencent.com/document/api/1361/65982)
* [DescribeScenes](https://cloud.tencent.com/document/api/1361/65986)
* [DescribeSubscriptionStatus](https://cloud.tencent.com/document/api/1361/65963)
* [ModifyBindPlanLiveChannel](https://cloud.tencent.com/document/api/1361/65966)
* [ModifyLiveChannel](https://cloud.tencent.com/document/api/1361/65974)
* [ModifyLiveRecordPlan](https://cloud.tencent.com/document/api/1361/65965)
* [ModifyLiveVideo](https://cloud.tencent.com/document/api/1361/65981)
* [ModifySubscriptionStatus](https://cloud.tencent.com/document/api/1361/65962)
* [ModifyVideoInfo](https://cloud.tencent.com/document/api/1361/65985)

新增数据结构：

* [LiveChannelInfo](https://cloud.tencent.com/document/api/1361/53754#LiveChannelInfo)
* [LiveChannelItem](https://cloud.tencent.com/document/api/1361/53754#LiveChannelItem)
* [LiveRecordItem](https://cloud.tencent.com/document/api/1361/53754#LiveRecordItem)
* [LiveRecordPlanItem](https://cloud.tencent.com/document/api/1361/53754#LiveRecordPlanItem)
* [SceneItem](https://cloud.tencent.com/document/api/1361/53754#SceneItem)
* [StreamAddress](https://cloud.tencent.com/document/api/1361/53754#StreamAddress)

### 第 12 次发布

发布时间：2021-12-03 08:08:18

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeStatisticSummary](https://cloud.tencent.com/document/api/1361/53727)

	* 新增出参：LivePushTotal

* [DescribeVideoList](https://cloud.tencent.com/document/api/1361/54757)

	* 新增入参：PlanId, SceneId, WarnId, RecordType


### 第 11 次发布

发布时间：2021-11-19 08:12:04

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [RecordTaskItem](https://cloud.tencent.com/document/api/1361/53754#RecordTaskItem)

	* 新增成员：SceneId, WarnId, RecordId


### 第 10 次发布

发布时间：2021-09-01 08:00:55

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeIPCChannels](https://cloud.tencent.com/document/api/1361/60994)

修改接口：

* [DescribeVideoList](https://cloud.tencent.com/document/api/1361/54757)

	* 新增入参：StartRecordTime, EndRecordTime, StartExpireTime, EndExpireTime, StartFileSize, EndFileSize, IsRecording, ChannelId

	* <font color="#dd0000">**修改入参**：</font>StartTime, EndTime


### 第 9 次发布

发布时间：2021-08-19 08:01:00

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [ControlRecordStream](https://cloud.tencent.com/document/api/1361/60440)

修改接口：

* [ControlDevicePTZ](https://cloud.tencent.com/document/api/1361/53725)

	* 新增入参：ChannelId

* [CreateRecordPlan](https://cloud.tencent.com/document/api/1361/53742)

	* 新增入参：RecordStorageTime

* [DescribeAllDeviceList](https://cloud.tencent.com/document/api/1361/53721)

	* 新增入参：DeviceTypes

* [DescribeDeviceStreams](https://cloud.tencent.com/document/api/1361/53744)

	* 新增入参：ChannelId

* [DescribeGroupDevices](https://cloud.tencent.com/document/api/1361/53748)

	* 新增入参：DeviceTypes

* [DescribeRecordStream](https://cloud.tencent.com/document/api/1361/54758)

	* 新增入参：ChannelId

* [DescribeStatisticSummary](https://cloud.tencent.com/document/api/1361/53727)

	* 新增出参：P2PFluxTotal, P2PPeakValue

* [GetRecordDatesByDev](https://cloud.tencent.com/document/api/1361/53738)

	* 新增入参：ChannelId, Type

* [GetVideoListByCon](https://cloud.tencent.com/document/api/1361/53732)

	* 新增入参：ChannelId, Type


修改数据结构：

* [AllDeviceInfo](https://cloud.tencent.com/document/api/1361/53754#AllDeviceInfo)

	* 新增成员：Protocol, GroupId, GroupName

* [DeviceItem](https://cloud.tencent.com/document/api/1361/53754#DeviceItem)

	* 新增成员：ChannelId

* [GroupDeviceItem](https://cloud.tencent.com/document/api/1361/53754#GroupDeviceItem)

	* 新增成员：Protocol


### 第 8 次发布

发布时间：2021-05-08 15:18:48

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateDevice](https://cloud.tencent.com/document/api/1361/53723)

	* 新增入参：DeviceType


### 第 7 次发布

发布时间：2021-04-21 08:00:08

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeVideoList](https://cloud.tencent.com/document/api/1361/54757)

	* 新增出参：RecordList


### 第 6 次发布

发布时间：2021-04-19 08:00:07

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeVideoList](https://cloud.tencent.com/document/api/1361/54757)

	* 新增入参：DeviceId


### 第 5 次发布

发布时间：2021-04-16 08:00:07

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeRecordStream](https://cloud.tencent.com/document/api/1361/54758)
* [DescribeVideoList](https://cloud.tencent.com/document/api/1361/54757)

新增数据结构：

* [DescribeRecordStreamData](https://cloud.tencent.com/document/api/1361/53754#DescribeRecordStreamData)

### 第 4 次发布

发布时间：2021-04-13 08:00:10

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [GroupInfo](https://cloud.tencent.com/document/api/1361/53754#GroupInfo)

	* 新增成员：Error


### 第 3 次发布

发布时间：2021-04-12 08:00:06

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateDevice](https://cloud.tencent.com/document/api/1361/53723)

	* 新增出参：VirtualGroupId

* [DescribeGroupDevices](https://cloud.tencent.com/document/api/1361/53748)

	* 新增入参：Recordable


修改数据结构：

* [AllDeviceInfo](https://cloud.tencent.com/document/api/1361/53754#AllDeviceInfo)

	* 新增成员：Recordable

* [GroupDeviceItem](https://cloud.tencent.com/document/api/1361/53754#GroupDeviceItem)

	* 新增成员：Recordable

* [GroupInfo](https://cloud.tencent.com/document/api/1361/53754#GroupInfo)

	* 新增成员：GroupStatus

* [GroupItem](https://cloud.tencent.com/document/api/1361/53754#GroupItem)

	* 新增成员：GroupStatus


### 第 2 次发布

发布时间：2021-03-23 08:00:09

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateRecordPlan](https://cloud.tencent.com/document/api/1361/53742)

	* 新增入参：EventId

* [UpdateRecordPlan](https://cloud.tencent.com/document/api/1361/53731)

	* 新增入参：EventId, IsModifyDevices


### 第 1 次发布

发布时间：2021-03-17 11:36:13

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [BindGroupDevices](https://cloud.tencent.com/document/api/1361/53753)
* [ControlDevicePTZ](https://cloud.tencent.com/document/api/1361/53725)
* [CreateDevice](https://cloud.tencent.com/document/api/1361/53723)
* [CreateDeviceGroup](https://cloud.tencent.com/document/api/1361/53752)
* [CreateRecordPlan](https://cloud.tencent.com/document/api/1361/53742)
* [CreateTimeTemplate](https://cloud.tencent.com/document/api/1361/53741)
* [DeleteDevice](https://cloud.tencent.com/document/api/1361/53722)
* [DeleteDeviceGroup](https://cloud.tencent.com/document/api/1361/53751)
* [DeleteRecordPlan](https://cloud.tencent.com/document/api/1361/53740)
* [DeleteTimeTemplate](https://cloud.tencent.com/document/api/1361/53739)
* [DescribeAllDeviceList](https://cloud.tencent.com/document/api/1361/53721)
* [DescribeDeviceGroup](https://cloud.tencent.com/document/api/1361/53720)
* [DescribeDevicePassWord](https://cloud.tencent.com/document/api/1361/53719)
* [DescribeDeviceStreams](https://cloud.tencent.com/document/api/1361/53744)
* [DescribeGroupById](https://cloud.tencent.com/document/api/1361/53750)
* [DescribeGroupByPath](https://cloud.tencent.com/document/api/1361/53749)
* [DescribeGroupDevices](https://cloud.tencent.com/document/api/1361/53748)
* [DescribeGroups](https://cloud.tencent.com/document/api/1361/53718)
* [DescribeSIPServer](https://cloud.tencent.com/document/api/1361/53717)
* [DescribeStatisticDetails](https://cloud.tencent.com/document/api/1361/53728)
* [DescribeStatisticSummary](https://cloud.tencent.com/document/api/1361/53727)
* [DescribeSubGroups](https://cloud.tencent.com/document/api/1361/53747)
* [GetRecordDatesByDev](https://cloud.tencent.com/document/api/1361/53738)
* [GetRecordPlanByDev](https://cloud.tencent.com/document/api/1361/53737)
* [GetRecordPlanById](https://cloud.tencent.com/document/api/1361/53736)
* [GetRecordPlans](https://cloud.tencent.com/document/api/1361/53735)
* [GetTimeTemplateById](https://cloud.tencent.com/document/api/1361/53734)
* [GetTimeTemplates](https://cloud.tencent.com/document/api/1361/53733)
* [GetVideoListByCon](https://cloud.tencent.com/document/api/1361/53732)
* [ModifyDeviceData](https://cloud.tencent.com/document/api/1361/53716)
* [UpdateDeviceGroup](https://cloud.tencent.com/document/api/1361/53746)
* [UpdateDevicePassWord](https://cloud.tencent.com/document/api/1361/53715)
* [UpdateRecordPlan](https://cloud.tencent.com/document/api/1361/53731)
* [UpdateTimeTemplate](https://cloud.tencent.com/document/api/1361/53730)

新增数据结构：

* [AllDeviceInfo](https://cloud.tencent.com/document/api/1361/53754#AllDeviceInfo)
* [DescribeDeviceStreamsData](https://cloud.tencent.com/document/api/1361/53754#DescribeDeviceStreamsData)
* [DevGroupInfo](https://cloud.tencent.com/document/api/1361/53754#DevGroupInfo)
* [DeviceItem](https://cloud.tencent.com/document/api/1361/53754#DeviceItem)
* [GroupDeviceItem](https://cloud.tencent.com/document/api/1361/53754#GroupDeviceItem)
* [GroupInfo](https://cloud.tencent.com/document/api/1361/53754#GroupInfo)
* [GroupItem](https://cloud.tencent.com/document/api/1361/53754#GroupItem)
* [RecordPlanItem](https://cloud.tencent.com/document/api/1361/53754#RecordPlanItem)
* [RecordTaskItem](https://cloud.tencent.com/document/api/1361/53754#RecordTaskItem)
* [ServerConfiguration](https://cloud.tencent.com/document/api/1361/53754#ServerConfiguration)
* [StatisticItem](https://cloud.tencent.com/document/api/1361/53754#StatisticItem)
* [TimeTemplateItem](https://cloud.tencent.com/document/api/1361/53754#TimeTemplateItem)
* [TimeTemplateSpec](https://cloud.tencent.com/document/api/1361/53754#TimeTemplateSpec)




## 智能推荐平台(irp) 版本：2022-03-24

### 第 1 次发布

发布时间：2022-07-11 16:20:35

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [RecommendContent](https://cloud.tencent.com/document/api/1541/76752)
* [ReportAction](https://cloud.tencent.com/document/api/1541/76751)
* [ReportMaterial](https://cloud.tencent.com/document/api/1541/76750)
* [ReportPortrait](https://cloud.tencent.com/document/api/1541/76749)

新增数据结构：

* [AuthorInfo](https://cloud.tencent.com/document/api/1541/76753#AuthorInfo)
* [DislikeInfo](https://cloud.tencent.com/document/api/1541/76753#DislikeInfo)
* [DocBehavior](https://cloud.tencent.com/document/api/1541/76753#DocBehavior)
* [DocItem](https://cloud.tencent.com/document/api/1541/76753#DocItem)
* [PortraitInfo](https://cloud.tencent.com/document/api/1541/76753#PortraitInfo)
* [RecItemData](https://cloud.tencent.com/document/api/1541/76753#RecItemData)
* [TagInfo](https://cloud.tencent.com/document/api/1541/76753#TagInfo)
* [UserIdInfo](https://cloud.tencent.com/document/api/1541/76753#UserIdInfo)



## 智能推荐平台(irp) 版本：2022-08-05

### 第 2 次发布

发布时间：2023-03-10 01:38:31

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeGoodsRecommend](https://cloud.tencent.com/document/api/1541/88106)
* [ReportGoodsBehavior](https://cloud.tencent.com/document/api/1541/88105)
* [ReportGoodsInfo](https://cloud.tencent.com/document/api/1541/88104)

新增数据结构：

* [GoodsBehaviorInfo](https://cloud.tencent.com/document/api/1541/78996#GoodsBehaviorInfo)
* [GoodsInfo](https://cloud.tencent.com/document/api/1541/78996#GoodsInfo)
* [RecGoodsData](https://cloud.tencent.com/document/api/1541/78996#RecGoodsData)
* [StrUserIdInfo](https://cloud.tencent.com/document/api/1541/78996#StrUserIdInfo)
* [UserPortraitInfo](https://cloud.tencent.com/document/api/1541/78996#UserPortraitInfo)

### 第 1 次发布

发布时间：2022-08-12 14:06:35

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [FeedRecommend](https://cloud.tencent.com/document/api/1541/78995)
* [ReportFeedBehavior](https://cloud.tencent.com/document/api/1541/78994)
* [ReportFeedItem](https://cloud.tencent.com/document/api/1541/78993)
* [ReportFeedUser](https://cloud.tencent.com/document/api/1541/78992)

新增数据结构：

* [DislikeInfo](https://cloud.tencent.com/document/api/1541/78996#DislikeInfo)
* [DocItem](https://cloud.tencent.com/document/api/1541/78996#DocItem)
* [FeedBehaviorInfo](https://cloud.tencent.com/document/api/1541/78996#FeedBehaviorInfo)
* [FeedUserInfo](https://cloud.tencent.com/document/api/1541/78996#FeedUserInfo)
* [RecItemData](https://cloud.tencent.com/document/api/1541/78996#RecItemData)
* [UserIdInfo](https://cloud.tencent.com/document/api/1541/78996#UserIdInfo)




## 智能视图计算平台(iss) 版本：2023-05-17

### 第 16 次发布

发布时间：2024-06-28 15:23:39

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [QueryForbidPlayChannelList](https://cloud.tencent.com/document/api/1344/107837)
* [SetForbidPlayChannels](https://cloud.tencent.com/document/api/1344/107836)

新增数据结构：

* [ChannelAttrInfo](https://cloud.tencent.com/document/api/1344/95952#ChannelAttrInfo)
* [ListForbidplayChannelsData](https://cloud.tencent.com/document/api/1344/95952#ListForbidplayChannelsData)
* [SetForbidplayChannelParam](https://cloud.tencent.com/document/api/1344/95952#SetForbidplayChannelParam)

### 第 15 次发布

发布时间：2024-05-09 01:17:57

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [DescribeDomainData](https://cloud.tencent.com/document/api/1344/95952#DescribeDomainData)

	* 新增成员：CertId


### 第 14 次发布

发布时间：2024-04-24 15:03:09

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [ControlDeviceStream](https://cloud.tencent.com/document/api/1344/95943)

	* 新增入参：IsInternal

* [DescribeRecordPlaybackUrl](https://cloud.tencent.com/document/api/1344/95933)

	* 新增入参：IsInternal

* [DescribeVideoDownloadUrl](https://cloud.tencent.com/document/api/1344/95932)

	* 新增入参：IsInternal

* [PlayRecord](https://cloud.tencent.com/document/api/1344/95931)

	* 新增入参：IsInternal


### 第 13 次发布

发布时间：2024-04-11 01:17:04

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [UpdateUserDevice](https://cloud.tencent.com/document/api/1344/95867)

	* 新增入参：AudioSwitch, SubscribeSwitch


修改数据结构：

* [DescribeDeviceData](https://cloud.tencent.com/document/api/1344/95952#DescribeDeviceData)

	* 新增成员：AudioSwitch, SubscribeSwitch


### 第 12 次发布

发布时间：2024-02-23 01:18:04

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [ListTasks](https://cloud.tencent.com/document/api/1344/97294)

	* 新增入参：BeginTime, EndTime


修改数据结构：

* [SubTaskData](https://cloud.tencent.com/document/api/1344/95952#SubTaskData)

	* 新增成员：DeviceId, DeviceName, ChannelId, ChannelName

* [TaskData](https://cloud.tencent.com/document/api/1344/95952#TaskData)

	* 新增成员：DeviceId, DeviceName, ChannelId, ChannelName


### 第 11 次发布

发布时间：2024-02-02 01:16:04

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [AddUserDevice](https://cloud.tencent.com/document/api/1344/95876)

	* 新增入参：SNCode


### 第 10 次发布

发布时间：2023-12-27 01:22:46

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [ListDevices](https://cloud.tencent.com/document/api/1344/95871)

	* 新增入参：IsContainUser


修改数据结构：

* [BaseAIResultInfo](https://cloud.tencent.com/document/api/1344/95952#BaseAIResultInfo)

	* <font color="#dd0000">**修改成员**：</font>Name, Score, Location

* [BodyAIResultInfo](https://cloud.tencent.com/document/api/1344/95952#BodyAIResultInfo)

	* <font color="#dd0000">**修改成员**：</font>Time, Url, BodyInfo

* [CarAIResultInfo](https://cloud.tencent.com/document/api/1344/95952#CarAIResultInfo)

	* <font color="#dd0000">**修改成员**：</font>Serial, Brand, Type, Color, Confidence, Year, PlateContent, Location

* [ChefClothAIResultInfo](https://cloud.tencent.com/document/api/1344/95952#ChefClothAIResultInfo)

	* <font color="#dd0000">**修改成员**：</font>Time, Url, ChefClothInfoInfo

* [ChefHatAIResultInfo](https://cloud.tencent.com/document/api/1344/95952#ChefHatAIResultInfo)

	* <font color="#dd0000">**修改成员**：</font>Time, Url, ChefHatInfo

* [DescribeGatewayMonitor](https://cloud.tencent.com/document/api/1344/95952#DescribeGatewayMonitor)

	* <font color="#dd0000">**修改成员**：</font>DeviceTotal, DeviceOnline, DeviceOffline, ChannelTotal, ChannelOnline, ChannelOffline, UpFlow, ChannelPull, ChannelUnPull

* [FaceMaskAIResultInfo](https://cloud.tencent.com/document/api/1344/95952#FaceMaskAIResultInfo)

	* <font color="#dd0000">**修改成员**：</font>Time, Url, FaceMaskInfo

* [GatewayVersion](https://cloud.tencent.com/document/api/1344/95952#GatewayVersion)

	* <font color="#dd0000">**修改成员**：</font>Name, Version

* [ListDeviceInfo](https://cloud.tencent.com/document/api/1344/95952#ListDeviceInfo)

	* <font color="#dd0000">**修改成员**：</font>DeviceId, Code, Status, TransportProtocol, Name, Type, Password, Description, ClusterId, ClusterName, AccessProtocol, OrganizationId, ChannelNum

* [Location](https://cloud.tencent.com/document/api/1344/95952#Location)

	* <font color="#dd0000">**修改成员**：</font>X, Y, Width, Height

* [PetAIResultInfo](https://cloud.tencent.com/document/api/1344/95952#PetAIResultInfo)

	* <font color="#dd0000">**修改成员**：</font>Time, Url, PetInfo

* [PhoneCallAIResultInfo](https://cloud.tencent.com/document/api/1344/95952#PhoneCallAIResultInfo)

	* <font color="#dd0000">**修改成员**：</font>Time, Url, PhoneCallInfo

* [PlateContent](https://cloud.tencent.com/document/api/1344/95952#PlateContent)

	* <font color="#dd0000">**修改成员**：</font>Plate, Color, Type, Location

* [RecordPlaybackUrl](https://cloud.tencent.com/document/api/1344/95952#RecordPlaybackUrl)

	* <font color="#dd0000">**修改成员**：</font>Hls

* [RecordTimeLine](https://cloud.tencent.com/document/api/1344/95952#RecordTimeLine)

	* <font color="#dd0000">**修改成员**：</font>Begin, End

* [SmokingAIResultInfo](https://cloud.tencent.com/document/api/1344/95952#SmokingAIResultInfo)

	* <font color="#dd0000">**修改成员**：</font>Time, Url, SmokingInfo


### 第 9 次发布

发布时间：2023-10-27 01:53:51

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [UpdateUserDevice](https://cloud.tencent.com/document/api/1344/95867)

	* 新增入参：ProtocolType


### 第 8 次发布

发布时间：2023-10-12 02:09:16

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeVideoBitRate](https://cloud.tencent.com/document/api/1344/100162)

新增数据结构：

* [BitRateInfo](https://cloud.tencent.com/document/api/1344/95952#BitRateInfo)
* [DescribeVideoBitRateList](https://cloud.tencent.com/document/api/1344/95952#DescribeVideoBitRateList)

### 第 7 次发布

发布时间：2023-09-19 17:35:39

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeRecordSlice](https://cloud.tencent.com/document/api/1344/98691)

新增数据结构：

* [RecordSliceInfo](https://cloud.tencent.com/document/api/1344/95952#RecordSliceInfo)

### 第 6 次发布

发布时间：2023-09-18 01:58:17

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [UpdateRecordBackupPlanModify](https://cloud.tencent.com/document/api/1344/95952#UpdateRecordBackupPlanModify)

	* <font color="#dd0000">**修改成员**：</font>Add, Del, OrganizationId


### 第 5 次发布

发布时间：2023-08-30 01:17:50

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [ListRecordBackupPlanDevices](https://cloud.tencent.com/document/api/1344/95921)

	* <font color="#dd0000">**修改入参**：</font>PageSize, PageNumber


修改数据结构：

* [ListRecordBackupPlanDevicesData](https://cloud.tencent.com/document/api/1344/95952#ListRecordBackupPlanDevicesData)

	* <font color="#dd0000">**修改成员**：</font>List


### 第 4 次发布

发布时间：2023-08-25 16:30:51

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [BatchOperateDevice](https://cloud.tencent.com/document/api/1344/97292)
* [DescribeTask](https://cloud.tencent.com/document/api/1344/97296)
* [ListSubTasks](https://cloud.tencent.com/document/api/1344/97295)
* [ListTasks](https://cloud.tencent.com/document/api/1344/97294)

修改接口：

* [ListGatewayDevices](https://cloud.tencent.com/document/api/1344/97279)

	* 新增入参：PageNumber, PageSize


新增数据结构：

* [BatchOperateDeviceData](https://cloud.tencent.com/document/api/1344/95952#BatchOperateDeviceData)
* [ListSubTasksData](https://cloud.tencent.com/document/api/1344/95952#ListSubTasksData)
* [ListTasksData](https://cloud.tencent.com/document/api/1344/95952#ListTasksData)
* [SubTaskData](https://cloud.tencent.com/document/api/1344/95952#SubTaskData)
* [TaskData](https://cloud.tencent.com/document/api/1344/95952#TaskData)

### 第 3 次发布

发布时间：2023-08-25 01:50:58

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [ListGatewayDevices](https://cloud.tencent.com/document/api/1344/97279)

新增数据结构：

* [GatewayDevice](https://cloud.tencent.com/document/api/1344/95952#GatewayDevice)
* [ListGatewayDevicesData](https://cloud.tencent.com/document/api/1344/95952#ListGatewayDevicesData)

### 第 2 次发布

发布时间：2023-08-07 15:48:42

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [AddOrganization](https://cloud.tencent.com/document/api/1344/95894)

	* <font color="#dd0000">**修改出参**：</font>Data

* [AddRecordBackupPlan](https://cloud.tencent.com/document/api/1344/95929)

	* 新增出参：Data, RequestId

	* <font color="#dd0000">**删除出参**：</font>PlanId, PlanName, TemplateId, Describe, LifeCycle, Status, ChannelCount, CreateAt, UpdateAt

* [AddRecordBackupTemplate](https://cloud.tencent.com/document/api/1344/95913)

	* 新增出参：Data, RequestId

	* <font color="#dd0000">**删除出参**：</font>TemplateId, TemplateName, TimeSections, DevTimeSections, Scale, CreateAt, UpdateAt

* [AddRecordPlan](https://cloud.tencent.com/document/api/1344/95928)

	* <font color="#dd0000">**修改出参**：</font>Data

* [AddRecordRetrieveTask](https://cloud.tencent.com/document/api/1344/95941)

	* 新增出参：Data, RequestId

	* <font color="#dd0000">**删除出参**：</font>TaskId, TaskName, StartTime, EndTime, Mode, Expiration, Status, Capacity, Describe

* [AddStreamAuth](https://cloud.tencent.com/document/api/1344/95902)

	* 新增出参：Data, RequestId

	* <font color="#dd0000">**删除出参**：</font>Id, PullState, PullSecret, PullExpired, PushState, PushSecret, PushExpired, AppId

* [AddUserDevice](https://cloud.tencent.com/document/api/1344/95876)

	* <font color="#dd0000">**修改出参**：</font>Data

* [ControlDeviceStream](https://cloud.tencent.com/document/api/1344/95943)

	* 新增出参：Data, RequestId

	* <font color="#dd0000">**删除出参**：</font>Flv, Hls, Rtmp

* [DescribeAITaskResult](https://cloud.tencent.com/document/api/1344/95948)

	* <font color="#dd0000">**修改出参**：</font>Data

* [DescribeDeviceChannel](https://cloud.tencent.com/document/api/1344/95874)

	* 新增出参：Data, RequestId

	* <font color="#dd0000">**删除出参**：</font>DeviceId, ChannelId, ChannelCode, Name, Status, PTZType, Manufacturer, Resolution, State, Region

* [DescribeDevicePreset](https://cloud.tencent.com/document/api/1344/95878)

	* 新增出参：Data, RequestId

	* <font color="#dd0000">**删除出参**：</font>Index, Name

* [DescribeDomain](https://cloud.tencent.com/document/api/1344/95898)

	* 新增出参：Data, RequestId

	* <font color="#dd0000">**删除出参**：</font>Id, PlayDomain, InternalDomain, HaveCert, ClusterId, ClusterName, AppId

* [DescribeDomainRegion](https://cloud.tencent.com/document/api/1344/95897)

	* 新增出参：Data, RequestId

	* <font color="#dd0000">**删除出参**：</font>Label, Value, Region

* [DescribeGateway](https://cloud.tencent.com/document/api/1344/95888)

	* 新增出参：Data, RequestId

	* <font color="#dd0000">**删除出参**：</font>GatewayId, GwId, Name, Description, ClusterId, ClusterName, Status, Version, DeviceNum, CreatedAt, Region

* [DescribeGatewayProtocol](https://cloud.tencent.com/document/api/1344/95886)

	* 新增出参：Data, RequestId

	* <font color="#dd0000">**删除出参**：</font>TypeCode, Value, Label

* [DescribeGatewayVersion](https://cloud.tencent.com/document/api/1344/95885)

	* 新增出参：Data, RequestId

	* <font color="#dd0000">**删除出参**：</font>Services

* [DescribeOrganization](https://cloud.tencent.com/document/api/1344/95892)

	* 新增出参：Data, RequestId

	* <font color="#dd0000">**删除出参**：</font>OrganizationId, Name, ParentId, Level, AppId, ParentIds, Total, Online

* [DescribeRecordBackupPlan](https://cloud.tencent.com/document/api/1344/95925)

	* 新增出参：Data, RequestId

	* <font color="#dd0000">**删除出参**：</font>PlanId, PlanName, TemplateId, Describe, LifeCycle, Status, ChannelCount, CreateAt, UpdateAt

* [DescribeRecordBackupTemplate](https://cloud.tencent.com/document/api/1344/95909)

	* 新增出参：Data, RequestId

	* <font color="#dd0000">**删除出参**：</font>TemplateId, TemplateName, TimeSections, DevTimeSections, Scale, CreateAt, UpdateAt

* [DescribeRecordFile](https://cloud.tencent.com/document/api/1344/95934)

	* 新增出参：Data, RequestId

	* <font color="#dd0000">**删除出参**：</font>Tips, List

* [DescribeRecordRetrieveTask](https://cloud.tencent.com/document/api/1344/95939)

	* 新增出参：Data, RequestId

	* <font color="#dd0000">**删除出参**：</font>TaskId, TaskName, StartTime, EndTime, Mode, Expiration, Status, Capacity, Channels, Describe, ChannelCount

* [DescribeStreamAuth](https://cloud.tencent.com/document/api/1344/95896)

	* 新增出参：Data, RequestId

	* <font color="#dd0000">**删除出参**：</font>Id, PullState, PullSecret, PullExpired, PushState, PushSecret, PushExpired, AppId

* [DescribeUserDevice](https://cloud.tencent.com/document/api/1344/95872)

	* <font color="#dd0000">**修改出参**：</font>Data

* [DescribeVideoDownloadUrl](https://cloud.tencent.com/document/api/1344/95932)

	* 新增出参：Data, RequestId

	* <font color="#dd0000">**删除出参**：</font>Url, ActualBeginTime, ActualEndTime

* [ListGateways](https://cloud.tencent.com/document/api/1344/95884)

	* 新增出参：Data, RequestId

	* <font color="#dd0000">**删除出参**：</font>List, TotalCount

* [ListOrganizationChannelNumbers](https://cloud.tencent.com/document/api/1344/95923)

	* 新增出参：Data, RequestId

	* <font color="#dd0000">**删除出参**：</font>TotalCount, NotInPlanCount

* [ListOrganizationChannels](https://cloud.tencent.com/document/api/1344/95922)

	* 新增出参：Data, RequestId

	* <font color="#dd0000">**删除出参**：</font>PageNumber, PageSize, TotalCount, List

* [ListRecordBackupPlanDevices](https://cloud.tencent.com/document/api/1344/95921)

	* 新增出参：Data, RequestId

	* <font color="#dd0000">**删除出参**：</font>PageNumber, PageSize, TotalCount, List

* [ListRecordBackupPlans](https://cloud.tencent.com/document/api/1344/95920)

	* <font color="#dd0000">**修改出参**：</font>Data

* [ListRecordBackupTemplates](https://cloud.tencent.com/document/api/1344/95907)

	* 新增出参：Data, RequestId

	* <font color="#dd0000">**删除出参**：</font>TemplateId, TemplateName, TimeSections, DevTimeSections, Scale, CreateAt, UpdateAt

* [ListRecordPlanChannels](https://cloud.tencent.com/document/api/1344/95919)

	* 新增出参：Data, RequestId

	* <font color="#dd0000">**删除出参**：</font>List

* [ListRecordPlanDevices](https://cloud.tencent.com/document/api/1344/95918)

	* 新增出参：Data, RequestId

	* <font color="#dd0000">**删除出参**：</font>PageNumber, PageSize, TotalCount, List

* [PlayRecord](https://cloud.tencent.com/document/api/1344/95931)

	* 新增出参：Data, RequestId

	* <font color="#dd0000">**删除出参**：</font>Flv

* [UpdateGateway](https://cloud.tencent.com/document/api/1344/95883)

	* 新增出参：Data, RequestId

	* <font color="#dd0000">**删除出参**：</font>GatewayId, GwId, Name, Description, ClusterId, ClusterName, Status, CreatedAt, Secret, Version

* [UpdateOrganization](https://cloud.tencent.com/document/api/1344/95891)

	* <font color="#dd0000">**修改出参**：</font>Data

* [UpdateRecordBackupPlan](https://cloud.tencent.com/document/api/1344/95916)

	* 新增出参：Data, RequestId

	* <font color="#dd0000">**删除出参**：</font>PlanId, PlanName, TemplateId, Describe, LifeCycle, Status, ChannelCount, CreateAt, UpdateAt

* [UpdateRecordBackupTemplate](https://cloud.tencent.com/document/api/1344/95905)

	* 新增出参：Data, RequestId

	* <font color="#dd0000">**删除出参**：</font>TemplateId, TemplateName, TimeSections, DevTimeSections, Scale, CreateAt, UpdateAt

* [UpdateRecordPlan](https://cloud.tencent.com/document/api/1344/95915)

	* <font color="#dd0000">**修改出参**：</font>Data

* [UpdateUserDevice](https://cloud.tencent.com/document/api/1344/95867)

	* <font color="#dd0000">**修改出参**：</font>Data


新增数据结构：

* [AITaskResultData](https://cloud.tencent.com/document/api/1344/95952#AITaskResultData)
* [AddDeviceData](https://cloud.tencent.com/document/api/1344/95952#AddDeviceData)
* [AddOrgData](https://cloud.tencent.com/document/api/1344/95952#AddOrgData)
* [AddRecordBackupPlanData](https://cloud.tencent.com/document/api/1344/95952#AddRecordBackupPlanData)
* [AddRecordBackupTemplateData](https://cloud.tencent.com/document/api/1344/95952#AddRecordBackupTemplateData)
* [AddRecordRetrieveTaskData](https://cloud.tencent.com/document/api/1344/95952#AddRecordRetrieveTaskData)
* [AddStreamAuthData](https://cloud.tencent.com/document/api/1344/95952#AddStreamAuthData)
* [ControlDeviceStreamData](https://cloud.tencent.com/document/api/1344/95952#ControlDeviceStreamData)
* [DescribeDeviceChannelData](https://cloud.tencent.com/document/api/1344/95952#DescribeDeviceChannelData)
* [DescribeDeviceData](https://cloud.tencent.com/document/api/1344/95952#DescribeDeviceData)
* [DescribeDevicePresetData](https://cloud.tencent.com/document/api/1344/95952#DescribeDevicePresetData)
* [DescribeDomainData](https://cloud.tencent.com/document/api/1344/95952#DescribeDomainData)
* [DescribeDomainRegionData](https://cloud.tencent.com/document/api/1344/95952#DescribeDomainRegionData)
* [DescribeGatewayData](https://cloud.tencent.com/document/api/1344/95952#DescribeGatewayData)
* [DescribeGatewayProtocolData](https://cloud.tencent.com/document/api/1344/95952#DescribeGatewayProtocolData)
* [DescribeGatewayVersionData](https://cloud.tencent.com/document/api/1344/95952#DescribeGatewayVersionData)
* [DescribeOrganizationData](https://cloud.tencent.com/document/api/1344/95952#DescribeOrganizationData)
* [DescribeRecordBackupPlanData](https://cloud.tencent.com/document/api/1344/95952#DescribeRecordBackupPlanData)
* [DescribeRecordBackupTemplateData](https://cloud.tencent.com/document/api/1344/95952#DescribeRecordBackupTemplateData)
* [DescribeRecordFileData](https://cloud.tencent.com/document/api/1344/95952#DescribeRecordFileData)
* [DescribeRecordRetrieveTaskData](https://cloud.tencent.com/document/api/1344/95952#DescribeRecordRetrieveTaskData)
* [DescribeStreamAuthData](https://cloud.tencent.com/document/api/1344/95952#DescribeStreamAuthData)
* [DescribeVideoDownloadUrlData](https://cloud.tencent.com/document/api/1344/95952#DescribeVideoDownloadUrlData)
* [ListGatewaysData](https://cloud.tencent.com/document/api/1344/95952#ListGatewaysData)
* [ListOrganizationChannelNumbersData](https://cloud.tencent.com/document/api/1344/95952#ListOrganizationChannelNumbersData)
* [ListOrganizationChannelsData](https://cloud.tencent.com/document/api/1344/95952#ListOrganizationChannelsData)
* [ListRecordBackupPlanData](https://cloud.tencent.com/document/api/1344/95952#ListRecordBackupPlanData)
* [ListRecordBackupPlanDevicesData](https://cloud.tencent.com/document/api/1344/95952#ListRecordBackupPlanDevicesData)
* [ListRecordBackupTemplatesData](https://cloud.tencent.com/document/api/1344/95952#ListRecordBackupTemplatesData)
* [ListRecordPlanChannelsData](https://cloud.tencent.com/document/api/1344/95952#ListRecordPlanChannelsData)
* [ListRecordPlanDevicesData](https://cloud.tencent.com/document/api/1344/95952#ListRecordPlanDevicesData)
* [PlayRecordData](https://cloud.tencent.com/document/api/1344/95952#PlayRecordData)
* [RecordPlanOptData](https://cloud.tencent.com/document/api/1344/95952#RecordPlanOptData)
* [UpdateDeviceData](https://cloud.tencent.com/document/api/1344/95952#UpdateDeviceData)
* [UpdateGatewayData](https://cloud.tencent.com/document/api/1344/95952#UpdateGatewayData)
* [UpdateOrgData](https://cloud.tencent.com/document/api/1344/95952#UpdateOrgData)
* [UpdateRecordBackupPlanData](https://cloud.tencent.com/document/api/1344/95952#UpdateRecordBackupPlanData)
* [UpdateRecordBackupTemplateData](https://cloud.tencent.com/document/api/1344/95952#UpdateRecordBackupTemplateData)

<font color="#dd0000">**删除数据结构**：</font>

* AITaskResultResponse
* AddDeviceResponse
* AddOrgResponse
* DescribeDeviceResponse
* ListRecordBackupPlanResponse
* RecordPlanOptResponse
* UpdateDeviceResponse
* UpdateOrgResponse

### 第 1 次发布

发布时间：2023-08-03 16:25:45

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [AddAITask](https://cloud.tencent.com/document/api/1344/95951)
* [AddOrganization](https://cloud.tencent.com/document/api/1344/95894)
* [AddRecordBackupPlan](https://cloud.tencent.com/document/api/1344/95929)
* [AddRecordBackupTemplate](https://cloud.tencent.com/document/api/1344/95913)
* [AddRecordPlan](https://cloud.tencent.com/document/api/1344/95928)
* [AddRecordRetrieveTask](https://cloud.tencent.com/document/api/1344/95941)
* [AddRecordTemplate](https://cloud.tencent.com/document/api/1344/95912)
* [AddStreamAuth](https://cloud.tencent.com/document/api/1344/95902)
* [AddUserDevice](https://cloud.tencent.com/document/api/1344/95876)
* [CheckDomain](https://cloud.tencent.com/document/api/1344/95901)
* [ControlDevicePTZ](https://cloud.tencent.com/document/api/1344/95880)
* [ControlDevicePreset](https://cloud.tencent.com/document/api/1344/95879)
* [ControlDeviceStream](https://cloud.tencent.com/document/api/1344/95943)
* [ControlRecord](https://cloud.tencent.com/document/api/1344/95936)
* [ControlRecordTimeline](https://cloud.tencent.com/document/api/1344/95935)
* [DeleteAITask](https://cloud.tencent.com/document/api/1344/95950)
* [DeleteDomain](https://cloud.tencent.com/document/api/1344/95900)
* [DeleteGateway](https://cloud.tencent.com/document/api/1344/95889)
* [DeleteOrganization](https://cloud.tencent.com/document/api/1344/95893)
* [DeleteRecordBackupPlan](https://cloud.tencent.com/document/api/1344/95927)
* [DeleteRecordBackupTemplate](https://cloud.tencent.com/document/api/1344/95911)
* [DeleteRecordPlan](https://cloud.tencent.com/document/api/1344/95926)
* [DeleteRecordRetrieveTask](https://cloud.tencent.com/document/api/1344/95940)
* [DeleteRecordTemplate](https://cloud.tencent.com/document/api/1344/95910)
* [DeleteUserDevice](https://cloud.tencent.com/document/api/1344/95875)
* [DescribeAITask](https://cloud.tencent.com/document/api/1344/95949)
* [DescribeAITaskResult](https://cloud.tencent.com/document/api/1344/95948)
* [DescribeCNAME](https://cloud.tencent.com/document/api/1344/95899)
* [DescribeDeviceChannel](https://cloud.tencent.com/document/api/1344/95874)
* [DescribeDevicePreset](https://cloud.tencent.com/document/api/1344/95878)
* [DescribeDeviceRegion](https://cloud.tencent.com/document/api/1344/95873)
* [DescribeDomain](https://cloud.tencent.com/document/api/1344/95898)
* [DescribeDomainRegion](https://cloud.tencent.com/document/api/1344/95897)
* [DescribeGateway](https://cloud.tencent.com/document/api/1344/95888)
* [DescribeGatewayMonitor](https://cloud.tencent.com/document/api/1344/95887)
* [DescribeGatewayProtocol](https://cloud.tencent.com/document/api/1344/95886)
* [DescribeGatewayVersion](https://cloud.tencent.com/document/api/1344/95885)
* [DescribeOrganization](https://cloud.tencent.com/document/api/1344/95892)
* [DescribeRecordBackupPlan](https://cloud.tencent.com/document/api/1344/95925)
* [DescribeRecordBackupTemplate](https://cloud.tencent.com/document/api/1344/95909)
* [DescribeRecordFile](https://cloud.tencent.com/document/api/1344/95934)
* [DescribeRecordPlan](https://cloud.tencent.com/document/api/1344/95924)
* [DescribeRecordPlaybackUrl](https://cloud.tencent.com/document/api/1344/95933)
* [DescribeRecordRetrieveTask](https://cloud.tencent.com/document/api/1344/95939)
* [DescribeRecordTemplate](https://cloud.tencent.com/document/api/1344/95908)
* [DescribeStreamAuth](https://cloud.tencent.com/document/api/1344/95896)
* [DescribeUserDevice](https://cloud.tencent.com/document/api/1344/95872)
* [DescribeVideoDownloadUrl](https://cloud.tencent.com/document/api/1344/95932)
* [ListAITasks](https://cloud.tencent.com/document/api/1344/95947)
* [ListDevices](https://cloud.tencent.com/document/api/1344/95871)
* [ListGateways](https://cloud.tencent.com/document/api/1344/95884)
* [ListOrganizationChannelNumbers](https://cloud.tencent.com/document/api/1344/95923)
* [ListOrganizationChannels](https://cloud.tencent.com/document/api/1344/95922)
* [ListRecordBackupPlanDevices](https://cloud.tencent.com/document/api/1344/95921)
* [ListRecordBackupPlans](https://cloud.tencent.com/document/api/1344/95920)
* [ListRecordBackupTemplates](https://cloud.tencent.com/document/api/1344/95907)
* [ListRecordPlanChannels](https://cloud.tencent.com/document/api/1344/95919)
* [ListRecordPlanDevices](https://cloud.tencent.com/document/api/1344/95918)
* [ListRecordPlans](https://cloud.tencent.com/document/api/1344/95917)
* [ListRecordRetrieveTasks](https://cloud.tencent.com/document/api/1344/95938)
* [ListRecordTemplates](https://cloud.tencent.com/document/api/1344/95906)
* [PlayRecord](https://cloud.tencent.com/document/api/1344/95931)
* [RefreshDeviceChannel](https://cloud.tencent.com/document/api/1344/95870)
* [UpdateAITask](https://cloud.tencent.com/document/api/1344/95946)
* [UpdateAITaskStatus](https://cloud.tencent.com/document/api/1344/95945)
* [UpdateDeviceOrganization](https://cloud.tencent.com/document/api/1344/95869)
* [UpdateDeviceStatus](https://cloud.tencent.com/document/api/1344/95868)
* [UpdateGateway](https://cloud.tencent.com/document/api/1344/95883)
* [UpdateOrganization](https://cloud.tencent.com/document/api/1344/95891)
* [UpdateRecordBackupPlan](https://cloud.tencent.com/document/api/1344/95916)
* [UpdateRecordBackupTemplate](https://cloud.tencent.com/document/api/1344/95905)
* [UpdateRecordPlan](https://cloud.tencent.com/document/api/1344/95915)
* [UpdateRecordTemplate](https://cloud.tencent.com/document/api/1344/95904)
* [UpdateUserDevice](https://cloud.tencent.com/document/api/1344/95867)
* [UpgradeGateway](https://cloud.tencent.com/document/api/1344/95882)

新增数据结构：

* [AIConfig](https://cloud.tencent.com/document/api/1344/95952#AIConfig)
* [AITaskInfo](https://cloud.tencent.com/document/api/1344/95952#AITaskInfo)
* [AITaskResultInfo](https://cloud.tencent.com/document/api/1344/95952#AITaskResultInfo)
* [AITaskResultResponse](https://cloud.tencent.com/document/api/1344/95952#AITaskResultResponse)
* [AITemplates](https://cloud.tencent.com/document/api/1344/95952#AITemplates)
* [AddDeviceResponse](https://cloud.tencent.com/document/api/1344/95952#AddDeviceResponse)
* [AddOrgResponse](https://cloud.tencent.com/document/api/1344/95952#AddOrgResponse)
* [BaseAIResultInfo](https://cloud.tencent.com/document/api/1344/95952#BaseAIResultInfo)
* [BodyAIResultInfo](https://cloud.tencent.com/document/api/1344/95952#BodyAIResultInfo)
* [CarAIResultInfo](https://cloud.tencent.com/document/api/1344/95952#CarAIResultInfo)
* [ChannelInfo](https://cloud.tencent.com/document/api/1344/95952#ChannelInfo)
* [ChefClothAIResultInfo](https://cloud.tencent.com/document/api/1344/95952#ChefClothAIResultInfo)
* [ChefHatAIResultInfo](https://cloud.tencent.com/document/api/1344/95952#ChefHatAIResultInfo)
* [DescribeDeviceRegion](https://cloud.tencent.com/document/api/1344/95952#DescribeDeviceRegion)
* [DescribeDeviceResponse](https://cloud.tencent.com/document/api/1344/95952#DescribeDeviceResponse)
* [DescribeGatewayMonitor](https://cloud.tencent.com/document/api/1344/95952#DescribeGatewayMonitor)
* [DescribeGatewayVersion](https://cloud.tencent.com/document/api/1344/95952#DescribeGatewayVersion)
* [FaceMaskAIResultInfo](https://cloud.tencent.com/document/api/1344/95952#FaceMaskAIResultInfo)
* [GatewayVersion](https://cloud.tencent.com/document/api/1344/95952#GatewayVersion)
* [GatewaysData](https://cloud.tencent.com/document/api/1344/95952#GatewaysData)
* [LifeCycleData](https://cloud.tencent.com/document/api/1344/95952#LifeCycleData)
* [ListAITaskData](https://cloud.tencent.com/document/api/1344/95952#ListAITaskData)
* [ListDeviceInfo](https://cloud.tencent.com/document/api/1344/95952#ListDeviceInfo)
* [ListRecordBackupPlanResponse](https://cloud.tencent.com/document/api/1344/95952#ListRecordBackupPlanResponse)
* [Location](https://cloud.tencent.com/document/api/1344/95952#Location)
* [OperTimeSlot](https://cloud.tencent.com/document/api/1344/95952#OperTimeSlot)
* [OrganizationChannelInfo](https://cloud.tencent.com/document/api/1344/95952#OrganizationChannelInfo)
* [PetAIResultInfo](https://cloud.tencent.com/document/api/1344/95952#PetAIResultInfo)
* [PhoneCallAIResultInfo](https://cloud.tencent.com/document/api/1344/95952#PhoneCallAIResultInfo)
* [PlateContent](https://cloud.tencent.com/document/api/1344/95952#PlateContent)
* [RecordPlanBaseInfo](https://cloud.tencent.com/document/api/1344/95952#RecordPlanBaseInfo)
* [RecordPlanChannelInfo](https://cloud.tencent.com/document/api/1344/95952#RecordPlanChannelInfo)
* [RecordPlanOptResponse](https://cloud.tencent.com/document/api/1344/95952#RecordPlanOptResponse)
* [RecordPlaybackUrl](https://cloud.tencent.com/document/api/1344/95952#RecordPlaybackUrl)
* [RecordRetrieveTaskChannelInfo](https://cloud.tencent.com/document/api/1344/95952#RecordRetrieveTaskChannelInfo)
* [RecordRetrieveTaskDetailsInfo](https://cloud.tencent.com/document/api/1344/95952#RecordRetrieveTaskDetailsInfo)
* [RecordTemplateInfo](https://cloud.tencent.com/document/api/1344/95952#RecordTemplateInfo)
* [RecordTemplateTimeSections](https://cloud.tencent.com/document/api/1344/95952#RecordTemplateTimeSections)
* [RecordTimeLine](https://cloud.tencent.com/document/api/1344/95952#RecordTimeLine)
* [SmokingAIResultInfo](https://cloud.tencent.com/document/api/1344/95952#SmokingAIResultInfo)
* [SnapshotConfig](https://cloud.tencent.com/document/api/1344/95952#SnapshotConfig)
* [Timeline](https://cloud.tencent.com/document/api/1344/95952#Timeline)
* [UpdateDeviceResponse](https://cloud.tencent.com/document/api/1344/95952#UpdateDeviceResponse)
* [UpdateOrgResponse](https://cloud.tencent.com/document/api/1344/95952#UpdateOrgResponse)
* [UpdateRecordBackupPlanModify](https://cloud.tencent.com/document/api/1344/95952#UpdateRecordBackupPlanModify)
* [UpdateRecordBackupTemplateModify](https://cloud.tencent.com/document/api/1344/95952#UpdateRecordBackupTemplateModify)
* [UpdateRecordPlanData](https://cloud.tencent.com/document/api/1344/95952#UpdateRecordPlanData)
* [UpdateRecordTemplateData](https://cloud.tencent.com/document/api/1344/95952#UpdateRecordTemplateData)




## 媒体智能标签(ivld) 版本：2021-09-03

### 第 9 次发布

发布时间：2024-07-09 14:27:21

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateVideoSummaryTask](https://cloud.tencent.com/document/api/1509/108448)
* [DescribeUsageAmount](https://cloud.tencent.com/document/api/1509/108447)
* [DescribeVideoSummaryDetail](https://cloud.tencent.com/document/api/1509/108446)

新增数据结构：

* [AsrResult](https://cloud.tencent.com/document/api/1509/65063#AsrResult)
* [ShotInfo](https://cloud.tencent.com/document/api/1509/65063#ShotInfo)
* [TTSMode](https://cloud.tencent.com/document/api/1509/65063#TTSMode)
* [TextSegMatchShotScore](https://cloud.tencent.com/document/api/1509/65063#TextSegMatchShotScore)
* [VideoRotationMode](https://cloud.tencent.com/document/api/1509/65063#VideoRotationMode)

### 第 8 次发布

发布时间：2022-10-25 19:11:18

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [PersonInfo](https://cloud.tencent.com/document/api/1509/65063#PersonInfo)

	* 新增成员：AppearRect


### 第 7 次发布

发布时间：2022-09-20 19:36:34

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeTaskDetail](https://cloud.tencent.com/document/api/1509/65055)

	* 新增出参：ImageTaskData, AudioTaskData, TextTaskData

* [ImportMedia](https://cloud.tencent.com/document/api/1509/65059)

	* 新增入参：MediaType


新增数据结构：

* [AudioData](https://cloud.tencent.com/document/api/1509/65063#AudioData)
* [AudioMetadata](https://cloud.tencent.com/document/api/1509/65063#AudioMetadata)
* [ImageData](https://cloud.tencent.com/document/api/1509/65063#ImageData)
* [ImageLogo](https://cloud.tencent.com/document/api/1509/65063#ImageLogo)
* [ImageMetadata](https://cloud.tencent.com/document/api/1509/65063#ImageMetadata)
* [ImageOcr](https://cloud.tencent.com/document/api/1509/65063#ImageOcr)
* [MultiLevelPersonInfo](https://cloud.tencent.com/document/api/1509/65063#MultiLevelPersonInfo)
* [Rectf](https://cloud.tencent.com/document/api/1509/65063#Rectf)
* [TextData](https://cloud.tencent.com/document/api/1509/65063#TextData)
* [TextMetadata](https://cloud.tencent.com/document/api/1509/65063#TextMetadata)
* [UnknownPerson](https://cloud.tencent.com/document/api/1509/65063#UnknownPerson)

修改数据结构：

* [MediaFilter](https://cloud.tencent.com/document/api/1509/65063#MediaFilter)

	* 新增成员：MediaType

* [MediaInfo](https://cloud.tencent.com/document/api/1509/65063#MediaInfo)

	* 新增成员：MediaType, AudioMetadata, ImageMetadata, TextMetadata

* [ShowInfo](https://cloud.tencent.com/document/api/1509/65063#ShowInfo)

	* 新增成员：UnknownPersonSet, MultiLevelPersonInfoSet

* [TaskInfo](https://cloud.tencent.com/document/api/1509/65063#TaskInfo)

	* 新增成员：AudioMetadata, ImageMetadata, TextMetadata, Metadata


### 第 6 次发布

发布时间：2022-04-24 15:20:20

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [MediaInfo](https://cloud.tencent.com/document/api/1509/65063#MediaInfo)

	* 新增成员：CallbackURL

* [TaskInfo](https://cloud.tencent.com/document/api/1509/65063#TaskInfo)

	* 新增成员：CallbackURL


### 第 5 次发布

发布时间：2022-03-07 10:30:32

本次发布包含了以下内容：

改善已有的文档。

新增数据结构：

* [ClassifiedPersonInfo](https://cloud.tencent.com/document/api/1509/65063#ClassifiedPersonInfo)
* [PersonInfo](https://cloud.tencent.com/document/api/1509/65063#PersonInfo)

修改数据结构：

* [ShowInfo](https://cloud.tencent.com/document/api/1509/65063#ShowInfo)

	* 新增成员：ClassifiedPersonInfoSet


### 第 4 次发布

发布时间：2022-03-02 12:16:47

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DeleteTask](https://cloud.tencent.com/document/api/1509/70513)
* [ModifyCallback](https://cloud.tencent.com/document/api/1509/70512)
* [QueryCallback](https://cloud.tencent.com/document/api/1509/70511)

修改接口：

* [CreateTask](https://cloud.tencent.com/document/api/1509/65057)

	* 新增入参：Label, CallbackURL

* [ImportMedia](https://cloud.tencent.com/document/api/1509/65059)

	* 新增入参：WriteBackCosPath, Label, CallbackURL


修改数据结构：

* [MediaFilter](https://cloud.tencent.com/document/api/1509/65063#MediaFilter)

	* 新增成员：LabelSet

* [MediaInfo](https://cloud.tencent.com/document/api/1509/65063#MediaInfo)

	* 新增成员：Label

* [TaskFilter](https://cloud.tencent.com/document/api/1509/65063#TaskFilter)

	* 新增成员：LabelSet

* [TaskInfo](https://cloud.tencent.com/document/api/1509/65063#TaskInfo)

	* 新增成员：Label


### 第 3 次发布

发布时间：2022-02-16 08:08:24

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [CustomPersonInfo](https://cloud.tencent.com/document/api/1509/65063#CustomPersonInfo)

	* 新增成员：ImageInfoSet, CreateTime


### 第 2 次发布

发布时间：2022-01-25 16:20:40

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [AddCustomPersonImage](https://cloud.tencent.com/document/api/1509/68841)
* [CreateCustomCategory](https://cloud.tencent.com/document/api/1509/68840)
* [CreateCustomGroup](https://cloud.tencent.com/document/api/1509/68839)
* [CreateCustomPerson](https://cloud.tencent.com/document/api/1509/68838)
* [CreateDefaultCategories](https://cloud.tencent.com/document/api/1509/68837)
* [DeleteCustomCategory](https://cloud.tencent.com/document/api/1509/68836)
* [DeleteCustomPerson](https://cloud.tencent.com/document/api/1509/68835)
* [DeleteCustomPersonImage](https://cloud.tencent.com/document/api/1509/68834)
* [DescribeCustomCategories](https://cloud.tencent.com/document/api/1509/68833)
* [DescribeCustomGroup](https://cloud.tencent.com/document/api/1509/68832)
* [DescribeCustomPersonDetail](https://cloud.tencent.com/document/api/1509/68831)
* [DescribeCustomPersons](https://cloud.tencent.com/document/api/1509/68830)
* [UpdateCustomCategory](https://cloud.tencent.com/document/api/1509/68829)
* [UpdateCustomPerson](https://cloud.tencent.com/document/api/1509/68828)

新增数据结构：

* [CustomCategory](https://cloud.tencent.com/document/api/1509/65063#CustomCategory)
* [CustomPersonFilter](https://cloud.tencent.com/document/api/1509/65063#CustomPersonFilter)
* [CustomPersonInfo](https://cloud.tencent.com/document/api/1509/65063#CustomPersonInfo)
* [PersonImageInfo](https://cloud.tencent.com/document/api/1509/65063#PersonImageInfo)

### 第 1 次发布

发布时间：2021-11-30 14:02:22

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateTask](https://cloud.tencent.com/document/api/1509/65057)
* [DeleteMedia](https://cloud.tencent.com/document/api/1509/65062)
* [DescribeMedia](https://cloud.tencent.com/document/api/1509/65061)
* [DescribeMedias](https://cloud.tencent.com/document/api/1509/65060)
* [DescribeTask](https://cloud.tencent.com/document/api/1509/65056)
* [DescribeTaskDetail](https://cloud.tencent.com/document/api/1509/65055)
* [DescribeTasks](https://cloud.tencent.com/document/api/1509/65054)
* [ImportMedia](https://cloud.tencent.com/document/api/1509/65059)

新增数据结构：

* [AppearIndexPair](https://cloud.tencent.com/document/api/1509/65063#AppearIndexPair)
* [AppearInfo](https://cloud.tencent.com/document/api/1509/65063#AppearInfo)
* [AudioInfo](https://cloud.tencent.com/document/api/1509/65063#AudioInfo)
* [Data](https://cloud.tencent.com/document/api/1509/65063#Data)
* [L1Tag](https://cloud.tencent.com/document/api/1509/65063#L1Tag)
* [L2Tag](https://cloud.tencent.com/document/api/1509/65063#L2Tag)
* [L3Tag](https://cloud.tencent.com/document/api/1509/65063#L3Tag)
* [MediaFilter](https://cloud.tencent.com/document/api/1509/65063#MediaFilter)
* [MediaInfo](https://cloud.tencent.com/document/api/1509/65063#MediaInfo)
* [MediaMetadata](https://cloud.tencent.com/document/api/1509/65063#MediaMetadata)
* [MediaPreknownInfo](https://cloud.tencent.com/document/api/1509/65063#MediaPreknownInfo)
* [MultiLevelTag](https://cloud.tencent.com/document/api/1509/65063#MultiLevelTag)
* [ShowInfo](https://cloud.tencent.com/document/api/1509/65063#ShowInfo)
* [SortBy](https://cloud.tencent.com/document/api/1509/65063#SortBy)
* [TaskFilter](https://cloud.tencent.com/document/api/1509/65063#TaskFilter)
* [TaskInfo](https://cloud.tencent.com/document/api/1509/65063#TaskInfo)
* [TextAppearInfo](https://cloud.tencent.com/document/api/1509/65063#TextAppearInfo)
* [TextInfo](https://cloud.tencent.com/document/api/1509/65063#TextInfo)
* [VideoAppearInfo](https://cloud.tencent.com/document/api/1509/65063#VideoAppearInfo)




## 云数据库 KeeWiDB(keewidb) 版本：2022-03-08

### 第 5 次发布

发布时间：2023-11-30 04:52:16

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeConnectionConfig](https://cloud.tencent.com/document/api/1520/90457)

	* 新增出参：ClientLimitMin, ClientLimitMax

* [ModifyNetworkConfig](https://cloud.tencent.com/document/api/1520/86194)

	* 新增出参：TaskId


### 第 4 次发布

发布时间：2023-07-19 01:29:34

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateInstances](https://cloud.tencent.com/document/api/1520/86207)

	* 新增入参：Compression

	* <font color="#dd0000">**修改入参**：</font>MachineCpu


### 第 3 次发布

发布时间：2023-04-24 01:28:29

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeConnectionConfig](https://cloud.tencent.com/document/api/1520/90457)

### 第 2 次发布

发布时间：2023-03-15 01:45:20

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeInstanceDealDetail](https://cloud.tencent.com/document/api/1520/88647)

新增数据结构：

* [TradeDealDetail](https://cloud.tencent.com/document/api/1520/86230#TradeDealDetail)

### 第 1 次发布

发布时间：2023-02-07 16:41:11

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [AssociateSecurityGroups](https://cloud.tencent.com/document/api/1520/86215)
* [ChangeInstanceMaster](https://cloud.tencent.com/document/api/1520/86229)
* [CleanUpInstance](https://cloud.tencent.com/document/api/1520/86209)
* [ClearInstance](https://cloud.tencent.com/document/api/1520/86208)
* [CreateBackupManually](https://cloud.tencent.com/document/api/1520/86221)
* [CreateInstances](https://cloud.tencent.com/document/api/1520/86207)
* [DescribeAutoBackupConfig](https://cloud.tencent.com/document/api/1520/86220)
* [DescribeDBSecurityGroups](https://cloud.tencent.com/document/api/1520/86214)
* [DescribeInstanceBackups](https://cloud.tencent.com/document/api/1520/86219)
* [DescribeInstanceBinlogs](https://cloud.tencent.com/document/api/1520/86218)
* [DescribeInstanceNodeInfo](https://cloud.tencent.com/document/api/1520/86206)
* [DescribeInstanceParamRecords](https://cloud.tencent.com/document/api/1520/86228)
* [DescribeInstanceParams](https://cloud.tencent.com/document/api/1520/86227)
* [DescribeInstanceReplicas](https://cloud.tencent.com/document/api/1520/86226)
* [DescribeInstances](https://cloud.tencent.com/document/api/1520/86205)
* [DescribeMaintenanceWindow](https://cloud.tencent.com/document/api/1520/86204)
* [DescribeProductInfo](https://cloud.tencent.com/document/api/1520/86223)
* [DescribeProjectSecurityGroups](https://cloud.tencent.com/document/api/1520/86213)
* [DescribeProxySlowLog](https://cloud.tencent.com/document/api/1520/86203)
* [DescribeTaskInfo](https://cloud.tencent.com/document/api/1520/86202)
* [DescribeTaskList](https://cloud.tencent.com/document/api/1520/86201)
* [DescribeTendisSlowLog](https://cloud.tencent.com/document/api/1520/86200)
* [DestroyPostpaidInstance](https://cloud.tencent.com/document/api/1520/86199)
* [DestroyPrepaidInstance](https://cloud.tencent.com/document/api/1520/86198)
* [DisassociateSecurityGroups](https://cloud.tencent.com/document/api/1520/86212)
* [ModifyAutoBackupConfig](https://cloud.tencent.com/document/api/1520/86217)
* [ModifyConnectionConfig](https://cloud.tencent.com/document/api/1520/86197)
* [ModifyDBInstanceSecurityGroups](https://cloud.tencent.com/document/api/1520/86211)
* [ModifyInstance](https://cloud.tencent.com/document/api/1520/86196)
* [ModifyInstanceParams](https://cloud.tencent.com/document/api/1520/86225)
* [ModifyMaintenanceWindow](https://cloud.tencent.com/document/api/1520/86195)
* [ModifyNetworkConfig](https://cloud.tencent.com/document/api/1520/86194)
* [RenewInstance](https://cloud.tencent.com/document/api/1520/86193)
* [ResetPassword](https://cloud.tencent.com/document/api/1520/86192)
* [StartUpInstance](https://cloud.tencent.com/document/api/1520/86191)
* [UpgradeInstance](https://cloud.tencent.com/document/api/1520/86190)

新增数据结构：

* [BackupInfo](https://cloud.tencent.com/document/api/1520/86230#BackupInfo)
* [BinlogInfo](https://cloud.tencent.com/document/api/1520/86230#BinlogInfo)
* [Inbound](https://cloud.tencent.com/document/api/1520/86230#Inbound)
* [InstanceEnumParam](https://cloud.tencent.com/document/api/1520/86230#InstanceEnumParam)
* [InstanceInfo](https://cloud.tencent.com/document/api/1520/86230#InstanceInfo)
* [InstanceIntegerParam](https://cloud.tencent.com/document/api/1520/86230#InstanceIntegerParam)
* [InstanceMultiParam](https://cloud.tencent.com/document/api/1520/86230#InstanceMultiParam)
* [InstanceNodeInfo](https://cloud.tencent.com/document/api/1520/86230#InstanceNodeInfo)
* [InstanceParam](https://cloud.tencent.com/document/api/1520/86230#InstanceParam)
* [InstanceParamHistory](https://cloud.tencent.com/document/api/1520/86230#InstanceParamHistory)
* [InstanceProxySlowlogDetail](https://cloud.tencent.com/document/api/1520/86230#InstanceProxySlowlogDetail)
* [InstanceTagInfo](https://cloud.tencent.com/document/api/1520/86230#InstanceTagInfo)
* [InstanceTextParam](https://cloud.tencent.com/document/api/1520/86230#InstanceTextParam)
* [KeeWiDBNode](https://cloud.tencent.com/document/api/1520/86230#KeeWiDBNode)
* [NodeInfo](https://cloud.tencent.com/document/api/1520/86230#NodeInfo)
* [Outbound](https://cloud.tencent.com/document/api/1520/86230#Outbound)
* [ProductConf](https://cloud.tencent.com/document/api/1520/86230#ProductConf)
* [ProxyNodeInfo](https://cloud.tencent.com/document/api/1520/86230#ProxyNodeInfo)
* [RedisNodeInfo](https://cloud.tencent.com/document/api/1520/86230#RedisNodeInfo)
* [RegionConf](https://cloud.tencent.com/document/api/1520/86230#RegionConf)
* [ReplicaGroup](https://cloud.tencent.com/document/api/1520/86230#ReplicaGroup)
* [ResourceTag](https://cloud.tencent.com/document/api/1520/86230#ResourceTag)
* [SecurityGroup](https://cloud.tencent.com/document/api/1520/86230#SecurityGroup)
* [TaskInfoDetail](https://cloud.tencent.com/document/api/1520/86230#TaskInfoDetail)
* [TendisSlowLogDetail](https://cloud.tencent.com/document/api/1520/86230#TendisSlowLogDetail)
* [ZoneCapacityConf](https://cloud.tencent.com/document/api/1520/86230#ZoneCapacityConf)




## 密钥管理系统(kms) 版本：2019-01-18

### 第 20 次发布

发布时间：2023-04-28 01:28:18

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [PostQuantumCryptoDecrypt](https://cloud.tencent.com/document/api/573/90742)
* [PostQuantumCryptoEncrypt](https://cloud.tencent.com/document/api/573/90741)
* [PostQuantumCryptoSign](https://cloud.tencent.com/document/api/573/90740)
* [PostQuantumCryptoVerify](https://cloud.tencent.com/document/api/573/90739)

### 第 19 次发布

发布时间：2023-03-03 01:26:52

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [GetServiceStatus](https://cloud.tencent.com/document/api/573/34417)

	* 新增出参：SubscriptionInfo


### 第 18 次发布

发布时间：2022-12-13 10:37:12

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [EnableKeyRotation](https://cloud.tencent.com/document/api/573/34422)

	* 新增入参：RotateDays


### 第 17 次发布

发布时间：2022-05-31 06:13:25

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateKey](https://cloud.tencent.com/document/api/573/34430)

	* 新增入参：HsmClusterId

	* 新增出参：HsmClusterId

* [GetServiceStatus](https://cloud.tencent.com/document/api/573/34417)

	* 新增出参：ExclusiveVSMEnabled, ExclusiveHSMEnabled

* [ListKeyDetail](https://cloud.tencent.com/document/api/573/34416)

	* 新增入参：HsmClusterId

* [ListKeys](https://cloud.tencent.com/document/api/573/34415)

	* 新增入参：HsmClusterId


修改数据结构：

* [KeyMetadata](https://cloud.tencent.com/document/api/573/34431#KeyMetadata)

	* 新增成员：HsmClusterId


### 第 16 次发布

发布时间：2021-12-23 08:12:09

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [Decrypt](https://cloud.tencent.com/document/api/573/34429)

	* 新增入参：EncryptionPublicKey, EncryptionAlgorithm

* [GenerateDataKey](https://cloud.tencent.com/document/api/573/34419)

	* 新增入参：EncryptionPublicKey, EncryptionAlgorithm


### 第 15 次发布

发布时间：2021-01-15 08:04:59

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [SignByAsymmetricKey](https://cloud.tencent.com/document/api/573/52065)
* [VerifyByAsymmetricKey](https://cloud.tencent.com/document/api/573/52064)

修改接口：

* [ListAlgorithms](https://cloud.tencent.com/document/api/573/42143)

	* 新增出参：AsymmetricSignVerifyAlgorithms


### 第 14 次发布

发布时间：2020-10-29 08:04:45

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [GetServiceStatus](https://cloud.tencent.com/document/api/573/34417)

	* 新增出参：UserLevel, ProExpireTime, ProRenewFlag, ProResourceId


### 第 13 次发布

发布时间：2020-09-01 08:04:17

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [ArchiveKey](https://cloud.tencent.com/document/api/573/47985)
* [CancelKeyArchive](https://cloud.tencent.com/document/api/573/47984)

### 第 12 次发布

发布时间：2020-08-25 08:05:11

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [GetRegions](https://cloud.tencent.com/document/api/573/47795)

### 第 11 次发布

发布时间：2020-08-17 08:13:41

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeWhiteBoxKeyDetails](https://cloud.tencent.com/document/api/573/43439)

	* 新增入参：Offset, Limit, TagFilters

	* 新增出参：TotalCount

* [ListKeyDetail](https://cloud.tencent.com/document/api/573/34416)

	* 新增入参：TagFilters


新增数据结构：

* [TagFilter](https://cloud.tencent.com/document/api/573/34431#TagFilter)

修改数据结构：

* [WhiteboxKeyInfo](https://cloud.tencent.com/document/api/573/34431#WhiteboxKeyInfo)

	* 新增成员：DeviceFingerprintBind


### 第 10 次发布

发布时间：2020-07-28 08:12:44

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [BindCloudResource](https://cloud.tencent.com/document/api/573/46918)
* [UnbindCloudResource](https://cloud.tencent.com/document/api/573/46917)

### 第 9 次发布

发布时间：2020-06-29 08:12:11

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeWhiteBoxDeviceFingerprints](https://cloud.tencent.com/document/api/573/45806)
* [OverwriteWhiteBoxDeviceFingerprints](https://cloud.tencent.com/document/api/573/45805)

新增数据结构：

* [DeviceFingerprint](https://cloud.tencent.com/document/api/573/34431#DeviceFingerprint)

### 第 8 次发布

发布时间：2020-06-03 08:12:31

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateKey](https://cloud.tencent.com/document/api/573/34430)

	* 新增入参：Tags

	* 新增出参：TagCode, TagMsg

* [CreateWhiteBoxKey](https://cloud.tencent.com/document/api/573/43443)

	* 新增入参：Tags

	* 新增出参：TagCode, TagMsg


新增数据结构：

* [Tag](https://cloud.tencent.com/document/api/573/34431#Tag)

### 第 7 次发布

发布时间：2020-04-27 08:11:13

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [KeyMetadata](https://cloud.tencent.com/document/api/573/34431#KeyMetadata)

	* 新增成员：ResourceId

* [WhiteboxKeyInfo](https://cloud.tencent.com/document/api/573/34431#WhiteboxKeyInfo)

	* 新增成员：ResourceId


### 第 6 次发布

发布时间：2020-04-15 08:11:54

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateWhiteBoxKey](https://cloud.tencent.com/document/api/573/43443)
* [DeleteWhiteBoxKey](https://cloud.tencent.com/document/api/573/43442)
* [DescribeWhiteBoxDecryptKey](https://cloud.tencent.com/document/api/573/43441)
* [DescribeWhiteBoxKey](https://cloud.tencent.com/document/api/573/43440)
* [DescribeWhiteBoxKeyDetails](https://cloud.tencent.com/document/api/573/43439)
* [DescribeWhiteBoxServiceStatus](https://cloud.tencent.com/document/api/573/43438)
* [DisableWhiteBoxKey](https://cloud.tencent.com/document/api/573/43437)
* [DisableWhiteBoxKeys](https://cloud.tencent.com/document/api/573/43436)
* [EnableWhiteBoxKey](https://cloud.tencent.com/document/api/573/43435)
* [EnableWhiteBoxKeys](https://cloud.tencent.com/document/api/573/43434)
* [EncryptByWhiteBox](https://cloud.tencent.com/document/api/573/43433)

新增数据结构：

* [WhiteboxKeyInfo](https://cloud.tencent.com/document/api/573/34431#WhiteboxKeyInfo)

### 第 5 次发布

发布时间：2020-03-12 07:59:55

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [AsymmetricRsaDecrypt](https://cloud.tencent.com/document/api/573/42142)
* [AsymmetricSm2Decrypt](https://cloud.tencent.com/document/api/573/42141)
* [GetPublicKey](https://cloud.tencent.com/document/api/573/42140)
* [ListAlgorithms](https://cloud.tencent.com/document/api/573/42143)

修改接口：

* [ListKeyDetail](https://cloud.tencent.com/document/api/573/34416)

	* 新增入参：KeyUsage


新增数据结构：

* [AlgorithmInfo](https://cloud.tencent.com/document/api/573/34431#AlgorithmInfo)

### 第 4 次发布

发布时间：2019-10-28 15:55:31

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [GenerateRandom](https://cloud.tencent.com/document/api/573/38693)

### 第 3 次发布

发布时间：2019-10-17 19:17:56

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DeleteImportedKeyMaterial](https://cloud.tencent.com/document/api/573/38498)
* [GetParametersForImport](https://cloud.tencent.com/document/api/573/38497)
* [ImportKeyMaterial](https://cloud.tencent.com/document/api/573/38496)

修改接口：

* [ListKeyDetail](https://cloud.tencent.com/document/api/573/34416)

	* 新增入参：Origin


修改数据结构：

* [KeyMetadata](https://cloud.tencent.com/document/api/573/34431#KeyMetadata)

	* 新增成员：Origin, ValidTo


### 第 2 次发布

发布时间：2019-07-04 17:15:14

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CancelKeyDeletion](https://cloud.tencent.com/document/api/573/35986)
* [ScheduleKeyDeletion](https://cloud.tencent.com/document/api/573/35985)

修改接口：

* [GetServiceStatus](https://cloud.tencent.com/document/api/573/34417)

	* 新增出参：InvalidType


修改数据结构：

* [KeyMetadata](https://cloud.tencent.com/document/api/573/34431#KeyMetadata)

	* 新增成员：DeletionDate


### 第 1 次发布

发布时间：2019-04-25 17:03:55

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateKey](https://cloud.tencent.com/document/api/573/34430)
* [Decrypt](https://cloud.tencent.com/document/api/573/34429)
* [DescribeKey](https://cloud.tencent.com/document/api/573/34428)
* [DescribeKeys](https://cloud.tencent.com/document/api/573/34427)
* [DisableKey](https://cloud.tencent.com/document/api/573/34426)
* [DisableKeyRotation](https://cloud.tencent.com/document/api/573/34425)
* [DisableKeys](https://cloud.tencent.com/document/api/573/34424)
* [EnableKey](https://cloud.tencent.com/document/api/573/34423)
* [EnableKeyRotation](https://cloud.tencent.com/document/api/573/34422)
* [EnableKeys](https://cloud.tencent.com/document/api/573/34421)
* [Encrypt](https://cloud.tencent.com/document/api/573/34420)
* [GenerateDataKey](https://cloud.tencent.com/document/api/573/34419)
* [GetKeyRotationStatus](https://cloud.tencent.com/document/api/573/34418)
* [GetServiceStatus](https://cloud.tencent.com/document/api/573/34417)
* [ListKeyDetail](https://cloud.tencent.com/document/api/573/34416)
* [ListKeys](https://cloud.tencent.com/document/api/573/34415)
* [ReEncrypt](https://cloud.tencent.com/document/api/573/34414)
* [UpdateAlias](https://cloud.tencent.com/document/api/573/34413)
* [UpdateKeyDescription](https://cloud.tencent.com/document/api/573/34412)

新增数据结构：

* [Key](https://cloud.tencent.com/document/api/573/34431#Key)
* [KeyMetadata](https://cloud.tencent.com/document/api/573/34431#KeyMetadata)




## 实时互动-教育版(lcic) 版本：2022-08-17

### 第 59 次发布

发布时间：2024-08-01 01:53:15

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeRoom](https://cloud.tencent.com/document/api/1639/80941)

	* 新增出参：RecordStream, RecordLayout


### 第 58 次发布

发布时间：2024-07-29 01:51:41

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [UnblockKickedUser](https://cloud.tencent.com/document/api/1639/109376)

### 第 57 次发布

发布时间：2024-07-17 01:19:12

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateRoom](https://cloud.tencent.com/document/api/1639/80942)

	* 新增入参：RecordStream


修改数据结构：

* [RoomInfo](https://cloud.tencent.com/document/api/1639/81423#RoomInfo)

	* 新增成员：RecordStream


### 第 56 次发布

发布时间：2024-04-16 01:14:56

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateDocument](https://cloud.tencent.com/document/api/1639/81421)

	* 新增入参：MinScaleResolution

* [DescribeDocument](https://cloud.tencent.com/document/api/1639/86321)

	* 新增出参：Resolution, MinScaleResolution


修改数据结构：

* [DocumentInfo](https://cloud.tencent.com/document/api/1639/81423#DocumentInfo)

	* 新增成员：Resolution, MinScaleResolution


### 第 55 次发布

发布时间：2024-03-29 01:20:28

本次发布包含了以下内容：

改善已有的文档。

新增数据结构：

* [CustomMsgContent](https://cloud.tencent.com/document/api/1639/81423#CustomMsgContent)

修改数据结构：

* [MessageItem](https://cloud.tencent.com/document/api/1639/81423#MessageItem)

	* 新增成员：CustomMessage

	* <font color="#dd0000">**修改成员**：</font>MessageType, TextMessage, ImageMessage

* [MsgBody](https://cloud.tencent.com/document/api/1639/81423#MsgBody)

	* 新增成员：CustomMsgContent


### 第 54 次发布

发布时间：2024-03-21 01:19:23

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateRoom](https://cloud.tencent.com/document/api/1639/80942)

* [ModifyRoom](https://cloud.tencent.com/document/api/1639/86030)


修改数据结构：

* [RoomInfo](https://cloud.tencent.com/document/api/1639/81423#RoomInfo)


### 第 53 次发布

发布时间：2024-03-15 01:17:42

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateRoom](https://cloud.tencent.com/document/api/1639/80942)

	* 新增入参：RecordScene, RecordLang

* [DescribeRoom](https://cloud.tencent.com/document/api/1639/80941)

	* 新增出参：RecordScene, RecordLang

* [ModifyRoom](https://cloud.tencent.com/document/api/1639/86030)

	* 新增入参：RecordScene, RecordLang


修改数据结构：

* [RoomInfo](https://cloud.tencent.com/document/api/1639/81423#RoomInfo)

	* 新增成员：RecordScene, RecordLang

* [RoomItem](https://cloud.tencent.com/document/api/1639/81423#RoomItem)

	* 新增成员：RecordScene, RecordLang


### 第 52 次发布

发布时间：2024-03-05 01:18:50

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeAppDetail](https://cloud.tencent.com/document/api/1639/85701)

	* 新增出参：TransferConfig

* [ModifyApp](https://cloud.tencent.com/document/api/1639/81546)

	* 新增入参：TransferId, TransferUrl


新增数据结构：

* [TransferItem](https://cloud.tencent.com/document/api/1639/81423#TransferItem)

修改数据结构：

* [AppConfig](https://cloud.tencent.com/document/api/1639/81423#AppConfig)

	* 新增成员：ApplicationId, AppName, State, AppVersion, CreatedAt, Callback, CallbackKey

* [SceneItem](https://cloud.tencent.com/document/api/1639/81423#SceneItem)

	* 新增成员：Scene, LogoUrl, HomeUrl, JSUrl, CSSUrl


### 第 51 次发布

发布时间：2024-02-27 01:18:37

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [AnswerInfo](https://cloud.tencent.com/document/api/1639/81423#AnswerInfo)

	* <font color="#dd0000">**修改成员**：</font>Name, Answer, CostTime, UserId, IsCorrect

* [BatchUserInfo](https://cloud.tencent.com/document/api/1639/81423#BatchUserInfo)

	* <font color="#dd0000">**修改成员**：</font>SdkAppId, UserId, OriginId

* [GroupInfo](https://cloud.tencent.com/document/api/1639/81423#GroupInfo)

	* <font color="#dd0000">**修改成员**：</font>GroupId, GroupName, TeacherId, GroupType, SubGroupIds

* [MemberRecord](https://cloud.tencent.com/document/api/1639/81423#MemberRecord)

	* <font color="#dd0000">**修改成员**：</font>IPAddress, Location, Device, PerMemberMicCount, PerMemberMessageCount, Role, GroupId, SubGroupId, Stage, CurrentState

* [MessageList](https://cloud.tencent.com/document/api/1639/81423#MessageList)

	* <font color="#dd0000">**修改成员**：</font>Timestamp, FromAccount, Seq, MessageBody

* [TextMarkConfig](https://cloud.tencent.com/document/api/1639/81423#TextMarkConfig)

	* <font color="#dd0000">**修改成员**：</font>Text, Color

* [WatermarkConfig](https://cloud.tencent.com/document/api/1639/81423#WatermarkConfig)

	* <font color="#dd0000">**修改成员**：</font>Url, Width, Height, LocationX, LocationY


### 第 50 次发布

发布时间：2024-01-31 01:17:54

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeRoom](https://cloud.tencent.com/document/api/1639/80941)

	* 新增入参：RTMPStreamingURL

	* 新增出参：RTMPStreamingURL


### 第 49 次发布

发布时间：2023-12-21 01:48:52

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [RoomInfo](https://cloud.tencent.com/document/api/1639/81423#RoomInfo)

	* 新增成员：RecordBackground


### 第 48 次发布

发布时间：2023-12-14 02:03:05

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateRoom](https://cloud.tencent.com/document/api/1639/80942)

	* 新增入参：RecordBackground

* [DescribeRoom](https://cloud.tencent.com/document/api/1639/80941)

	* 新增出参：RecordBackground


### 第 47 次发布

发布时间：2023-12-12 02:02:36

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [RoomItem](https://cloud.tencent.com/document/api/1639/81423#RoomItem)

	* 新增成员：RecordBackground


### 第 46 次发布

发布时间：2023-11-09 01:19:33

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeRoomForbiddenUser](https://cloud.tencent.com/document/api/1639/101432)
* [ForbidSendMsg](https://cloud.tencent.com/document/api/1639/101431)

修改接口：

* [SendRoomNormalMessage](https://cloud.tencent.com/document/api/1639/100449)

	* 新增入参：NickName


新增数据结构：

* [MutedAccountList](https://cloud.tencent.com/document/api/1639/81423#MutedAccountList)

### 第 45 次发布

发布时间：2023-10-23 00:14:04

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateRoom](https://cloud.tencent.com/document/api/1639/80942)

	* 新增入参：LiveType, RecordLiveUrl, EnableAutoStart

* [DescribeRoom](https://cloud.tencent.com/document/api/1639/80941)

	* 新增出参：LiveType, RecordLiveUrl, EnableAutoStart

* [ModifyRoom](https://cloud.tencent.com/document/api/1639/86030)

	* 新增入参：LiveType, RecordLiveUrl, EnableAutoStart


修改数据结构：

* [RoomInfo](https://cloud.tencent.com/document/api/1639/81423#RoomInfo)

	* 新增成员：LiveType, RecordLiveUrl, EnableAutoStart

* [RoomItem](https://cloud.tencent.com/document/api/1639/81423#RoomItem)

	* 新增成员：LiveType, RecordLiveUrl, EnableAutoStart


### 第 44 次发布

发布时间：2023-10-19 16:09:49

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [SendRoomNormalMessage](https://cloud.tencent.com/document/api/1639/100449)
* [SendRoomNotificationMessage](https://cloud.tencent.com/document/api/1639/100448)

新增数据结构：

* [FaceMsgContent](https://cloud.tencent.com/document/api/1639/81423#FaceMsgContent)
* [ImageInfo](https://cloud.tencent.com/document/api/1639/81423#ImageInfo)
* [ImageMsgContent](https://cloud.tencent.com/document/api/1639/81423#ImageMsgContent)
* [MsgBody](https://cloud.tencent.com/document/api/1639/81423#MsgBody)
* [TextMsgContent](https://cloud.tencent.com/document/api/1639/81423#TextMsgContent)

### 第 43 次发布

发布时间：2023-10-12 02:11:22

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeScoreList](https://cloud.tencent.com/document/api/1639/100163)

新增数据结构：

* [ClassScoreItem](https://cloud.tencent.com/document/api/1639/81423#ClassScoreItem)

### 第 42 次发布

发布时间：2023-09-12 02:07:10

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateDocument](https://cloud.tencent.com/document/api/1639/81421)

	* 新增入参：AutoHandleUnsupportedElement


### 第 41 次发布

发布时间：2023-09-06 02:00:58

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateRoom](https://cloud.tencent.com/document/api/1639/80942)

	* 新增入参：EndDelayTime

* [DescribeRoom](https://cloud.tencent.com/document/api/1639/80941)

	* 新增出参：EndDelayTime

* [ModifyRoom](https://cloud.tencent.com/document/api/1639/86030)

	* 新增入参：EndDelayTime


修改数据结构：

* [DocumentInfo](https://cloud.tencent.com/document/api/1639/81423#DocumentInfo)

	* 新增成员：Preview

	* <font color="#dd0000">**修改成员**：</font>DocumentId, DocumentUrl, DocumentName, Owner, SdkAppId, Permission, TranscodeResult, TranscodeType, TranscodeProgress, TranscodeState, TranscodeInfo, DocumentType, DocumentSize, UpdateTime, Pages, Width, Height, Cover

* [RoomInfo](https://cloud.tencent.com/document/api/1639/81423#RoomInfo)

	* 新增成员：EndDelayTime

* [RoomItem](https://cloud.tencent.com/document/api/1639/81423#RoomItem)

	* 新增成员：EndDelayTime


### 第 40 次发布

发布时间：2023-08-29 01:17:54

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeUser](https://cloud.tencent.com/document/api/1639/80936)

	* 新增出参：OriginId


修改数据结构：

* [UserInfo](https://cloud.tencent.com/document/api/1639/81423#UserInfo)

	* 新增成员：OriginId

	* <font color="#dd0000">**修改成员**：</font>SdkAppId, UserId, Name, Avatar


### 第 39 次发布

发布时间：2023-08-23 01:30:17

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [ModifyRoom](https://cloud.tencent.com/document/api/1639/86030)

	* 新增入参：RecordLayout


### 第 38 次发布

发布时间：2023-08-22 01:15:27

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [EventDataInfo](https://cloud.tencent.com/document/api/1639/81423#EventDataInfo)

	* 新增成员：Device, Duration, RecordSize, RecordUrl

	* <font color="#dd0000">**修改成员**：</font>RoomId, UserId


### 第 37 次发布

发布时间：2023-08-17 20:45:43

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DeleteUser](https://cloud.tencent.com/document/api/1639/96698)

### 第 36 次发布

发布时间：2023-08-11 01:27:55

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeRoom](https://cloud.tencent.com/document/api/1639/80941)

	* 新增出参：VideoDuration


### 第 35 次发布

发布时间：2023-07-31 01:30:04

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeRoom](https://cloud.tencent.com/document/api/1639/80941)

	* 新增出参：AudienceType


### 第 34 次发布

发布时间：2023-07-28 01:32:25

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [RoomItem](https://cloud.tencent.com/document/api/1639/81423#RoomItem)

	* 新增成员：IsGradingRequiredPostClass, RoomType


### 第 33 次发布

发布时间：2023-07-27 01:15:22

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [EventInfo](https://cloud.tencent.com/document/api/1639/81423#EventInfo)

	* <font color="#dd0000">**修改成员**：</font>Timestamp, EventType, EventData


### 第 32 次发布

发布时间：2023-07-26 01:25:48

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateRoom](https://cloud.tencent.com/document/api/1639/80942)

	* 新增入参：RoomType

* [DescribeRoom](https://cloud.tencent.com/document/api/1639/80941)

	* 新增出参：RoomType

* [ModifyRoom](https://cloud.tencent.com/document/api/1639/86030)

	* 新增入参：RoomType


修改数据结构：

* [RoomInfo](https://cloud.tencent.com/document/api/1639/81423#RoomInfo)

	* 新增成员：IsGradingRequiredPostClass, RoomType


### 第 31 次发布

发布时间：2023-07-21 01:29:56

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateRoom](https://cloud.tencent.com/document/api/1639/80942)

	* 新增入参：IsGradingRequiredPostClass

* [DescribeRoom](https://cloud.tencent.com/document/api/1639/80941)

	* 新增出参：IsGradingRequiredPostClass

* [ModifyRoom](https://cloud.tencent.com/document/api/1639/86030)

	* 新增入参：IsGradingRequiredPostClass


### 第 30 次发布

发布时间：2023-07-14 01:25:31

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeDocument](https://cloud.tencent.com/document/api/1639/86321)

	* 新增出参：Preview


### 第 29 次发布

发布时间：2023-07-12 01:30:32

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeDocument](https://cloud.tencent.com/document/api/1639/86321)

	* 新增出参：Pages


### 第 28 次发布

发布时间：2023-07-10 01:31:48

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [GetRooms](https://cloud.tencent.com/document/api/1639/90012)

	* 新增入参：Status


修改数据结构：

* [RoomItem](https://cloud.tencent.com/document/api/1639/81423#RoomItem)

	* 新增成员：InteractionMode, VideoOrientation

	* <font color="#dd0000">**修改成员**：</font>Name, RoomId, Status, StartTime, EndTime, RealStartTime, RealEndTime, Resolution, MaxRTCMember, ReplayUrl, RecordUrl, MaxMicNumber, EnableDirectControl


### 第 27 次发布

发布时间：2023-06-29 01:28:41

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateRoom](https://cloud.tencent.com/document/api/1639/80942)

	* 新增入参：InteractionMode, VideoOrientation

* [DescribeRoom](https://cloud.tencent.com/document/api/1639/80941)

	* 新增出参：InteractionMode, VideoOrientation

* [ModifyRoom](https://cloud.tencent.com/document/api/1639/86030)

	* 新增入参：InteractionMode, VideoOrientation


修改数据结构：

* [MemberRecord](https://cloud.tencent.com/document/api/1639/81423#MemberRecord)

	* 新增成员：CurrentState

* [RoomInfo](https://cloud.tencent.com/document/api/1639/81423#RoomInfo)

	* 新增成员：InteractionMode, VideoOrientation


### 第 26 次发布

发布时间：2023-05-16 01:58:33

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [KickUserFromRoom](https://cloud.tencent.com/document/api/1639/91054)

### 第 25 次发布

发布时间：2023-04-27 01:26:43

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateRoom](https://cloud.tencent.com/document/api/1639/80942)

	* 新增入参：EnableDirectControl

* [DescribeRoom](https://cloud.tencent.com/document/api/1639/80941)

	* 新增出参：EnableDirectControl

* [ModifyRoom](https://cloud.tencent.com/document/api/1639/86030)

	* 新增入参：EnableDirectControl


修改数据结构：

* [RoomInfo](https://cloud.tencent.com/document/api/1639/81423#RoomInfo)

	* 新增成员：EnableDirectControl

* [RoomItem](https://cloud.tencent.com/document/api/1639/81423#RoomItem)

	* 新增成员：MaxMicNumber, EnableDirectControl


### 第 24 次发布

发布时间：2023-04-21 01:29:46

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [BatchDescribeDocument](https://cloud.tencent.com/document/api/1639/90374)

<font color="#dd0000">**预下线接口**：</font>

* DescribeDocuments

### 第 23 次发布

发布时间：2023-04-19 01:35:50

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DeleteSupervisor](https://cloud.tencent.com/document/api/1639/90295)
* [DescribeDocuments](https://cloud.tencent.com/document/api/1639/90292)
* [EndRoom](https://cloud.tencent.com/document/api/1639/90294)
* [StartRoom](https://cloud.tencent.com/document/api/1639/90293)

修改数据结构：

* [DocumentInfo](https://cloud.tencent.com/document/api/1639/81423#DocumentInfo)

	* 新增成员：Pages, Width, Height, Cover

* [MemberRecord](https://cloud.tencent.com/document/api/1639/81423#MemberRecord)

	* 新增成员：Role, GroupId, SubGroupId, Stage


### 第 22 次发布

发布时间：2023-04-11 01:26:50

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateRoom](https://cloud.tencent.com/document/api/1639/80942)

	* 新增入参：TurnOffMic, RTCAudienceNumber, AudienceType


### 第 21 次发布

发布时间：2023-04-10 01:39:57

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [GetRooms](https://cloud.tencent.com/document/api/1639/90012)

新增数据结构：

* [RoomItem](https://cloud.tencent.com/document/api/1639/81423#RoomItem)

### 第 20 次发布

发布时间：2023-04-03 01:23:43

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeDeveloper](https://cloud.tencent.com/document/api/1639/89115)

	* 新增出参：DeveloperId


### 第 19 次发布

发布时间：2023-03-31 01:33:58

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeAnswerList](https://cloud.tencent.com/document/api/1639/89679)
* [DescribeQuestionList](https://cloud.tencent.com/document/api/1639/89678)
* [DescribeSupervisors](https://cloud.tencent.com/document/api/1639/89680)

新增数据结构：

* [AnswerInfo](https://cloud.tencent.com/document/api/1639/81423#AnswerInfo)
* [AnswerStat](https://cloud.tencent.com/document/api/1639/81423#AnswerStat)
* [QuestionInfo](https://cloud.tencent.com/document/api/1639/81423#QuestionInfo)

### 第 18 次发布

发布时间：2023-03-22 01:59:37

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeDeveloper](https://cloud.tencent.com/document/api/1639/89115)

### 第 17 次发布

发布时间：2023-03-20 01:37:28

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [GetRoomEvent](https://cloud.tencent.com/document/api/1639/88910)

新增数据结构：

* [EventDataInfo](https://cloud.tencent.com/document/api/1639/81423#EventDataInfo)
* [EventInfo](https://cloud.tencent.com/document/api/1639/81423#EventInfo)

### 第 16 次发布

发布时间：2023-03-14 01:33:18

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateSupervisor](https://cloud.tencent.com/document/api/1639/80944)

	* 新增入参：SdkAppId, Users


### 第 15 次发布

发布时间：2023-03-13 01:49:55

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DeleteAppCustomContent](https://cloud.tencent.com/document/api/1639/88133)

### 第 14 次发布

发布时间：2023-02-28 01:44:45

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [GetRoomMessage](https://cloud.tencent.com/document/api/1639/86972)

修改接口：

* [DescribeRoomStatistics](https://cloud.tencent.com/document/api/1639/81545)

	* 新增出参：MessageCount, MicCount


新增数据结构：

* [MessageItem](https://cloud.tencent.com/document/api/1639/81423#MessageItem)
* [MessageList](https://cloud.tencent.com/document/api/1639/81423#MessageList)

修改数据结构：

* [MemberRecord](https://cloud.tencent.com/document/api/1639/81423#MemberRecord)

	* 新增成员：PerMemberMicCount, PerMemberMessageCount


### 第 13 次发布

发布时间：2023-02-17 04:12:57

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [AddGroupMember](https://cloud.tencent.com/document/api/1639/86647)
* [BatchAddGroupMember](https://cloud.tencent.com/document/api/1639/86646)
* [BatchCreateGroupWithMembers](https://cloud.tencent.com/document/api/1639/86645)
* [BatchDeleteGroupMember](https://cloud.tencent.com/document/api/1639/86644)
* [CreateGroupWithMembers](https://cloud.tencent.com/document/api/1639/86643)
* [CreateGroupWithSubGroup](https://cloud.tencent.com/document/api/1639/86642)
* [DeleteGroup](https://cloud.tencent.com/document/api/1639/86641)
* [DeleteGroupMember](https://cloud.tencent.com/document/api/1639/86640)
* [DescribeGroup](https://cloud.tencent.com/document/api/1639/86639)
* [DescribeGroupList](https://cloud.tencent.com/document/api/1639/86638)
* [DescribeGroupMemberList](https://cloud.tencent.com/document/api/1639/86637)
* [ModifyGroup](https://cloud.tencent.com/document/api/1639/86636)

修改接口：

* [CreateRoom](https://cloud.tencent.com/document/api/1639/80942)

	* 新增入参：GroupId

* [DescribeRoom](https://cloud.tencent.com/document/api/1639/80941)

	* 新增出参：GroupId

* [ModifyRoom](https://cloud.tencent.com/document/api/1639/86030)

	* 新增入参：GroupId


新增数据结构：

* [GroupBaseInfo](https://cloud.tencent.com/document/api/1639/81423#GroupBaseInfo)
* [GroupInfo](https://cloud.tencent.com/document/api/1639/81423#GroupInfo)

修改数据结构：

* [RoomInfo](https://cloud.tencent.com/document/api/1639/81423#RoomInfo)

	* 新增成员：GroupId


### 第 12 次发布

发布时间：2023-02-16 01:33:21

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [MemberRecord](https://cloud.tencent.com/document/api/1639/81423#MemberRecord)

	* 新增成员：IPAddress, Location, Device


### 第 11 次发布

发布时间：2023-02-15 01:40:03

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeCurrentMemberList](https://cloud.tencent.com/document/api/1639/86554)

### 第 10 次发布

发布时间：2023-02-14 01:35:04

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeRoom](https://cloud.tencent.com/document/api/1639/80941)

	* 新增出参：Status

* [DescribeRoomStatistics](https://cloud.tencent.com/document/api/1639/81545)

	* 新增出参：RealStartTime, RealEndTime


### 第 9 次发布

发布时间：2023-02-09 01:47:12

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [BatchCreateRoom](https://cloud.tencent.com/document/api/1639/86325)
* [BatchDeleteRecord](https://cloud.tencent.com/document/api/1639/86328)
* [DeleteDocument](https://cloud.tencent.com/document/api/1639/86322)
* [DeleteRecord](https://cloud.tencent.com/document/api/1639/86327)
* [DescribeDocument](https://cloud.tencent.com/document/api/1639/86321)
* [DescribeDocumentsByRoom](https://cloud.tencent.com/document/api/1639/86320)
* [DescribeSdkAppIdUsers](https://cloud.tencent.com/document/api/1639/86324)
* [GetWatermark](https://cloud.tencent.com/document/api/1639/86330)
* [ModifyUserProfile](https://cloud.tencent.com/document/api/1639/86323)
* [SetWatermark](https://cloud.tencent.com/document/api/1639/86329)

新增数据结构：

* [BackgroundPictureConfig](https://cloud.tencent.com/document/api/1639/81423#BackgroundPictureConfig)
* [DocumentInfo](https://cloud.tencent.com/document/api/1639/81423#DocumentInfo)
* [RoomInfo](https://cloud.tencent.com/document/api/1639/81423#RoomInfo)
* [TextMarkConfig](https://cloud.tencent.com/document/api/1639/81423#TextMarkConfig)
* [UserInfo](https://cloud.tencent.com/document/api/1639/81423#UserInfo)
* [WatermarkConfig](https://cloud.tencent.com/document/api/1639/81423#WatermarkConfig)

### 第 8 次发布

发布时间：2023-02-02 01:35:14

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [BatchRegister](https://cloud.tencent.com/document/api/1639/86029)
* [ModifyRoom](https://cloud.tencent.com/document/api/1639/86030)

新增数据结构：

* [BatchUserInfo](https://cloud.tencent.com/document/api/1639/81423#BatchUserInfo)
* [BatchUserRequest](https://cloud.tencent.com/document/api/1639/81423#BatchUserRequest)

### 第 7 次发布

发布时间：2023-01-16 01:41:05

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeAppDetail](https://cloud.tencent.com/document/api/1639/85701)

	* 新增入参：ApplicationId, DeveloperId

	* 新增出参：SdkAppId, AppConfig, SceneConfig


新增数据结构：

* [AppConfig](https://cloud.tencent.com/document/api/1639/81423#AppConfig)
* [SceneItem](https://cloud.tencent.com/document/api/1639/81423#SceneItem)

### 第 6 次发布

发布时间：2023-01-13 01:33:56

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeAppDetail](https://cloud.tencent.com/document/api/1639/85701)

修改接口：

* [ModifyApp](https://cloud.tencent.com/document/api/1639/81546)

	* 新增入参：CallbackKey


### 第 5 次发布

发布时间：2022-10-19 06:31:50

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [BindDocumentToRoom](https://cloud.tencent.com/document/api/1639/81544)
* [DescribeRoomStatistics](https://cloud.tencent.com/document/api/1639/81545)
* [ModifyApp](https://cloud.tencent.com/document/api/1639/81546)
* [UnbindDocumentFromRoom](https://cloud.tencent.com/document/api/1639/81543)

修改接口：

* [DescribeRoom](https://cloud.tencent.com/document/api/1639/80941)

	* 新增出参：RecordUrl


新增数据结构：

* [MemberRecord](https://cloud.tencent.com/document/api/1639/81423#MemberRecord)

### 第 4 次发布

发布时间：2022-10-18 06:36:52

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DeleteRoom](https://cloud.tencent.com/document/api/1639/81518)

### 第 3 次发布

发布时间：2022-10-14 06:37:15

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateDocument](https://cloud.tencent.com/document/api/1639/81421)
* [SetAppCustomContent](https://cloud.tencent.com/document/api/1639/81422)

新增数据结构：

* [AppCustomContent](https://cloud.tencent.com/document/api/1639/81423#AppCustomContent)

### 第 2 次发布

发布时间：2022-09-22 10:11:52

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateRoom](https://cloud.tencent.com/document/api/1639/80942)
* [CreateSupervisor](https://cloud.tencent.com/document/api/1639/80944)
* [DescribeRoom](https://cloud.tencent.com/document/api/1639/80941)
* [DescribeUser](https://cloud.tencent.com/document/api/1639/80936)
* [LoginOriginId](https://cloud.tencent.com/document/api/1639/80939)
* [RegisterUser](https://cloud.tencent.com/document/api/1639/80935)

### 第 1 次发布

发布时间：2022-09-22 10:03:08

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [LoginUser](https://cloud.tencent.com/document/api/1639/80938)




## 轻量应用服务器(lighthouse) 版本：2020-03-24

### 第 61 次发布

发布时间：2024-06-18 01:53:48

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [Bundle](https://cloud.tencent.com/document/api/1207/47576#Bundle)

	* <font color="#dd0000">**修改成员**：</font>BundleTypeDescription


### 第 60 次发布

发布时间：2024-05-13 01:21:46

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [Instance](https://cloud.tencent.com/document/api/1207/47576#Instance)

	* 新增成员：LatestOperationStartedTime

* [InstancePriceDetail](https://cloud.tencent.com/document/api/1207/47576#InstancePriceDetail)

	* <font color="#dd0000">**修改成员**：</font>InstanceId, InstancePrice, DiscountDetail


### 第 59 次发布

发布时间：2024-03-11 01:18:22

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateInstances](https://cloud.tencent.com/document/api/1207/69573)

	* 新增入参：InitCommand


新增数据结构：

* [Command](https://cloud.tencent.com/document/api/1207/47576#Command)

修改数据结构：

* [Instance](https://cloud.tencent.com/document/api/1207/47576#Instance)

	* 新增成员：InitInvocationId


### 第 58 次发布

发布时间：2024-02-29 01:19:13

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [ModifyDisksBackupQuota](https://cloud.tencent.com/document/api/1207/104011)
* [ResizeDisks](https://cloud.tencent.com/document/api/1207/104010)

### 第 57 次发布

发布时间：2023-12-13 02:03:09

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [ResetInstance](https://cloud.tencent.com/document/api/1207/47571)

	* 新增入参：Containers, LoginConfiguration


修改数据结构：

* [InstancePrice](https://cloud.tencent.com/document/api/1207/47576#InstancePrice)

	* <font color="#dd0000">**修改成员**：</font>OriginalBundlePrice, OriginalPrice, Discount, DiscountPrice, Currency


### 第 56 次发布

发布时间：2023-12-05 01:59:59

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [PolicyDetail](https://cloud.tencent.com/document/api/1207/47576#PolicyDetail)

	* <font color="#dd0000">**修改成员**：</font>UserDiscount, CommonDiscount, FinalDiscount, ActivityDiscount, DiscountType


### 第 55 次发布

发布时间：2023-11-07 01:54:12

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CancelShareBlueprintAcrossAccounts](https://cloud.tencent.com/document/api/1207/101339)
* [ShareBlueprintAcrossAccounts](https://cloud.tencent.com/document/api/1207/101338)

### 第 54 次发布

发布时间：2023-10-11 02:02:31

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateInstances](https://cloud.tencent.com/document/api/1207/69573)

	* 新增入参：Tags


### 第 53 次发布

发布时间：2023-09-15 02:04:15

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [Blueprint](https://cloud.tencent.com/document/api/1207/47576#Blueprint)

	* 新增成员：BlueprintShared

	* <font color="#dd0000">**修改成员**：</font>DockerVersion


### 第 52 次发布

发布时间：2023-08-23 01:30:37

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [ApplyFirewallTemplate](https://cloud.tencent.com/document/api/1207/96883)
* [CreateFirewallTemplate](https://cloud.tencent.com/document/api/1207/96882)
* [CreateFirewallTemplateRules](https://cloud.tencent.com/document/api/1207/96881)
* [DeleteFirewallTemplate](https://cloud.tencent.com/document/api/1207/96880)
* [DeleteFirewallTemplateRules](https://cloud.tencent.com/document/api/1207/96879)
* [DescribeFirewallTemplateApplyRecords](https://cloud.tencent.com/document/api/1207/96878)
* [DescribeFirewallTemplateQuota](https://cloud.tencent.com/document/api/1207/96877)
* [DescribeFirewallTemplateRuleQuota](https://cloud.tencent.com/document/api/1207/96876)
* [DescribeFirewallTemplateRules](https://cloud.tencent.com/document/api/1207/96875)
* [DescribeFirewallTemplates](https://cloud.tencent.com/document/api/1207/96874)
* [ModifyFirewallTemplate](https://cloud.tencent.com/document/api/1207/96873)
* [ReplaceFirewallTemplateRule](https://cloud.tencent.com/document/api/1207/96872)
* [ResetFirewallTemplateRules](https://cloud.tencent.com/document/api/1207/96871)

修改接口：

* [CreateInstances](https://cloud.tencent.com/document/api/1207/69573)

	* 新增入参：FirewallTemplateId


新增数据结构：

* [FirewallTemplate](https://cloud.tencent.com/document/api/1207/47576#FirewallTemplate)
* [FirewallTemplateApplyRecord](https://cloud.tencent.com/document/api/1207/47576#FirewallTemplateApplyRecord)
* [FirewallTemplateApplyRecordDetail](https://cloud.tencent.com/document/api/1207/47576#FirewallTemplateApplyRecordDetail)
* [FirewallTemplateRule](https://cloud.tencent.com/document/api/1207/47576#FirewallTemplateRule)
* [FirewallTemplateRuleInfo](https://cloud.tencent.com/document/api/1207/47576#FirewallTemplateRuleInfo)
* [InstanceIdentifier](https://cloud.tencent.com/document/api/1207/47576#InstanceIdentifier)

### 第 51 次发布

发布时间：2023-07-25 11:04:43

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeDockerActivities](https://cloud.tencent.com/document/api/1207/95476)
* [DescribeDockerContainerConfiguration](https://cloud.tencent.com/document/api/1207/95475)
* [DescribeDockerContainerDetail](https://cloud.tencent.com/document/api/1207/95474)
* [DescribeDockerContainers](https://cloud.tencent.com/document/api/1207/95473)
* [ModifyDockerContainer](https://cloud.tencent.com/document/api/1207/95472)
* [RemoveDockerContainers](https://cloud.tencent.com/document/api/1207/95471)
* [RenameDockerContainer](https://cloud.tencent.com/document/api/1207/95470)
* [RerunDockerContainer](https://cloud.tencent.com/document/api/1207/95469)
* [RestartDockerContainers](https://cloud.tencent.com/document/api/1207/95468)
* [RunDockerContainers](https://cloud.tencent.com/document/api/1207/95467)
* [StartDockerContainers](https://cloud.tencent.com/document/api/1207/95466)
* [StopDockerContainers](https://cloud.tencent.com/document/api/1207/95465)

新增数据结构：

* [DockerActivity](https://cloud.tencent.com/document/api/1207/47576#DockerActivity)
* [DockerContainer](https://cloud.tencent.com/document/api/1207/47576#DockerContainer)

修改数据结构：

* [LoginConfiguration](https://cloud.tencent.com/document/api/1207/47576#LoginConfiguration)

	* 新增成员：KeyIds


### 第 50 次发布

发布时间：2023-07-19 01:30:20

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [DockerContainerConfiguration](https://cloud.tencent.com/document/api/1207/47576#DockerContainerConfiguration)

	* 新增成员：RestartPolicy


### 第 49 次发布

发布时间：2023-07-10 01:32:08

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [LoginConfiguration](https://cloud.tencent.com/document/api/1207/47576#LoginConfiguration)

	* <font color="#dd0000">**修改成员**：</font>AutoGeneratePassword


### 第 48 次发布

发布时间：2023-05-10 01:33:30

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [IsolateDisks](https://cloud.tencent.com/document/api/1207/90904)
* [RenewDisks](https://cloud.tencent.com/document/api/1207/90903)

### 第 47 次发布

发布时间：2023-05-09 01:27:20

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateDisks](https://cloud.tencent.com/document/api/1207/90853)

新增数据结构：

* [AutoMountConfiguration](https://cloud.tencent.com/document/api/1207/47576#AutoMountConfiguration)

修改数据结构：

* [PolicyDetail](https://cloud.tencent.com/document/api/1207/47576#PolicyDetail)

	* <font color="#dd0000">**修改成员**：</font>UserDiscount, CommonDiscount, FinalDiscount


### 第 46 次发布

发布时间：2023-04-20 01:27:41

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateBlueprint](https://cloud.tencent.com/document/api/1207/54385)

	* 新增入参：ForcePowerOff


### 第 45 次发布

发布时间：2023-04-19 01:37:08

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [Bundle](https://cloud.tencent.com/document/api/1207/47576#Bundle)

	* 新增成员：BundleTypeDescription


### 第 44 次发布

发布时间：2023-02-27 01:32:02

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [InquirePriceCreateInstances](https://cloud.tencent.com/document/api/1207/55558)

	* <font color="#dd0000">**修改入参**：</font>InstanceChargePrepaid

* [InquirePriceRenewInstances](https://cloud.tencent.com/document/api/1207/55557)

	* <font color="#dd0000">**修改入参**：</font>InstanceChargePrepaid


### 第 43 次发布

发布时间：2023-02-24 01:14:10

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [BlueprintPrice](https://cloud.tencent.com/document/api/1207/47576#BlueprintPrice)

	* <font color="#dd0000">**修改成员**：</font>Discount

* [DiscountDetail](https://cloud.tencent.com/document/api/1207/47576#DiscountDetail)

	* <font color="#dd0000">**修改成员**：</font>Discount

* [InstancePrice](https://cloud.tencent.com/document/api/1207/47576#InstancePrice)

	* <font color="#dd0000">**修改成员**：</font>Discount


### 第 42 次发布

发布时间：2023-02-17 04:14:14

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [Blueprint](https://cloud.tencent.com/document/api/1207/47576#Blueprint)

	* 新增成员：DockerVersion


### 第 41 次发布

发布时间：2022-12-23 01:40:27

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [PolicyDetail](https://cloud.tencent.com/document/api/1207/47576#PolicyDetail)

	* 新增成员：ActivityDiscount, DiscountType

	* <font color="#dd0000">**修改成员**：</font>UserDiscount, CommonDiscount, FinalDiscount


### 第 40 次发布

发布时间：2022-12-21 01:48:07

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [ApplyDiskBackup](https://cloud.tencent.com/document/api/1207/84382)
* [CreateDiskBackup](https://cloud.tencent.com/document/api/1207/84381)
* [DeleteDiskBackups](https://cloud.tencent.com/document/api/1207/84380)
* [DescribeDiskBackups](https://cloud.tencent.com/document/api/1207/84379)
* [DescribeDiskBackupsDeniedActions](https://cloud.tencent.com/document/api/1207/84378)
* [ModifyDiskBackupsAttribute](https://cloud.tencent.com/document/api/1207/84377)

新增数据结构：

* [DiskBackup](https://cloud.tencent.com/document/api/1207/47576#DiskBackup)
* [DiskBackupDeniedActions](https://cloud.tencent.com/document/api/1207/47576#DiskBackupDeniedActions)

### 第 39 次发布

发布时间：2022-12-14 01:33:53

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [InstancePrice](https://cloud.tencent.com/document/api/1207/47576#InstancePrice)

	* 新增成员：Currency

	* <font color="#dd0000">**修改成员**：</font>OriginalBundlePrice, OriginalPrice, Discount, DiscountPrice

* [InstancePriceDetail](https://cloud.tencent.com/document/api/1207/47576#InstancePriceDetail)

	* 新增成员：DiscountDetail

	* <font color="#dd0000">**修改成员**：</font>InstanceId, InstancePrice


### 第 38 次发布

发布时间：2022-12-05 07:01:06

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [InquirePriceRenewInstances](https://cloud.tencent.com/document/api/1207/55557)

	* 新增出参：TotalPrice


新增数据结构：

* [TotalPrice](https://cloud.tencent.com/document/api/1207/47576#TotalPrice)

### 第 37 次发布

发布时间：2022-11-30 06:44:08

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeAllScenes](https://cloud.tencent.com/document/api/1207/83513)
* [DescribeScenes](https://cloud.tencent.com/document/api/1207/83512)

新增数据结构：

* [Scene](https://cloud.tencent.com/document/api/1207/47576#Scene)
* [SceneInfo](https://cloud.tencent.com/document/api/1207/47576#SceneInfo)

### 第 36 次发布

发布时间：2022-11-17 06:33:03

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [ModifyInstancesBundle](https://cloud.tencent.com/document/api/1207/82998)

### 第 35 次发布

发布时间：2022-11-16 06:28:46

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [InquirePriceRenewInstances](https://cloud.tencent.com/document/api/1207/55557)

	* 新增出参：InstancePriceDetailSet


新增数据结构：

* [InstancePriceDetail](https://cloud.tencent.com/document/api/1207/47576#InstancePriceDetail)

修改数据结构：

* [DataDiskPrice](https://cloud.tencent.com/document/api/1207/47576#DataDiskPrice)

	* 新增成员：InstanceId


### 第 34 次发布

发布时间：2022-09-14 06:27:13

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [Blueprint](https://cloud.tencent.com/document/api/1207/47576#Blueprint)

	* 新增成员：CommunityUrl, GuideUrl, SceneIdSet


### 第 33 次发布

发布时间：2022-08-11 06:38:25

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeDiskDiscount](https://cloud.tencent.com/document/api/1207/66094)

	* 新增入参：DiskBackupQuota

* [InquirePriceCreateDisks](https://cloud.tencent.com/document/api/1207/66089)

	* 新增入参：DiskBackupQuota


### 第 32 次发布

发布时间：2022-08-09 12:16:13

本次发布包含了以下内容：

改善已有的文档。

新增数据结构：

* [DetailPrice](https://cloud.tencent.com/document/api/1207/47576#DetailPrice)

修改数据结构：

* [Disk](https://cloud.tencent.com/document/api/1207/47576#Disk)

	* 新增成员：DiskBackupCount, DiskBackupQuota

* [DiskPrice](https://cloud.tencent.com/document/api/1207/47576#DiskPrice)

	* 新增成员：DetailPrices


### 第 31 次发布

发布时间：2022-05-20 06:14:11

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeZones](https://cloud.tencent.com/document/api/1207/57513)

	* 新增入参：OrderField, Order


### 第 30 次发布

发布时间：2022-04-29 06:09:55

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [IsolateInstances](https://cloud.tencent.com/document/api/1207/73214)

### 第 29 次发布

发布时间：2022-04-26 06:12:41

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [RenewInstances](https://cloud.tencent.com/document/api/1207/73099)

修改数据结构：

* [LoginConfiguration](https://cloud.tencent.com/document/api/1207/47576#LoginConfiguration)

	* 新增成员：AutoGeneratePassword, Password


### 第 28 次发布

发布时间：2022-04-08 06:09:37

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateInstances](https://cloud.tencent.com/document/api/1207/69573)

	* 新增入参：AutoVoucher


### 第 27 次发布

发布时间：2022-04-01 06:11:10

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [Instance](https://cloud.tencent.com/document/api/1207/47576#Instance)

	* 新增成员：InstanceRestrictState


### 第 26 次发布

发布时间：2022-03-03 08:08:18

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [ModifyBundle](https://cloud.tencent.com/document/api/1207/47576#ModifyBundle)

	* 新增成员：NotSupportModifyMessage


### 第 25 次发布

发布时间：2022-02-16 08:08:43

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateInstances](https://cloud.tencent.com/document/api/1207/69573)

新增数据结构：

* [ContainerEnv](https://cloud.tencent.com/document/api/1207/47576#ContainerEnv)
* [DockerContainerConfiguration](https://cloud.tencent.com/document/api/1207/47576#DockerContainerConfiguration)
* [DockerContainerPublishPort](https://cloud.tencent.com/document/api/1207/47576#DockerContainerPublishPort)
* [DockerContainerVolume](https://cloud.tencent.com/document/api/1207/47576#DockerContainerVolume)
* [LoginConfiguration](https://cloud.tencent.com/document/api/1207/47576#LoginConfiguration)

### 第 24 次发布

发布时间：2022-01-11 08:11:43

本次发布包含了以下内容：

改善已有的文档。

新增数据结构：

* [Tag](https://cloud.tencent.com/document/api/1207/47576#Tag)

修改数据结构：

* [Instance](https://cloud.tencent.com/document/api/1207/47576#Instance)

	* 新增成员：Tags


### 第 23 次发布

发布时间：2021-12-20 08:09:41

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [InquirePriceRenewInstances](https://cloud.tencent.com/document/api/1207/55557)

	* 新增入参：RenewDataDisk, AlignInstanceExpiredTime

	* 新增出参：DataDiskPriceSet


新增数据结构：

* [DataDiskPrice](https://cloud.tencent.com/document/api/1207/47576#DataDiskPrice)

### 第 22 次发布

发布时间：2021-12-16 08:11:07

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [AttachDisks](https://cloud.tencent.com/document/api/1207/66096)
* [DescribeDiskConfigs](https://cloud.tencent.com/document/api/1207/66095)
* [DescribeDiskDiscount](https://cloud.tencent.com/document/api/1207/66094)
* [DescribeDisks](https://cloud.tencent.com/document/api/1207/66093)
* [DescribeDisksDeniedActions](https://cloud.tencent.com/document/api/1207/66092)
* [DescribeDisksReturnable](https://cloud.tencent.com/document/api/1207/66091)
* [DescribeInstancesDiskNum](https://cloud.tencent.com/document/api/1207/66083)
* [DetachDisks](https://cloud.tencent.com/document/api/1207/66090)
* [InquirePriceCreateDisks](https://cloud.tencent.com/document/api/1207/66089)
* [InquirePriceRenewDisks](https://cloud.tencent.com/document/api/1207/66088)
* [ModifyDisksAttribute](https://cloud.tencent.com/document/api/1207/66087)
* [ModifyDisksRenewFlag](https://cloud.tencent.com/document/api/1207/66086)
* [TerminateDisks](https://cloud.tencent.com/document/api/1207/66085)

新增数据结构：

* [AttachDetail](https://cloud.tencent.com/document/api/1207/47576#AttachDetail)
* [Disk](https://cloud.tencent.com/document/api/1207/47576#Disk)
* [DiskChargePrepaid](https://cloud.tencent.com/document/api/1207/47576#DiskChargePrepaid)
* [DiskConfig](https://cloud.tencent.com/document/api/1207/47576#DiskConfig)
* [DiskDeniedActions](https://cloud.tencent.com/document/api/1207/47576#DiskDeniedActions)
* [DiskPrice](https://cloud.tencent.com/document/api/1207/47576#DiskPrice)
* [DiskReturnable](https://cloud.tencent.com/document/api/1207/47576#DiskReturnable)
* [RenewDiskChargePrepaid](https://cloud.tencent.com/document/api/1207/47576#RenewDiskChargePrepaid)

### 第 21 次发布

发布时间：2021-11-30 20:01:47

本次发布包含了以下内容：

改善已有的文档。

<font color="#dd0000">**删除数据结构**：</font>

* DataDiskPrice

修改数据结构：

* [Price](https://cloud.tencent.com/document/api/1207/47576#Price)

	* <font color="#dd0000">**删除成员**：</font>DataDiskPrices


### 第 20 次发布

发布时间：2021-10-20 08:12:10

本次发布包含了以下内容：

改善已有的文档。

新增数据结构：

* [DataDiskPrice](https://cloud.tencent.com/document/api/1207/47576#DataDiskPrice)

修改数据结构：

* [Price](https://cloud.tencent.com/document/api/1207/47576#Price)

	* 新增成员：DataDiskPrices


### 第 19 次发布

发布时间：2021-07-30 08:01:31

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [Blueprint](https://cloud.tencent.com/document/api/1207/47576#Blueprint)

	* 新增成员：ImageId


### 第 18 次发布

发布时间：2021-07-19 08:01:24

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [AttachCcn](https://cloud.tencent.com/document/api/1207/58798)
* [DescribeCcnAttachedInstances](https://cloud.tencent.com/document/api/1207/58797)
* [DetachCcn](https://cloud.tencent.com/document/api/1207/58796)
* [ResetAttachCcn](https://cloud.tencent.com/document/api/1207/58795)

新增数据结构：

* [CcnAttachedInstance](https://cloud.tencent.com/document/api/1207/47576#CcnAttachedInstance)

### 第 17 次发布

发布时间：2021-07-13 08:02:15

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [ZoneInfo](https://cloud.tencent.com/document/api/1207/47576#ZoneInfo)

	* 新增成员：InstanceDisplayLabel


### 第 16 次发布

发布时间：2021-07-06 08:01:43

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeBundles](https://cloud.tencent.com/document/api/1207/47575)

	* 新增入参：Zones


修改数据结构：

* [Instance](https://cloud.tencent.com/document/api/1207/47576#Instance)

	* 新增成员：Zone


### 第 15 次发布

发布时间：2021-06-18 08:01:16

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeZones](https://cloud.tencent.com/document/api/1207/57513)

新增数据结构：

* [ZoneInfo](https://cloud.tencent.com/document/api/1207/47576#ZoneInfo)

### 第 14 次发布

发布时间：2021-06-04 08:01:17

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeKeyPairs](https://cloud.tencent.com/document/api/1207/55540)

	* 新增入参：Filters


### 第 13 次发布

发布时间：2021-05-11 08:00:57

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeBundleDiscount](https://cloud.tencent.com/document/api/1207/55627)

新增数据结构：

* [DiscountDetail](https://cloud.tencent.com/document/api/1207/47576#DiscountDetail)
* [PolicyDetail](https://cloud.tencent.com/document/api/1207/47576#PolicyDetail)

### 第 12 次发布

发布时间：2021-05-08 15:19:32

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [AssociateInstancesKeyPairs](https://cloud.tencent.com/document/api/1207/55544)
* [CreateKeyPair](https://cloud.tencent.com/document/api/1207/55543)
* [DeleteKeyPairs](https://cloud.tencent.com/document/api/1207/55542)
* [DescribeBlueprintInstances](https://cloud.tencent.com/document/api/1207/55532)
* [DescribeFirewallRulesTemplate](https://cloud.tencent.com/document/api/1207/55530)
* [DescribeGeneralResourceQuotas](https://cloud.tencent.com/document/api/1207/55534)
* [DescribeInstanceLoginKeyPairAttribute](https://cloud.tencent.com/document/api/1207/55541)
* [DescribeInstanceVncUrl](https://cloud.tencent.com/document/api/1207/55553)
* [DescribeInstancesDeniedActions](https://cloud.tencent.com/document/api/1207/55552)
* [DescribeInstancesReturnable](https://cloud.tencent.com/document/api/1207/55551)
* [DescribeKeyPairs](https://cloud.tencent.com/document/api/1207/55540)
* [DescribeModifyInstanceBundles](https://cloud.tencent.com/document/api/1207/55550)
* [DescribeRegions](https://cloud.tencent.com/document/api/1207/55555)
* [DescribeResetInstanceBlueprints](https://cloud.tencent.com/document/api/1207/55549)
* [DescribeSnapshotsDeniedActions](https://cloud.tencent.com/document/api/1207/55535)
* [DisassociateInstancesKeyPairs](https://cloud.tencent.com/document/api/1207/55539)
* [ImportKeyPair](https://cloud.tencent.com/document/api/1207/55538)
* [InquirePriceCreateBlueprint](https://cloud.tencent.com/document/api/1207/55531)
* [InquirePriceCreateInstances](https://cloud.tencent.com/document/api/1207/55558)
* [InquirePriceRenewInstances](https://cloud.tencent.com/document/api/1207/55557)
* [ModifyFirewallRuleDescription](https://cloud.tencent.com/document/api/1207/55529)
* [ModifyFirewallRules](https://cloud.tencent.com/document/api/1207/55528)
* [ModifyInstancesAttribute](https://cloud.tencent.com/document/api/1207/55548)
* [ModifyInstancesLoginKeyPairAttribute](https://cloud.tencent.com/document/api/1207/55537)
* [ModifyInstancesRenewFlag](https://cloud.tencent.com/document/api/1207/55547)
* [ResetInstancesPassword](https://cloud.tencent.com/document/api/1207/55546)
* [TerminateInstances](https://cloud.tencent.com/document/api/1207/55545)

新增数据结构：

* [BlueprintInstance](https://cloud.tencent.com/document/api/1207/47576#BlueprintInstance)
* [BlueprintPrice](https://cloud.tencent.com/document/api/1207/47576#BlueprintPrice)
* [DeniedAction](https://cloud.tencent.com/document/api/1207/47576#DeniedAction)
* [GeneralResourceQuota](https://cloud.tencent.com/document/api/1207/47576#GeneralResourceQuota)
* [InstanceChargePrepaid](https://cloud.tencent.com/document/api/1207/47576#InstanceChargePrepaid)
* [InstanceDeniedActions](https://cloud.tencent.com/document/api/1207/47576#InstanceDeniedActions)
* [InstanceReturnable](https://cloud.tencent.com/document/api/1207/47576#InstanceReturnable)
* [KeyPair](https://cloud.tencent.com/document/api/1207/47576#KeyPair)
* [ModifyBundle](https://cloud.tencent.com/document/api/1207/47576#ModifyBundle)
* [RegionInfo](https://cloud.tencent.com/document/api/1207/47576#RegionInfo)
* [ResetInstanceBlueprint](https://cloud.tencent.com/document/api/1207/47576#ResetInstanceBlueprint)
* [SnapshotDeniedActions](https://cloud.tencent.com/document/api/1207/47576#SnapshotDeniedActions)
* [Software](https://cloud.tencent.com/document/api/1207/47576#Software)
* [SoftwareDetail](https://cloud.tencent.com/document/api/1207/47576#SoftwareDetail)

### 第 11 次发布

发布时间：2021-04-08 08:00:44

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [ApplyInstanceSnapshot](https://cloud.tencent.com/document/api/1207/54391)
* [CreateBlueprint](https://cloud.tencent.com/document/api/1207/54385)
* [CreateInstanceSnapshot](https://cloud.tencent.com/document/api/1207/54390)
* [DeleteBlueprints](https://cloud.tencent.com/document/api/1207/54384)
* [DeleteSnapshots](https://cloud.tencent.com/document/api/1207/54389)
* [DescribeSnapshots](https://cloud.tencent.com/document/api/1207/54388)
* [ModifyBlueprintAttribute](https://cloud.tencent.com/document/api/1207/54383)
* [ModifySnapshotAttribute](https://cloud.tencent.com/document/api/1207/54387)

新增数据结构：

* [Snapshot](https://cloud.tencent.com/document/api/1207/47576#Snapshot)

### 第 10 次发布

发布时间：2021-03-19 08:00:45

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateFirewallRules](https://cloud.tencent.com/document/api/1207/48254)

	* 新增入参：FirewallVersion

* [DeleteFirewallRules](https://cloud.tencent.com/document/api/1207/48253)

	* 新增入参：FirewallVersion

* [DescribeFirewallRules](https://cloud.tencent.com/document/api/1207/48252)

	* 新增出参：FirewallVersion


修改数据结构：

* [Blueprint](https://cloud.tencent.com/document/api/1207/47576#Blueprint)

	* 新增成员：RequiredMemorySize

* [FirewallRule](https://cloud.tencent.com/document/api/1207/47576#FirewallRule)

	* 新增成员：CidrBlock, Action, FirewallRuleDescription

* [FirewallRuleInfo](https://cloud.tencent.com/document/api/1207/47576#FirewallRuleInfo)

	* 新增成员：CidrBlock, Action, FirewallRuleDescription


### 第 9 次发布

发布时间：2021-03-01 08:00:42

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [Blueprint](https://cloud.tencent.com/document/api/1207/47576#Blueprint)

	* 新增成员：CreatedTime, BlueprintName, SupportAutomationTools


### 第 8 次发布

发布时间：2021-01-07 08:00:25

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [Bundle](https://cloud.tencent.com/document/api/1207/47576#Bundle)

	* 新增成员：BundleDisplayLabel


### 第 7 次发布

发布时间：2020-10-28 08:00:12

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [Bundle](https://cloud.tencent.com/document/api/1207/47576#Bundle)

	* 新增成员：BundleType


### 第 6 次发布

发布时间：2020-10-13 08:00:11

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [Blueprint](https://cloud.tencent.com/document/api/1207/47576#Blueprint)

	* 新增成员：BlueprintState


### 第 5 次发布

发布时间：2020-09-24 08:00:13

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeInstancesTrafficPackages](https://cloud.tencent.com/document/api/1207/48681)

新增数据结构：

* [InstanceTrafficPackage](https://cloud.tencent.com/document/api/1207/47576#InstanceTrafficPackage)
* [TrafficPackage](https://cloud.tencent.com/document/api/1207/47576#TrafficPackage)

### 第 4 次发布

发布时间：2020-09-17 08:00:09

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [Blueprint](https://cloud.tencent.com/document/api/1207/47576#Blueprint)

	* 新增成员：RequiredSystemDiskSize


### 第 3 次发布

发布时间：2020-09-10 08:00:19

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateFirewallRules](https://cloud.tencent.com/document/api/1207/48254)
* [DeleteFirewallRules](https://cloud.tencent.com/document/api/1207/48253)
* [DescribeFirewallRules](https://cloud.tencent.com/document/api/1207/48252)

新增数据结构：

* [FirewallRule](https://cloud.tencent.com/document/api/1207/47576#FirewallRule)
* [FirewallRuleInfo](https://cloud.tencent.com/document/api/1207/47576#FirewallRuleInfo)

### 第 2 次发布

发布时间：2020-08-21 08:00:08

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeBlueprints](https://cloud.tencent.com/document/api/1207/47689)

新增数据结构：

* [Blueprint](https://cloud.tencent.com/document/api/1207/47576#Blueprint)

### 第 1 次发布

发布时间：2020-08-18 08:00:08

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeBundles](https://cloud.tencent.com/document/api/1207/47575)
* [DescribeInstances](https://cloud.tencent.com/document/api/1207/47573)
* [RebootInstances](https://cloud.tencent.com/document/api/1207/47572)
* [ResetInstance](https://cloud.tencent.com/document/api/1207/47571)
* [StartInstances](https://cloud.tencent.com/document/api/1207/47570)
* [StopInstances](https://cloud.tencent.com/document/api/1207/47569)

新增数据结构：

* [Bundle](https://cloud.tencent.com/document/api/1207/47576#Bundle)
* [Filter](https://cloud.tencent.com/document/api/1207/47576#Filter)
* [Instance](https://cloud.tencent.com/document/api/1207/47576#Instance)
* [InstancePrice](https://cloud.tencent.com/document/api/1207/47576#InstancePrice)
* [InternetAccessible](https://cloud.tencent.com/document/api/1207/47576#InternetAccessible)
* [LoginSettings](https://cloud.tencent.com/document/api/1207/47576#LoginSettings)
* [Price](https://cloud.tencent.com/document/api/1207/47576#Price)
* [SystemDisk](https://cloud.tencent.com/document/api/1207/47576#SystemDisk)




## 云直播CSS(live) 版本：2018-08-01

### 第 130 次发布

发布时间：2024-06-26 01:19:20

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [CommonMixControlParams](https://cloud.tencent.com/document/api/267/20474#CommonMixControlParams)

	* 新增成员：UsePictureTransparent


### 第 129 次发布

发布时间：2024-05-29 01:52:02

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateLivePullStreamTask](https://cloud.tencent.com/document/api/267/56245)

	* 新增入参：TranscodeTemplateName


修改数据结构：

* [PullStreamTaskInfo](https://cloud.tencent.com/document/api/267/20474#PullStreamTaskInfo)

	* 新增成员：TranscodeTemplateName


### 第 128 次发布

发布时间：2024-05-13 01:22:02

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeLivePadProcessorList](https://cloud.tencent.com/document/api/267/106082)
* [StopLivePadProcessor](https://cloud.tencent.com/document/api/267/106081)

### 第 127 次发布

发布时间：2024-04-22 01:19:59

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [ModifyLivePullStreamTask](https://cloud.tencent.com/document/api/267/56242)

	* 新增入参：BackupVodUrl


### 第 126 次发布

发布时间：2024-04-19 01:20:58

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateLiveStreamMonitor](https://cloud.tencent.com/document/api/267/93521)

	* 新增入参：AiQualityControl

* [ModifyLiveStreamMonitor](https://cloud.tencent.com/document/api/267/93516)

	* 新增入参：AiQualityControl


修改数据结构：

* [LiveStreamMonitorInfo](https://cloud.tencent.com/document/api/267/20474#LiveStreamMonitorInfo)

	* 新增成员：AiQualityControl


### 第 125 次发布

发布时间：2024-04-11 01:17:46

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [DomainInfo](https://cloud.tencent.com/document/api/267/20474#DomainInfo)

	* <font color="#dd0000">**修改成员**：</font>Name, Type, Status, CreateTime, BCName, TargetDomain, PlayType, IsDelayLive, CurrentCName, RentTag, RentExpireTime, IsMiniProgramLive


### 第 124 次发布

发布时间：2024-04-08 01:18:24

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [RecordParam](https://cloud.tencent.com/document/api/267/20474#RecordParam)

	* 新增成员：CosBucketName, CosBucketRegion, CosBucketPath


### 第 123 次发布

发布时间：2024-04-03 11:22:46

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateLiveRecordTemplate](https://cloud.tencent.com/document/api/267/32614)

	* 新增入参：CosStore


### 第 122 次发布

发布时间：2024-04-02 01:18:22

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [RecordTemplateInfo](https://cloud.tencent.com/document/api/267/20474#RecordTemplateInfo)

	* 新增成员：CosStore


### 第 121 次发布

发布时间：2024-03-21 01:19:47

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeLiveWatermarks](https://cloud.tencent.com/document/api/267/30152)

	* 新增入参：Name, PageNo, PageSize


### 第 120 次发布

发布时间：2024-03-19 01:18:08

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateLiveTranscodeRule](https://cloud.tencent.com/document/api/267/32647)

	* 新增入参：StreamName


### 第 119 次发布

发布时间：2024-03-18 01:17:44

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateLiveTranscodeRule](https://cloud.tencent.com/document/api/267/32647)

	* <font color="#dd0000">**删除入参**：</font>StreamName


### 第 118 次发布

发布时间：2024-03-14 01:19:23

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribePullTransformPushInfo](https://cloud.tencent.com/document/api/267/104324)

新增数据结构：

* [TaskDurationInfo](https://cloud.tencent.com/document/api/267/20474#TaskDurationInfo)

### 第 117 次发布

发布时间：2024-01-22 01:16:38

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeLiveTranscodeTemplates](https://cloud.tencent.com/document/api/267/32641)

	* 新增入参：TemplateType


### 第 116 次发布

发布时间：2023-11-14 01:19:55

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateLivePullStreamTask](https://cloud.tencent.com/document/api/267/56245)

	* 新增入参：BackupToUrl

* [ModifyLivePullStreamTask](https://cloud.tencent.com/document/api/267/56242)

	* 新增入参：BackupToUrl


### 第 115 次发布

发布时间：2023-10-26 01:18:09

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateLiveCallbackTemplate](https://cloud.tencent.com/document/api/267/32637)

	* 新增入参：RecordStatusNotifyUrl

* [ModifyLiveCallbackTemplate](https://cloud.tencent.com/document/api/267/32631)

	* 新增入参：RecordStatusNotifyUrl


修改数据结构：

* [CallBackTemplateInfo](https://cloud.tencent.com/document/api/267/20474#CallBackTemplateInfo)

	* <font color="#dd0000">**修改成员**：</font>AudioAuditNotifyUrl


### 第 114 次发布

发布时间：2023-10-18 02:20:12

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeBackupStreamList](https://cloud.tencent.com/document/api/267/100422)
* [EnableOptimalSwitching](https://cloud.tencent.com/document/api/267/100421)
* [SwitchBackupStream](https://cloud.tencent.com/document/api/267/100420)

新增数据结构：

* [BackupStreamDetailData](https://cloud.tencent.com/document/api/267/20474#BackupStreamDetailData)
* [BackupStreamGroupInfo](https://cloud.tencent.com/document/api/267/20474#BackupStreamGroupInfo)

### 第 113 次发布

发布时间：2023-10-13 01:19:37

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateLivePullStreamTask](https://cloud.tencent.com/document/api/267/56245)

	* 新增入参：SpecifyTaskId

* [ModifyLivePullStreamTask](https://cloud.tencent.com/document/api/267/56242)

	* 新增入参：SpecifyTaskId


### 第 112 次发布

发布时间：2023-09-28 01:17:11

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [ModifyLivePullStreamTask](https://cloud.tencent.com/document/api/267/56242)

	* 新增入参：ToUrl


### 第 111 次发布

发布时间：2023-09-18 02:01:47

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [PullStreamTaskInfo](https://cloud.tencent.com/document/api/267/20474#PullStreamTaskInfo)

	* 新增成员：BackupToUrl

	* <font color="#dd0000">**修改成员**：</font>RecordTemplateId


### 第 110 次发布

发布时间：2023-09-04 02:06:58

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeDeliverLogDownList](https://cloud.tencent.com/document/api/267/97727)

新增数据结构：

* [PushLogInfo](https://cloud.tencent.com/document/api/267/20474#PushLogInfo)

### 第 109 次发布

发布时间：2023-08-01 01:30:51

本次发布包含了以下内容：

改善已有的文档。

新增数据结构：

* [MixPortraitSegmentParams](https://cloud.tencent.com/document/api/267/20474#MixPortraitSegmentParams)

修改数据结构：

* [CommonMixInputParam](https://cloud.tencent.com/document/api/267/20474#CommonMixInputParam)

	* 新增成员：PortraitSegmentParams


### 第 108 次发布

发布时间：2023-07-05 01:34:10

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateLiveStreamMonitor](https://cloud.tencent.com/document/api/267/93521)

	* 新增入参：AiFormatDiagnose

* [ModifyLiveStreamMonitor](https://cloud.tencent.com/document/api/267/93516)

	* 新增入参：AiFormatDiagnose


修改数据结构：

* [DiagnoseResult](https://cloud.tencent.com/document/api/267/20474#DiagnoseResult)

	* 新增成员：StreamFormatResults

* [LiveStreamMonitorInfo](https://cloud.tencent.com/document/api/267/20474#LiveStreamMonitorInfo)

	* 新增成员：AiFormatDiagnose


### 第 107 次发布

发布时间：2023-06-21 01:25:23

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeLivePullStreamTaskStatus](https://cloud.tencent.com/document/api/267/94221)

新增数据结构：

* [TaskStatusInfo](https://cloud.tencent.com/document/api/267/20474#TaskStatusInfo)

修改数据结构：

* [StreamOnlineInfo](https://cloud.tencent.com/document/api/267/20474#StreamOnlineInfo)

	* 新增成员：PushToDelay


### 第 106 次发布

发布时间：2023-06-15 01:25:15

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateLivePadRule](https://cloud.tencent.com/document/api/267/93530)
* [CreateLivePadTemplate](https://cloud.tencent.com/document/api/267/93529)
* [CreateLiveStreamMonitor](https://cloud.tencent.com/document/api/267/93521)
* [DeleteLivePadRule](https://cloud.tencent.com/document/api/267/93528)
* [DeleteLivePadTemplate](https://cloud.tencent.com/document/api/267/93527)
* [DeleteLiveStreamMonitor](https://cloud.tencent.com/document/api/267/93520)
* [DescribeLivePadRules](https://cloud.tencent.com/document/api/267/93526)
* [DescribeLivePadTemplate](https://cloud.tencent.com/document/api/267/93525)
* [DescribeLivePadTemplates](https://cloud.tencent.com/document/api/267/93524)
* [DescribeLiveStreamMonitor](https://cloud.tencent.com/document/api/267/93519)
* [DescribeLiveStreamMonitorList](https://cloud.tencent.com/document/api/267/93518)
* [DescribeMonitorReport](https://cloud.tencent.com/document/api/267/93517)
* [ModifyLivePadTemplate](https://cloud.tencent.com/document/api/267/93523)
* [ModifyLiveStreamMonitor](https://cloud.tencent.com/document/api/267/93516)
* [StartLiveStreamMonitor](https://cloud.tencent.com/document/api/267/93515)
* [StopLiveStreamMonitor](https://cloud.tencent.com/document/api/267/93514)

新增数据结构：

* [DiagnoseResult](https://cloud.tencent.com/document/api/267/20474#DiagnoseResult)
* [LiveStreamMonitorInfo](https://cloud.tencent.com/document/api/267/20474#LiveStreamMonitorInfo)
* [LiveStreamMonitorInputInfo](https://cloud.tencent.com/document/api/267/20474#LiveStreamMonitorInputInfo)
* [LiveStreamMonitorNotifyPolicy](https://cloud.tencent.com/document/api/267/20474#LiveStreamMonitorNotifyPolicy)
* [LiveStreamMonitorOutputInfo](https://cloud.tencent.com/document/api/267/20474#LiveStreamMonitorOutputInfo)
* [MPSResult](https://cloud.tencent.com/document/api/267/20474#MPSResult)
* [PadTemplate](https://cloud.tencent.com/document/api/267/20474#PadTemplate)

### 第 105 次发布

发布时间：2023-06-14 01:30:33

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [RestartLivePullStreamTask](https://cloud.tencent.com/document/api/267/93478)

### 第 104 次发布

发布时间：2023-06-13 01:26:49

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateLivePullStreamTask](https://cloud.tencent.com/document/api/267/56245)

	* 新增入参：RecordTemplateId


### 第 103 次发布

发布时间：2023-06-07 01:33:34

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [PullStreamTaskInfo](https://cloud.tencent.com/document/api/267/20474#PullStreamTaskInfo)

	* 新增成员：RecordTemplateId


### 第 102 次发布

发布时间：2023-05-29 14:52:01

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [AddLiveWatermark](https://cloud.tencent.com/document/api/267/30154)

	* 新增入参：BackgroundWidth, BackgroundHeight

* [UpdateLiveWatermark](https://cloud.tencent.com/document/api/267/30150)

	* 新增入参：BackgroundWidth, BackgroundHeight


修改数据结构：

* [WatermarkInfo](https://cloud.tencent.com/document/api/267/20474#WatermarkInfo)

	* 新增成员：BackgroundWidth, BackgroundHeight


### 第 101 次发布

发布时间：2023-05-22 01:41:23

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [ModifyLiveCallbackTemplate](https://cloud.tencent.com/document/api/267/32631)

	* 新增入参：AudioAuditNotifyUrl


### 第 100 次发布

发布时间：2023-05-10 01:34:14

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeLiveXP2PDetailInfoList](https://cloud.tencent.com/document/api/267/90905)

新增数据结构：

* [XP2PDetailInfo](https://cloud.tencent.com/document/api/267/20474#XP2PDetailInfo)

### 第 99 次发布

发布时间：2023-04-28 01:29:18

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateLiveCallbackTemplate](https://cloud.tencent.com/document/api/267/32637)

	* 新增入参：AudioAuditNotifyUrl


### 第 98 次发布

发布时间：2023-04-19 01:38:43

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [CallBackTemplateInfo](https://cloud.tencent.com/document/api/267/20474#CallBackTemplateInfo)

	* 新增成员：AudioAuditNotifyUrl

* [LivePackageInfo](https://cloud.tencent.com/document/api/267/20474#LivePackageInfo)

	* 新增成员：WillRenew, RenewalResult


### 第 97 次发布

发布时间：2023-03-20 01:38:41

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeLogDownloadList](https://cloud.tencent.com/document/api/267/34084)

	* 新增入参：IsFastLive


### 第 96 次发布

发布时间：2023-02-07 01:40:55

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateLiveTimeShiftRule](https://cloud.tencent.com/document/api/267/86170)
* [CreateLiveTimeShiftTemplate](https://cloud.tencent.com/document/api/267/86169)
* [DeleteLiveTimeShiftRule](https://cloud.tencent.com/document/api/267/86168)
* [DeleteLiveTimeShiftTemplate](https://cloud.tencent.com/document/api/267/86167)
* [DescribeLiveTimeShiftRules](https://cloud.tencent.com/document/api/267/86166)
* [DescribeLiveTimeShiftTemplates](https://cloud.tencent.com/document/api/267/86165)
* [ModifyLiveTimeShiftTemplate](https://cloud.tencent.com/document/api/267/86164)

新增数据结构：

* [TimeShiftTemplate](https://cloud.tencent.com/document/api/267/20474#TimeShiftTemplate)

### 第 95 次发布

发布时间：2023-02-03 01:31:09

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeTimeShiftRecordDetail](https://cloud.tencent.com/document/api/267/86091)
* [DescribeTimeShiftStreamList](https://cloud.tencent.com/document/api/267/86090)

新增数据结构：

* [TimeShiftRecord](https://cloud.tencent.com/document/api/267/20474#TimeShiftRecord)
* [TimeShiftStreamInfo](https://cloud.tencent.com/document/api/267/20474#TimeShiftStreamInfo)

### 第 94 次发布

发布时间：2022-12-30 01:32:32

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [CallBackRuleInfo](https://cloud.tencent.com/document/api/267/20474#CallBackRuleInfo)

	* <font color="#dd0000">**修改成员**：</font>CreateTime, UpdateTime, TemplateId, DomainName, AppName

* [CertInfo](https://cloud.tencent.com/document/api/267/20474#CertInfo)

	* <font color="#dd0000">**修改成员**：</font>CertId, CertName, Description, CreateTime, HttpsCrt, CertType, CertExpireTime, DomainList

* [DomainCertInfo](https://cloud.tencent.com/document/api/267/20474#DomainCertInfo)

	* <font color="#dd0000">**修改成员**：</font>CertId, CertName, Description, CreateTime, HttpsCrt, CertType, CertExpireTime, DomainName, Status, CertDomains, CloudCertId

* [DomainInfo](https://cloud.tencent.com/document/api/267/20474#DomainInfo)

	* <font color="#dd0000">**修改成员**：</font>Name, Type, Status, CreateTime, BCName, TargetDomain, PlayType, IsDelayLive, CurrentCName, RentTag, RentExpireTime, IsMiniProgramLive

* [ForbidStreamInfo](https://cloud.tencent.com/document/api/267/20474#ForbidStreamInfo)

	* <font color="#dd0000">**修改成员**：</font>StreamName, CreateTime, ExpireTime, AppName, DomainName

* [LiveDomainCertBindings](https://cloud.tencent.com/document/api/267/20474#LiveDomainCertBindings)

	* <font color="#dd0000">**修改成员**：</font>DomainName, CertificateAlias, CertType, Status, CertExpireTime, CertId, CloudCertId, UpdateTime

* [LivePackageInfo](https://cloud.tencent.com/document/api/267/20474#LivePackageInfo)

	* <font color="#dd0000">**修改成员**：</font>Id, Total, Used, Left, BuyTime, ExpireTime, Type, Status

* [LogInfo](https://cloud.tencent.com/document/api/267/20474#LogInfo)

	* <font color="#dd0000">**修改成员**：</font>LogName, LogUrl, LogTime, FileSize

* [RuleInfo](https://cloud.tencent.com/document/api/267/20474#RuleInfo)

	* <font color="#dd0000">**修改成员**：</font>CreateTime, UpdateTime, TemplateId, DomainName, AppName, StreamName

* [WatermarkInfo](https://cloud.tencent.com/document/api/267/20474#WatermarkInfo)

	* <font color="#dd0000">**修改成员**：</font>WatermarkId, PictureUrl, XPosition, YPosition, WatermarkName, Status, CreateTime, Width, Height


### 第 93 次发布

发布时间：2022-12-14 01:34:24

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateLiveCallbackTemplate](https://cloud.tencent.com/document/api/267/32637)

	* 新增入参：PushExceptionNotifyUrl

* [ModifyLiveCallbackTemplate](https://cloud.tencent.com/document/api/267/32631)

	* 新增入参：PushExceptionNotifyUrl


修改数据结构：

* [CallBackTemplateInfo](https://cloud.tencent.com/document/api/267/20474#CallBackTemplateInfo)

	* 新增成员：PushExceptionNotifyUrl


### 第 92 次发布

发布时间：2022-11-09 06:38:57

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateLivePullStreamTask](https://cloud.tencent.com/document/api/267/56245)

	* 新增入参：VodLocalMode

* [ModifyLivePullStreamTask](https://cloud.tencent.com/document/api/267/56242)

	* 新增入参：VodLocalMode


### 第 91 次发布

发布时间：2022-11-08 06:31:20

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [PullStreamTaskInfo](https://cloud.tencent.com/document/api/267/20474#PullStreamTaskInfo)

	* 新增成员：VodLocalMode

* [PushQualityData](https://cloud.tencent.com/document/api/267/20474#PushQualityData)

	* 新增成员：ServerIp


### 第 90 次发布

发布时间：2022-10-28 06:35:04

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [TranscodeDetailInfo](https://cloud.tencent.com/document/api/267/20474#TranscodeDetailInfo)

	* 新增成员：MainlandOrOversea


### 第 89 次发布

发布时间：2022-09-23 06:36:42

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [ModifyLiveSnapshotTemplate](https://cloud.tencent.com/document/api/267/32618)

	* <font color="#dd0000">**修改入参**：</font>CosAppId, CosBucket, CosRegion


### 第 88 次发布

发布时间：2022-09-16 06:31:07

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [AuthenticateDomainOwner](https://cloud.tencent.com/document/api/267/80524)

修改接口：

* [AddLiveDomain](https://cloud.tencent.com/document/api/267/33862)

	* 新增入参：VerifyOwnerType


### 第 87 次发布

发布时间：2022-09-14 06:27:40

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeTranscodeTaskNum](https://cloud.tencent.com/document/api/267/80463)

新增数据结构：

* [TranscodeTaskNum](https://cloud.tencent.com/document/api/267/20474#TranscodeTaskNum)

### 第 86 次发布

发布时间：2022-08-17 06:29:38

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateLivePullStreamTask](https://cloud.tencent.com/document/api/267/56245)

	* 新增入参：WatermarkList

* [ModifyLivePullStreamTask](https://cloud.tencent.com/document/api/267/56242)

	* 新增入参：WatermarkList


新增数据结构：

* [PullPushWatermarkInfo](https://cloud.tencent.com/document/api/267/20474#PullPushWatermarkInfo)

修改数据结构：

* [PullStreamTaskInfo](https://cloud.tencent.com/document/api/267/20474#PullStreamTaskInfo)

	* 新增成员：BackupSourceType, BackupSourceUrl, WatermarkList


### 第 85 次发布

发布时间：2022-08-11 06:39:01

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeLiveDomains](https://cloud.tencent.com/document/api/267/33856)

	* 新增出参：PlayTypeCount


### 第 84 次发布

发布时间：2022-08-08 06:27:50

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeLiveDomainCertBindings](https://cloud.tencent.com/document/api/267/78656)

	* 新增出参：LiveDomainCertBindings, TotalNum

* [ModifyLiveDomainCertBindings](https://cloud.tencent.com/document/api/267/78655)

	* 新增出参：Errors


新增数据结构：

* [BatchDomainOperateErrors](https://cloud.tencent.com/document/api/267/20474#BatchDomainOperateErrors)
* [LiveDomainCertBindings](https://cloud.tencent.com/document/api/267/20474#LiveDomainCertBindings)

### 第 83 次发布

发布时间：2022-08-05 06:27:26

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeLiveDomainCertBindings](https://cloud.tencent.com/document/api/267/78656)
* [ModifyLiveDomainCertBindings](https://cloud.tencent.com/document/api/267/78655)

新增数据结构：

* [LiveCertDomainInfo](https://cloud.tencent.com/document/api/267/20474#LiveCertDomainInfo)

### 第 82 次发布

发布时间：2022-07-29 06:11:33

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [ForbidStreamInfo](https://cloud.tencent.com/document/api/267/20474#ForbidStreamInfo)

	* 新增成员：AppName, DomainName


### 第 81 次发布

发布时间：2022-07-12 06:13:23

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribePushBandwidthAndFluxList](https://cloud.tencent.com/document/api/267/59511)

	* 新增入参：CountryNames


### 第 80 次发布

发布时间：2022-07-11 06:14:37

本次发布包含了以下内容：

改善已有的文档。

<font color="#dd0000">**删除接口**：</font>

* BindLiveDomainCert
* CreateLiveCert
* DeleteLiveCert
* ModifyLiveCert
* ModifyLiveDomainCert

### 第 79 次发布

发布时间：2022-06-22 06:10:05

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateLiveTranscodeTemplate](https://cloud.tencent.com/document/api/267/32646)

	* 新增入参：DRMType, DRMTracks

* [ModifyLiveTranscodeTemplate](https://cloud.tencent.com/document/api/267/32640)

	* 新增入参：DRMType, DRMTracks


修改数据结构：

* [TemplateInfo](https://cloud.tencent.com/document/api/267/20474#TemplateInfo)

	* 新增成员：DRMType, DRMTracks

* [TimeShiftBillData](https://cloud.tencent.com/document/api/267/20474#TimeShiftBillData)

	* 新增成员：TotalDuration


### 第 78 次发布

发布时间：2022-06-14 06:13:41

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeLiveTimeShiftBillInfoList](https://cloud.tencent.com/document/api/267/75504)

新增数据结构：

* [TimeShiftBillData](https://cloud.tencent.com/document/api/267/20474#TimeShiftBillData)

### 第 77 次发布

发布时间：2022-06-08 06:11:54

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateLivePullStreamTask](https://cloud.tencent.com/document/api/267/56245)

	* 新增入参：ToUrl

* [CreateLiveRecordTemplate](https://cloud.tencent.com/document/api/267/32614)

	* 新增入参：FlvSpecialParam

* [ModifyLiveRecordTemplate](https://cloud.tencent.com/document/api/267/32608)

	* 新增入参：FlvSpecialParam


新增数据结构：

* [FlvSpecialParam](https://cloud.tencent.com/document/api/267/20474#FlvSpecialParam)

修改数据结构：

* [RecordTemplateInfo](https://cloud.tencent.com/document/api/267/20474#RecordTemplateInfo)

	* 新增成员：FlvSpecialParam


### 第 76 次发布

发布时间：2022-03-29 08:12:29

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [PushQualityData](https://cloud.tencent.com/document/api/267/20474#PushQualityData)

	* 新增成员：Bandwidth, Flux


### 第 75 次发布

发布时间：2022-03-23 08:08:55

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateLiveRecordTemplate](https://cloud.tencent.com/document/api/267/32614)

	* 新增入参：RemoveWatermark

* [ModifyLiveRecordTemplate](https://cloud.tencent.com/document/api/267/32608)

	* 新增入参：RemoveWatermark


修改数据结构：

* [RecordTemplateInfo](https://cloud.tencent.com/document/api/267/20474#RecordTemplateInfo)

	* 新增成员：RemoveWatermark


### 第 74 次发布

发布时间：2022-03-22 08:11:37

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateLivePullStreamTask](https://cloud.tencent.com/document/api/267/56245)

	* 新增入参：BackupSourceType, BackupSourceUrl

* [ModifyLivePullStreamTask](https://cloud.tencent.com/document/api/267/56242)

	* 新增入参：BackupSourceType, BackupSourceUrl


### 第 73 次发布

发布时间：2022-02-24 08:10:24

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateScreenshotTask](https://cloud.tencent.com/document/api/267/70281)
* [DeleteScreenshotTask](https://cloud.tencent.com/document/api/267/70280)
* [DescribeScreenshotTask](https://cloud.tencent.com/document/api/267/70279)
* [StopScreenshotTask](https://cloud.tencent.com/document/api/267/70278)

新增数据结构：

* [ScreenshotTask](https://cloud.tencent.com/document/api/267/20474#ScreenshotTask)

### 第 72 次发布

发布时间：2022-01-05 08:10:51

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeBillBandwidthAndFluxList](https://cloud.tencent.com/document/api/267/35971)

	* 新增入参：RegionNames

* [DescribePushBandwidthAndFluxList](https://cloud.tencent.com/document/api/267/59511)

	* 新增入参：RegionNames


### 第 71 次发布

发布时间：2021-12-15 08:10:09

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeLivePackageInfo](https://cloud.tencent.com/document/api/267/40942)

	* 新增出参：FluxPackageBillMode


### 第 70 次发布

发布时间：2021-09-09 08:06:21

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeLiveDomains](https://cloud.tencent.com/document/api/267/33856)

	* 新增入参：PlayType


### 第 69 次发布

发布时间：2021-08-24 08:07:29

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeLiveDomains](https://cloud.tencent.com/document/api/267/33856)

	* 新增出参：CreateLimitCount


### 第 68 次发布

发布时间：2021-08-06 08:06:31

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeLiveTranscodeTotalInfo](https://cloud.tencent.com/document/api/267/59864)

新增数据结构：

* [TranscodeTotalInfo](https://cloud.tencent.com/document/api/267/20474#TranscodeTotalInfo)

### 第 67 次发布

发布时间：2021-08-05 08:06:30

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribePushBandwidthAndFluxList](https://cloud.tencent.com/document/api/267/59511)

### 第 66 次发布

发布时间：2021-07-14 08:06:33

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [UnBindLiveDomainCert](https://cloud.tencent.com/document/api/267/32649)

	* 新增入参：Type


### 第 65 次发布

发布时间：2021-06-25 08:06:13

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [RecordParam](https://cloud.tencent.com/document/api/267/20474#RecordParam)

	* 新增成员：Procedure, StorageMode, ClassId


### 第 64 次发布

发布时间：2021-05-25 08:07:04

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateLivePullStreamTask](https://cloud.tencent.com/document/api/267/56245)
* [DeleteLivePullStreamTask](https://cloud.tencent.com/document/api/267/56244)
* [DescribeLivePullStreamTasks](https://cloud.tencent.com/document/api/267/56243)
* [ModifyLivePullStreamTask](https://cloud.tencent.com/document/api/267/56242)

新增数据结构：

* [PullStreamTaskInfo](https://cloud.tencent.com/document/api/267/20474#PullStreamTaskInfo)
* [RecentPullInfo](https://cloud.tencent.com/document/api/267/20474#RecentPullInfo)

### 第 63 次发布

发布时间：2021-05-21 08:05:51

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeRecordTask](https://cloud.tencent.com/document/api/267/56135)

新增数据结构：

* [RecordTask](https://cloud.tencent.com/document/api/267/20474#RecordTask)

### 第 62 次发布

发布时间：2021-05-20 08:05:50

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeLiveDomainReferer](https://cloud.tencent.com/document/api/267/56106)
* [ModifyLiveDomainReferer](https://cloud.tencent.com/document/api/267/56105)

新增数据结构：

* [RefererAuthConfig](https://cloud.tencent.com/document/api/267/20474#RefererAuthConfig)

### 第 61 次发布

发布时间：2021-04-23 08:05:42

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [CommonMixControlParams](https://cloud.tencent.com/document/api/267/20474#CommonMixControlParams)

	* 新增成员：PassInputSei


### 第 60 次发布

发布时间：2021-04-21 08:05:49

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeLiveForbidStreamList](https://cloud.tencent.com/document/api/267/33187)

	* 新增入参：StreamName


### 第 59 次发布

发布时间：2021-04-02 08:05:49

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [PushQualityData](https://cloud.tencent.com/document/api/267/20474#PushQualityData)

	* 新增成员：StreamParam


### 第 58 次发布

发布时间：2021-03-24 08:05:54

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeAllStreamPlayInfoList](https://cloud.tencent.com/document/api/267/43743)

	* 新增入参：PlayDomains


### 第 57 次发布

发布时间：2021-02-02 08:06:16

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeLivePackageInfo](https://cloud.tencent.com/document/api/267/40942)

	* 新增入参：OrderBy, PageNum, PageSize

	* 新增出参：TotalPage, TotalNum, PageNum, PageSize

* [DescribeStreamDayPlayInfoList](https://cloud.tencent.com/document/api/267/33987)

	* 新增入参：MainlandOrOversea, ServiceName

* [DescribeStreamPlayInfoList](https://cloud.tencent.com/document/api/267/33850)

	* 新增入参：ServiceName


### 第 56 次发布

发布时间：2020-12-31 08:05:01

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeProvinceIspPlayInfoList](https://cloud.tencent.com/document/api/267/33988)

	* 新增入参：IpType


### 第 55 次发布

发布时间：2020-12-23 08:04:51

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeCallbackRecordsList](https://cloud.tencent.com/document/api/267/51328)

新增数据结构：

* [CallbackEventInfo](https://cloud.tencent.com/document/api/267/20474#CallbackEventInfo)

### 第 54 次发布

发布时间：2020-12-22 08:05:51

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeLivePackageInfo](https://cloud.tencent.com/document/api/267/40942)

	* 新增出参：PackageBillMode


### 第 53 次发布

发布时间：2020-11-26 08:04:28

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [DomainCertInfo](https://cloud.tencent.com/document/api/267/20474#DomainCertInfo)

	* 新增成员：CertDomains, CloudCertId


### 第 52 次发布

发布时间：2020-11-17 08:05:26

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeUploadStreamNums](https://cloud.tencent.com/document/api/267/49978)

### 第 51 次发布

发布时间：2020-09-28 08:05:59

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeLiveDomain](https://cloud.tencent.com/document/api/267/33858)

	* <font color="#dd0000">**修改入参**：</font>DomainName


### 第 50 次发布

发布时间：2020-09-17 08:04:41

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeAreaBillBandwidthAndFluxList](https://cloud.tencent.com/document/api/267/48474)

新增数据结构：

* [BillAreaInfo](https://cloud.tencent.com/document/api/267/20474#BillAreaInfo)
* [BillCountryInfo](https://cloud.tencent.com/document/api/267/20474#BillCountryInfo)

### 第 49 次发布

发布时间：2020-09-15 08:05:13

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeLiveTranscodeRules](https://cloud.tencent.com/document/api/267/32643)

	* 新增入参：TemplateIds, DomainNames


修改数据结构：

* [TemplateInfo](https://cloud.tencent.com/document/api/267/20474#TemplateInfo)

	* 新增成员：ShortEdgeAsHeight


### 第 48 次发布

发布时间：2020-09-01 08:04:27

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateLiveTranscodeTemplate](https://cloud.tencent.com/document/api/267/32646)

	* 新增入参：ShortEdgeAsHeight

* [ModifyLiveTranscodeTemplate](https://cloud.tencent.com/document/api/267/32640)

	* 新增入参：ShortEdgeAsHeight


### 第 47 次发布

发布时间：2020-08-19 08:13:57

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateLiveCallbackTemplate](https://cloud.tencent.com/document/api/267/32637)

	* 新增入参：StreamMixNotifyUrl


### 第 46 次发布

发布时间：2020-08-06 08:13:31

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [CommonMixControlParams](https://cloud.tencent.com/document/api/267/20474#CommonMixControlParams)

	* 新增成员：AllowCopy


### 第 45 次发布

发布时间：2020-07-23 08:12:45

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeDeliverBandwidthList](https://cloud.tencent.com/document/api/267/46769)

新增数据结构：

* [BandwidthInfo](https://cloud.tencent.com/document/api/267/20474#BandwidthInfo)

### 第 44 次发布

发布时间：2020-07-03 08:12:43

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateRecordTask](https://cloud.tencent.com/document/api/267/45983)
* [DeleteRecordTask](https://cloud.tencent.com/document/api/267/45982)
* [StopRecordTask](https://cloud.tencent.com/document/api/267/45981)

### 第 43 次发布

发布时间：2020-04-30 08:11:54

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [RecordParam](https://cloud.tencent.com/document/api/267/20474#RecordParam)

	* 新增成员：VodFileName


### 第 42 次发布

发布时间：2020-04-27 08:11:28

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateLiveSnapshotTemplate](https://cloud.tencent.com/document/api/267/32624)

	* 新增入参：CosPrefix, CosFileName

* [ModifyLiveSnapshotTemplate](https://cloud.tencent.com/document/api/267/32618)

	* 新增入参：CosPrefix, CosFileName


修改数据结构：

* [SnapshotTemplateInfo](https://cloud.tencent.com/document/api/267/20474#SnapshotTemplateInfo)

	* 新增成员：CosPrefix, CosFileName


### 第 41 次发布

发布时间：2020-04-24 08:11:08

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeAllStreamPlayInfoList](https://cloud.tencent.com/document/api/267/43743)

新增数据结构：

* [MonitorStreamPlayInfo](https://cloud.tencent.com/document/api/267/20474#MonitorStreamPlayInfo)

### 第 40 次发布

发布时间：2020-04-20 08:11:19

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [AddLiveDomain](https://cloud.tencent.com/document/api/267/33862)

	* 新增入参：IsMiniProgramLive


### 第 39 次发布

发布时间：2020-04-16 08:10:54

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DeletePullStreamConfig](https://cloud.tencent.com/document/api/267/31311)
* [DescribePullStreamConfigs](https://cloud.tencent.com/document/api/267/30158)
* [ModifyPullStreamConfig](https://cloud.tencent.com/document/api/267/30157)
* [ModifyPullStreamStatus](https://cloud.tencent.com/document/api/267/30156)

新增数据结构：

* [PullStreamConfig](https://cloud.tencent.com/document/api/267/20474#PullStreamConfig)

### 第 38 次发布

发布时间：2020-04-15 08:12:18

本次发布包含了以下内容：

改善已有的文档。

<font color="#dd0000">**删除接口**：</font>

* DescribePullStreamConfigs
* ModifyPullStreamConfig
* ModifyPullStreamStatus

<font color="#dd0000">**删除数据结构**：</font>

* PullStreamConfig

### 第 37 次发布

发布时间：2020-04-14 08:11:00

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CancelCommonMixStream](https://cloud.tencent.com/document/api/267/43405)
* [CreateCommonMixStream](https://cloud.tencent.com/document/api/267/43404)

新增数据结构：

* [CommonMixControlParams](https://cloud.tencent.com/document/api/267/20474#CommonMixControlParams)
* [CommonMixCropParams](https://cloud.tencent.com/document/api/267/20474#CommonMixCropParams)
* [CommonMixInputParam](https://cloud.tencent.com/document/api/267/20474#CommonMixInputParam)
* [CommonMixLayoutParams](https://cloud.tencent.com/document/api/267/20474#CommonMixLayoutParams)
* [CommonMixOutputParams](https://cloud.tencent.com/document/api/267/20474#CommonMixOutputParams)

### 第 36 次发布

发布时间：2020-04-13 08:11:12

本次发布包含了以下内容：

改善已有的文档。

<font color="#dd0000">**删除接口**：</font>

* DeletePullStreamConfig

### 第 35 次发布

发布时间：2020-03-31 08:09:29

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeBillBandwidthAndFluxList](https://cloud.tencent.com/document/api/267/35971)

	* 新增入参：ServiceName


### 第 34 次发布

发布时间：2020-03-16 08:13:24

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [DomainInfo](https://cloud.tencent.com/document/api/267/20474#DomainInfo)

	* 新增成员：IsMiniProgramLive


### 第 33 次发布

发布时间：2020-03-13 12:08:15

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeConcurrentRecordStreamNum](https://cloud.tencent.com/document/api/267/42219)

新增数据结构：

* [ConcurrentRecordStreamNum](https://cloud.tencent.com/document/api/267/20474#ConcurrentRecordStreamNum)

修改数据结构：

* [PushDataInfo](https://cloud.tencent.com/document/api/267/20474#PushDataInfo)

	* 新增成员：MetaAudioSpeed, MetaVideoSpeed, MetaFps

* [PushQualityData](https://cloud.tencent.com/document/api/267/20474#PushQualityData)

	* 新增成员：MetaVideoRate, MetaAudioRate, MateFps

* [TranscodeDetailInfo](https://cloud.tencent.com/document/api/267/20474#TranscodeDetailInfo)

	* 新增成员：Resolution


### 第 32 次发布

发布时间：2020-03-10 00:49:58

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [RecordParam](https://cloud.tencent.com/document/api/267/20474#RecordParam)

	* 新增成员：VodSubAppId


### 第 31 次发布

发布时间：2020-02-28 16:17:02

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeScreenShotSheetNumList](https://cloud.tencent.com/document/api/267/41695)

新增数据结构：

* [TimeValue](https://cloud.tencent.com/document/api/267/20474#TimeValue)

### 第 30 次发布

发布时间：2020-01-09 11:19:44

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeLivePackageInfo](https://cloud.tencent.com/document/api/267/40942)

新增数据结构：

* [LivePackageInfo](https://cloud.tencent.com/document/api/267/20474#LivePackageInfo)

### 第 29 次发布

发布时间：2020-01-02 21:28:28

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateLiveCert](https://cloud.tencent.com/document/api/267/32656)

	* 新增入参：CloudCertId

	* <font color="#dd0000">**修改入参**：</font>HttpsCrt, HttpsKey


### 第 28 次发布

发布时间：2019-12-26 10:31:31

本次发布包含了以下内容：

改善已有的文档。

<font color="#dd0000">**删除接口**：</font>

* DescribeLiveStreamOnlineInfo

<font color="#dd0000">**删除数据结构**：</font>

* StreamInfo

### 第 27 次发布

发布时间：2019-12-05 18:05:17

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [DomainInfo](https://cloud.tencent.com/document/api/267/20474#DomainInfo)

	* 新增成员：RentTag, RentExpireTime

* [LogInfo](https://cloud.tencent.com/document/api/267/20474#LogInfo)

	* 新增成员：FileSize

* [PushDataInfo](https://cloud.tencent.com/document/api/267/20474#PushDataInfo)

	* 新增成员：AsampleRate


### 第 26 次发布

发布时间：2019-11-11 12:04:15

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribePlayErrorCodeDetailInfoList](https://cloud.tencent.com/document/api/267/35967)

	* 新增入参：MainlandOrOversea

* [DescribePlayErrorCodeSumInfoList](https://cloud.tencent.com/document/api/267/35966)

	* 新增入参：MainlandOrOversea, GroupType, OutLanguage

	* 新增出参：TotalCode2xx, TotalCode3xx

* [DescribeProIspPlaySumInfoList](https://cloud.tencent.com/document/api/267/33989)

	* 新增入参：MainlandOrOversea, OutLanguage

* [DescribeProvinceIspPlayInfoList](https://cloud.tencent.com/document/api/267/33988)

	* 新增入参：MainlandOrOversea

* [DescribeTopClientIpSumInfoList](https://cloud.tencent.com/document/api/267/35964)

	* 新增入参：MainlandOrOversea, OutLanguage


修改数据结构：

* [ClientIpPlaySumInfo](https://cloud.tencent.com/document/api/267/20474#ClientIpPlaySumInfo)

	* 新增成员：CountryArea

* [ProIspPlayCodeDataInfo](https://cloud.tencent.com/document/api/267/20474#ProIspPlayCodeDataInfo)

	* 新增成员：CountryAreaName


### 第 25 次发布

发布时间：2019-10-28 16:12:48

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeLiveTranscodeDetailInfo](https://cloud.tencent.com/document/api/267/33851)

	* 新增入参：StartDayTime, EndDayTime

	* <font color="#dd0000">**修改入参**：</font>DayTime


修改数据结构：

* [ProIspPlayCodeDataInfo](https://cloud.tencent.com/document/api/267/20474#ProIspPlayCodeDataInfo)

	* 新增成员：Code2xx, Code3xx


### 第 24 次发布

发布时间：2019-09-05 21:10:19

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeLiveDomains](https://cloud.tencent.com/document/api/267/33856)

	* 新增入参：DomainPrefix


修改数据结构：

* [BillDataInfo](https://cloud.tencent.com/document/api/267/20474#BillDataInfo)

	* 新增成员：PeakTime


### 第 23 次发布

发布时间：2019-08-15 21:23:09

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [ForbidLiveStream](https://cloud.tencent.com/document/api/267/20468)

	* 新增入参：Reason


修改数据结构：

* [DomainInfo](https://cloud.tencent.com/document/api/267/20474#DomainInfo)

	* 新增成员：CurrentCName


### 第 22 次发布

发布时间：2019-08-08 23:51:49

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateLiveTranscodeTemplate](https://cloud.tencent.com/document/api/267/32646)

	* 新增入参：AiTransCode, AdaptBitratePercent

* [ModifyLiveTranscodeTemplate](https://cloud.tencent.com/document/api/267/32640)

	* 新增入参：AdaptBitratePercent


修改数据结构：

* [TemplateInfo](https://cloud.tencent.com/document/api/267/20474#TemplateInfo)

	* 新增成员：AiTransCode, AdaptBitratePercent


### 第 21 次发布

发布时间：2019-07-25 20:27:34

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeLiveStreamPublishedList](https://cloud.tencent.com/document/api/267/20471)

	* 新增入参：StreamName


### 第 20 次发布

发布时间：2019-07-18 21:40:44

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [StreamName](https://cloud.tencent.com/document/api/267/20474#StreamName)

	* 新增成员：AppName, DomainName, StreamStartTime, StreamEndTime, StopReason, Duration, ClientIp, Resolution


### 第 19 次发布

发布时间：2019-07-12 11:44:55

本次发布包含了以下内容：

改善已有的文档。

<font color="#dd0000">**删除接口**：</font>

* SetLiveWatermarkStatus

### 第 18 次发布

发布时间：2019-07-04 17:06:39

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeBillBandwidthAndFluxList](https://cloud.tencent.com/document/api/267/35971)
* [DescribeGroupProIspPlayInfoList](https://cloud.tencent.com/document/api/267/35970)
* [DescribeHttpStatusInfoList](https://cloud.tencent.com/document/api/267/35969)
* [DescribeLiveDelayInfoList](https://cloud.tencent.com/document/api/267/35976)
* [DescribeLiveDomainPlayInfoList](https://cloud.tencent.com/document/api/267/35968)
* [DescribePlayErrorCodeDetailInfoList](https://cloud.tencent.com/document/api/267/35967)
* [DescribePlayErrorCodeSumInfoList](https://cloud.tencent.com/document/api/267/35966)
* [DescribeStreamPushInfoList](https://cloud.tencent.com/document/api/267/35965)
* [DescribeTopClientIpSumInfoList](https://cloud.tencent.com/document/api/267/35964)
* [DescribeVisitTopSumInfoList](https://cloud.tencent.com/document/api/267/35963)

修改接口：

* [CreateLiveRecordTemplate](https://cloud.tencent.com/document/api/267/32614)

	* 新增入参：Mp3Param

* [ModifyLiveRecordTemplate](https://cloud.tencent.com/document/api/267/32608)

	* 新增入参：Mp3Param


新增数据结构：

* [BillDataInfo](https://cloud.tencent.com/document/api/267/20474#BillDataInfo)
* [CdnPlayStatData](https://cloud.tencent.com/document/api/267/20474#CdnPlayStatData)
* [ClientIpPlaySumInfo](https://cloud.tencent.com/document/api/267/20474#ClientIpPlaySumInfo)
* [DelayInfo](https://cloud.tencent.com/document/api/267/20474#DelayInfo)
* [DomainDetailInfo](https://cloud.tencent.com/document/api/267/20474#DomainDetailInfo)
* [DomainInfoList](https://cloud.tencent.com/document/api/267/20474#DomainInfoList)
* [GroupProIspDataInfo](https://cloud.tencent.com/document/api/267/20474#GroupProIspDataInfo)
* [HttpCodeInfo](https://cloud.tencent.com/document/api/267/20474#HttpCodeInfo)
* [HttpCodeValue](https://cloud.tencent.com/document/api/267/20474#HttpCodeValue)
* [HttpStatusData](https://cloud.tencent.com/document/api/267/20474#HttpStatusData)
* [HttpStatusInfo](https://cloud.tencent.com/document/api/267/20474#HttpStatusInfo)
* [PlayCodeTotalInfo](https://cloud.tencent.com/document/api/267/20474#PlayCodeTotalInfo)
* [PlaySumStatInfo](https://cloud.tencent.com/document/api/267/20474#PlaySumStatInfo)
* [ProIspPlayCodeDataInfo](https://cloud.tencent.com/document/api/267/20474#ProIspPlayCodeDataInfo)
* [PushQualityData](https://cloud.tencent.com/document/api/267/20474#PushQualityData)

修改数据结构：

* [RecordTemplateInfo](https://cloud.tencent.com/document/api/267/20474#RecordTemplateInfo)

	* 新增成员：Mp3Param


### 第 17 次发布

发布时间：2019-05-30 20:43:49

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateLiveSnapshotRule](https://cloud.tencent.com/document/api/267/32625)

	* <font color="#dd0000">**修改入参**：</font>AppName, StreamName

* [DeleteLiveSnapshotRule](https://cloud.tencent.com/document/api/267/32623)

	* <font color="#dd0000">**修改入参**：</font>AppName, StreamName


### 第 16 次发布

发布时间：2019-05-09 19:23:08

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [AddLiveWatermark](https://cloud.tencent.com/document/api/267/30154)

	* 新增入参：Width, Height

* [ModifyLiveRecordTemplate](https://cloud.tencent.com/document/api/267/32608)

	* 新增入参：HlsSpecialParam

* [UpdateLiveWatermark](https://cloud.tencent.com/document/api/267/30150)

	* 新增入参：Width, Height


修改数据结构：

* [WatermarkInfo](https://cloud.tencent.com/document/api/267/20474#WatermarkInfo)

	* 新增成员：Width, Height


### 第 15 次发布

发布时间：2019-04-19 17:21:05

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateLiveRecordRule](https://cloud.tencent.com/document/api/267/32615)

	* <font color="#dd0000">**修改入参**：</font>AppName, StreamName

* [CreateLiveRecordTemplate](https://cloud.tencent.com/document/api/267/32614)

	* 新增入参：HlsSpecialParam

* [DeleteLiveRecordRule](https://cloud.tencent.com/document/api/267/32613)

	* <font color="#dd0000">**修改入参**：</font>AppName, StreamName

* [DescribeStreamPlayInfoList](https://cloud.tencent.com/document/api/267/33850)

	* 新增入参：AppName


新增数据结构：

* [HlsSpecialParam](https://cloud.tencent.com/document/api/267/20474#HlsSpecialParam)

修改数据结构：

* [RecordTemplateInfo](https://cloud.tencent.com/document/api/267/20474#RecordTemplateInfo)

	* 新增成员：HlsSpecialParam


### 第 14 次发布

发布时间：2019-04-12 10:08:45

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [AddLiveDomain](https://cloud.tencent.com/document/api/267/33862)

	* 新增入参：IsDelayLive

* [CreateLiveRecordTemplate](https://cloud.tencent.com/document/api/267/32614)

	* 新增入参：IsDelayLive

* [DescribeLiveDomains](https://cloud.tencent.com/document/api/267/33856)

	* 新增入参：IsDelayLive

* [DescribeLiveRecordTemplates](https://cloud.tencent.com/document/api/267/32609)

	* 新增入参：IsDelayLive


### 第 13 次发布

发布时间：2019-04-04 18:50:47

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeLogDownloadList](https://cloud.tencent.com/document/api/267/34084)

新增数据结构：

* [LogInfo](https://cloud.tencent.com/document/api/267/20474#LogInfo)

### 第 12 次发布

发布时间：2019-03-29 15:02:56

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeLiveStreamPushInfoList](https://cloud.tencent.com/document/api/267/33990)
* [DescribeProIspPlaySumInfoList](https://cloud.tencent.com/document/api/267/33989)
* [DescribeProvinceIspPlayInfoList](https://cloud.tencent.com/document/api/267/33988)
* [DescribeStreamDayPlayInfoList](https://cloud.tencent.com/document/api/267/33987)

<font color="#dd0000">**删除接口**：</font>

* CreateLiveDomainStrategy
* DeleteLiveDomainStrategy
* DescribeLiveDomainStrategys

新增数据结构：

* [PlayDataInfoByStream](https://cloud.tencent.com/document/api/267/20474#PlayDataInfoByStream)
* [PlayStatInfo](https://cloud.tencent.com/document/api/267/20474#PlayStatInfo)
* [ProIspPlaySumInfo](https://cloud.tencent.com/document/api/267/20474#ProIspPlaySumInfo)
* [PushDataInfo](https://cloud.tencent.com/document/api/267/20474#PushDataInfo)

<font color="#dd0000">**删除数据结构**：</font>

* StrategyInfo

修改数据结构：

* [DomainInfo](https://cloud.tencent.com/document/api/267/20474#DomainInfo)

	* 新增成员：IsDelayLive

* [RecordTemplateInfo](https://cloud.tencent.com/document/api/267/20474#RecordTemplateInfo)

	* 新增成员：IsDelayLive


### 第 11 次发布

发布时间：2019-03-21 20:04:22

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [AddLiveDomain](https://cloud.tencent.com/document/api/267/33862)
* [CreateLiveDomainStrategy](https://cloud.tencent.com/document/api/267/33861)
* [DeleteLiveDomain](https://cloud.tencent.com/document/api/267/33860)
* [DeleteLiveDomainStrategy](https://cloud.tencent.com/document/api/267/33859)
* [DescribeLiveDomain](https://cloud.tencent.com/document/api/267/33858)
* [DescribeLiveDomainStrategys](https://cloud.tencent.com/document/api/267/33857)
* [DescribeLiveDomains](https://cloud.tencent.com/document/api/267/33856)
* [DescribeLiveTranscodeDetailInfo](https://cloud.tencent.com/document/api/267/33851)
* [DescribeStreamPlayInfoList](https://cloud.tencent.com/document/api/267/33850)
* [EnableLiveDomain](https://cloud.tencent.com/document/api/267/33855)
* [ForbidLiveDomain](https://cloud.tencent.com/document/api/267/33854)
* [ModifyLivePlayDomain](https://cloud.tencent.com/document/api/267/33853)

新增数据结构：

* [DayStreamPlayInfo](https://cloud.tencent.com/document/api/267/20474#DayStreamPlayInfo)
* [DomainInfo](https://cloud.tencent.com/document/api/267/20474#DomainInfo)
* [StrategyInfo](https://cloud.tencent.com/document/api/267/20474#StrategyInfo)
* [TranscodeDetailInfo](https://cloud.tencent.com/document/api/267/20474#TranscodeDetailInfo)

### 第 10 次发布

发布时间：2019-03-08 17:38:22

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateLiveCallbackTemplate](https://cloud.tencent.com/document/api/267/32637)

	* 新增入参：CallbackKey

* [ModifyLiveCallbackTemplate](https://cloud.tencent.com/document/api/267/32631)

	* 新增入参：CallbackKey


修改数据结构：

* [CallBackTemplateInfo](https://cloud.tencent.com/document/api/267/20474#CallBackTemplateInfo)

	* 新增成员：CallbackKey


### 第 9 次发布

发布时间：2019-02-22 14:53:43

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeLiveForbidStreamList](https://cloud.tencent.com/document/api/267/33187)
* [DescribeLiveStreamEventList](https://cloud.tencent.com/document/api/267/33186)

新增数据结构：

* [ForbidStreamInfo](https://cloud.tencent.com/document/api/267/20474#ForbidStreamInfo)
* [StreamEventInfo](https://cloud.tencent.com/document/api/267/20474#StreamEventInfo)

### 第 8 次发布

发布时间：2019-01-18 19:51:10

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [BindLiveDomainCert](https://cloud.tencent.com/document/api/267/32657)
* [CreateLiveCallbackRule](https://cloud.tencent.com/document/api/267/32638)
* [CreateLiveCallbackTemplate](https://cloud.tencent.com/document/api/267/32637)
* [CreateLiveCert](https://cloud.tencent.com/document/api/267/32656)
* [CreateLiveRecordRule](https://cloud.tencent.com/document/api/267/32615)
* [CreateLiveRecordTemplate](https://cloud.tencent.com/document/api/267/32614)
* [CreateLiveSnapshotRule](https://cloud.tencent.com/document/api/267/32625)
* [CreateLiveSnapshotTemplate](https://cloud.tencent.com/document/api/267/32624)
* [CreateLiveTranscodeRule](https://cloud.tencent.com/document/api/267/32647)
* [CreateLiveTranscodeTemplate](https://cloud.tencent.com/document/api/267/32646)
* [CreateLiveWatermarkRule](https://cloud.tencent.com/document/api/267/32629)
* [DeleteLiveCallbackRule](https://cloud.tencent.com/document/api/267/32636)
* [DeleteLiveCallbackTemplate](https://cloud.tencent.com/document/api/267/32635)
* [DeleteLiveCert](https://cloud.tencent.com/document/api/267/32655)
* [DeleteLiveRecordRule](https://cloud.tencent.com/document/api/267/32613)
* [DeleteLiveRecordTemplate](https://cloud.tencent.com/document/api/267/32612)
* [DeleteLiveSnapshotRule](https://cloud.tencent.com/document/api/267/32623)
* [DeleteLiveSnapshotTemplate](https://cloud.tencent.com/document/api/267/32622)
* [DeleteLiveTranscodeRule](https://cloud.tencent.com/document/api/267/32645)
* [DeleteLiveTranscodeTemplate](https://cloud.tencent.com/document/api/267/32644)
* [DeleteLiveWatermarkRule](https://cloud.tencent.com/document/api/267/32628)
* [DescribeLiveCallbackRules](https://cloud.tencent.com/document/api/267/32634)
* [DescribeLiveCallbackTemplate](https://cloud.tencent.com/document/api/267/32633)
* [DescribeLiveCallbackTemplates](https://cloud.tencent.com/document/api/267/32632)
* [DescribeLiveCert](https://cloud.tencent.com/document/api/267/32654)
* [DescribeLiveCerts](https://cloud.tencent.com/document/api/267/32653)
* [DescribeLiveDomainCert](https://cloud.tencent.com/document/api/267/32652)
* [DescribeLiveRecordRules](https://cloud.tencent.com/document/api/267/32611)
* [DescribeLiveRecordTemplate](https://cloud.tencent.com/document/api/267/32610)
* [DescribeLiveRecordTemplates](https://cloud.tencent.com/document/api/267/32609)
* [DescribeLiveSnapshotRules](https://cloud.tencent.com/document/api/267/32621)
* [DescribeLiveSnapshotTemplate](https://cloud.tencent.com/document/api/267/32620)
* [DescribeLiveSnapshotTemplates](https://cloud.tencent.com/document/api/267/32619)
* [DescribeLiveTranscodeRules](https://cloud.tencent.com/document/api/267/32643)
* [DescribeLiveTranscodeTemplate](https://cloud.tencent.com/document/api/267/32642)
* [DescribeLiveTranscodeTemplates](https://cloud.tencent.com/document/api/267/32641)
* [DescribeLiveWatermark](https://cloud.tencent.com/document/api/267/32627)
* [DescribeLiveWatermarkRules](https://cloud.tencent.com/document/api/267/32626)
* [ModifyLiveCallbackTemplate](https://cloud.tencent.com/document/api/267/32631)
* [ModifyLiveCert](https://cloud.tencent.com/document/api/267/32651)
* [ModifyLiveDomainCert](https://cloud.tencent.com/document/api/267/32650)
* [ModifyLiveRecordTemplate](https://cloud.tencent.com/document/api/267/32608)
* [ModifyLiveSnapshotTemplate](https://cloud.tencent.com/document/api/267/32618)
* [ModifyLiveTranscodeTemplate](https://cloud.tencent.com/document/api/267/32640)
* [UnBindLiveDomainCert](https://cloud.tencent.com/document/api/267/32649)

修改接口：

* [DescribeLiveStreamOnlineList](https://cloud.tencent.com/document/api/267/20472)

	* 新增入参：StreamName

	* <font color="#dd0000">**修改入参**：</font>DomainName


新增数据结构：

* [CallBackRuleInfo](https://cloud.tencent.com/document/api/267/20474#CallBackRuleInfo)
* [CallBackTemplateInfo](https://cloud.tencent.com/document/api/267/20474#CallBackTemplateInfo)
* [CertInfo](https://cloud.tencent.com/document/api/267/20474#CertInfo)
* [DomainCertInfo](https://cloud.tencent.com/document/api/267/20474#DomainCertInfo)
* [RecordParam](https://cloud.tencent.com/document/api/267/20474#RecordParam)
* [RecordTemplateInfo](https://cloud.tencent.com/document/api/267/20474#RecordTemplateInfo)
* [RuleInfo](https://cloud.tencent.com/document/api/267/20474#RuleInfo)
* [SnapshotTemplateInfo](https://cloud.tencent.com/document/api/267/20474#SnapshotTemplateInfo)
* [TemplateInfo](https://cloud.tencent.com/document/api/267/20474#TemplateInfo)

### 第 7 次发布

发布时间：2019-01-17 20:40:05

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [StreamOnlineInfo](https://cloud.tencent.com/document/api/267/20474#StreamOnlineInfo)

	* 新增成员：DomainName


### 第 6 次发布

发布时间：2019-01-10 20:11:53

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreatePullStreamConfig](https://cloud.tencent.com/document/api/267/30159)

	* <font color="#dd0000">**修改入参**：</font>StartTime, EndTime

* [ModifyPullStreamConfig](https://cloud.tencent.com/document/api/267/30157)

	* <font color="#dd0000">**修改入参**：</font>StartTime, EndTime


修改数据结构：

* [PullStreamConfig](https://cloud.tencent.com/document/api/267/20474#PullStreamConfig)

	* <font color="#dd0000">**修改成员**：</font>StartTime, EndTime

* [StreamOnlineInfo](https://cloud.tencent.com/document/api/267/20474#StreamOnlineInfo)

	* 新增成员：AppName


### 第 5 次发布

发布时间：2018-12-27 20:38:48

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [AddDelayLiveStream](https://cloud.tencent.com/document/api/267/20465)

	* 新增入参：ExpireTime


### 第 4 次发布

发布时间：2018-12-06 19:05:52

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DeletePullStreamConfig](https://cloud.tencent.com/document/api/267/31311)

修改接口：

* [ModifyLivePlayAuthKey](https://cloud.tencent.com/document/api/267/30424)

	* 新增入参：AuthBackKey


修改数据结构：

* [PlayAuthKeyInfo](https://cloud.tencent.com/document/api/267/20474#PlayAuthKeyInfo)

	* 新增成员：AuthBackKey


### 第 3 次发布

发布时间：2018-11-15 15:42:56

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeLivePlayAuthKey](https://cloud.tencent.com/document/api/267/30426)
* [DescribeLivePushAuthKey](https://cloud.tencent.com/document/api/267/30425)
* [ModifyLivePlayAuthKey](https://cloud.tencent.com/document/api/267/30424)
* [ModifyLivePushAuthKey](https://cloud.tencent.com/document/api/267/30423)

新增数据结构：

* [PlayAuthKeyInfo](https://cloud.tencent.com/document/api/267/20474#PlayAuthKeyInfo)
* [PushAuthKeyInfo](https://cloud.tencent.com/document/api/267/20474#PushAuthKeyInfo)

### 第 2 次发布

发布时间：2018-10-26 14:29:15

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [AddLiveWatermark](https://cloud.tencent.com/document/api/267/30154)
* [CreateLiveRecord](https://cloud.tencent.com/document/api/267/30148)
* [CreatePullStreamConfig](https://cloud.tencent.com/document/api/267/30159)
* [DeleteLiveRecord](https://cloud.tencent.com/document/api/267/30147)
* [DeleteLiveWatermark](https://cloud.tencent.com/document/api/267/30153)
* [DescribeLiveWatermarks](https://cloud.tencent.com/document/api/267/30152)
* [DescribePullStreamConfigs](https://cloud.tencent.com/document/api/267/30158)
* [ModifyPullStreamConfig](https://cloud.tencent.com/document/api/267/30157)
* [ModifyPullStreamStatus](https://cloud.tencent.com/document/api/267/30156)
* [SetLiveWatermarkStatus](https://cloud.tencent.com/document/api/267/30151)
* [StopLiveRecord](https://cloud.tencent.com/document/api/267/30146)
* [UpdateLiveWatermark](https://cloud.tencent.com/document/api/267/30150)

新增数据结构：

* [PullStreamConfig](https://cloud.tencent.com/document/api/267/20474#PullStreamConfig)
* [WatermarkInfo](https://cloud.tencent.com/document/api/267/20474#WatermarkInfo)

### 第 1 次发布

发布时间：2018-10-11 19:44:12

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [AddDelayLiveStream](https://cloud.tencent.com/document/api/267/20465)
* [DescribeLiveStreamOnlineInfo](https://cloud.tencent.com/document/api/267/20473)
* [DescribeLiveStreamOnlineList](https://cloud.tencent.com/document/api/267/20472)
* [DescribeLiveStreamPublishedList](https://cloud.tencent.com/document/api/267/20471)
* [DescribeLiveStreamState](https://cloud.tencent.com/document/api/267/20470)
* [DropLiveStream](https://cloud.tencent.com/document/api/267/20469)
* [ForbidLiveStream](https://cloud.tencent.com/document/api/267/20468)
* [ResumeDelayLiveStream](https://cloud.tencent.com/document/api/267/20464)
* [ResumeLiveStream](https://cloud.tencent.com/document/api/267/20467)

新增数据结构：

* [PublishTime](https://cloud.tencent.com/document/api/267/20474#PublishTime)
* [StreamInfo](https://cloud.tencent.com/document/api/267/20474#StreamInfo)
* [StreamName](https://cloud.tencent.com/document/api/267/20474#StreamName)
* [StreamOnlineInfo](https://cloud.tencent.com/document/api/267/20474#StreamOnlineInfo)




## 大模型知识引擎(lke) 版本：2023-11-30

### 第 13 次发布

发布时间：2024-07-31 01:49:50

本次发布包含了以下内容：

改善已有的文档。

新增数据结构：

* [HistorySummary](https://cloud.tencent.com/document/api/1759/105104#HistorySummary)
* [InvokeAPI](https://cloud.tencent.com/document/api/1759/105104#InvokeAPI)
* [KnowledgeSummary](https://cloud.tencent.com/document/api/1759/105104#KnowledgeSummary)
* [ProcedureDebugging](https://cloud.tencent.com/document/api/1759/105104#ProcedureDebugging)
* [RunNodeInfo](https://cloud.tencent.com/document/api/1759/105104#RunNodeInfo)
* [StrValue](https://cloud.tencent.com/document/api/1759/105104#StrValue)
* [TaskFlowSummary](https://cloud.tencent.com/document/api/1759/105104#TaskFlowSummary)
* [ValueInfo](https://cloud.tencent.com/document/api/1759/105104#ValueInfo)

修改数据结构：

* [AppModel](https://cloud.tencent.com/document/api/1759/105104#AppModel)

	* 新增成员：IsUseContext, HistoryLimit, UsageType

* [KnowledgeQaOutput](https://cloud.tencent.com/document/api/1759/105104#KnowledgeQaOutput)

	* 新增成员：UseRecommended

* [KnowledgeQaSearch](https://cloud.tencent.com/document/api/1759/105104#KnowledgeQaSearch)

	* 新增成员：ResourceStatus

* [ModelInfo](https://cloud.tencent.com/document/api/1759/105104#ModelInfo)

	* 新增成员：ResourceStatus, PromptWordsLimit

* [Procedure](https://cloud.tencent.com/document/api/1759/105104#Procedure)

	* 新增成员：Debugging, ResourceStatus

* [TokenStat](https://cloud.tencent.com/document/api/1759/105104#TokenStat)

	* 新增成员：TraceId


### 第 12 次发布

发布时间：2024-07-15 01:15:17

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateReconstructDocumentFlow](https://cloud.tencent.com/document/api/1759/107506)

	* 新增入参：FileType


### 第 11 次发布

发布时间：2024-07-11 01:19:53

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeSegments](https://cloud.tencent.com/document/api/1759/108533)

新增数据结构：

* [DocSegment](https://cloud.tencent.com/document/api/1759/105104#DocSegment)

### 第 10 次发布

发布时间：2024-07-08 10:47:57

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [ListDocItem](https://cloud.tencent.com/document/api/1759/105104#ListDocItem)

	* 新增成员：IsAllowRetry


### 第 9 次发布

发布时间：2024-06-25 01:18:18

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [ConvertDocument](https://cloud.tencent.com/document/api/1759/107672)
* [GetAnswerTypeDataCount](https://cloud.tencent.com/document/api/1759/107674)
* [GetLikeDataCount](https://cloud.tencent.com/document/api/1759/107673)

新增数据结构：

* [WordRecognizeInfo](https://cloud.tencent.com/document/api/1759/105104#WordRecognizeInfo)

### 第 8 次发布

发布时间：2024-06-21 21:11:25

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeStorageCredential](https://cloud.tencent.com/document/api/1759/105050)

	* 新增入参：TypeKey

	* <font color="#dd0000">**修改入参**：</font>BotBizId

* [GetDocPreview](https://cloud.tencent.com/document/api/1759/105067)

	* 新增入参：TypeKey

* [GetWsToken](https://cloud.tencent.com/document/api/1759/105089)

	* 新增出参：Balance, InputLenLimit


新增数据结构：

* [FileInfo](https://cloud.tencent.com/document/api/1759/105104#FileInfo)
* [MsgFileInfo](https://cloud.tencent.com/document/api/1759/105104#MsgFileInfo)

修改数据结构：

* [AppModel](https://cloud.tencent.com/document/api/1759/105104#AppModel)

	* 新增成员：TokenBalance

* [Context](https://cloud.tencent.com/document/api/1759/105104#Context)

	* 新增成员：FileInfos

* [KnowledgeQaSearch](https://cloud.tencent.com/document/api/1759/105104#KnowledgeQaSearch)

	* 新增成员：Confidence

* [MsgRecord](https://cloud.tencent.com/document/api/1759/105104#MsgRecord)

	* 新增成员：FileInfos


### 第 7 次发布

发布时间：2024-06-20 01:56:34

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateReconstructDocumentFlow](https://cloud.tencent.com/document/api/1759/107506)
* [GetReconstructDocumentResult](https://cloud.tencent.com/document/api/1759/107505)
* [ReconstructDocument](https://cloud.tencent.com/document/api/1759/107504)

新增数据结构：

* [Coord](https://cloud.tencent.com/document/api/1759/105104#Coord)
* [CreateReconstructDocumentFlowConfig](https://cloud.tencent.com/document/api/1759/105104#CreateReconstructDocumentFlowConfig)
* [DocumentElement](https://cloud.tencent.com/document/api/1759/105104#DocumentElement)
* [DocumentRecognizeInfo](https://cloud.tencent.com/document/api/1759/105104#DocumentRecognizeInfo)
* [Polygon](https://cloud.tencent.com/document/api/1759/105104#Polygon)
* [ReconstructDocumentConfig](https://cloud.tencent.com/document/api/1759/105104#ReconstructDocumentConfig)
* [ReconstructDocumentFailedPage](https://cloud.tencent.com/document/api/1759/105104#ReconstructDocumentFailedPage)

### 第 6 次发布

发布时间：2024-05-13 01:22:27

本次发布包含了以下内容：

改善已有的文档。

新增数据结构：

* [TaskFlowInfo](https://cloud.tencent.com/document/api/1759/105104#TaskFlowInfo)

修改数据结构：

* [MsgRecord](https://cloud.tencent.com/document/api/1759/105104#MsgRecord)

	* 新增成员：SessionId, CanFeedback, ReplyMethod, OptionCards, TaskFlow


### 第 5 次发布

发布时间：2024-04-29 00:05:46

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [ParseDoc](https://cloud.tencent.com/document/api/1759/105749)
* [QueryParseDocResult](https://cloud.tencent.com/document/api/1759/105748)

修改接口：

* [DescribeApp](https://cloud.tencent.com/document/api/1759/105072)

	* 新增出参：AppStatus, AppStatusDesc

* [DescribeStorageCredential](https://cloud.tencent.com/document/api/1759/105050)

	* 新增入参：FileType, IsPublic

	* 新增出参：UploadPath

* [GetMsgRecord](https://cloud.tencent.com/document/api/1759/105090)

	* 新增入参：Scene

	* 新增出参：SessionDisassociatedTimestamp

* [ResetSession](https://cloud.tencent.com/document/api/1759/105086)

	* 新增入参：IsOnlyEmptyTheDialog


新增数据结构：

* [Procedure](https://cloud.tencent.com/document/api/1759/105104#Procedure)
* [TokenStat](https://cloud.tencent.com/document/api/1759/105104#TokenStat)

修改数据结构：

* [ClassifyConfig](https://cloud.tencent.com/document/api/1759/105104#ClassifyConfig)

	* 新增成员：Greeting

* [KnowledgeQaOutput](https://cloud.tencent.com/document/api/1759/105104#KnowledgeQaOutput)

	* 新增成员：ShowQuestionClarify, UseQuestionClarify, QuestionClarifyKeywords

* [MsgRecord](https://cloud.tencent.com/document/api/1759/105104#MsgRecord)

	* 新增成员：ImageUrls, TokenStat

* [SummaryConfig](https://cloud.tencent.com/document/api/1759/105104#SummaryConfig)

	* 新增成员：Greeting


### 第 4 次发布

发布时间：2024-04-25 01:19:55

本次发布包含了以下内容：

改善已有的文档。

<font color="#dd0000">**删除接口**：</font>

* ParseDoc
* QueryParseDocResult

### 第 3 次发布

发布时间：2024-04-23 01:19:53

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [GetEmbedding](https://cloud.tencent.com/document/api/1759/105084)

	* 新增出参：Usage

* [ParseDoc](https://cloud.tencent.com/document/api/1759/105749)

* [QueryParseDocResult](https://cloud.tencent.com/document/api/1759/105748)

	* 新增出参：Usage

* [QueryRewrite](https://cloud.tencent.com/document/api/1759/105081)

	* 新增出参：Usage


新增数据结构：

* [Usage](https://cloud.tencent.com/document/api/1759/105104#Usage)

### 第 2 次发布

发布时间：2024-04-16 01:15:35

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeStorageCredential](https://cloud.tencent.com/document/api/1759/105050)

	* 新增出参：ImagePath


### 第 1 次发布

发布时间：2024-04-11 17:23:26

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CheckAttributeLabelExist](https://cloud.tencent.com/document/api/1759/105047)
* [CheckAttributeLabelRefer](https://cloud.tencent.com/document/api/1759/105046)
* [CreateApp](https://cloud.tencent.com/document/api/1759/105074)
* [CreateAttributeLabel](https://cloud.tencent.com/document/api/1759/105045)
* [CreateCorp](https://cloud.tencent.com/document/api/1759/105103)
* [CreateQA](https://cloud.tencent.com/document/api/1759/105037)
* [CreateQACate](https://cloud.tencent.com/document/api/1759/105036)
* [CreateRejectedQuestion](https://cloud.tencent.com/document/api/1759/105102)
* [CreateRelease](https://cloud.tencent.com/document/api/1759/105079)
* [DeleteApp](https://cloud.tencent.com/document/api/1759/105073)
* [DeleteAttributeLabel](https://cloud.tencent.com/document/api/1759/105044)
* [DeleteDoc](https://cloud.tencent.com/document/api/1759/105101)
* [DeleteQA](https://cloud.tencent.com/document/api/1759/105035)
* [DeleteQACate](https://cloud.tencent.com/document/api/1759/105034)
* [DeleteRejectedQuestion](https://cloud.tencent.com/document/api/1759/105100)
* [DescribeApp](https://cloud.tencent.com/document/api/1759/105072)
* [DescribeAttributeLabel](https://cloud.tencent.com/document/api/1759/105043)
* [DescribeCorp](https://cloud.tencent.com/document/api/1759/105099)
* [DescribeDoc](https://cloud.tencent.com/document/api/1759/105071)
* [DescribeQA](https://cloud.tencent.com/document/api/1759/105098)
* [DescribeRefer](https://cloud.tencent.com/document/api/1759/105070)
* [DescribeRelease](https://cloud.tencent.com/document/api/1759/105078)
* [DescribeReleaseInfo](https://cloud.tencent.com/document/api/1759/105033)
* [DescribeRobotBizIDByAppKey](https://cloud.tencent.com/document/api/1759/105051)
* [DescribeStorageCredential](https://cloud.tencent.com/document/api/1759/105050)
* [DescribeUnsatisfiedReplyContext](https://cloud.tencent.com/document/api/1759/105032)
* [ExportAttributeLabel](https://cloud.tencent.com/document/api/1759/105042)
* [ExportQAList](https://cloud.tencent.com/document/api/1759/105097)
* [ExportUnsatisfiedReply](https://cloud.tencent.com/document/api/1759/105031)
* [GenerateQA](https://cloud.tencent.com/document/api/1759/105069)
* [GetAppKnowledgeCount](https://cloud.tencent.com/document/api/1759/105068)
* [GetAppSecret](https://cloud.tencent.com/document/api/1759/105049)
* [GetDocPreview](https://cloud.tencent.com/document/api/1759/105067)
* [GetEmbedding](https://cloud.tencent.com/document/api/1759/105084)
* [GetMsgRecord](https://cloud.tencent.com/document/api/1759/105090)
* [GetTaskStatus](https://cloud.tencent.com/document/api/1759/105096)
* [GetWsToken](https://cloud.tencent.com/document/api/1759/105089)
* [GroupQA](https://cloud.tencent.com/document/api/1759/105030)
* [IgnoreUnsatisfiedReply](https://cloud.tencent.com/document/api/1759/105029)
* [IsTransferIntent](https://cloud.tencent.com/document/api/1759/105088)
* [ListApp](https://cloud.tencent.com/document/api/1759/105066)
* [ListAppCategory](https://cloud.tencent.com/document/api/1759/105065)
* [ListAttributeLabel](https://cloud.tencent.com/document/api/1759/105041)
* [ListDoc](https://cloud.tencent.com/document/api/1759/105064)
* [ListModel](https://cloud.tencent.com/document/api/1759/105063)
* [ListQA](https://cloud.tencent.com/document/api/1759/105028)
* [ListQACate](https://cloud.tencent.com/document/api/1759/105027)
* [ListRejectedQuestion](https://cloud.tencent.com/document/api/1759/105095)
* [ListRejectedQuestionPreview](https://cloud.tencent.com/document/api/1759/105062)
* [ListRelease](https://cloud.tencent.com/document/api/1759/105077)
* [ListReleaseConfigPreview](https://cloud.tencent.com/document/api/1759/105076)
* [ListReleaseDocPreview](https://cloud.tencent.com/document/api/1759/105061)
* [ListReleaseQAPreview](https://cloud.tencent.com/document/api/1759/105060)
* [ListSelectDoc](https://cloud.tencent.com/document/api/1759/105094)
* [ListUnsatisfiedReply](https://cloud.tencent.com/document/api/1759/105026)
* [ModifyApp](https://cloud.tencent.com/document/api/1759/105059)
* [ModifyAttributeLabel](https://cloud.tencent.com/document/api/1759/105040)
* [ModifyDoc](https://cloud.tencent.com/document/api/1759/105058)
* [ModifyDocAttrRange](https://cloud.tencent.com/document/api/1759/105057)
* [ModifyQA](https://cloud.tencent.com/document/api/1759/105025)
* [ModifyQAAttrRange](https://cloud.tencent.com/document/api/1759/105024)
* [ModifyQACate](https://cloud.tencent.com/document/api/1759/105023)
* [ModifyRejectedQuestion](https://cloud.tencent.com/document/api/1759/105093)
* [ParseDoc](https://cloud.tencent.com/document/api/1759/105749)
* [QueryParseDocResult](https://cloud.tencent.com/document/api/1759/105748)
* [QueryRewrite](https://cloud.tencent.com/document/api/1759/105081)
* [RateMsgRecord](https://cloud.tencent.com/document/api/1759/105087)
* [ResetSession](https://cloud.tencent.com/document/api/1759/105086)
* [RetryDocAudit](https://cloud.tencent.com/document/api/1759/105056)
* [RetryDocParse](https://cloud.tencent.com/document/api/1759/105055)
* [RetryRelease](https://cloud.tencent.com/document/api/1759/105092)
* [SaveDoc](https://cloud.tencent.com/document/api/1759/105054)
* [StopDocParse](https://cloud.tencent.com/document/api/1759/105053)
* [UploadAttributeLabel](https://cloud.tencent.com/document/api/1759/105039)
* [VerifyQA](https://cloud.tencent.com/document/api/1759/105022)

新增数据结构：

* [AppConfig](https://cloud.tencent.com/document/api/1759/105104#AppConfig)
* [AppInfo](https://cloud.tencent.com/document/api/1759/105104#AppInfo)
* [AppModel](https://cloud.tencent.com/document/api/1759/105104#AppModel)
* [AttrLabel](https://cloud.tencent.com/document/api/1759/105104#AttrLabel)
* [AttrLabelDetail](https://cloud.tencent.com/document/api/1759/105104#AttrLabelDetail)
* [AttrLabelRefer](https://cloud.tencent.com/document/api/1759/105104#AttrLabelRefer)
* [AttributeFilters](https://cloud.tencent.com/document/api/1759/105104#AttributeFilters)
* [AttributeLabel](https://cloud.tencent.com/document/api/1759/105104#AttributeLabel)
* [BaseConfig](https://cloud.tencent.com/document/api/1759/105104#BaseConfig)
* [ClassifyConfig](https://cloud.tencent.com/document/api/1759/105104#ClassifyConfig)
* [ClassifyLabel](https://cloud.tencent.com/document/api/1759/105104#ClassifyLabel)
* [Context](https://cloud.tencent.com/document/api/1759/105104#Context)
* [Credentials](https://cloud.tencent.com/document/api/1759/105104#Credentials)
* [EmbeddingObject](https://cloud.tencent.com/document/api/1759/105104#EmbeddingObject)
* [Filters](https://cloud.tencent.com/document/api/1759/105104#Filters)
* [GetWsTokenReq_Label](https://cloud.tencent.com/document/api/1759/105104#GetWsTokenReq_Label)
* [Highlight](https://cloud.tencent.com/document/api/1759/105104#Highlight)
* [KnowledgeQaConfig](https://cloud.tencent.com/document/api/1759/105104#KnowledgeQaConfig)
* [KnowledgeQaOutput](https://cloud.tencent.com/document/api/1759/105104#KnowledgeQaOutput)
* [KnowledgeQaSearch](https://cloud.tencent.com/document/api/1759/105104#KnowledgeQaSearch)
* [Label](https://cloud.tencent.com/document/api/1759/105104#Label)
* [ListAppCategoryRspOption](https://cloud.tencent.com/document/api/1759/105104#ListAppCategoryRspOption)
* [ListDocItem](https://cloud.tencent.com/document/api/1759/105104#ListDocItem)
* [ListQaItem](https://cloud.tencent.com/document/api/1759/105104#ListQaItem)
* [ListReleaseItem](https://cloud.tencent.com/document/api/1759/105104#ListReleaseItem)
* [Message](https://cloud.tencent.com/document/api/1759/105104#Message)
* [ModelInfo](https://cloud.tencent.com/document/api/1759/105104#ModelInfo)
* [MsgRecord](https://cloud.tencent.com/document/api/1759/105104#MsgRecord)
* [MsgRecordReference](https://cloud.tencent.com/document/api/1759/105104#MsgRecordReference)
* [Option](https://cloud.tencent.com/document/api/1759/105104#Option)
* [QACate](https://cloud.tencent.com/document/api/1759/105104#QACate)
* [QAList](https://cloud.tencent.com/document/api/1759/105104#QAList)
* [QAQuery](https://cloud.tencent.com/document/api/1759/105104#QAQuery)
* [ReferDetail](https://cloud.tencent.com/document/api/1759/105104#ReferDetail)
* [RejectedQuestion](https://cloud.tencent.com/document/api/1759/105104#RejectedQuestion)
* [ReleaseConfigs](https://cloud.tencent.com/document/api/1759/105104#ReleaseConfigs)
* [ReleaseDoc](https://cloud.tencent.com/document/api/1759/105104#ReleaseDoc)
* [ReleaseQA](https://cloud.tencent.com/document/api/1759/105104#ReleaseQA)
* [ReleaseRejectedQuestion](https://cloud.tencent.com/document/api/1759/105104#ReleaseRejectedQuestion)
* [SummaryConfig](https://cloud.tencent.com/document/api/1759/105104#SummaryConfig)
* [SummaryOutput](https://cloud.tencent.com/document/api/1759/105104#SummaryOutput)
* [TaskParams](https://cloud.tencent.com/document/api/1759/105104#TaskParams)
* [UnsatisfiedReply](https://cloud.tencent.com/document/api/1759/105104#UnsatisfiedReply)




## 云开发低码(lowcode) 版本：2021-01-08

### 第 1 次发布

发布时间：2022-01-27 10:15:18

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeDataSourceList](https://cloud.tencent.com/document/api/1301/68877)

新增数据结构：

* [DataSourceDetail](https://cloud.tencent.com/document/api/1301/68878#DataSourceDetail)
* [DataSourceDetailItems](https://cloud.tencent.com/document/api/1301/68878#DataSourceDetailItems)
* [DataSourceLinkApp](https://cloud.tencent.com/document/api/1301/68878#DataSourceLinkApp)
* [DataSourceQueryOption](https://cloud.tencent.com/document/api/1301/68878#DataSourceQueryOption)
* [TicketAuthInfo](https://cloud.tencent.com/document/api/1301/68878#TicketAuthInfo)




## 登录保护(lp) 版本：2020-02-24

### 第 1 次发布

发布时间：2020-04-28 15:12:29

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [QueryLoginProtection](https://cloud.tencent.com/document/api/1190/43989)




## 商场客留大数据(mall) 版本：2023-05-18

### 第 1 次发布

发布时间：2023-07-14 16:30:43

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeDrawResourceList](https://cloud.tencent.com/document/api/1707/95048)

新增数据结构：

* [ResourceDrawListType](https://cloud.tencent.com/document/api/1707/95049#ResourceDrawListType)




## 云数据库 MariaDB(mariadb) 版本：2017-03-12

### 第 63 次发布

发布时间：2024-07-12 01:20:13

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [UpgradeHourDBInstance](https://cloud.tencent.com/document/api/237/108599)

### 第 62 次发布

发布时间：2024-07-03 01:20:08

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [InstanceBackupFileItem](https://cloud.tencent.com/document/api/237/16191#InstanceBackupFileItem)

	* 新增成员：StorageClass


### 第 61 次发布

发布时间：2024-04-24 01:16:00

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeDBInstanceDetail](https://cloud.tencent.com/document/api/237/89390)

	* 新增出参：ProxyVersion

* [DescribeDBInstances](https://cloud.tencent.com/document/api/237/16184)

	* 新增入参：Tags


新增数据结构：

* [Tag](https://cloud.tencent.com/document/api/237/16191#Tag)

### 第 60 次发布

发布时间：2024-03-08 01:19:33

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [DBAccount](https://cloud.tencent.com/document/api/237/16191#DBAccount)

	* <font color="#dd0000">**修改成员**：</font>MaxUserConnections


### 第 59 次发布

发布时间：2023-10-30 00:58:10

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateDBInstance](https://cloud.tencent.com/document/api/237/16180)

	* 新增入参：DcnSyncMode

* [CreateDedicatedClusterDBInstance](https://cloud.tencent.com/document/api/237/61370)

	* 新增入参：DcnSyncMode

* [DescribeDBInstanceDetail](https://cloud.tencent.com/document/api/237/89390)

	* 新增出参：IsDcnStrongSyncSupported, IsDcnSwitchSupported


修改数据结构：

* [DcnDetailItem](https://cloud.tencent.com/document/api/237/16191#DcnDetailItem)

	* 新增成员：DcnStatusDesc, PolarisInstanceId, PolarisInstanceName, PolarisNamespace, PolarisService, PolarisServiceStatus, PolarisServiceStatusDesc, PolarisRegion, IsDcnSwitchSupported


### 第 58 次发布

发布时间：2023-08-29 01:18:45

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateHourDBInstance](https://cloud.tencent.com/document/api/237/67878)

	* 新增入参：DcnSyncMode


### 第 57 次发布

发布时间：2023-06-21 01:26:12

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeDBTmpInstances](https://cloud.tencent.com/document/api/237/94222)

新增数据结构：

* [TmpInstance](https://cloud.tencent.com/document/api/237/16191#TmpInstance)

### 第 56 次发布

发布时间：2023-06-13 01:27:34

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeDBInstanceDetail](https://cloud.tencent.com/document/api/237/89390)

	* 新增出参：IsPhysicalReplicationSupported


### 第 55 次发布

发布时间：2023-05-29 01:31:45

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeDBInstanceDetail](https://cloud.tencent.com/document/api/237/89390)

	* 新增出参：ReservedNetResources


新增数据结构：

* [ReservedNetResource](https://cloud.tencent.com/document/api/237/16191#ReservedNetResource)

修改数据结构：

* [DBAccount](https://cloud.tencent.com/document/api/237/16191#DBAccount)

	* 新增成员：MaxUserConnections


### 第 54 次发布

发布时间：2023-05-23 01:29:45

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [UpgradeDedicatedDBInstance](https://cloud.tencent.com/document/api/237/92618)

### 第 53 次发布

发布时间：2023-03-29 03:50:31

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeDBInstanceDetail](https://cloud.tencent.com/document/api/237/89390)

	* 新增出参：RsAccessStrategy


### 第 52 次发布

发布时间：2023-03-27 02:12:03

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeDBInstanceDetail](https://cloud.tencent.com/document/api/237/89390)

### 第 51 次发布

发布时间：2023-03-20 01:40:40

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeBackupFiles](https://cloud.tencent.com/document/api/237/88911)

新增数据结构：

* [InstanceBackupFileItem](https://cloud.tencent.com/document/api/237/16191#InstanceBackupFileItem)

### 第 50 次发布

发布时间：2023-02-20 01:41:08

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [ModifyDBEncryptAttributes](https://cloud.tencent.com/document/api/237/86692)

### 第 49 次发布

发布时间：2023-01-31 01:40:45

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeDBEncryptAttributes](https://cloud.tencent.com/document/api/237/85940)

### 第 48 次发布

发布时间：2022-11-23 06:38:36

本次发布包含了以下内容：

改善已有的文档。

新增数据结构：

* [DCNReplicaConfig](https://cloud.tencent.com/document/api/237/16191#DCNReplicaConfig)
* [DCNReplicaStatus](https://cloud.tencent.com/document/api/237/16191#DCNReplicaStatus)

修改数据结构：

* [DcnDetailItem](https://cloud.tencent.com/document/api/237/16191#DcnDetailItem)

	* 新增成员：ReplicaConfig, ReplicaStatus, EncryptStatus


### 第 47 次发布

发布时间：2022-11-16 06:29:49

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribePrice](https://cloud.tencent.com/document/api/237/16175)

	* 新增入参：AmountUnit

* [DescribeRenewalPrice](https://cloud.tencent.com/document/api/237/16181)

	* 新增入参：AmountUnit

* [DescribeUpgradePrice](https://cloud.tencent.com/document/api/237/16183)

	* 新增入参：AmountUnit


### 第 46 次发布

发布时间：2022-11-08 06:32:06

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [TerminateDedicatedDBInstance](https://cloud.tencent.com/document/api/237/82555)

### 第 45 次发布

发布时间：2022-11-07 06:26:59

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [IsolateDBInstance](https://cloud.tencent.com/document/api/237/82426)

### 第 44 次发布

发布时间：2022-11-04 06:29:56

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [IsolateDedicatedDBInstance](https://cloud.tencent.com/document/api/237/82372)

修改数据结构：

* [ZonesInfo](https://cloud.tencent.com/document/api/237/16191#ZonesInfo)

	* 新增成员：OnSale


### 第 43 次发布

发布时间：2022-10-26 06:46:25

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [ModifyInstanceNetwork](https://cloud.tencent.com/document/api/237/81949)
* [ModifyInstanceVip](https://cloud.tencent.com/document/api/237/81948)
* [ModifyInstanceVport](https://cloud.tencent.com/document/api/237/81947)

### 第 42 次发布

发布时间：2022-10-13 06:35:29

本次发布包含了以下内容：

改善已有的文档。

<font color="#dd0000">**删除接口**：</font>

* DescribeDBResourceUsage
* DescribeDBResourceUsageDetails

<font color="#dd0000">**删除数据结构**：</font>

* MonitorData
* ResourceUsageMonitorSet

### 第 41 次发布

发布时间：2022-10-12 06:43:12

本次发布包含了以下内容：

改善已有的文档。

<font color="#dd0000">**删除接口**：</font>

* DescribeDBPerformance
* DescribeDBPerformanceDetails
* DescribeSqlLogs

<font color="#dd0000">**删除数据结构**：</font>

* PerformanceMonitorSet
* SqlLogItem

### 第 40 次发布

发布时间：2022-07-27 06:13:02

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateDedicatedClusterDBInstance](https://cloud.tencent.com/document/api/237/61370)

	* 新增入参：RollbackInstanceId, RollbackTime


### 第 39 次发布

发布时间：2022-07-22 06:10:50

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateHourDBInstance](https://cloud.tencent.com/document/api/237/67878)

	* 新增出参：FlowId


修改数据结构：

* [DBInstance](https://cloud.tencent.com/document/api/237/16191#DBInstance)

	* 新增成员：DbVersionId


### 第 38 次发布

发布时间：2022-07-06 06:15:28

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DestroyDBInstance](https://cloud.tencent.com/document/api/237/76451)

### 第 37 次发布

发布时间：2022-07-05 06:18:01

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateAccount](https://cloud.tencent.com/document/api/237/16165)

	* 新增入参：SlaveConst, MaxUserConnections


修改数据结构：

* [DBAccount](https://cloud.tencent.com/document/api/237/16191#DBAccount)

	* 新增成员：SlaveConst


### 第 36 次发布

发布时间：2022-05-25 06:11:46

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeDBSecurityGroups](https://cloud.tencent.com/document/api/237/51787)
* [DescribeOrders](https://cloud.tencent.com/document/api/237/16186)

新增数据结构：

* [Deal](https://cloud.tencent.com/document/api/237/16191#Deal)

### 第 35 次发布

发布时间：2022-04-13 06:56:52

本次发布包含了以下内容：

改善已有的文档。

<font color="#dd0000">**删除接口**：</font>

* DescribeDBSecurityGroups
* DescribeOrders

<font color="#dd0000">**删除数据结构**：</font>

* Deal

### 第 34 次发布

发布时间：2022-03-24 20:42:49

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [ParamDesc](https://cloud.tencent.com/document/api/237/16191#ParamDesc)

	* 新增成员：NeedRestart


### 第 33 次发布

发布时间：2022-03-01 08:09:32

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [ActivateHourDBInstance](https://cloud.tencent.com/document/api/237/70426)
* [IsolateHourDBInstance](https://cloud.tencent.com/document/api/237/70425)

### 第 32 次发布

发布时间：2022-02-22 08:09:47

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeDatabaseObjects](https://cloud.tencent.com/document/api/237/70216)

新增数据结构：

* [DatabaseFunction](https://cloud.tencent.com/document/api/237/16191#DatabaseFunction)
* [DatabaseProcedure](https://cloud.tencent.com/document/api/237/16191#DatabaseProcedure)
* [DatabaseTable](https://cloud.tencent.com/document/api/237/16191#DatabaseTable)
* [DatabaseView](https://cloud.tencent.com/document/api/237/16191#DatabaseView)

### 第 31 次发布

发布时间：2022-02-11 08:09:25

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeDatabaseTable](https://cloud.tencent.com/document/api/237/69130)

新增数据结构：

* [TableColumn](https://cloud.tencent.com/document/api/237/16191#TableColumn)

### 第 30 次发布

发布时间：2022-01-13 08:50:16

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [SwitchDBInstanceHA](https://cloud.tencent.com/document/api/237/68116)

### 第 29 次发布

发布时间：2022-01-11 08:12:13

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateHourDBInstance](https://cloud.tencent.com/document/api/237/67878)

修改接口：

* [DescribeProjectSecurityGroups](https://cloud.tencent.com/document/api/237/51786)

	* 新增出参：Total


修改数据结构：

* [DBInstance](https://cloud.tencent.com/document/api/237/16191#DBInstance)

	* 新增成员：ResourceTags


### 第 28 次发布

发布时间：2021-12-17 08:13:52

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeFileDownloadUrl](https://cloud.tencent.com/document/api/237/66230)

### 第 27 次发布

发布时间：2021-11-26 08:11:04

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeUpgradePrice](https://cloud.tencent.com/document/api/237/16183)

	* 新增入参：NodeCount

* [UpgradeDBInstance](https://cloud.tencent.com/document/api/237/16189)

	* 新增入参：Zones


### 第 26 次发布

发布时间：2021-11-17 08:13:35

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [ModifyDBSyncMode](https://cloud.tencent.com/document/api/237/64090)
* [ModifySyncTaskAttribute](https://cloud.tencent.com/document/api/237/64091)

修改数据结构：

* [SlowLogData](https://cloud.tencent.com/document/api/237/16191#SlowLogData)

	* 新增成员：Host


### 第 25 次发布

发布时间：2021-09-10 08:06:48

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateDedicatedClusterDBInstance](https://cloud.tencent.com/document/api/237/61370)

### 第 24 次发布

发布时间：2021-08-11 08:06:54

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [ModifyRealServerAccessStrategy](https://cloud.tencent.com/document/api/237/60076)

### 第 23 次发布

发布时间：2021-08-05 08:06:50

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateDBInstance](https://cloud.tencent.com/document/api/237/16180)

	* 新增入参：DcnRegion, DcnInstanceId


### 第 22 次发布

发布时间：2021-07-20 08:10:14

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CancelDcnJob](https://cloud.tencent.com/document/api/237/58911)

### 第 21 次发布

发布时间：2021-07-14 08:06:54

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeUpgradePrice](https://cloud.tencent.com/document/api/237/16183)

	* 新增出参：Formula


修改数据结构：

* [DcnDetailItem](https://cloud.tencent.com/document/api/237/16191#DcnDetailItem)

	* 新增成员：Cpu, Memory, Storage, PayMode, CreateTime, PeriodEndTime, InstanceType


### 第 20 次发布

发布时间：2021-06-01 14:53:40

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [FunctionPrivilege](https://cloud.tencent.com/document/api/237/16191#FunctionPrivilege)

	* 新增成员：FunctionName

	* <font color="#dd0000">**删除成员**：</font>Function


### 第 19 次发布

发布时间：2021-06-01 08:07:15

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DestroyHourDBInstance](https://cloud.tencent.com/document/api/237/56487)
* [ModifyAccountPrivileges](https://cloud.tencent.com/document/api/237/56486)

修改接口：

* [CreateDBInstance](https://cloud.tencent.com/document/api/237/16180)

	* 新增入参：InitParams

* [DescribeDBInstances](https://cloud.tencent.com/document/api/237/16184)

	* 新增入参：Status, ExcludeStatus

* [RestartDBInstances](https://cloud.tencent.com/document/api/237/40096)

	* 新增入参：RestartTime


新增数据结构：

* [Account](https://cloud.tencent.com/document/api/237/16191#Account)
* [ColumnPrivilege](https://cloud.tencent.com/document/api/237/16191#ColumnPrivilege)
* [DatabasePrivilege](https://cloud.tencent.com/document/api/237/16191#DatabasePrivilege)
* [FunctionPrivilege](https://cloud.tencent.com/document/api/237/16191#FunctionPrivilege)
* [ProcedurePrivilege](https://cloud.tencent.com/document/api/237/16191#ProcedurePrivilege)
* [TablePrivilege](https://cloud.tencent.com/document/api/237/16191#TablePrivilege)
* [ViewPrivileges](https://cloud.tencent.com/document/api/237/16191#ViewPrivileges)

### 第 18 次发布

发布时间：2021-05-27 08:06:17

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeDcnDetail](https://cloud.tencent.com/document/api/237/56347)

新增数据结构：

* [DcnDetailItem](https://cloud.tencent.com/document/api/237/16191#DcnDetailItem)

### 第 17 次发布

发布时间：2021-04-21 08:06:07

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeInstanceNodeInfo](https://cloud.tencent.com/document/api/237/54875)

新增数据结构：

* [NodeInfo](https://cloud.tencent.com/document/api/237/16191#NodeInfo)

### 第 16 次发布

发布时间：2021-03-24 08:06:11

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeDBSecurityGroups](https://cloud.tencent.com/document/api/237/51787)

	* 新增出参：VIP, VPort


### 第 15 次发布

发布时间：2021-03-15 08:05:27

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [KillSession](https://cloud.tencent.com/document/api/237/53596)

### 第 14 次发布

发布时间：2021-01-07 08:06:13

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [AssociateSecurityGroups](https://cloud.tencent.com/document/api/237/51788)
* [DescribeDBSecurityGroups](https://cloud.tencent.com/document/api/237/51787)
* [DescribeProjectSecurityGroups](https://cloud.tencent.com/document/api/237/51786)
* [DisassociateSecurityGroups](https://cloud.tencent.com/document/api/237/51785)
* [ModifyDBInstanceSecurityGroups](https://cloud.tencent.com/document/api/237/51784)

新增数据结构：

* [SecurityGroup](https://cloud.tencent.com/document/api/237/16191#SecurityGroup)
* [SecurityGroupBound](https://cloud.tencent.com/document/api/237/16191#SecurityGroupBound)

### 第 13 次发布

发布时间：2020-12-16 08:05:45

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [DBInstance](https://cloud.tencent.com/document/api/237/16191#DBInstance)

	* 新增成员：InstanceType


### 第 12 次发布

发布时间：2020-09-28 08:06:19

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeDBInstances](https://cloud.tencent.com/document/api/237/16184)

	* 新增入参：FilterInstanceType


修改数据结构：

* [DBInstance](https://cloud.tencent.com/document/api/237/16191#DBInstance)

	* 新增成员：DcnFlag, DcnStatus, DcnDstNum


### 第 11 次发布

发布时间：2020-08-18 08:16:12

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [FlushBinlog](https://cloud.tencent.com/document/api/237/47584)

修改接口：

* [CreateDBInstance](https://cloud.tencent.com/document/api/237/16180)

	* 新增入参：ResourceTags

* [DescribeDBInstances](https://cloud.tencent.com/document/api/237/16184)

	* 新增入参：TagKeys


新增数据结构：

* [ResourceTag](https://cloud.tencent.com/document/api/237/16191#ResourceTag)

修改数据结构：

* [DBInstance](https://cloud.tencent.com/document/api/237/16191#DBInstance)

	* 新增成员：Ipv6Flag, Vipv6, WanVipv6, WanPortIpv6, WanStatusIpv6, DbEngine, DbVersion


### 第 10 次发布

发布时间：2020-07-02 08:13:09

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CloseDBExtranetAccess](https://cloud.tencent.com/document/api/237/16179)

	* 新增入参：Ipv6Flag

* [CreateDBInstance](https://cloud.tencent.com/document/api/237/16180)

	* 新增入参：Ipv6Flag

* [OpenDBExtranetAccess](https://cloud.tencent.com/document/api/237/16174)

	* 新增入参：Ipv6Flag


### 第 9 次发布

发布时间：2020-04-24 08:11:39

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateDBInstance](https://cloud.tencent.com/document/api/237/16180)

	* 新增入参：InstanceName, SecurityGroupIds, AutoRenewFlag

* [DescribePrice](https://cloud.tencent.com/document/api/237/16175)

	* 新增入参：Paymode

* [ModifyDBInstanceName](https://cloud.tencent.com/document/api/237/16190)

	* 新增出参：InstanceId


### 第 8 次发布

发布时间：2020-03-16 08:13:52

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [DBInstance](https://cloud.tencent.com/document/api/237/16191#DBInstance)

	* 新增成员：Cpu

* [SpecConfigInfo](https://cloud.tencent.com/document/api/237/16191#SpecConfigInfo)

	* 新增成员：Cpu


### 第 7 次发布

发布时间：2019-12-30 13:29:24

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateTmpInstances](https://cloud.tencent.com/document/api/237/40544)

### 第 6 次发布

发布时间：2019-12-05 20:34:38

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeDatabases](https://cloud.tencent.com/document/api/237/40098)
* [RestartDBInstances](https://cloud.tencent.com/document/api/237/40096)

新增数据结构：

* [Database](https://cloud.tencent.com/document/api/237/16191#Database)

修改数据结构：

* [SlowLogData](https://cloud.tencent.com/document/api/237/16191#SlowLogData)

	* 新增成员：ExampleSql


### 第 5 次发布

发布时间：2019-05-09 17:11:52

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeBackupTime](https://cloud.tencent.com/document/api/237/16182)

	* <font color="#dd0000">**修改出参**：</font>Items

* [DescribeDBInstances](https://cloud.tencent.com/document/api/237/16184)

	* 新增入参：ExclusterIds

* [DescribeDBPerformance](https://cloud.tencent.com/document/api/237/16160)

	* 新增入参：MetricName

* [DescribeDBPerformanceDetails](https://cloud.tencent.com/document/api/237/16156)

	* 新增入参：MetricName

* [DescribeDBResourceUsage](https://cloud.tencent.com/document/api/237/16158)

	* 新增入参：MetricName

* [DescribeDBResourceUsageDetails](https://cloud.tencent.com/document/api/237/16157)

	* 新增入参：MetricName

* [DescribeDBSlowLogs](https://cloud.tencent.com/document/api/237/16159)

	* 新增入参：Slave


<font color="#dd0000">**删除数据结构**：</font>

* MonitorIntData

修改数据结构：

* [DBInstance](https://cloud.tencent.com/document/api/237/16191#DBInstance)

	* 新增成员：IsEncryptSupported

* [LogFileInfo](https://cloud.tencent.com/document/api/237/16191#LogFileInfo)

	* 新增成员：FileName

* [ParamDesc](https://cloud.tencent.com/document/api/237/16191#ParamDesc)

	* 新增成员：HaveSetValue

* [ResourceUsageMonitorSet](https://cloud.tencent.com/document/api/237/16191#ResourceUsageMonitorSet)

	* <font color="#dd0000">**修改成员**：</font>DataDiskAvailable

* [SlowLogData](https://cloud.tencent.com/document/api/237/16191#SlowLogData)

	* <font color="#dd0000">**修改成员**：</font>LockTimeAvg, LockTimeMax, LockTimeMin, LockTimeSum, QueryCount, QueryTimeAvg, QueryTimeMax, QueryTimeMin, QueryTimeSum, RowsExaminedSum, RowsSentSum, TsMax, TsMin


### 第 4 次发布

发布时间：2019-03-08 17:43:33

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [DBInstance](https://cloud.tencent.com/document/api/237/16191#DBInstance)

	* 新增成员：IsAuditSupported, Machine


### 第 3 次发布

发布时间：2018-12-13 15:00:04

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateAccount](https://cloud.tencent.com/document/api/237/16165)

	* 新增入参：DelayThresh


修改数据结构：

* [DBInstance](https://cloud.tencent.com/document/api/237/16191#DBInstance)

	* 新增成员：WanStatus


### 第 2 次发布

发布时间：2018-09-27 19:27:29

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CloneAccount](https://cloud.tencent.com/document/api/237/20257)
* [DescribeSqlLogs](https://cloud.tencent.com/document/api/237/20256)

修改接口：

* [DescribeDBInstances](https://cloud.tencent.com/document/api/237/16184)

	* 新增入参：IsFilterExcluster, ExclusterType

	* <font color="#dd0000">**修改入参**：</font>IsFilterVpc, VpcId, SubnetId

	* <font color="#dd0000">**修改出参**：</font>TotalCount

* [DescribeDBLogFiles](https://cloud.tencent.com/document/api/237/16162)

	* 新增出参：VpcPrefix, NormalPrefix

	* <font color="#dd0000">**删除出参**：</font>Vpcprefix, Normalprefix

* [DescribeDBSlowLogs](https://cloud.tencent.com/document/api/237/16159)

	* <font color="#dd0000">**修改出参**：</font>LockTimeSum, QueryCount, Total, QueryTimeSum

* [ModifyDBParameters](https://cloud.tencent.com/document/api/237/16153)

	* 新增出参：Result

	* <font color="#dd0000">**删除出参**：</font>Config

* [UpgradeDBInstance](https://cloud.tencent.com/document/api/237/16189)

	* <font color="#dd0000">**修改入参**：</font>VoucherIds


新增数据结构：

* [SqlLogItem](https://cloud.tencent.com/document/api/237/16191#SqlLogItem)

修改数据结构：

* [DBAccount](https://cloud.tencent.com/document/api/237/16191#DBAccount)

	* 新增成员：DelayThresh

* [DBInstance](https://cloud.tencent.com/document/api/237/16191#DBInstance)

	* 新增成员：UniqueVpcId, UniqueSubnetId, OriginSerialId, NodeCount, IsTmp, ExclusterId, Id, Qps, Paymode, Locker, StatusDesc

* [Deal](https://cloud.tencent.com/document/api/237/16191#Deal)

	* 新增成员：Count, PayMode

	* <font color="#dd0000">**删除成员**：</font>Quantity

* [LogFileInfo](https://cloud.tencent.com/document/api/237/16191#LogFileInfo)

	* <font color="#dd0000">**修改成员**：</font>Uri

* [ParamConstraint](https://cloud.tencent.com/document/api/237/16191#ParamConstraint)

	* 新增成员：String

* [ParamModifyResult](https://cloud.tencent.com/document/api/237/16191#ParamModifyResult)

	* <font color="#dd0000">**修改成员**：</font>Code

* [SlowLogData](https://cloud.tencent.com/document/api/237/16191#SlowLogData)

	* <font color="#dd0000">**修改成员**：</font>LockTimeAvg, LockTimeMax, LockTimeMin, LockTimeSum, QueryCount, QueryTimeAvg, QueryTimeMax, QueryTimeMin, QueryTimeSum, RowsExaminedSum, RowsSentSum


### 第 1 次发布

发布时间：2018-04-24

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CloseDBExtranetAccess](https://cloud.tencent.com/document/api/237/16179)
* [CopyAccountPrivileges](https://cloud.tencent.com/document/api/237/16169)
* [CreateAccount](https://cloud.tencent.com/document/api/237/16165)
* [CreateDBInstance](https://cloud.tencent.com/document/api/237/16180)
* [DeleteAccount](https://cloud.tencent.com/document/api/237/16171)
* [DescribeAccountPrivileges](https://cloud.tencent.com/document/api/237/16164)
* [DescribeAccounts](https://cloud.tencent.com/document/api/237/16167)
* [DescribeBackupTime](https://cloud.tencent.com/document/api/237/16182)
* [DescribeDBInstanceSpecs](https://cloud.tencent.com/document/api/237/16188)
* [DescribeDBInstances](https://cloud.tencent.com/document/api/237/16184)
* [DescribeDBLogFiles](https://cloud.tencent.com/document/api/237/16162)
* [DescribeDBParameters](https://cloud.tencent.com/document/api/237/16154)
* [DescribeDBPerformance](https://cloud.tencent.com/document/api/237/16160)
* [DescribeDBPerformanceDetails](https://cloud.tencent.com/document/api/237/16156)
* [DescribeDBResourceUsage](https://cloud.tencent.com/document/api/237/16158)
* [DescribeDBResourceUsageDetails](https://cloud.tencent.com/document/api/237/16157)
* [DescribeDBSlowLogs](https://cloud.tencent.com/document/api/237/16159)
* [DescribeFlow](https://cloud.tencent.com/document/api/237/16177)
* [DescribeLogFileRetentionPeriod](https://cloud.tencent.com/document/api/237/16152)
* [DescribeOrders](https://cloud.tencent.com/document/api/237/16186)
* [DescribePrice](https://cloud.tencent.com/document/api/237/16175)
* [DescribeRenewalPrice](https://cloud.tencent.com/document/api/237/16181)
* [DescribeSaleInfo](https://cloud.tencent.com/document/api/237/16178)
* [DescribeUpgradePrice](https://cloud.tencent.com/document/api/237/16183)
* [GrantAccountPrivileges](https://cloud.tencent.com/document/api/237/16166)
* [InitDBInstances](https://cloud.tencent.com/document/api/237/16185)
* [ModifyAccountDescription](https://cloud.tencent.com/document/api/237/16170)
* [ModifyBackupTime](https://cloud.tencent.com/document/api/237/16173)
* [ModifyDBInstanceName](https://cloud.tencent.com/document/api/237/16190)
* [ModifyDBInstancesProject](https://cloud.tencent.com/document/api/237/16176)
* [ModifyDBParameters](https://cloud.tencent.com/document/api/237/16153)
* [ModifyLogFileRetentionPeriod](https://cloud.tencent.com/document/api/237/16151)
* [OpenDBExtranetAccess](https://cloud.tencent.com/document/api/237/16174)
* [RenewDBInstance](https://cloud.tencent.com/document/api/237/16187)
* [ResetAccountPassword](https://cloud.tencent.com/document/api/237/16168)
* [UpgradeDBInstance](https://cloud.tencent.com/document/api/237/16189)

新增数据结构：

* [ConstraintRange](https://cloud.tencent.com/document/api/237/16191#ConstraintRange)
* [DBAccount](https://cloud.tencent.com/document/api/237/16191#DBAccount)
* [DBBackupTimeConfig](https://cloud.tencent.com/document/api/237/16191#DBBackupTimeConfig)
* [DBInstance](https://cloud.tencent.com/document/api/237/16191#DBInstance)
* [DBParamValue](https://cloud.tencent.com/document/api/237/16191#DBParamValue)
* [Deal](https://cloud.tencent.com/document/api/237/16191#Deal)
* [InstanceSpec](https://cloud.tencent.com/document/api/237/16191#InstanceSpec)
* [LogFileInfo](https://cloud.tencent.com/document/api/237/16191#LogFileInfo)
* [MonitorData](https://cloud.tencent.com/document/api/237/16191#MonitorData)
* [MonitorIntData](https://cloud.tencent.com/document/api/237/16191#MonitorIntData)
* [ParamConstraint](https://cloud.tencent.com/document/api/237/16191#ParamConstraint)
* [ParamDesc](https://cloud.tencent.com/document/api/237/16191#ParamDesc)
* [ParamModifyResult](https://cloud.tencent.com/document/api/237/16191#ParamModifyResult)
* [PerformanceMonitorSet](https://cloud.tencent.com/document/api/237/16191#PerformanceMonitorSet)
* [RegionInfo](https://cloud.tencent.com/document/api/237/16191#RegionInfo)
* [ResourceUsageMonitorSet](https://cloud.tencent.com/document/api/237/16191#ResourceUsageMonitorSet)
* [SlowLogData](https://cloud.tencent.com/document/api/237/16191#SlowLogData)
* [SpecConfigInfo](https://cloud.tencent.com/document/api/237/16191#SpecConfigInfo)
* [ZoneChooseInfo](https://cloud.tencent.com/document/api/237/16191#ZoneChooseInfo)
* [ZonesInfo](https://cloud.tencent.com/document/api/237/16191#ZonesInfo)




## 云市场(market) 版本：2019-10-10

### 第 5 次发布

发布时间：2021-08-17 08:00:13

本次发布包含了以下内容：

改善已有的文档。

<font color="#dd0000">**删除接口**：</font>

* SyncUserAndOrderInfo

<font color="#dd0000">**删除数据结构**：</font>

* Error
* OfflineProductDeal
* SyncUserAndOrderInfoDetail
* WeChatOrderInfo
* WeChatUserInfo

### 第 4 次发布

发布时间：2021-07-27 08:00:11

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [SyncUserAndOrderInfo](https://cloud.tencent.com/document/api/306/59174)

新增数据结构：

* [Error](https://cloud.tencent.com/document/api/306/59175#Error)
* [OfflineProductDeal](https://cloud.tencent.com/document/api/306/59175#OfflineProductDeal)
* [SyncUserAndOrderInfoDetail](https://cloud.tencent.com/document/api/306/59175#SyncUserAndOrderInfoDetail)
* [WeChatOrderInfo](https://cloud.tencent.com/document/api/306/59175#WeChatOrderInfo)
* [WeChatUserInfo](https://cloud.tencent.com/document/api/306/59175#WeChatUserInfo)

### 第 3 次发布

发布时间：2021-07-06 10:48:27

本次发布包含了以下内容：

改善已有的文档。

<font color="#dd0000">**删除接口**：</font>

* GetCateTree

### 第 2 次发布

发布时间：2021-06-18 08:00:04

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [FlowProductRemind](https://cloud.tencent.com/document/api/306/57512)

### 第 1 次发布

发布时间：2021-06-17 08:00:04

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [GetCateTree](https://cloud.tencent.com/document/api/306/57445)
* [GetUsagePlanUsageAmount](https://cloud.tencent.com/document/api/306/57443)




## 云数据库Memcached(memcached) 版本：2019-03-18

### 第 2 次发布

发布时间：2020-03-17 08:01:08

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeInstances](https://cloud.tencent.com/document/api/241/42207)

	* 新增入参：UniqSubnetIds, UniqVpcIds


### 第 1 次发布

发布时间：2020-03-13 08:01:22

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeInstances](https://cloud.tencent.com/document/api/241/42207)

新增数据结构：

* [InstanceListInfo](https://cloud.tencent.com/document/api/241/42208#InstanceListInfo)
* [TagInfo](https://cloud.tencent.com/document/api/241/42208#TagInfo)




## 游戏联机对战引擎(mgobe) 版本：2019-09-29

### 第 1 次发布

发布时间：2020-10-14 14:25:07

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DismissRoom](https://cloud.tencent.com/document/api/1038/49120)



## 游戏联机对战引擎(mgobe) 版本：2020-10-14

### 第 3 次发布

发布时间：2021-01-26 08:00:28

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribePlayer](https://cloud.tencent.com/document/api/1038/52498)
* [DescribeRoom](https://cloud.tencent.com/document/api/1038/52497)

### 第 2 次发布

发布时间：2021-01-14 08:00:25

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [ChangeRoomPlayerProfile](https://cloud.tencent.com/document/api/1038/51985)
* [ChangeRoomPlayerStatus](https://cloud.tencent.com/document/api/1038/51984)
* [ModifyRoom](https://cloud.tencent.com/document/api/1038/51983)
* [RemoveRoomPlayer](https://cloud.tencent.com/document/api/1038/51982)

新增数据结构：

* [Player](https://cloud.tencent.com/document/api/1038/51986#Player)
* [Room](https://cloud.tencent.com/document/api/1038/51986#Room)
* [Team](https://cloud.tencent.com/document/api/1038/51986#Team)

### 第 1 次发布

发布时间：2020-10-30 08:00:07

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DismissRoom](https://cloud.tencent.com/document/api/1038/49557)




## 小程序安全(mmps) 版本：2020-07-10

### 第 8 次发布

发布时间：2023-01-10 01:33:47

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [AppInfoItem](https://cloud.tencent.com/document/api/1223/75143#AppInfoItem)

	* 新增成员：PrivacyTextName, SoftwareMD5, PrivacyTextMD5

* [AppTaskData](https://cloud.tencent.com/document/api/1223/75143#AppTaskData)

	* 新增成员：ContactName


### 第 7 次发布

发布时间：2022-08-25 06:38:57

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeScanTaskReportUrl](https://cloud.tencent.com/document/api/1223/75156)

	* 新增出参：ReportResult


### 第 6 次发布

发布时间：2022-07-21 15:01:26

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateFlySecMiniAppProfessionalScanTask](https://cloud.tencent.com/document/api/1223/77611)

### 第 5 次发布

发布时间：2022-06-27 14:56:37

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeFlySecMiniAppScanReportList](https://cloud.tencent.com/document/api/1223/76058)

新增数据结构：

* [FlySecMiniAppReportData](https://cloud.tencent.com/document/api/1223/75143#FlySecMiniAppReportData)
* [FlySecMiniAppRiskItems](https://cloud.tencent.com/document/api/1223/75143#FlySecMiniAppRiskItems)

### 第 4 次发布

发布时间：2022-06-24 06:14:40

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [AppInfoItem](https://cloud.tencent.com/document/api/1223/75143#AppInfoItem)

	* 新增成员：HighRiskCount


### 第 3 次发布

发布时间：2022-06-14 11:16:30

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeBasicDiagnosisResourceUsageInfo](https://cloud.tencent.com/document/api/1223/75520)
* [DescribeResourceUsageInfo](https://cloud.tencent.com/document/api/1223/75519)

新增数据结构：

* [ResourceUsageInfoData](https://cloud.tencent.com/document/api/1223/75143#ResourceUsageInfoData)

### 第 2 次发布

发布时间：2022-06-08 15:18:22

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateAppScanTask](https://cloud.tencent.com/document/api/1223/75159)
* [CreateAppScanTaskRepeat](https://cloud.tencent.com/document/api/1223/75158)
* [DescribeScanTaskList](https://cloud.tencent.com/document/api/1223/75157)
* [DescribeScanTaskReportUrl](https://cloud.tencent.com/document/api/1223/75156)
* [DescribeScanTaskStatus](https://cloud.tencent.com/document/api/1223/75155)

新增数据结构：

* [AppInfoItem](https://cloud.tencent.com/document/api/1223/75143#AppInfoItem)
* [AppTaskData](https://cloud.tencent.com/document/api/1223/75143#AppTaskData)
* [TaskFlowStepsInfo](https://cloud.tencent.com/document/api/1223/75143#TaskFlowStepsInfo)

### 第 1 次发布

发布时间：2022-06-08 15:12:00

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateFlySecMiniAppScanTask](https://cloud.tencent.com/document/api/1223/75142)
* [CreateFlySecMiniAppScanTaskRepeat](https://cloud.tencent.com/document/api/1223/75141)
* [DescribeFlySecMiniAppReportUrl](https://cloud.tencent.com/document/api/1223/75140)
* [DescribeFlySecMiniAppScanTaskList](https://cloud.tencent.com/document/api/1223/75139)
* [DescribeFlySecMiniAppScanTaskParam](https://cloud.tencent.com/document/api/1223/75138)
* [DescribeFlySecMiniAppScanTaskStatus](https://cloud.tencent.com/document/api/1223/75137)

新增数据结构：

* [FlySecMiniAppTaskData](https://cloud.tencent.com/document/api/1223/75143#FlySecMiniAppTaskData)




## 多网聚合加速(mna) 版本：2021-01-19

### 第 21 次发布

发布时间：2024-07-22 01:55:24

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [AddL3Conn](https://cloud.tencent.com/document/api/1385/109052)
* [DeleteL3Conn](https://cloud.tencent.com/document/api/1385/109051)
* [GetL3ConnList](https://cloud.tencent.com/document/api/1385/109050)
* [UpdateL3Cidr](https://cloud.tencent.com/document/api/1385/109049)
* [UpdateL3Conn](https://cloud.tencent.com/document/api/1385/109048)
* [UpdateL3Switch](https://cloud.tencent.com/document/api/1385/109047)

新增数据结构：

* [L3ConnInfo](https://cloud.tencent.com/document/api/1385/55846#L3ConnInfo)

### 第 20 次发布

发布时间：2024-07-11 01:20:22

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [AddGroup](https://cloud.tencent.com/document/api/1385/108542)
* [DeleteGroup](https://cloud.tencent.com/document/api/1385/108541)
* [GetFlowStatisticByRegion](https://cloud.tencent.com/document/api/1385/108540)
* [GetGroupDetail](https://cloud.tencent.com/document/api/1385/108539)
* [GetGroupList](https://cloud.tencent.com/document/api/1385/108538)
* [GroupAddDevice](https://cloud.tencent.com/document/api/1385/108537)
* [GroupDeleteDevice](https://cloud.tencent.com/document/api/1385/108536)
* [SetNotifyUrl](https://cloud.tencent.com/document/api/1385/108535)
* [UpdateGroup](https://cloud.tencent.com/document/api/1385/108534)

修改接口：

* [AddDevice](https://cloud.tencent.com/document/api/1385/80483)

	* 新增入参：FlowTrunc

* [UpdateDevice](https://cloud.tencent.com/document/api/1385/80478)

	* 新增入参：FlowTrunc


新增数据结构：

* [GroupInfo](https://cloud.tencent.com/document/api/1385/55846#GroupInfo)

修改数据结构：

* [ActivateHardware](https://cloud.tencent.com/document/api/1385/55846#ActivateHardware)

	* 新增成员：FlowTrunc, DeviceId

* [DeviceBaseInfo](https://cloud.tencent.com/document/api/1385/55846#DeviceBaseInfo)

	* 新增成员：FlowTrunc

* [HardwareInfo](https://cloud.tencent.com/document/api/1385/55846#HardwareInfo)

	* 新增成员：FlowTrunc


### 第 19 次发布

发布时间：2024-05-28 01:54:57

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [GetFlowAlarmInfo](https://cloud.tencent.com/document/api/1385/106608)
* [GetFlowStatisticByGroup](https://cloud.tencent.com/document/api/1385/106607)

### 第 18 次发布

发布时间：2024-04-12 01:19:07

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [AddDevice](https://cloud.tencent.com/document/api/1385/80483)

	* 新增入参：LicensePayMode, GroupName, GroupId

* [GetFlowStatistic](https://cloud.tencent.com/document/api/1385/80486)

	* 新增入参：DeviceList

* [GetStatisticData](https://cloud.tencent.com/document/api/1385/80479)

	* 新增入参：DeviceList, GroupId

* [OrderFlowPackage](https://cloud.tencent.com/document/api/1385/102108)

	* 新增入参：FlowTruncFlag


修改数据结构：

* [ActivateHardware](https://cloud.tencent.com/document/api/1385/55846#ActivateHardware)

	* 新增成员：LicensePayMode, GroupId, GroupName

* [DeviceBaseInfo](https://cloud.tencent.com/document/api/1385/55846#DeviceBaseInfo)

	* 新增成员：LicensePayMode, Payer, GroupId, GroupName

* [DeviceDetails](https://cloud.tencent.com/document/api/1385/55846#DeviceDetails)

	* <font color="#dd0000">**修改成员**：</font>GatewaySite, BusinessDownRate, BusinessUpRate

* [FlowPackageInfo](https://cloud.tencent.com/document/api/1385/55846#FlowPackageInfo)

	* 新增成员：TruncFlag, CapacityRemainPrecise

* [HardwareInfo](https://cloud.tencent.com/document/api/1385/55846#HardwareInfo)

	* 新增成员：LicensePayMode, Payer, GroupId, GroupName

	* <font color="#dd0000">**修改成员**：</font>DeviceId, DeviceName, ActiveTime, LastOnlineTime, Description, VendorDescription, LicenseChargingMode, CreateTime, SN

* [VendorHardware](https://cloud.tencent.com/document/api/1385/55846#VendorHardware)

	* 新增成员：LicensePayMode, Payer

	* <font color="#dd0000">**修改成员**：</font>HardwareId, SN, CreateTime, Status, ActiveTime, Description, DeviceId, LicenseChargingMode, LastOnlineTime


### 第 17 次发布

发布时间：2024-03-01 01:20:25

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [AddDevice](https://cloud.tencent.com/document/api/1385/80483)

	* 新增入参：AccessScope

* [GetFlowStatistic](https://cloud.tencent.com/document/api/1385/80486)

	* 新增入参：AccessRegion, GatewayType

* [GetMultiFlowStatistic](https://cloud.tencent.com/document/api/1385/86864)

	* 新增入参：AccessRegion, GatewayType

* [GetNetMonitor](https://cloud.tencent.com/document/api/1385/101384)

	* 新增入参：GatewayType

	* 新增出参：AccessRegion

* [GetStatisticData](https://cloud.tencent.com/document/api/1385/80479)

	* 新增入参：AccessRegion, GatewayType


修改数据结构：

* [ActivateHardware](https://cloud.tencent.com/document/api/1385/55846#ActivateHardware)

	* 新增成员：AccessScope

* [DeviceBaseInfo](https://cloud.tencent.com/document/api/1385/55846#DeviceBaseInfo)

	* 新增成员：AccessScope

* [FlowPackageInfo](https://cloud.tencent.com/document/api/1385/55846#FlowPackageInfo)

	* 新增成员：CreateTime, ModifyStatus


### 第 16 次发布

发布时间：2024-02-26 01:19:32

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [OrderFlowPackage](https://cloud.tencent.com/document/api/1385/102108)

	* 新增入参：AutoVoucher, VoucherIds


### 第 15 次发布

发布时间：2023-12-01 01:19:47

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [GetDevicePayMode](https://cloud.tencent.com/document/api/1385/102111)
* [GetFlowPackages](https://cloud.tencent.com/document/api/1385/102110)
* [ModifyPackageRenewFlag](https://cloud.tencent.com/document/api/1385/102109)
* [OrderFlowPackage](https://cloud.tencent.com/document/api/1385/102108)

新增数据结构：

* [DevicePayModeInfo](https://cloud.tencent.com/document/api/1385/55846#DevicePayModeInfo)
* [FlowPackageInfo](https://cloud.tencent.com/document/api/1385/55846#FlowPackageInfo)

### 第 14 次发布

发布时间：2023-11-28 01:19:46

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [ActivateHardware](https://cloud.tencent.com/document/api/1385/101985)
* [AddHardware](https://cloud.tencent.com/document/api/1385/101984)
* [GetHardwareList](https://cloud.tencent.com/document/api/1385/101983)
* [GetVendorHardware](https://cloud.tencent.com/document/api/1385/101982)
* [UpdateHardware](https://cloud.tencent.com/document/api/1385/101981)

新增数据结构：

* [ActivateHardware](https://cloud.tencent.com/document/api/1385/55846#ActivateHardware)
* [Hardware](https://cloud.tencent.com/document/api/1385/55846#Hardware)
* [HardwareInfo](https://cloud.tencent.com/document/api/1385/55846#HardwareInfo)
* [VendorHardware](https://cloud.tencent.com/document/api/1385/55846#VendorHardware)

### 第 13 次发布

发布时间：2023-11-08 01:53:44

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [GetNetMonitor](https://cloud.tencent.com/document/api/1385/101384)

新增数据结构：

* [MonitorData](https://cloud.tencent.com/document/api/1385/55846#MonitorData)
* [SlotNetInfo](https://cloud.tencent.com/document/api/1385/55846#SlotNetInfo)

### 第 12 次发布

发布时间：2023-08-01 01:32:11

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [GetDevices](https://cloud.tencent.com/document/api/1385/80480)

	* 新增入参：DeviceType


### 第 11 次发布

发布时间：2023-02-24 01:20:12

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [GetMultiFlowStatistic](https://cloud.tencent.com/document/api/1385/86864)

新增数据结构：

* [FlowDetails](https://cloud.tencent.com/document/api/1385/55846#FlowDetails)

### 第 10 次发布

发布时间：2023-02-23 01:43:45

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [DeviceDetails](https://cloud.tencent.com/document/api/1385/55846#DeviceDetails)

	* 新增成员：GatewaySite, BusinessDownRate, BusinessUpRate

* [DeviceNetInfo](https://cloud.tencent.com/document/api/1385/55846#DeviceNetInfo)

	* 新增成员：DownRate, UpRate


### 第 9 次发布

发布时间：2022-11-17 11:16:37

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateEncryptedKey](https://cloud.tencent.com/document/api/1385/83048)
* [GetPublicKey](https://cloud.tencent.com/document/api/1385/83047)

### 第 8 次发布

发布时间：2022-11-17 06:34:55

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [AddDevice](https://cloud.tencent.com/document/api/1385/80483)

	* 新增入参：Encrypted

	* 新增出参：Signature


### 第 7 次发布

发布时间：2022-09-14 20:21:28

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [GetFlowStatistic](https://cloud.tencent.com/document/api/1385/80486)

新增数据结构：

* [NetDetails](https://cloud.tencent.com/document/api/1385/55846#NetDetails)

### 第 6 次发布

发布时间：2022-09-14 15:06:36

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [AddDevice](https://cloud.tencent.com/document/api/1385/80483)
* [DeleteDevice](https://cloud.tencent.com/document/api/1385/80482)
* [GetDevice](https://cloud.tencent.com/document/api/1385/80481)
* [GetDevices](https://cloud.tencent.com/document/api/1385/80480)
* [GetStatisticData](https://cloud.tencent.com/document/api/1385/80479)
* [UpdateDevice](https://cloud.tencent.com/document/api/1385/80478)

新增数据结构：

* [DeviceBaseInfo](https://cloud.tencent.com/document/api/1385/55846#DeviceBaseInfo)
* [DeviceDetails](https://cloud.tencent.com/document/api/1385/55846#DeviceDetails)
* [DeviceNetInfo](https://cloud.tencent.com/document/api/1385/55846#DeviceNetInfo)
* [UpdateNetInfo](https://cloud.tencent.com/document/api/1385/55846#UpdateNetInfo)

### 第 5 次发布

发布时间：2022-02-21 08:09:33

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateQos](https://cloud.tencent.com/document/api/1385/55845)

	* 新增入参：Context, Extern


新增数据结构：

* [Context](https://cloud.tencent.com/document/api/1385/55846#Context)
* [ExpectedThreshold](https://cloud.tencent.com/document/api/1385/55846#ExpectedThreshold)
* [NetworkData](https://cloud.tencent.com/document/api/1385/55846#NetworkData)

### 第 4 次发布

发布时间：2021-09-29 08:07:33

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeQos](https://cloud.tencent.com/document/api/1385/62090)

### 第 3 次发布

发布时间：2021-09-27 08:14:04

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateQos](https://cloud.tencent.com/document/api/1385/55845)

	* 新增入参：Protocol


### 第 2 次发布

发布时间：2021-07-22 08:00:32

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateQos](https://cloud.tencent.com/document/api/1385/55845)

	* 新增入参：TemplateId


### 第 1 次发布

发布时间：2021-05-17 08:00:05

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateQos](https://cloud.tencent.com/document/api/1385/55845)
* [DeleteQos](https://cloud.tencent.com/document/api/1385/55844)

新增数据结构：

* [Capacity](https://cloud.tencent.com/document/api/1385/55846#Capacity)
* [DestAddressInfo](https://cloud.tencent.com/document/api/1385/55846#DestAddressInfo)
* [DeviceInfo](https://cloud.tencent.com/document/api/1385/55846#DeviceInfo)
* [SrcAddressInfo](https://cloud.tencent.com/document/api/1385/55846#SrcAddressInfo)




## 云数据库 MongoDB(mongodb) 版本：2018-04-08

### 第 6 次发布

发布时间：2024-03-11 15:09:36

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeClientConnections](https://cloud.tencent.com/document/api/240/37233)

	* 新增出参：TotalCount


### 第 5 次发布

发布时间：2020-01-16 18:25:41

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [SpecificationInfo](https://cloud.tencent.com/document/api/240/35771#SpecificationInfo)

	* 新增成员：SpecItems

	* <font color="#dd0000">**删除成员**：</font>SpecItem


### 第 4 次发布

发布时间：2019-08-16 23:30:12

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeClientConnections](https://cloud.tencent.com/document/api/240/37233)

新增数据结构：

* [ClientConnection](https://cloud.tencent.com/document/api/240/35771#ClientConnection)

### 第 3 次发布

发布时间：2019-07-16 19:28:09

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateDBInstance](https://cloud.tencent.com/document/api/240/31810)

	* 新增出参：InstanceIds

* [CreateDBInstanceHour](https://cloud.tencent.com/document/api/240/31809)

	* 新增出参：InstanceIds


### 第 2 次发布

发布时间：2019-06-27 15:13:10

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [AssignProject](https://cloud.tencent.com/document/api/240/35770)
* [DescribeDBInstances](https://cloud.tencent.com/document/api/240/35769)
* [DescribeSlowLog](https://cloud.tencent.com/document/api/240/35768)
* [DescribeSpecInfo](https://cloud.tencent.com/document/api/240/35767)
* [RenameInstance](https://cloud.tencent.com/document/api/240/35766)
* [SetAutoRenew](https://cloud.tencent.com/document/api/240/35765)
* [SetPassword](https://cloud.tencent.com/document/api/240/35764)

新增数据结构：

* [MongoDBInstance](https://cloud.tencent.com/document/api/240/35771#MongoDBInstance)
* [MongoDBInstanceDetail](https://cloud.tencent.com/document/api/240/35771#MongoDBInstanceDetail)
* [MongodbShardInfo](https://cloud.tencent.com/document/api/240/35771#MongodbShardInfo)
* [SpecItem](https://cloud.tencent.com/document/api/240/35771#SpecItem)
* [SpecificationInfo](https://cloud.tencent.com/document/api/240/35771#SpecificationInfo)
* [TagInfo](https://cloud.tencent.com/document/api/240/35771#TagInfo)

### 第 1 次发布

发布时间：2018-12-20 20:21:26

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateDBInstance](https://cloud.tencent.com/document/api/240/31810)
* [CreateDBInstanceHour](https://cloud.tencent.com/document/api/240/31809)
* [TerminateDBInstance](https://cloud.tencent.com/document/api/240/31808)
* [UpgradeDBInstance](https://cloud.tencent.com/document/api/240/31807)
* [UpgradeDBInstanceHour](https://cloud.tencent.com/document/api/240/31806)



## 云数据库 MongoDB(mongodb) 版本：2019-07-25

### 第 44 次发布

发布时间：2024-07-25 01:56:02

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [RestartNodes](https://cloud.tencent.com/document/api/240/109311)

修改接口：

* [CreateDBInstance](https://cloud.tencent.com/document/api/240/38571)

	* 新增入参：ParamTemplateId

* [CreateDBInstanceHour](https://cloud.tencent.com/document/api/240/38570)

	* 新增入参：ParamTemplateId


### 第 43 次发布

发布时间：2024-07-24 01:54:54

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateDBInstanceParamTpl](https://cloud.tencent.com/document/api/240/109156)
* [DescribeDBInstanceParamTpl](https://cloud.tencent.com/document/api/240/109155)
* [DescribeDBInstanceParamTplDetail](https://cloud.tencent.com/document/api/240/109154)
* [DropDBInstanceParamTpl](https://cloud.tencent.com/document/api/240/109153)
* [ModifyDBInstanceParamTpl](https://cloud.tencent.com/document/api/240/109152)

新增数据结构：

* [ParamTpl](https://cloud.tencent.com/document/api/240/38576#ParamTpl)
* [ParamType](https://cloud.tencent.com/document/api/240/38576#ParamType)

### 第 42 次发布

发布时间：2024-07-15 01:15:52

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [ModifyDBInstanceSpec](https://cloud.tencent.com/document/api/240/38565)

	* 新增入参：MongosMemory


### 第 41 次发布

发布时间：2024-06-21 01:58:00

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [ModifyInstanceParams](https://cloud.tencent.com/document/api/240/107557)

新增数据结构：

* [ModifyMongoDBParamType](https://cloud.tencent.com/document/api/240/38576#ModifyMongoDBParamType)

### 第 40 次发布

发布时间：2024-06-18 01:57:52

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [BackupInfo](https://cloud.tencent.com/document/api/240/38576#BackupInfo)

	* 新增成员：BackId, DeleteTime, BackupRegion


### 第 39 次发布

发布时间：2024-06-12 02:08:47

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeBackupRules](https://cloud.tencent.com/document/api/240/107169)
* [DescribeTransparentDataEncryptionStatus](https://cloud.tencent.com/document/api/240/107168)
* [EnableTransparentDataEncryption](https://cloud.tencent.com/document/api/240/107167)
* [SetBackupRules](https://cloud.tencent.com/document/api/240/107166)

新增数据结构：

* [KMSInfoDetail](https://cloud.tencent.com/document/api/240/38576#KMSInfoDetail)

### 第 38 次发布

发布时间：2024-04-09 01:18:23

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [FlashBackDBInstance](https://cloud.tencent.com/document/api/240/104930)

新增数据结构：

* [FBKeyValue](https://cloud.tencent.com/document/api/240/38576#FBKeyValue)
* [FlashbackCollection](https://cloud.tencent.com/document/api/240/38576#FlashbackCollection)
* [FlashbackDatabase](https://cloud.tencent.com/document/api/240/38576#FlashbackDatabase)

### 第 37 次发布

发布时间：2024-03-18 01:18:19

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [ModifyDBInstanceNetworkAddress](https://cloud.tencent.com/document/api/240/71918)

	* 新增出参：FlowId


### 第 36 次发布

发布时间：2024-03-13 01:19:31

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [SetInstanceMaintenance](https://cloud.tencent.com/document/api/240/104304)

### 第 35 次发布

发布时间：2024-03-05 01:20:29

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeDBInstanceDeal](https://cloud.tencent.com/document/api/240/43667)

	* 新增出参：InstanceId


### 第 34 次发布

发布时间：2024-01-29 01:17:07

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [InstanceDetail](https://cloud.tencent.com/document/api/240/38576#InstanceDetail)

	* 新增成员：ZoneList


### 第 33 次发布

发布时间：2023-12-27 01:26:46

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [ModifyDBInstanceSpec](https://cloud.tencent.com/document/api/240/38565)

	* 新增入参：AddNodeList, RemoveNodeList


新增数据结构：

* [AddNodeList](https://cloud.tencent.com/document/api/240/38576#AddNodeList)
* [RemoveNodeList](https://cloud.tencent.com/document/api/240/38576#RemoveNodeList)

### 第 32 次发布

发布时间：2023-04-11 01:28:42

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DeleteAccountUser](https://cloud.tencent.com/document/api/240/90048)

### 第 31 次发布

发布时间：2023-03-31 01:36:51

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeDBInstances](https://cloud.tencent.com/document/api/240/38568)

	* <font color="#dd0000">**修改入参**：</font>Tags


### 第 30 次发布

发布时间：2023-03-01 01:35:11

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateDBInstanceHour](https://cloud.tencent.com/document/api/240/38570)

	* 新增入参：ReadonlyNodeNum, ReadonlyNodeAvailabilityZoneList, HiddenZone


### 第 29 次发布

发布时间：2023-02-22 01:37:39

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [InstanceDetail](https://cloud.tencent.com/document/api/240/38576#InstanceDetail)

	* 新增成员：MongosNodeNum, MongosMemory, MongosCpuNum, ConfigServerNodeNum, ConfigServerMemory, ConfigServerVolume, ConfigServerCpuNum, ReadonlyNodeNum


### 第 28 次发布

发布时间：2023-01-02 01:31:42

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateAccountUser](https://cloud.tencent.com/document/api/240/84704)

### 第 27 次发布

发布时间：2022-11-25 06:45:10

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateDBInstance](https://cloud.tencent.com/document/api/240/38571)

	* 新增入参：ReadonlyNodeNum, ReadonlyNodeAvailabilityZoneList, HiddenZone


### 第 26 次发布

发布时间：2022-10-28 06:36:39

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeDBInstanceNodeProperty](https://cloud.tencent.com/document/api/240/82022)

新增数据结构：

* [NodeProperty](https://cloud.tencent.com/document/api/240/38576#NodeProperty)
* [NodeTag](https://cloud.tencent.com/document/api/240/38576#NodeTag)
* [ReplicateSetInfo](https://cloud.tencent.com/document/api/240/38576#ReplicateSetInfo)

### 第 25 次发布

发布时间：2022-10-10 06:31:49

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [InquirePriceCreateDBInstances](https://cloud.tencent.com/document/api/240/43666)

	* 新增入参：InstanceChargeType, MongosCpu, MongosMemory, MongosNum, ConfigServerCpu, ConfigServerMemory, ConfigServerVolume

	* <font color="#dd0000">**修改入参**：</font>Period


### 第 24 次发布

发布时间：2022-09-21 06:37:03

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeAccountUsers](https://cloud.tencent.com/document/api/240/80800)

新增数据结构：

* [UserInfo](https://cloud.tencent.com/document/api/240/38576#UserInfo)

### 第 23 次发布

发布时间：2022-08-15 06:31:24

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [TerminateDBInstances](https://cloud.tencent.com/document/api/240/79047)

### 第 22 次发布

发布时间：2022-08-11 06:40:51

本次发布包含了以下内容：

改善已有的文档。

<font color="#dd0000">**删除接口**：</font>

* DescribeBackupAccess

<font color="#dd0000">**删除数据结构**：</font>

* BackupFile

### 第 21 次发布

发布时间：2022-06-07 06:10:21

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [SpecificationInfo](https://cloud.tencent.com/document/api/240/38576#SpecificationInfo)

	* 新增成员：SupportMultiAZ


### 第 20 次发布

发布时间：2022-04-01 06:11:50

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [ModifyDBInstanceNetworkAddress](https://cloud.tencent.com/document/api/240/71918)

新增数据结构：

* [ModifyNetworkAddress](https://cloud.tencent.com/document/api/240/38576#ModifyNetworkAddress)

### 第 19 次发布

发布时间：2022-03-03 08:08:57

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [ModifyDBInstanceSecurityGroup](https://cloud.tencent.com/document/api/240/70577)

### 第 18 次发布

发布时间：2022-02-25 08:11:43

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [InquirePriceModifyDBInstanceSpec](https://cloud.tencent.com/document/api/240/43665)

	* 新增入参：NodeNum, ReplicateSetNum


修改数据结构：

* [BackupDownloadTask](https://cloud.tencent.com/document/api/240/38576#BackupDownloadTask)

	* 新增成员：BackupMethod, BackupDesc


### 第 17 次发布

发布时间：2022-01-05 08:11:21

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [SetAccountUserPrivilege](https://cloud.tencent.com/document/api/240/67357)

新增数据结构：

* [Auth](https://cloud.tencent.com/document/api/240/38576#Auth)

### 第 16 次发布

发布时间：2021-12-14 08:12:21

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeInstanceParams](https://cloud.tencent.com/document/api/240/65903)

新增数据结构：

* [InstanceEnumParam](https://cloud.tencent.com/document/api/240/38576#InstanceEnumParam)
* [InstanceIntegerParam](https://cloud.tencent.com/document/api/240/38576#InstanceIntegerParam)
* [InstanceMultiParam](https://cloud.tencent.com/document/api/240/38576#InstanceMultiParam)
* [InstanceTextParam](https://cloud.tencent.com/document/api/240/38576#InstanceTextParam)

### 第 15 次发布

发布时间：2021-12-09 08:08:23

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [ClientConnection](https://cloud.tencent.com/document/api/240/38576#ClientConnection)

	* 新增成员：InternalService


### 第 14 次发布

发布时间：2021-09-27 08:14:06

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateDBInstance](https://cloud.tencent.com/document/api/240/38571)

	* 新增入参：RestoreTime, InstanceName, AvailabilityZoneList, MongosCpu, MongosMemory, MongosNodeNum

* [CreateDBInstanceHour](https://cloud.tencent.com/document/api/240/38570)

	* 新增入参：RestoreTime, InstanceName, AvailabilityZoneList, MongosCpu, MongosMemory, MongosNodeNum


### 第 13 次发布

发布时间：2021-08-24 08:07:53

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [ModifyDBInstanceSpec](https://cloud.tencent.com/document/api/240/38565)

	* 新增入参：NodeNum, ReplicateSetNum, InMaintenance


### 第 12 次发布

发布时间：2021-05-27 08:06:27

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [SecurityGroupBound](https://cloud.tencent.com/document/api/240/38576#SecurityGroupBound)

	* 新增成员：Id, AddressModule, ServiceModule, Desc


### 第 11 次发布

发布时间：2021-05-12 08:06:12

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeSecurityGroup](https://cloud.tencent.com/document/api/240/55675)

新增数据结构：

* [SecurityGroup](https://cloud.tencent.com/document/api/240/38576#SecurityGroup)
* [SecurityGroupBound](https://cloud.tencent.com/document/api/240/38576#SecurityGroupBound)

### 第 10 次发布

发布时间：2021-03-29 08:05:40

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateBackupDownloadTask](https://cloud.tencent.com/document/api/240/54175)
* [DescribeBackupDownloadTask](https://cloud.tencent.com/document/api/240/54174)

新增数据结构：

* [BackupDownloadTask](https://cloud.tencent.com/document/api/240/38576#BackupDownloadTask)
* [BackupDownloadTaskStatus](https://cloud.tencent.com/document/api/240/38576#BackupDownloadTaskStatus)
* [ReplicaSetInfo](https://cloud.tencent.com/document/api/240/38576#ReplicaSetInfo)

### 第 9 次发布

发布时间：2021-03-03 08:05:46

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeSlowLogPatterns](https://cloud.tencent.com/document/api/240/43597)

	* 新增入参：Format

* [DescribeSlowLogs](https://cloud.tencent.com/document/api/240/43596)

	* 新增入参：Format


### 第 8 次发布

发布时间：2020-09-16 08:04:22

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeDBInstances](https://cloud.tencent.com/document/api/240/38568)

	* 新增入参：Tags


### 第 7 次发布

发布时间：2020-09-04 08:04:58

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeCurrentOp](https://cloud.tencent.com/document/api/240/48120)
* [KillOps](https://cloud.tencent.com/document/api/240/48119)

修改接口：

* [DescribeDBBackups](https://cloud.tencent.com/document/api/240/38574)

	* 新增入参：BackupMethod, Limit, Offset


新增数据结构：

* [CurrentOp](https://cloud.tencent.com/document/api/240/38576#CurrentOp)
* [Operation](https://cloud.tencent.com/document/api/240/38576#Operation)

### 第 6 次发布

发布时间：2020-07-22 08:14:25

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateBackupDBInstance](https://cloud.tencent.com/document/api/240/46599)
* [DescribeAsyncRequestInfo](https://cloud.tencent.com/document/api/240/46601)
* [ResetDBInstancePassword](https://cloud.tencent.com/document/api/240/46598)

### 第 5 次发布

发布时间：2020-07-20 08:13:13

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateDBInstance](https://cloud.tencent.com/document/api/240/38571)

	* 新增入参：AutoVoucher, Clone, Father, SecurityGroup

* [CreateDBInstanceHour](https://cloud.tencent.com/document/api/240/38570)

	* 新增入参：Clone, Father, SecurityGroup


### 第 4 次发布

发布时间：2020-06-02 08:13:21

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [FlushInstanceRouterConfig](https://cloud.tencent.com/document/api/240/45080)

### 第 3 次发布

发布时间：2020-04-22 08:12:39

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeDBInstanceDeal](https://cloud.tencent.com/document/api/240/43667)
* [InquirePriceCreateDBInstances](https://cloud.tencent.com/document/api/240/43666)
* [InquirePriceModifyDBInstanceSpec](https://cloud.tencent.com/document/api/240/43665)
* [InquirePriceRenewDBInstances](https://cloud.tencent.com/document/api/240/43664)

新增数据结构：

* [DBInstancePrice](https://cloud.tencent.com/document/api/240/38576#DBInstancePrice)

### 第 2 次发布

发布时间：2020-04-21 08:12:45

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeSlowLogPatterns](https://cloud.tencent.com/document/api/240/43597)
* [DescribeSlowLogs](https://cloud.tencent.com/document/api/240/43596)
* [RenewDBInstances](https://cloud.tencent.com/document/api/240/43595)

修改接口：

* [DescribeClientConnections](https://cloud.tencent.com/document/api/240/38569)

	* 新增入参：Limit, Offset

	* 新增出参：TotalCount


新增数据结构：

* [InstanceChargePrepaid](https://cloud.tencent.com/document/api/240/38576#InstanceChargePrepaid)
* [SlowLogPattern](https://cloud.tencent.com/document/api/240/38576#SlowLogPattern)

### 第 1 次发布

发布时间：2019-10-18 16:36:58

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [AssignProject](https://cloud.tencent.com/document/api/240/38572)
* [CreateDBInstance](https://cloud.tencent.com/document/api/240/38571)
* [CreateDBInstanceHour](https://cloud.tencent.com/document/api/240/38570)
* [DescribeBackupAccess](https://cloud.tencent.com/document/api/240/38575)
* [DescribeClientConnections](https://cloud.tencent.com/document/api/240/38569)
* [DescribeDBBackups](https://cloud.tencent.com/document/api/240/38574)
* [DescribeDBInstances](https://cloud.tencent.com/document/api/240/38568)
* [DescribeSpecInfo](https://cloud.tencent.com/document/api/240/38567)
* [IsolateDBInstance](https://cloud.tencent.com/document/api/240/38566)
* [ModifyDBInstanceSpec](https://cloud.tencent.com/document/api/240/38565)
* [OfflineIsolatedDBInstance](https://cloud.tencent.com/document/api/240/38564)
* [RenameInstance](https://cloud.tencent.com/document/api/240/38563)

新增数据结构：

* [BackupFile](https://cloud.tencent.com/document/api/240/38576#BackupFile)
* [BackupInfo](https://cloud.tencent.com/document/api/240/38576#BackupInfo)
* [ClientConnection](https://cloud.tencent.com/document/api/240/38576#ClientConnection)
* [DBInstanceInfo](https://cloud.tencent.com/document/api/240/38576#DBInstanceInfo)
* [InstanceDetail](https://cloud.tencent.com/document/api/240/38576#InstanceDetail)
* [ShardInfo](https://cloud.tencent.com/document/api/240/38576#ShardInfo)
* [SpecItem](https://cloud.tencent.com/document/api/240/38576#SpecItem)
* [SpecificationInfo](https://cloud.tencent.com/document/api/240/38576#SpecificationInfo)
* [TagInfo](https://cloud.tencent.com/document/api/240/38576#TagInfo)




## 腾讯云可观测平台(monitor) 版本：2018-07-24

### 第 119 次发布

发布时间：2024-07-17 01:20:37

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [PrometheusRecordRuleYamlItem](https://cloud.tencent.com/document/api/248/30354#PrometheusRecordRuleYamlItem)

	* <font color="#dd0000">**修改成员**：</font>Status, Id, Count


### 第 118 次发布

发布时间：2024-07-03 01:20:32

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeAlarmHistories](https://cloud.tencent.com/document/api/248/48684)

	* 新增入参：ConvergenceHistoryIDs


### 第 117 次发布

发布时间：2024-06-20 01:58:59

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DeleteAlarmPolicy](https://cloud.tencent.com/document/api/248/51285)

	* 新增入参：PromInsIds


### 第 116 次发布

发布时间：2024-06-14 02:13:11

本次发布包含了以下内容：

改善已有的文档。

<font color="#dd0000">**预下线接口**：</font>

* CheckIsPrometheusNewUser

修改数据结构：

* [AlarmNotice](https://cloud.tencent.com/document/api/248/30354#AlarmNotice)

	* <font color="#dd0000">**修改成员**：</font>Id, Name, UpdatedAt, UpdatedBy, NoticeType, UserNotices, URLNotices, IsPreset, NoticeLanguage, PolicyIds, AMPConsumerId, CLSNotices, Tags


### 第 115 次发布

发布时间：2024-06-13 02:05:31

本次发布包含了以下内容：

改善已有的文档。

<font color="#dd0000">**预下线接口**：</font>

* DescribePrometheusRecordRuleYaml

### 第 114 次发布

发布时间：2024-05-30 01:55:28

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [AlarmPolicyRule](https://cloud.tencent.com/document/api/248/30354#AlarmPolicyRule)

	* 新增成员：IsLatenessMetric

* [Metric](https://cloud.tencent.com/document/api/248/30354#Metric)

	* 新增成员：IsLatenessMetric

	* <font color="#dd0000">**修改成员**：</font>Operators, Periods


### 第 113 次发布

发布时间：2024-05-24 01:55:33

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribePrometheusClusterAgents](https://cloud.tencent.com/document/api/248/86040)

	* 新增入参：ClusterIds, ClusterTypes, ClusterName


### 第 112 次发布

发布时间：2024-05-08 01:22:13

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [ModifyPrometheusInstanceAttributes](https://cloud.tencent.com/document/api/248/76009)

	* <font color="#dd0000">**修改入参**：</font>InstanceName


### 第 111 次发布

发布时间：2024-04-19 01:22:14

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribePrometheusTargetsTMP](https://cloud.tencent.com/document/api/248/86037)

	* 新增入参：Offset, Limit


### 第 110 次发布

发布时间：2024-04-15 01:57:02

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [Condition](https://cloud.tencent.com/document/api/248/30354#Condition)

	* 新增成员：HierarchicalValue

* [EventCondition](https://cloud.tencent.com/document/api/248/30354#EventCondition)

	* 新增成员：MetricName


### 第 109 次发布

发布时间：2024-04-11 01:18:27

本次发布包含了以下内容：

改善已有的文档。

<font color="#dd0000">**删除接口**：</font>

* SendCustomAlarmMsg

### 第 108 次发布

发布时间：2024-03-20 01:20:37

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeAlarmSmsQuota](https://cloud.tencent.com/document/api/248/104513)
* [DescribeMonitorResourceInfo](https://cloud.tencent.com/document/api/248/104515)
* [DescribePhoneAlarmFlowTotalCount](https://cloud.tencent.com/document/api/248/104512)

新增数据结构：

* [DescribeAlarmSmsQuotaQuota](https://cloud.tencent.com/document/api/248/30354#DescribeAlarmSmsQuotaQuota)

### 第 107 次发布

发布时间：2024-03-04 01:19:57

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [PrometheusAgentOverview](https://cloud.tencent.com/document/api/248/30354#PrometheusAgentOverview)

	* 新增成员：DesiredAgentNum, ReadyAgentNum


### 第 106 次发布

发布时间：2024-02-26 01:19:42

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [BindingPolicyTag](https://cloud.tencent.com/document/api/248/67219)

	* 新增入参：TagOperation


修改数据结构：

* [AlarmPolicy](https://cloud.tencent.com/document/api/248/30354#AlarmPolicy)

	* 新增成员：TagOperation


### 第 105 次发布

发布时间：2024-01-24 01:32:19

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribePrometheusInstanceInitStatus](https://cloud.tencent.com/document/api/248/85716)

	* 新增出参：SecurityGroupId


### 第 104 次发布

发布时间：2024-01-23 14:38:25

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [PrometheusAgentOverview](https://cloud.tencent.com/document/api/248/30354#PrometheusAgentOverview)

	* 新增成员：EnableExternal

	* <font color="#dd0000">**修改成员**：</font>Name


### 第 103 次发布

发布时间：2024-01-17 01:18:35

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [GetMonitorData](https://cloud.tencent.com/document/api/248/31014)

	* 新增入参：SpecifyStatistics


修改数据结构：

* [DataPoint](https://cloud.tencent.com/document/api/248/30354#DataPoint)

	* 新增成员：MaxValues, MinValues, AvgValues


### 第 102 次发布

发布时间：2024-01-12 01:19:06

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreatePrometheusAlertGroup](https://cloud.tencent.com/document/api/248/102990)
* [DeletePrometheusAlertGroups](https://cloud.tencent.com/document/api/248/102989)
* [DescribePrometheusAlertGroups](https://cloud.tencent.com/document/api/248/102988)
* [UpdatePrometheusAlertGroup](https://cloud.tencent.com/document/api/248/102987)
* [UpdatePrometheusAlertGroupState](https://cloud.tencent.com/document/api/248/102986)

新增数据结构：

* [PrometheusAlertAllowTimeRange](https://cloud.tencent.com/document/api/248/30354#PrometheusAlertAllowTimeRange)
* [PrometheusAlertCustomReceiver](https://cloud.tencent.com/document/api/248/30354#PrometheusAlertCustomReceiver)
* [PrometheusAlertGroupRuleSet](https://cloud.tencent.com/document/api/248/30354#PrometheusAlertGroupRuleSet)
* [PrometheusAlertGroupSet](https://cloud.tencent.com/document/api/248/30354#PrometheusAlertGroupSet)

### 第 101 次发布

发布时间：2024-01-10 01:19:07

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateGrafanaInstance](https://cloud.tencent.com/document/api/248/79219)

	* 新增入参：AutoVoucher


### 第 100 次发布

发布时间：2023-12-19 01:56:30

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [AlarmHierarchicalNotice](https://cloud.tencent.com/document/api/248/30354#AlarmHierarchicalNotice)

	* 新增成员：PolicyId


### 第 99 次发布

发布时间：2023-12-15 19:59:38

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribePrometheusClusterAgents](https://cloud.tencent.com/document/api/248/86040)

	* 新增出参：ImageNeedUpdate

* [DescribePrometheusConfig](https://cloud.tencent.com/document/api/248/85705)

	* 新增出参：ImageNeedUpdate

* [DescribePrometheusTargetsTMP](https://cloud.tencent.com/document/api/248/86037)

	* <font color="#dd0000">**修改入参**：</font>ClusterType

* [ModifyPrometheusConfig](https://cloud.tencent.com/document/api/248/86031)

	* 新增入参：UpdateImage


新增数据结构：

* [PrometheusTarget](https://cloud.tencent.com/document/api/248/30354#PrometheusTarget)

修改数据结构：

* [PrometheusJobTargets](https://cloud.tencent.com/document/api/248/30354#PrometheusJobTargets)

	* 新增成员：Targets, JobName, Total, Up


### 第 98 次发布

发布时间：2023-12-11 01:02:24

本次发布包含了以下内容：

改善已有的文档。

新增数据结构：

* [AlarmConditionFilter](https://cloud.tencent.com/document/api/248/30354#AlarmConditionFilter)
* [AlarmGroupByItem](https://cloud.tencent.com/document/api/248/30354#AlarmGroupByItem)

修改数据结构：

* [AlarmPolicy](https://cloud.tencent.com/document/api/248/30354#AlarmPolicy)

	* 新增成员：Filter, GroupBy


### 第 97 次发布

发布时间：2023-12-05 02:04:16

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateGrafanaNotificationChannel](https://cloud.tencent.com/document/api/248/79217)

	* <font color="#dd0000">**修改入参**：</font>OrgId

* [UpdateGrafanaNotificationChannel](https://cloud.tencent.com/document/api/248/79190)

	* <font color="#dd0000">**修改入参**：</font>ChannelName


修改数据结构：

* [AlarmHistory](https://cloud.tencent.com/document/api/248/30354#AlarmHistory)

	* 新增成员：ShieldFlag, AlarmShieldingType, AlarmShieldingTime, AlarmShieldingShowType, AlarmShieldingShowTime, AlarmShieldReason, InternalDimensions, MetricName

	* <font color="#dd0000">**修改成员**：</font>AlarmLevel


### 第 96 次发布

发布时间：2023-10-17 01:21:47

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [AlarmPolicy](https://cloud.tencent.com/document/api/248/30354#AlarmPolicy)

	* 新增成员：IsSupportAlarmTag


### 第 95 次发布

发布时间：2023-10-09 01:19:36

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [PrometheusZoneItem](https://cloud.tencent.com/document/api/248/30354#PrometheusZoneItem)

	* 新增成员：ZoneResourceState


### 第 94 次发布

发布时间：2023-09-15 02:09:24

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeAlarmHistories](https://cloud.tencent.com/document/api/248/48684)

	* 新增入参：AlarmLevels


### 第 93 次发布

发布时间：2023-09-13 02:04:57

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [AlarmHistory](https://cloud.tencent.com/document/api/248/30354#AlarmHistory)

	* 新增成员：AlarmLevel


### 第 92 次发布

发布时间：2023-09-06 02:06:16

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribePrometheusRegions](https://cloud.tencent.com/document/api/248/97797)

新增数据结构：

* [PrometheusRegionItem](https://cloud.tencent.com/document/api/248/30354#PrometheusRegionItem)

### 第 91 次发布

发布时间：2023-07-19 01:32:20

本次发布包含了以下内容：

改善已有的文档。

<font color="#dd0000">**删除接口**：</font>

* PutMonitorData

<font color="#dd0000">**删除数据结构**：</font>

* MetricDatum

### 第 90 次发布

发布时间：2023-06-09 01:29:13

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [BindingPolicyTag](https://cloud.tencent.com/document/api/248/67219)

	* 新增入参：EbEventFlag, EbSubject


### 第 89 次发布

发布时间：2023-05-22 01:43:10

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeAlarmNotices](https://cloud.tencent.com/document/api/248/51280)

	* 新增入参：OnCallFormIDs

* [DescribeAlarmPolicies](https://cloud.tencent.com/document/api/248/51279)

	* 新增入参：PromInsId, ReceiverOnCallFormIDs


修改数据结构：

* [UserNotice](https://cloud.tencent.com/document/api/248/30354#UserNotice)

	* 新增成员：OnCallFormIDs


### 第 88 次发布

发布时间：2023-05-12 01:36:37

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeClusterAgentCreatingProgress](https://cloud.tencent.com/document/api/248/90977)

### 第 87 次发布

发布时间：2023-05-08 01:39:58

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [Metric](https://cloud.tencent.com/document/api/248/30354#Metric)

	* 新增成员：Operators, Periods


### 第 86 次发布

发布时间：2023-04-10 01:43:28

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribePrometheusGlobalConfig](https://cloud.tencent.com/document/api/248/86039)

	* 新增出参：Probes


新增数据结构：

* [Targets](https://cloud.tencent.com/document/api/248/30354#Targets)

修改数据结构：

* [PrometheusConfigItem](https://cloud.tencent.com/document/api/248/30354#PrometheusConfigItem)

	* 新增成员：Targets

* [PrometheusRecordRuleYamlItem](https://cloud.tencent.com/document/api/248/30354#PrometheusRecordRuleYamlItem)

	* 新增成员：Status, Id, Count


### 第 85 次发布

发布时间：2023-04-04 01:32:21

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [Filter](https://cloud.tencent.com/document/api/248/30354#Filter)

	* 新增成员：Name, Values

	* <font color="#dd0000">**修改成员**：</font>Type, Key, Value

* [PrometheusInstancesOverview](https://cloud.tencent.com/document/api/248/30354#PrometheusInstancesOverview)

	* 新增成员：ResourcePackageStatus, ResourcePackageSpecName


### 第 84 次发布

发布时间：2023-03-29 03:52:31

本次发布包含了以下内容：

改善已有的文档。

<font color="#dd0000">**预下线接口**：</font>

* PutMonitorData

### 第 83 次发布

发布时间：2023-03-28 01:47:28

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribePrometheusClusterAgents](https://cloud.tencent.com/document/api/248/86040)

	* 新增出参：IsFirstBind


### 第 82 次发布

发布时间：2023-03-24 01:56:44

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [PrometheusClusterAgentBasic](https://cloud.tencent.com/document/api/248/30354#PrometheusClusterAgentBasic)

	* 新增成员：OpenDefaultRecord


### 第 81 次发布

发布时间：2023-03-23 01:53:03

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [ModifyAlarmPolicyNotice](https://cloud.tencent.com/document/api/248/51274)

	* 新增入参：HierarchicalNotices


### 第 80 次发布

发布时间：2023-03-20 01:42:06

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateGrafanaInstance](https://cloud.tencent.com/document/api/248/79219)

	* <font color="#dd0000">**修改入参**：</font>GrafanaInitPassword

* [CreatePrometheusRecordRuleYaml](https://cloud.tencent.com/document/api/248/85707)

	* 新增入参：Name


### 第 79 次发布

发布时间：2023-03-13 01:52:39

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribePrometheusConfig](https://cloud.tencent.com/document/api/248/85705)

	* 新增出参：Probes


修改数据结构：

* [PrometheusAgentOverview](https://cloud.tencent.com/document/api/248/30354#PrometheusAgentOverview)

	* 新增成员：Name


### 第 78 次发布

发布时间：2023-03-08 01:43:17

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [Label](https://cloud.tencent.com/document/api/248/30354#Label)

	* 新增成员：Name, Value

* [PrometheusAgentInfo](https://cloud.tencent.com/document/api/248/30354#PrometheusAgentInfo)

	* 新增成员：ClusterType, ClusterId, Describe


### 第 77 次发布

发布时间：2023-03-03 01:29:23

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribePrometheusConfig](https://cloud.tencent.com/document/api/248/85705)

	* 新增出参：Config, ServiceMonitors, PodMonitors, RawJobs


### 第 76 次发布

发布时间：2023-03-02 10:45:52

本次发布包含了以下内容：

改善已有的文档。

新增数据结构：

* [DescribePolicyConditionListResponseDeprecatingInfo](https://cloud.tencent.com/document/api/248/30354#DescribePolicyConditionListResponseDeprecatingInfo)

修改数据结构：

* [AlarmPolicyCondition](https://cloud.tencent.com/document/api/248/30354#AlarmPolicyCondition)

	* 新增成员：ComplexExpression

* [DescribePolicyConditionListCondition](https://cloud.tencent.com/document/api/248/30354#DescribePolicyConditionListCondition)

	* 新增成员：DeprecatingInfo


### 第 75 次发布

发布时间：2023-02-13 01:52:53

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribePrometheusZones](https://cloud.tencent.com/document/api/248/83596)

	* 新增入参：RegionName

	* <font color="#dd0000">**修改入参**：</font>RegionId


### 第 74 次发布

发布时间：2023-02-02 01:38:12

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreatePrometheusAlertPolicy](https://cloud.tencent.com/document/api/248/86045)
* [CreatePrometheusClusterAgent](https://cloud.tencent.com/document/api/248/86044)
* [CreatePrometheusConfig](https://cloud.tencent.com/document/api/248/86033)
* [CreatePrometheusGlobalNotification](https://cloud.tencent.com/document/api/248/86043)
* [DeletePrometheusAlertPolicy](https://cloud.tencent.com/document/api/248/86042)
* [DeletePrometheusClusterAgent](https://cloud.tencent.com/document/api/248/86041)
* [DeletePrometheusConfig](https://cloud.tencent.com/document/api/248/86032)
* [DescribePrometheusClusterAgents](https://cloud.tencent.com/document/api/248/86040)
* [DescribePrometheusGlobalConfig](https://cloud.tencent.com/document/api/248/86039)
* [DescribePrometheusGlobalNotification](https://cloud.tencent.com/document/api/248/86038)
* [DescribePrometheusTargetsTMP](https://cloud.tencent.com/document/api/248/86037)
* [ModifyPrometheusAgentExternalLabels](https://cloud.tencent.com/document/api/248/86036)
* [ModifyPrometheusAlertPolicy](https://cloud.tencent.com/document/api/248/86035)
* [ModifyPrometheusConfig](https://cloud.tencent.com/document/api/248/86031)
* [ModifyPrometheusGlobalNotification](https://cloud.tencent.com/document/api/248/86034)

新增数据结构：

* [PrometheusAgentInfo](https://cloud.tencent.com/document/api/248/30354#PrometheusAgentInfo)
* [PrometheusAgentOverview](https://cloud.tencent.com/document/api/248/30354#PrometheusAgentOverview)
* [PrometheusClusterAgentBasic](https://cloud.tencent.com/document/api/248/30354#PrometheusClusterAgentBasic)
* [PrometheusClusterAgentPodConfig](https://cloud.tencent.com/document/api/248/30354#PrometheusClusterAgentPodConfig)
* [PrometheusJobTargets](https://cloud.tencent.com/document/api/248/30354#PrometheusJobTargets)
* [Toleration](https://cloud.tencent.com/document/api/248/30354#Toleration)

### 第 73 次发布

发布时间：2023-01-13 01:36:35

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CheckIsPrometheusNewUser](https://cloud.tencent.com/document/api/248/85723)
* [CreatePrometheusRecordRuleYaml](https://cloud.tencent.com/document/api/248/85707)
* [CreatePrometheusTemp](https://cloud.tencent.com/document/api/248/85722)
* [DeletePrometheusRecordRuleYaml](https://cloud.tencent.com/document/api/248/85706)
* [DeletePrometheusTemp](https://cloud.tencent.com/document/api/248/85721)
* [DeletePrometheusTempSync](https://cloud.tencent.com/document/api/248/85720)
* [DescribePrometheusAgentInstances](https://cloud.tencent.com/document/api/248/85719)
* [DescribePrometheusAlertPolicy](https://cloud.tencent.com/document/api/248/85718)
* [DescribePrometheusConfig](https://cloud.tencent.com/document/api/248/85705)
* [DescribePrometheusInstanceDetail](https://cloud.tencent.com/document/api/248/85717)
* [DescribePrometheusInstanceInitStatus](https://cloud.tencent.com/document/api/248/85716)
* [DescribePrometheusInstancesOverview](https://cloud.tencent.com/document/api/248/85715)
* [DescribePrometheusRecordRuleYaml](https://cloud.tencent.com/document/api/248/85704)
* [DescribePrometheusRecordRules](https://cloud.tencent.com/document/api/248/85714)
* [DescribePrometheusTemp](https://cloud.tencent.com/document/api/248/85713)
* [DescribePrometheusTempSync](https://cloud.tencent.com/document/api/248/85712)
* [ModifyPrometheusRecordRuleYaml](https://cloud.tencent.com/document/api/248/85703)
* [ModifyPrometheusTemp](https://cloud.tencent.com/document/api/248/85711)
* [RunPrometheusInstance](https://cloud.tencent.com/document/api/248/85710)
* [SyncPrometheusTemp](https://cloud.tencent.com/document/api/248/85709)

新增数据结构：

* [Filter](https://cloud.tencent.com/document/api/248/30354#Filter)
* [Label](https://cloud.tencent.com/document/api/248/30354#Label)
* [PrometheusAlertManagerConfig](https://cloud.tencent.com/document/api/248/30354#PrometheusAlertManagerConfig)
* [PrometheusAlertPolicyItem](https://cloud.tencent.com/document/api/248/30354#PrometheusAlertPolicyItem)
* [PrometheusAlertRule](https://cloud.tencent.com/document/api/248/30354#PrometheusAlertRule)
* [PrometheusConfigItem](https://cloud.tencent.com/document/api/248/30354#PrometheusConfigItem)
* [PrometheusInstancesOverview](https://cloud.tencent.com/document/api/248/30354#PrometheusInstancesOverview)
* [PrometheusNotificationItem](https://cloud.tencent.com/document/api/248/30354#PrometheusNotificationItem)
* [PrometheusRecordRuleYamlItem](https://cloud.tencent.com/document/api/248/30354#PrometheusRecordRuleYamlItem)
* [PrometheusTemp](https://cloud.tencent.com/document/api/248/30354#PrometheusTemp)
* [PrometheusTempModify](https://cloud.tencent.com/document/api/248/30354#PrometheusTempModify)
* [PrometheusTemplateSyncTarget](https://cloud.tencent.com/document/api/248/30354#PrometheusTemplateSyncTarget)
* [TaskStepInfo](https://cloud.tencent.com/document/api/248/30354#TaskStepInfo)

### 第 72 次发布

发布时间：2023-01-02 01:32:07

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [BindingPolicyObject](https://cloud.tencent.com/document/api/248/40421)

	* 新增入参：EbSubject, EbEventFlag

* [CreateAlarmPolicy](https://cloud.tencent.com/document/api/248/51287)

	* 新增入参：EbSubject

* [DeleteAlarmNotices](https://cloud.tencent.com/document/api/248/51286)

	* 新增入参：NoticeBindPolicys

* [ModifyAlarmNotice](https://cloud.tencent.com/document/api/248/51277)

	* 新增入参：PolicyIds

* [ModifyAlarmPolicyCondition](https://cloud.tencent.com/document/api/248/51276)

	* 新增入参：NoticeIds, Enable, PolicyName, EbSubject

* [UnBindingAllPolicyObject](https://cloud.tencent.com/document/api/248/40568)

	* 新增入参：EbSubject, EbEventFlag

* [UnBindingPolicyObject](https://cloud.tencent.com/document/api/248/40567)

	* 新增入参：EbSubject, EbEventFlag


新增数据结构：

* [NoticeBindPolicys](https://cloud.tencent.com/document/api/248/30354#NoticeBindPolicys)

### 第 71 次发布

发布时间：2022-12-28 14:12:10

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [GrafanaNotificationChannel](https://cloud.tencent.com/document/api/248/30354#GrafanaNotificationChannel)

	* <font color="#dd0000">**修改成员**：</font>UpdatedAt, OrgIds, OrganizationIds


### 第 70 次发布

发布时间：2022-12-21 01:51:22

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribePrometheusInstanceUsage](https://cloud.tencent.com/document/api/248/84383)

新增数据结构：

* [PrometheusInstanceTenantUsage](https://cloud.tencent.com/document/api/248/30354#PrometheusInstanceTenantUsage)

### 第 69 次发布

发布时间：2022-12-05 07:04:52

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribePrometheusZones](https://cloud.tencent.com/document/api/248/83596)

新增数据结构：

* [PrometheusZoneItem](https://cloud.tencent.com/document/api/248/30354#PrometheusZoneItem)

### 第 68 次发布

发布时间：2022-11-18 06:38:09

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [UpdateExporterIntegration](https://cloud.tencent.com/document/api/248/76005)

	* <font color="#dd0000">**修改入参**：</font>KubeType, ClusterId


### 第 67 次发布

发布时间：2022-10-21 06:35:12

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateAlarmPolicy](https://cloud.tencent.com/document/api/248/51287)

	* 新增入参：HierarchicalNotices, MigrateFlag


新增数据结构：

* [AlarmHierarchicalNotice](https://cloud.tencent.com/document/api/248/30354#AlarmHierarchicalNotice)

### 第 66 次发布

发布时间：2022-10-19 06:34:09

本次发布包含了以下内容：

改善已有的文档。

新增数据结构：

* [AlarmHierarchicalValue](https://cloud.tencent.com/document/api/248/30354#AlarmHierarchicalValue)

修改数据结构：

* [AlarmPolicyRule](https://cloud.tencent.com/document/api/248/30354#AlarmPolicyRule)

	* 新增成员：HierarchicalValue


### 第 65 次发布

发布时间：2022-10-11 06:43:21

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [GetMonitorData](https://cloud.tencent.com/document/api/248/31014)

	* 新增出参：Msg


### 第 64 次发布

发布时间：2022-10-10 06:32:08

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [PrometheusInstancesItem](https://cloud.tencent.com/document/api/248/30354#PrometheusInstancesItem)

	* 新增成员：MigrationType


### 第 63 次发布

发布时间：2022-09-26 06:41:40

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateAlarmNotice](https://cloud.tencent.com/document/api/248/51288)

	* 新增入参：Tags

* [CreateAlarmPolicy](https://cloud.tencent.com/document/api/248/51287)

	* 新增入参：Tags, LogAlarmReqInfo

* [DescribeAlarmNotices](https://cloud.tencent.com/document/api/248/51280)

	* 新增入参：Tags

* [DescribeAlarmPolicies](https://cloud.tencent.com/document/api/248/51279)

	* 新增入参：NotBindAll, NotInstanceGroup, Tags

* [ModifyAlarmPolicyCondition](https://cloud.tencent.com/document/api/248/51276)

	* 新增入参：LogAlarmReqInfo


新增数据结构：

* [LogAlarmReq](https://cloud.tencent.com/document/api/248/30354#LogAlarmReq)
* [LogFilterInfo](https://cloud.tencent.com/document/api/248/30354#LogFilterInfo)
* [Tag](https://cloud.tencent.com/document/api/248/30354#Tag)

修改数据结构：

* [AlarmNotice](https://cloud.tencent.com/document/api/248/30354#AlarmNotice)

	* 新增成员：Tags

* [AlarmPolicy](https://cloud.tencent.com/document/api/248/30354#AlarmPolicy)

	* 新增成员：IsBindAll, Tags

* [AlarmPolicyRule](https://cloud.tencent.com/document/api/248/30354#AlarmPolicyRule)

	* 新增成员：ValueMax, ValueMin


### 第 62 次发布

发布时间：2022-09-15 06:31:40

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeConditionsTemplateList](https://cloud.tencent.com/document/api/248/70250)

	* 新增入参：PolicyCountOrder


修改数据结构：

* [Condition](https://cloud.tencent.com/document/api/248/30354#Condition)

	* 新增成员：IsAdvanced, IsOpen, ProductId


### 第 61 次发布

发布时间：2022-09-09 06:33:40

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeGrafanaChannels](https://cloud.tencent.com/document/api/248/80324)

新增数据结构：

* [GrafanaChannel](https://cloud.tencent.com/document/api/248/30354#GrafanaChannel)

修改数据结构：

* [GrafanaAccountInfo](https://cloud.tencent.com/document/api/248/30354#GrafanaAccountInfo)

	* 新增成员：InstanceId, Uin

* [GrafanaIntegrationConfig](https://cloud.tencent.com/document/api/248/30354#GrafanaIntegrationConfig)

	* 新增成员：GrafanaURL

* [RecordingRuleSet](https://cloud.tencent.com/document/api/248/30354#RecordingRuleSet)

	* 新增成员：RuleName


### 第 60 次发布

发布时间：2022-09-08 06:32:23

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateGrafanaNotificationChannel](https://cloud.tencent.com/document/api/248/79217)

	* 新增入参：OrganizationIds

* [UpdateGrafanaNotificationChannel](https://cloud.tencent.com/document/api/248/79190)

	* 新增入参：OrganizationIds


修改数据结构：

* [GrafanaNotificationChannel](https://cloud.tencent.com/document/api/248/30354#GrafanaNotificationChannel)

	* 新增成员：OrganizationIds


### 第 59 次发布

发布时间：2022-09-07 06:39:04

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateGrafanaIntegration](https://cloud.tencent.com/document/api/248/79218)

	* 新增出参：IntegrationId


### 第 58 次发布

发布时间：2022-09-06 06:42:23

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateGrafanaNotificationChannel](https://cloud.tencent.com/document/api/248/79217)

	* 新增出参：ChannelId

* [CreateSSOAccount](https://cloud.tencent.com/document/api/248/79216)

	* 新增出参：UserId

* [DescribeInstalledPlugins](https://cloud.tencent.com/document/api/248/79204)

	* 新增入参：PluginId

* [DescribeSSOAccount](https://cloud.tencent.com/document/api/248/79202)

	* 新增入参：UserId

* [InstallPlugins](https://cloud.tencent.com/document/api/248/79198)

	* 新增出参：PluginIds


修改数据结构：

* [GrafanaNotificationChannel](https://cloud.tencent.com/document/api/248/30354#GrafanaNotificationChannel)

	* 新增成员：OrgId, ExtraOrgIds, OrgIds


### 第 57 次发布

发布时间：2022-09-02 06:42:08

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [PrometheusInstancesItem](https://cloud.tencent.com/document/api/248/30354#PrometheusInstancesItem)

	* 新增成员：AlertRuleLimit, RecordingRuleLimit


### 第 56 次发布

发布时间：2022-08-31 06:39:03

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [AlarmNotice](https://cloud.tencent.com/document/api/248/30354#AlarmNotice)

	* 新增成员：AMPConsumerId


### 第 55 次发布

发布时间：2022-08-22 06:38:10

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeAllNamespaces](https://cloud.tencent.com/document/api/248/48683)

	* 新增出参：CommonNamespaces


新增数据结构：

* [CommonNamespaceNew](https://cloud.tencent.com/document/api/248/30354#CommonNamespaceNew)
* [DimensionNew](https://cloud.tencent.com/document/api/248/30354#DimensionNew)
* [Operator](https://cloud.tencent.com/document/api/248/30354#Operator)

### 第 54 次发布

发布时间：2022-08-19 06:29:18

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeBasicAlarmList](https://cloud.tencent.com/document/api/248/41199)

	* 新增出参：Warning

* [DescribePolicyGroupList](https://cloud.tencent.com/document/api/248/40945)

	* 新增出参：Warning


### 第 53 次发布

发布时间：2022-08-18 06:31:02

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CleanGrafanaInstance](https://cloud.tencent.com/document/api/248/79220)
* [CreateGrafanaInstance](https://cloud.tencent.com/document/api/248/79219)
* [CreateGrafanaIntegration](https://cloud.tencent.com/document/api/248/79218)
* [CreateGrafanaNotificationChannel](https://cloud.tencent.com/document/api/248/79217)
* [CreateSSOAccount](https://cloud.tencent.com/document/api/248/79216)
* [DeleteGrafanaInstance](https://cloud.tencent.com/document/api/248/79215)
* [DeleteGrafanaIntegration](https://cloud.tencent.com/document/api/248/79214)
* [DeleteGrafanaNotificationChannel](https://cloud.tencent.com/document/api/248/79213)
* [DeleteSSOAccount](https://cloud.tencent.com/document/api/248/79212)
* [DescribeDNSConfig](https://cloud.tencent.com/document/api/248/79211)
* [DescribeGrafanaConfig](https://cloud.tencent.com/document/api/248/79210)
* [DescribeGrafanaEnvironments](https://cloud.tencent.com/document/api/248/79209)
* [DescribeGrafanaInstances](https://cloud.tencent.com/document/api/248/79208)
* [DescribeGrafanaIntegrations](https://cloud.tencent.com/document/api/248/79207)
* [DescribeGrafanaNotificationChannels](https://cloud.tencent.com/document/api/248/79206)
* [DescribeGrafanaWhiteList](https://cloud.tencent.com/document/api/248/79205)
* [DescribeInstalledPlugins](https://cloud.tencent.com/document/api/248/79204)
* [DescribePluginOverviews](https://cloud.tencent.com/document/api/248/79203)
* [DescribeSSOAccount](https://cloud.tencent.com/document/api/248/79202)
* [EnableGrafanaInternet](https://cloud.tencent.com/document/api/248/79201)
* [EnableGrafanaSSO](https://cloud.tencent.com/document/api/248/79200)
* [EnableSSOCamCheck](https://cloud.tencent.com/document/api/248/79199)
* [InstallPlugins](https://cloud.tencent.com/document/api/248/79198)
* [ModifyGrafanaInstance](https://cloud.tencent.com/document/api/248/79197)
* [ResumeGrafanaInstance](https://cloud.tencent.com/document/api/248/79196)
* [UninstallGrafanaPlugins](https://cloud.tencent.com/document/api/248/79195)
* [UpdateDNSConfig](https://cloud.tencent.com/document/api/248/79194)
* [UpdateGrafanaConfig](https://cloud.tencent.com/document/api/248/79193)
* [UpdateGrafanaEnvironments](https://cloud.tencent.com/document/api/248/79192)
* [UpdateGrafanaIntegration](https://cloud.tencent.com/document/api/248/79191)
* [UpdateGrafanaNotificationChannel](https://cloud.tencent.com/document/api/248/79190)
* [UpdateGrafanaWhiteList](https://cloud.tencent.com/document/api/248/79189)
* [UpdateSSOAccount](https://cloud.tencent.com/document/api/248/79188)
* [UpgradeGrafanaInstance](https://cloud.tencent.com/document/api/248/79187)

修改接口：

* [DeleteExporterIntegration](https://cloud.tencent.com/document/api/248/76016)

	* <font color="#dd0000">**修改入参**：</font>KubeType, ClusterId

* [DescribeExporterIntegrations](https://cloud.tencent.com/document/api/248/76014)

	* <font color="#dd0000">**修改入参**：</font>KubeType, ClusterId


新增数据结构：

* [GrafanaAccountInfo](https://cloud.tencent.com/document/api/248/30354#GrafanaAccountInfo)
* [GrafanaAccountRole](https://cloud.tencent.com/document/api/248/30354#GrafanaAccountRole)
* [GrafanaInstanceInfo](https://cloud.tencent.com/document/api/248/30354#GrafanaInstanceInfo)
* [GrafanaIntegrationConfig](https://cloud.tencent.com/document/api/248/30354#GrafanaIntegrationConfig)
* [GrafanaNotificationChannel](https://cloud.tencent.com/document/api/248/30354#GrafanaNotificationChannel)
* [GrafanaPlugin](https://cloud.tencent.com/document/api/248/30354#GrafanaPlugin)

### 第 52 次发布

发布时间：2022-08-09 12:18:17

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeMonitorTypes](https://cloud.tencent.com/document/api/248/49979)

	* 新增出参：MonitorTypeInfos


新增数据结构：

* [MonitorTypeInfo](https://cloud.tencent.com/document/api/248/30354#MonitorTypeInfo)

### 第 51 次发布

发布时间：2022-07-15 06:12:20

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateExporterIntegration](https://cloud.tencent.com/document/api/248/76019)

	* <font color="#dd0000">**修改入参**：</font>KubeType, ClusterId

	* 新增出参：Names

* [CreatePrometheusAgent](https://cloud.tencent.com/document/api/248/76018)

	* 新增出参：AgentId

* [CreatePrometheusScrapeJob](https://cloud.tencent.com/document/api/248/76017)

	* 新增出参：JobId


### 第 50 次发布

发布时间：2022-06-28 06:13:35

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreatePrometheusMultiTenantInstancePostPayMode](https://cloud.tencent.com/document/api/248/76097)

### 第 49 次发布

发布时间：2022-06-27 06:12:15

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateRecordingRule](https://cloud.tencent.com/document/api/248/76041)
* [DeleteRecordingRules](https://cloud.tencent.com/document/api/248/76040)
* [DescribeRecordingRules](https://cloud.tencent.com/document/api/248/76039)
* [UpdateRecordingRule](https://cloud.tencent.com/document/api/248/76038)

新增数据结构：

* [RecordingRuleSet](https://cloud.tencent.com/document/api/248/30354#RecordingRuleSet)

### 第 48 次发布

发布时间：2022-06-24 06:14:48

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [BindPrometheusManagedGrafana](https://cloud.tencent.com/document/api/248/76020)
* [CreateExporterIntegration](https://cloud.tencent.com/document/api/248/76019)
* [CreatePrometheusAgent](https://cloud.tencent.com/document/api/248/76018)
* [CreatePrometheusScrapeJob](https://cloud.tencent.com/document/api/248/76017)
* [DeleteExporterIntegration](https://cloud.tencent.com/document/api/248/76016)
* [DeletePrometheusScrapeJobs](https://cloud.tencent.com/document/api/248/76015)
* [DescribeExporterIntegrations](https://cloud.tencent.com/document/api/248/76014)
* [DescribePrometheusAgents](https://cloud.tencent.com/document/api/248/76013)
* [DescribePrometheusScrapeJobs](https://cloud.tencent.com/document/api/248/76012)
* [DestroyPrometheusInstance](https://cloud.tencent.com/document/api/248/76011)
* [GetPrometheusAgentManagementCommand](https://cloud.tencent.com/document/api/248/76010)
* [ModifyPrometheusInstanceAttributes](https://cloud.tencent.com/document/api/248/76009)
* [TerminatePrometheusInstances](https://cloud.tencent.com/document/api/248/76008)
* [UnbindPrometheusManagedGrafana](https://cloud.tencent.com/document/api/248/76007)
* [UninstallGrafanaDashboard](https://cloud.tencent.com/document/api/248/76006)
* [UpdateExporterIntegration](https://cloud.tencent.com/document/api/248/76005)
* [UpdatePrometheusAgentStatus](https://cloud.tencent.com/document/api/248/76004)
* [UpdatePrometheusScrapeJob](https://cloud.tencent.com/document/api/248/76003)
* [UpgradeGrafanaDashboard](https://cloud.tencent.com/document/api/248/76002)

新增数据结构：

* [IntegrationConfiguration](https://cloud.tencent.com/document/api/248/30354#IntegrationConfiguration)
* [ManagementCommand](https://cloud.tencent.com/document/api/248/30354#ManagementCommand)
* [PrometheusAgent](https://cloud.tencent.com/document/api/248/30354#PrometheusAgent)
* [PrometheusScrapeJob](https://cloud.tencent.com/document/api/248/30354#PrometheusScrapeJob)

### 第 47 次发布

发布时间：2022-06-23 06:15:13

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [BindingPolicyTag](https://cloud.tencent.com/document/api/248/67219)

	* 新增入参：BatchTag

	* <font color="#dd0000">**修改入参**：</font>Tag


### 第 46 次发布

发布时间：2022-05-25 06:12:07

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [AlarmPolicy](https://cloud.tencent.com/document/api/248/30354#AlarmPolicy)

	* 新增成员：AdvancedMetricNumber

* [AlarmPolicyRule](https://cloud.tencent.com/document/api/248/30354#AlarmPolicyRule)

	* 新增成员：IsAdvanced, IsOpen, ProductId

* [Metric](https://cloud.tencent.com/document/api/248/30354#Metric)

	* 新增成员：IsAdvanced, IsOpen, ProductId


### 第 45 次发布

发布时间：2022-05-13 06:15:04

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeAlarmPolicies](https://cloud.tencent.com/document/api/248/51279)

	* 新增入参：OneClickPolicyType


### 第 44 次发布

发布时间：2022-05-10 06:09:42

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [AlarmPolicy](https://cloud.tencent.com/document/api/248/30354#AlarmPolicy)

	* 新增成员：IsOneClick, OneClickStatus


### 第 43 次发布

发布时间：2022-04-19 06:13:47

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [URLNotice](https://cloud.tencent.com/document/api/248/30354#URLNotice)

	* 新增成员：Weekday

* [UserNotice](https://cloud.tencent.com/document/api/248/30354#UserNotice)

	* 新增成员：Weekday


### 第 42 次发布

发布时间：2022-03-18 08:14:49

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateAlarmNotice](https://cloud.tencent.com/document/api/248/51288)

	* 新增入参：CLSNotices

* [DescribeAlarmPolicies](https://cloud.tencent.com/document/api/248/51279)

	* 新增入参：TriggerTasks

* [ModifyAlarmNotice](https://cloud.tencent.com/document/api/248/51277)

	* 新增入参：CLSNotices


新增数据结构：

* [CLSNotice](https://cloud.tencent.com/document/api/248/30354#CLSNotice)

修改数据结构：

* [AlarmNotice](https://cloud.tencent.com/document/api/248/30354#AlarmNotice)

	* 新增成员：CLSNotices


### 第 41 次发布

发布时间：2022-03-09 08:14:02

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [ModifyAlarmPolicyNotice](https://cloud.tencent.com/document/api/248/51274)

	* 新增入参：PolicyIds

	* <font color="#dd0000">**修改入参**：</font>PolicyId


### 第 40 次发布

发布时间：2022-03-03 08:09:04

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribePrometheusInstances](https://cloud.tencent.com/document/api/248/66097)

	* 新增入参：InstanceChargeType


### 第 39 次发布

发布时间：2022-02-23 08:10:23

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeConditionsTemplateList](https://cloud.tencent.com/document/api/248/70250)

新增数据结构：

* [Condition](https://cloud.tencent.com/document/api/248/30354#Condition)
* [EventCondition](https://cloud.tencent.com/document/api/248/30354#EventCondition)
* [PolicyGroup](https://cloud.tencent.com/document/api/248/30354#PolicyGroup)
* [PolicyGroupReceiverInfo](https://cloud.tencent.com/document/api/248/30354#PolicyGroupReceiverInfo)
* [TemplateGroup](https://cloud.tencent.com/document/api/248/30354#TemplateGroup)

### 第 38 次发布

发布时间：2022-02-17 08:13:29

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeAlarmPolicies](https://cloud.tencent.com/document/api/248/51279)

	* 新增入参：NeedCorrespondence


修改数据结构：

* [AlarmPolicy](https://cloud.tencent.com/document/api/248/30354#AlarmPolicy)

	* 新增成员：FilterDimensionsParam

* [UserNotice](https://cloud.tencent.com/document/api/248/30354#UserNotice)

	* 新增成员：PhoneCallType


### 第 37 次发布

发布时间：2022-01-21 08:14:26

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeBaseMetrics](https://cloud.tencent.com/document/api/248/30351)

	* 新增入参：Dimensions


### 第 36 次发布

发布时间：2022-01-12 08:12:33

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [URLNotice](https://cloud.tencent.com/document/api/248/30354#URLNotice)

	* 新增成员：StartTime, EndTime


### 第 35 次发布

发布时间：2021-12-30 08:11:53

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [BindingPolicyTag](https://cloud.tencent.com/document/api/248/67219)

新增数据结构：

* [PolicyTag](https://cloud.tencent.com/document/api/248/30354#PolicyTag)

### 第 34 次发布

发布时间：2021-12-29 08:10:29

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [PrometheusInstancesItem](https://cloud.tencent.com/document/api/248/30354#PrometheusInstancesItem)

	* 新增成员：GrafanaInstanceId


### 第 33 次发布

发布时间：2021-12-16 08:11:56

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribePrometheusInstances](https://cloud.tencent.com/document/api/248/66097)

新增数据结构：

* [PrometheusInstanceGrantInfo](https://cloud.tencent.com/document/api/248/30354#PrometheusInstanceGrantInfo)
* [PrometheusInstancesItem](https://cloud.tencent.com/document/api/248/30354#PrometheusInstancesItem)
* [PrometheusTag](https://cloud.tencent.com/document/api/248/30354#PrometheusTag)

### 第 32 次发布

发布时间：2021-12-03 08:09:12

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [BindingPolicyObject](https://cloud.tencent.com/document/api/248/40421)

	* <font color="#dd0000">**修改入参**：</font>GroupId


### 第 31 次发布

发布时间：2021-11-15 08:10:59

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [TagInstance](https://cloud.tencent.com/document/api/248/30354#TagInstance)

	* <font color="#dd0000">**修改成员**：</font>RegionId


### 第 30 次发布

发布时间：2021-09-23 08:10:38

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [MetricSet](https://cloud.tencent.com/document/api/248/30354#MetricSet)

	* 新增成员：MetricCName, MetricEName


### 第 29 次发布

发布时间：2021-09-10 08:07:03

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeAlarmNotices](https://cloud.tencent.com/document/api/248/51280)

	* 新增入参：NoticeIds


### 第 28 次发布

发布时间：2021-08-19 08:07:10

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeAlarmPolicies](https://cloud.tencent.com/document/api/248/51279)

	* 新增入参：InstanceGroupId


### 第 27 次发布

发布时间：2021-07-28 08:07:18

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [AlarmHistory](https://cloud.tencent.com/document/api/248/30354#AlarmHistory)

	* 新增成员：Dimensions


### 第 26 次发布

发布时间：2021-07-21 08:07:16

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeBindingPolicyObjectList](https://cloud.tencent.com/document/api/248/40570)

	* 新增入参：PolicyId


### 第 25 次发布

发布时间：2021-06-25 08:06:44

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateAlarmPolicy](https://cloud.tencent.com/document/api/248/51287)

	* 新增入参：Filter, GroupBy

* [DescribeAlarmEvents](https://cloud.tencent.com/document/api/248/51284)

	* 新增入参：MonitorType

* [ModifyAlarmPolicyCondition](https://cloud.tencent.com/document/api/248/51276)

	* 新增入参：Filter, GroupBy


### 第 24 次发布

发布时间：2021-05-11 08:06:47

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateAlertRule](https://cloud.tencent.com/document/api/248/55635)
* [DeleteAlertRules](https://cloud.tencent.com/document/api/248/55634)
* [DescribeAlertRules](https://cloud.tencent.com/document/api/248/55633)
* [UpdateAlertRule](https://cloud.tencent.com/document/api/248/55632)
* [UpdateAlertRuleState](https://cloud.tencent.com/document/api/248/55631)

新增数据结构：

* [PrometheusRuleKV](https://cloud.tencent.com/document/api/248/30354#PrometheusRuleKV)
* [PrometheusRuleSet](https://cloud.tencent.com/document/api/248/30354#PrometheusRuleSet)

### 第 23 次发布

发布时间：2021-04-12 08:05:59

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateAlarmPolicy](https://cloud.tencent.com/document/api/248/51287)

	* 新增入参：ConditionTemplateId

* [ModifyAlarmPolicyCondition](https://cloud.tencent.com/document/api/248/51276)

	* 新增入参：ConditionTemplateId


### 第 22 次发布

发布时间：2021-03-15 08:05:41

本次发布包含了以下内容：

改善已有的文档。

新增数据结构：

* [AlarmHistoryMetric](https://cloud.tencent.com/document/api/248/30354#AlarmHistoryMetric)

修改数据结构：

* [AlarmHistory](https://cloud.tencent.com/document/api/248/30354#AlarmHistory)

	* 新增成员：MetricsInfo


### 第 21 次发布

发布时间：2021-01-29 08:05:41

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeAlarmPolicies](https://cloud.tencent.com/document/api/248/51279)

	* 新增入参：NotBindingNoticeRule


新增数据结构：

* [TagInstance](https://cloud.tencent.com/document/api/248/30354#TagInstance)

修改数据结构：

* [AlarmPolicy](https://cloud.tencent.com/document/api/248/30354#AlarmPolicy)

	* 新增成员：TagInstances

* [DescribeProductEventListEvents](https://cloud.tencent.com/document/api/248/30354#DescribeProductEventListEvents)

	* 新增成员：ViewName


### 第 20 次发布

发布时间：2021-01-15 08:05:34

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [BindingPolicyObject](https://cloud.tencent.com/document/api/248/40421)

	* 新增入参：PolicyId

* [UnBindingAllPolicyObject](https://cloud.tencent.com/document/api/248/40568)

	* 新增入参：PolicyId

* [UnBindingPolicyObject](https://cloud.tencent.com/document/api/248/40567)

	* 新增入参：PolicyId


### 第 19 次发布

发布时间：2021-01-11 08:05:09

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeStatisticData](https://cloud.tencent.com/document/api/248/51845)

新增数据结构：

* [MetricData](https://cloud.tencent.com/document/api/248/30354#MetricData)
* [MetricDataPoint](https://cloud.tencent.com/document/api/248/30354#MetricDataPoint)
* [MidQueryCondition](https://cloud.tencent.com/document/api/248/30354#MidQueryCondition)
* [Point](https://cloud.tencent.com/document/api/248/30354#Point)

### 第 18 次发布

发布时间：2020-12-22 08:06:22

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateAlarmNotice](https://cloud.tencent.com/document/api/248/51288)
* [CreateAlarmPolicy](https://cloud.tencent.com/document/api/248/51287)
* [DeleteAlarmNotices](https://cloud.tencent.com/document/api/248/51286)
* [DeleteAlarmPolicy](https://cloud.tencent.com/document/api/248/51285)
* [DescribeAlarmEvents](https://cloud.tencent.com/document/api/248/51284)
* [DescribeAlarmMetrics](https://cloud.tencent.com/document/api/248/51283)
* [DescribeAlarmNotice](https://cloud.tencent.com/document/api/248/51282)
* [DescribeAlarmNoticeCallbacks](https://cloud.tencent.com/document/api/248/51281)
* [DescribeAlarmNotices](https://cloud.tencent.com/document/api/248/51280)
* [DescribeAlarmPolicies](https://cloud.tencent.com/document/api/248/51279)
* [DescribeAlarmPolicy](https://cloud.tencent.com/document/api/248/51278)
* [ModifyAlarmNotice](https://cloud.tencent.com/document/api/248/51277)
* [ModifyAlarmPolicyCondition](https://cloud.tencent.com/document/api/248/51276)
* [ModifyAlarmPolicyInfo](https://cloud.tencent.com/document/api/248/51275)
* [ModifyAlarmPolicyNotice](https://cloud.tencent.com/document/api/248/51274)
* [ModifyAlarmPolicyStatus](https://cloud.tencent.com/document/api/248/51273)
* [ModifyAlarmPolicyTasks](https://cloud.tencent.com/document/api/248/51272)
* [SetDefaultAlarmPolicy](https://cloud.tencent.com/document/api/248/51271)

修改接口：

* [DescribeAllNamespaces](https://cloud.tencent.com/document/api/248/48683)

	* 新增出参：QceNamespacesNew, CustomNamespacesNew


新增数据结构：

* [AlarmEvent](https://cloud.tencent.com/document/api/248/30354#AlarmEvent)
* [AlarmNotice](https://cloud.tencent.com/document/api/248/30354#AlarmNotice)
* [AlarmPolicy](https://cloud.tencent.com/document/api/248/30354#AlarmPolicy)
* [AlarmPolicyCondition](https://cloud.tencent.com/document/api/248/30354#AlarmPolicyCondition)
* [AlarmPolicyEventCondition](https://cloud.tencent.com/document/api/248/30354#AlarmPolicyEventCondition)
* [AlarmPolicyFilter](https://cloud.tencent.com/document/api/248/30354#AlarmPolicyFilter)
* [AlarmPolicyRule](https://cloud.tencent.com/document/api/248/30354#AlarmPolicyRule)
* [AlarmPolicyTriggerTask](https://cloud.tencent.com/document/api/248/30354#AlarmPolicyTriggerTask)
* [ConditionsTemp](https://cloud.tencent.com/document/api/248/30354#ConditionsTemp)
* [Metric](https://cloud.tencent.com/document/api/248/30354#Metric)
* [MetricConfig](https://cloud.tencent.com/document/api/248/30354#MetricConfig)
* [URLNotice](https://cloud.tencent.com/document/api/248/30354#URLNotice)
* [UserNotice](https://cloud.tencent.com/document/api/248/30354#UserNotice)

修改数据结构：

* [AlarmHistory](https://cloud.tencent.com/document/api/248/30354#AlarmHistory)

	* 新增成员：PolicyExists


### 第 17 次发布

发布时间：2020-11-17 08:05:56

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeMonitorTypes](https://cloud.tencent.com/document/api/248/49979)

### 第 16 次发布

发布时间：2020-11-09 08:05:37

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateServiceDiscovery](https://cloud.tencent.com/document/api/248/49784)
* [DeleteServiceDiscovery](https://cloud.tencent.com/document/api/248/49780)
* [DescribeServiceDiscovery](https://cloud.tencent.com/document/api/248/49783)
* [UpdateServiceDiscovery](https://cloud.tencent.com/document/api/248/49782)

新增数据结构：

* [ServiceDiscoveryItem](https://cloud.tencent.com/document/api/248/30354#ServiceDiscoveryItem)

### 第 15 次发布

发布时间：2020-09-24 08:04:40

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeAlarmHistories](https://cloud.tencent.com/document/api/248/48684)
* [DescribeAllNamespaces](https://cloud.tencent.com/document/api/248/48683)

新增数据结构：

* [AlarmHistory](https://cloud.tencent.com/document/api/248/30354#AlarmHistory)
* [CommonNamespace](https://cloud.tencent.com/document/api/248/30354#CommonNamespace)
* [InstanceGroups](https://cloud.tencent.com/document/api/248/30354#InstanceGroups)
* [MonitorTypeNamespace](https://cloud.tencent.com/document/api/248/30354#MonitorTypeNamespace)

### 第 14 次发布

发布时间：2020-07-24 08:13:45

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribePolicyGroupList](https://cloud.tencent.com/document/api/248/40945)

	* 新增入参：IsOpen


### 第 13 次发布

发布时间：2020-06-02 08:13:34

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [DescribePolicyGroupInfoCondition](https://cloud.tencent.com/document/api/248/30354#DescribePolicyGroupInfoCondition)

	* 新增成员：MetricName


### 第 12 次发布

发布时间：2020-05-12 08:12:35

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [ModifyPolicyGroup](https://cloud.tencent.com/document/api/248/44396)

新增数据结构：

* [ModifyPolicyGroupCondition](https://cloud.tencent.com/document/api/248/30354#ModifyPolicyGroupCondition)
* [ModifyPolicyGroupEventCondition](https://cloud.tencent.com/document/api/248/30354#ModifyPolicyGroupEventCondition)

修改数据结构：

* [ProductSimple](https://cloud.tencent.com/document/api/248/30354#ProductSimple)

	* 新增成员：ProductEnName


### 第 11 次发布

发布时间：2020-05-11 10:11:18

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeProductList](https://cloud.tencent.com/document/api/248/44374)

新增数据结构：

* [ProductSimple](https://cloud.tencent.com/document/api/248/30354#ProductSimple)

### 第 10 次发布

发布时间：2020-05-08 08:13:19

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeBasicAlarmList](https://cloud.tencent.com/document/api/248/41199)

	* 新增入参：MetricNames


修改数据结构：

* [ReceiverInfo](https://cloud.tencent.com/document/api/248/30354#ReceiverInfo)

	* <font color="#dd0000">**修改成员**：</font>ReceiverType


### 第 9 次发布

发布时间：2020-04-01 08:30:38

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [SendCustomAlarmMsg](https://cloud.tencent.com/document/api/248/43042)

### 第 8 次发布

发布时间：2020-03-24 08:10:13

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [DescribePolicyGroupInfoReceiverInfo](https://cloud.tencent.com/document/api/248/30354#DescribePolicyGroupInfoReceiverInfo)

	* 新增成员：ReceiveLanguage

* [ReceiverInfo](https://cloud.tencent.com/document/api/248/30354#ReceiverInfo)

	* 新增成员：ReceiveLanguage


### 第 7 次发布

发布时间：2020-03-16 08:14:16

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreatePolicyGroup](https://cloud.tencent.com/document/api/248/40420)

	* 新增入参：IsUnionRule

* [DescribeBindingPolicyObjectList](https://cloud.tencent.com/document/api/248/40570)

	* 新增入参：Limit, Offset, Dimensions

	* 新增出参：InstanceGroup

* [DescribePolicyGroupInfo](https://cloud.tencent.com/document/api/248/40569)

	* 新增出参：IsUnionRule

* [DescribePolicyGroupList](https://cloud.tencent.com/document/api/248/40945)

	* 新增入参：Like, InstanceGroupId, UpdateTimeOrder, ProjectIds, ViewNames, FilterUnuseReceiver, Receivers, ReceiverUserList, Dimensions, ConditionTempGroupId, ReceiverType

* [UnBindingPolicyObject](https://cloud.tencent.com/document/api/248/40567)

	* 新增入参：InstanceGroupId


新增数据结构：

* [DescribeBindingPolicyObjectListDimension](https://cloud.tencent.com/document/api/248/30354#DescribeBindingPolicyObjectListDimension)
* [DescribeBindingPolicyObjectListInstanceGroup](https://cloud.tencent.com/document/api/248/30354#DescribeBindingPolicyObjectListInstanceGroup)

修改数据结构：

* [DescribePolicyGroupInfoConditionTpl](https://cloud.tencent.com/document/api/248/30354#DescribePolicyGroupInfoConditionTpl)

	* 新增成员：UpdateTime, InsertTime, IsUnionRule

* [DescribePolicyGroupListGroup](https://cloud.tencent.com/document/api/248/30354#DescribePolicyGroupListGroup)

	* 新增成员：IsUnionRule


### 第 6 次发布

发布时间：2020-02-11 13:04:48

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeBasicAlarmList](https://cloud.tencent.com/document/api/248/41199)

新增数据结构：

* [DescribeBasicAlarmListAlarms](https://cloud.tencent.com/document/api/248/30354#DescribeBasicAlarmListAlarms)
* [InstanceGroup](https://cloud.tencent.com/document/api/248/30354#InstanceGroup)

### 第 5 次发布

发布时间：2020-01-09 14:39:43

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribePolicyConditionList](https://cloud.tencent.com/document/api/248/40946)
* [DescribePolicyGroupList](https://cloud.tencent.com/document/api/248/40945)

新增数据结构：

* [DescribePolicyConditionListCondition](https://cloud.tencent.com/document/api/248/30354#DescribePolicyConditionListCondition)
* [DescribePolicyConditionListConfigManual](https://cloud.tencent.com/document/api/248/30354#DescribePolicyConditionListConfigManual)
* [DescribePolicyConditionListConfigManualCalcType](https://cloud.tencent.com/document/api/248/30354#DescribePolicyConditionListConfigManualCalcType)
* [DescribePolicyConditionListConfigManualCalcValue](https://cloud.tencent.com/document/api/248/30354#DescribePolicyConditionListConfigManualCalcValue)
* [DescribePolicyConditionListConfigManualContinueTime](https://cloud.tencent.com/document/api/248/30354#DescribePolicyConditionListConfigManualContinueTime)
* [DescribePolicyConditionListConfigManualPeriod](https://cloud.tencent.com/document/api/248/30354#DescribePolicyConditionListConfigManualPeriod)
* [DescribePolicyConditionListConfigManualPeriodNum](https://cloud.tencent.com/document/api/248/30354#DescribePolicyConditionListConfigManualPeriodNum)
* [DescribePolicyConditionListConfigManualStatType](https://cloud.tencent.com/document/api/248/30354#DescribePolicyConditionListConfigManualStatType)
* [DescribePolicyConditionListEventMetric](https://cloud.tencent.com/document/api/248/30354#DescribePolicyConditionListEventMetric)
* [DescribePolicyConditionListMetric](https://cloud.tencent.com/document/api/248/30354#DescribePolicyConditionListMetric)
* [DescribePolicyGroupListGroup](https://cloud.tencent.com/document/api/248/30354#DescribePolicyGroupListGroup)
* [DescribePolicyGroupListGroupInstanceGroup](https://cloud.tencent.com/document/api/248/30354#DescribePolicyGroupListGroupInstanceGroup)

### 第 4 次发布

发布时间：2019-12-30 16:17:26

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DeletePolicyGroup](https://cloud.tencent.com/document/api/248/40571)
* [DescribeBindingPolicyObjectList](https://cloud.tencent.com/document/api/248/40570)
* [DescribePolicyGroupInfo](https://cloud.tencent.com/document/api/248/40569)
* [UnBindingAllPolicyObject](https://cloud.tencent.com/document/api/248/40568)
* [UnBindingPolicyObject](https://cloud.tencent.com/document/api/248/40567)

新增数据结构：

* [DescribeBindingPolicyObjectListInstance](https://cloud.tencent.com/document/api/248/30354#DescribeBindingPolicyObjectListInstance)
* [DescribePolicyGroupInfoCallback](https://cloud.tencent.com/document/api/248/30354#DescribePolicyGroupInfoCallback)
* [DescribePolicyGroupInfoCondition](https://cloud.tencent.com/document/api/248/30354#DescribePolicyGroupInfoCondition)
* [DescribePolicyGroupInfoConditionTpl](https://cloud.tencent.com/document/api/248/30354#DescribePolicyGroupInfoConditionTpl)
* [DescribePolicyGroupInfoEventCondition](https://cloud.tencent.com/document/api/248/30354#DescribePolicyGroupInfoEventCondition)
* [DescribePolicyGroupInfoReceiverInfo](https://cloud.tencent.com/document/api/248/30354#DescribePolicyGroupInfoReceiverInfo)

### 第 3 次发布

发布时间：2019-12-23 23:22:27

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [BindingPolicyObject](https://cloud.tencent.com/document/api/248/40421)
* [CreatePolicyGroup](https://cloud.tencent.com/document/api/248/40420)
* [DescribeAccidentEventList](https://cloud.tencent.com/document/api/248/40419)
* [DescribeProductEventList](https://cloud.tencent.com/document/api/248/40418)
* [ModifyAlarmReceivers](https://cloud.tencent.com/document/api/248/40417)

新增数据结构：

* [BindingPolicyObjectDimension](https://cloud.tencent.com/document/api/248/30354#BindingPolicyObjectDimension)
* [CreatePolicyGroupCondition](https://cloud.tencent.com/document/api/248/30354#CreatePolicyGroupCondition)
* [CreatePolicyGroupEventCondition](https://cloud.tencent.com/document/api/248/30354#CreatePolicyGroupEventCondition)
* [DescribeAccidentEventListAlarms](https://cloud.tencent.com/document/api/248/30354#DescribeAccidentEventListAlarms)
* [DescribeProductEventListDimensions](https://cloud.tencent.com/document/api/248/30354#DescribeProductEventListDimensions)
* [DescribeProductEventListEvents](https://cloud.tencent.com/document/api/248/30354#DescribeProductEventListEvents)
* [DescribeProductEventListEventsDimensions](https://cloud.tencent.com/document/api/248/30354#DescribeProductEventListEventsDimensions)
* [DescribeProductEventListEventsGroupInfo](https://cloud.tencent.com/document/api/248/30354#DescribeProductEventListEventsGroupInfo)
* [DescribeProductEventListOverView](https://cloud.tencent.com/document/api/248/30354#DescribeProductEventListOverView)
* [ReceiverInfo](https://cloud.tencent.com/document/api/248/30354#ReceiverInfo)

### 第 2 次发布

发布时间：2019-12-13 11:30:54

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [PutMonitorData](https://cloud.tencent.com/document/api/248/40245)

新增数据结构：

* [MetricDatum](https://cloud.tencent.com/document/api/248/30354#MetricDatum)

### 第 1 次发布

发布时间：2018-11-08 19:03:41

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeBaseMetrics](https://cloud.tencent.com/document/api/248/30351)
* [GetMonitorData](https://cloud.tencent.com/document/api/248/31014)

新增数据结构：

* [DataPoint](https://cloud.tencent.com/document/api/248/30354#DataPoint)
* [Dimension](https://cloud.tencent.com/document/api/248/30354#Dimension)
* [DimensionsDesc](https://cloud.tencent.com/document/api/248/30354#DimensionsDesc)
* [Instance](https://cloud.tencent.com/document/api/248/30354#Instance)
* [MetricObjectMeaning](https://cloud.tencent.com/document/api/248/30354#MetricObjectMeaning)
* [MetricSet](https://cloud.tencent.com/document/api/248/30354#MetricSet)
* [PeriodsSt](https://cloud.tencent.com/document/api/248/30354#PeriodsSt)




## 媒体处理(mps) 版本：2019-06-12

### 第 91 次发布

发布时间：2024-08-02 01:54:19

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [TranslateConfigureInfo](https://cloud.tencent.com/document/api/862/37615#TranslateConfigureInfo)

	* 新增成员：SubtitleFormat

* [TranslateConfigureInfoForUpdate](https://cloud.tencent.com/document/api/862/37615#TranslateConfigureInfoForUpdate)

	* 新增成员：SubtitleFormat


### 第 90 次发布

发布时间：2024-07-11 01:21:03

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [LiveStreamObjectRecognitionResult](https://cloud.tencent.com/document/api/862/37615#LiveStreamObjectRecognitionResult)

	* 新增成员：Url

* [LiveStreamTaskNotifyConfig](https://cloud.tencent.com/document/api/862/37615#LiveStreamTaskNotifyConfig)

	* 新增成员：NotifyKey


### 第 89 次发布

发布时间：2024-07-09 01:19:04

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [AiAnalysisTaskDelLogoOutput](https://cloud.tencent.com/document/api/862/37615#AiAnalysisTaskDelLogoOutput)

	* 新增成员：OriginSubtitlePath, TranslateSubtitlePath


### 第 88 次发布

发布时间：2024-07-08 01:18:48

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateQualityControlTemplate](https://cloud.tencent.com/document/api/862/108314)
* [DeleteQualityControlTemplate](https://cloud.tencent.com/document/api/862/108313)
* [DescribeQualityControlTemplates](https://cloud.tencent.com/document/api/862/108312)
* [ModifyQualityControlTemplate](https://cloud.tencent.com/document/api/862/108311)

新增数据结构：

* [ContainerDiagnoseResultItem](https://cloud.tencent.com/document/api/862/37615#ContainerDiagnoseResultItem)
* [QualityControlItemConfig](https://cloud.tencent.com/document/api/862/37615#QualityControlItemConfig)
* [QualityControlTemplate](https://cloud.tencent.com/document/api/862/37615#QualityControlTemplate)

修改数据结构：

* [ActivityPara](https://cloud.tencent.com/document/api/862/37615#ActivityPara)

	* 新增成员：QualityControlTask

* [ActivityResItem](https://cloud.tencent.com/document/api/862/37615#ActivityResItem)

	* 新增成员：QualityControlTask

* [QualityControlData](https://cloud.tencent.com/document/api/862/37615#QualityControlData)

	* 新增成员：ContainerDiagnoseResultSet


### 第 87 次发布

发布时间：2024-06-28 01:16:00

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [CreateInput](https://cloud.tencent.com/document/api/862/37615#CreateInput)

	* 新增成员：Zones

* [CreateOutputInfo](https://cloud.tencent.com/document/api/862/37615#CreateOutputInfo)

	* 新增成员：Zones

* [DescribeInput](https://cloud.tencent.com/document/api/862/37615#DescribeInput)

	* 新增成员：Zones

* [DescribeOutput](https://cloud.tencent.com/document/api/862/37615#DescribeOutput)

	* 新增成员：Zones

* [LiveActivityResItem](https://cloud.tencent.com/document/api/862/37615#LiveActivityResItem)

	* 新增成员：LiveQualityControlTask

* [ModifyInput](https://cloud.tencent.com/document/api/862/37615#ModifyInput)

	* 新增成员：Zones

* [TerrorismConfigureInfo](https://cloud.tencent.com/document/api/862/37615#TerrorismConfigureInfo)

	* <font color="#dd0000">**修改成员**：</font>OcrReviewInfo


### 第 86 次发布

发布时间：2024-06-21 01:59:51

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateAdaptiveDynamicStreamingTemplate](https://cloud.tencent.com/document/api/862/45749)

	* 新增入参：SegmentType

* [ModifyAdaptiveDynamicStreamingTemplate](https://cloud.tencent.com/document/api/862/45746)

	* 新增入参：SegmentType


修改数据结构：

* [AdaptiveDynamicStreamingTemplate](https://cloud.tencent.com/document/api/862/37615#AdaptiveDynamicStreamingTemplate)

	* 新增成员：SegmentType

* [VideoTemplateInfo](https://cloud.tencent.com/document/api/862/37615#VideoTemplateInfo)

	* 新增成员：SegmentType

* [VideoTemplateInfoForUpdate](https://cloud.tencent.com/document/api/862/37615#VideoTemplateInfoForUpdate)

	* 新增成员：SegmentType


### 第 85 次发布

发布时间：2024-06-14 02:15:02

本次发布包含了以下内容：

改善已有的文档。

新增数据结构：

* [AiAnalysisTaskSegmentInput](https://cloud.tencent.com/document/api/862/37615#AiAnalysisTaskSegmentInput)
* [AiAnalysisTaskSegmentOutput](https://cloud.tencent.com/document/api/862/37615#AiAnalysisTaskSegmentOutput)
* [AiAnalysisTaskSegmentResult](https://cloud.tencent.com/document/api/862/37615#AiAnalysisTaskSegmentResult)

修改数据结构：

* [AiAnalysisResult](https://cloud.tencent.com/document/api/862/37615#AiAnalysisResult)

	* 新增成员：SegmentTask

* [SegmentRecognitionItem](https://cloud.tencent.com/document/api/862/37615#SegmentRecognitionItem)

	* 新增成员：Title, Summary

	* <font color="#dd0000">**修改成员**：</font>SegmentUrl


### 第 84 次发布

发布时间：2024-06-06 02:11:55

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [MediaProcessTaskAnimatedGraphicResult](https://cloud.tencent.com/document/api/862/37615#MediaProcessTaskAnimatedGraphicResult)

	* <font color="#dd0000">**修改成员**：</font>BeginProcessTime, FinishTime

* [MediaProcessTaskImageSpriteResult](https://cloud.tencent.com/document/api/862/37615#MediaProcessTaskImageSpriteResult)

	* <font color="#dd0000">**修改成员**：</font>BeginProcessTime, FinishTime


### 第 83 次发布

发布时间：2024-05-24 01:56:56

本次发布包含了以下内容：

改善已有的文档。

新增数据结构：

* [LiveStreamObjectRecognitionResult](https://cloud.tencent.com/document/api/862/37615#LiveStreamObjectRecognitionResult)

修改数据结构：

* [LiveStreamAiRecognitionResultItem](https://cloud.tencent.com/document/api/862/37615#LiveStreamAiRecognitionResultItem)

	* 新增成员：ObjectRecognitionResultSet


### 第 82 次发布

发布时间：2024-04-26 01:20:19

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [ParseLiveStreamProcessNotification](https://cloud.tencent.com/document/api/862/39229)

	* 新增出参：LiveRecordResultInfo


新增数据结构：

* [LiveStreamRecordResultInfo](https://cloud.tencent.com/document/api/862/37615#LiveStreamRecordResultInfo)

### 第 81 次发布

发布时间：2024-04-22 01:21:36

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateAdaptiveDynamicStreamingTemplate](https://cloud.tencent.com/document/api/862/45749)

	* 新增入参：PureAudio

* [DescribeAdaptiveDynamicStreamingTemplates](https://cloud.tencent.com/document/api/862/45747)

	* 新增入参：PureAudio

* [ModifyAdaptiveDynamicStreamingTemplate](https://cloud.tencent.com/document/api/862/45746)

	* 新增入参：PureAudio


修改数据结构：

* [AdaptiveDynamicStreamingTaskInput](https://cloud.tencent.com/document/api/862/37615#AdaptiveDynamicStreamingTaskInput)

	* 新增成员：DefinitionType

* [AdaptiveDynamicStreamingTemplate](https://cloud.tencent.com/document/api/862/37615#AdaptiveDynamicStreamingTemplate)

	* 新增成员：PureAudio

* [AdaptiveStreamTemplate](https://cloud.tencent.com/document/api/862/37615#AdaptiveStreamTemplate)

	* <font color="#dd0000">**修改成员**：</font>Video

* [TextWatermarkTemplateInput](https://cloud.tencent.com/document/api/862/37615#TextWatermarkTemplateInput)

	* 新增成员：TextContent

* [TextWatermarkTemplateInputForUpdate](https://cloud.tencent.com/document/api/862/37615#TextWatermarkTemplateInputForUpdate)

	* 新增成员：TextContent


### 第 80 次发布

发布时间：2024-04-02 01:19:24

本次发布包含了以下内容：

改善已有的文档。

新增数据结构：

* [AiAnalysisTaskHeadTailInput](https://cloud.tencent.com/document/api/862/37615#AiAnalysisTaskHeadTailInput)
* [AiAnalysisTaskHeadTailOutput](https://cloud.tencent.com/document/api/862/37615#AiAnalysisTaskHeadTailOutput)
* [AiAnalysisTaskHeadTailResult](https://cloud.tencent.com/document/api/862/37615#AiAnalysisTaskHeadTailResult)

修改数据结构：

* [AiAnalysisResult](https://cloud.tencent.com/document/api/862/37615#AiAnalysisResult)

	* 新增成员：HeadTailTask


### 第 79 次发布

发布时间：2024-01-26 01:17:35

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateSchedule](https://cloud.tencent.com/document/api/862/88061)

	* 新增入参：ResourceId

* [ModifySchedule](https://cloud.tencent.com/document/api/862/88056)

	* 新增入参：ResourceId


修改数据结构：

* [SchedulesInfo](https://cloud.tencent.com/document/api/862/37615#SchedulesInfo)

	* 新增成员：ResourceId


### 第 78 次发布

发布时间：2024-01-09 01:20:43

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [AiRecognitionTaskAsrFullTextResult](https://cloud.tencent.com/document/api/862/37615#AiRecognitionTaskAsrFullTextResult)

	* 新增成员：Progress

* [AiRecognitionTaskTransTextResult](https://cloud.tencent.com/document/api/862/37615#AiRecognitionTaskTransTextResult)

	* 新增成员：Progress

* [ComposeAudioStream](https://cloud.tencent.com/document/api/862/37615#ComposeAudioStream)

	* 新增成员：Bitrate

* [ComposeVideoStream](https://cloud.tencent.com/document/api/862/37615#ComposeVideoStream)

	* 新增成员：Bitrate


### 第 77 次发布

发布时间：2023-12-06 20:13:59

本次发布包含了以下内容：

改善已有的文档。

新增数据结构：

* [AiAnalysisTaskDescriptionInput](https://cloud.tencent.com/document/api/862/37615#AiAnalysisTaskDescriptionInput)
* [AiAnalysisTaskDescriptionOutput](https://cloud.tencent.com/document/api/862/37615#AiAnalysisTaskDescriptionOutput)
* [AiAnalysisTaskDescriptionResult](https://cloud.tencent.com/document/api/862/37615#AiAnalysisTaskDescriptionResult)
* [AiParagraphInfo](https://cloud.tencent.com/document/api/862/37615#AiParagraphInfo)
* [MediaAiAnalysisDescriptionItem](https://cloud.tencent.com/document/api/862/37615#MediaAiAnalysisDescriptionItem)

修改数据结构：

* [AiAnalysisResult](https://cloud.tencent.com/document/api/862/37615#AiAnalysisResult)

	* 新增成员：DescriptionTask


### 第 76 次发布

发布时间：2023-10-23 09:46:19

本次发布包含了以下内容：

改善已有的文档。

新增数据结构：

* [AiRecognitionTaskObjectResult](https://cloud.tencent.com/document/api/862/37615#AiRecognitionTaskObjectResult)
* [AiRecognitionTaskObjectResultInput](https://cloud.tencent.com/document/api/862/37615#AiRecognitionTaskObjectResultInput)
* [AiRecognitionTaskObjectResultItem](https://cloud.tencent.com/document/api/862/37615#AiRecognitionTaskObjectResultItem)
* [AiRecognitionTaskObjectResultOutput](https://cloud.tencent.com/document/api/862/37615#AiRecognitionTaskObjectResultOutput)
* [AiRecognitionTaskObjectSeqmentItem](https://cloud.tencent.com/document/api/862/37615#AiRecognitionTaskObjectSeqmentItem)

修改数据结构：

* [AiRecognitionResult](https://cloud.tencent.com/document/api/862/37615#AiRecognitionResult)

	* 新增成员：ObjectTask


### 第 75 次发布

发布时间：2023-10-11 02:08:20

本次发布包含了以下内容：

改善已有的文档。

新增数据结构：

* [AiAnalysisTaskDelLogoInput](https://cloud.tencent.com/document/api/862/37615#AiAnalysisTaskDelLogoInput)
* [AiAnalysisTaskDelLogoOutput](https://cloud.tencent.com/document/api/862/37615#AiAnalysisTaskDelLogoOutput)
* [AiAnalysisTaskDelLogoResult](https://cloud.tencent.com/document/api/862/37615#AiAnalysisTaskDelLogoResult)

修改数据结构：

* [AiAnalysisResult](https://cloud.tencent.com/document/api/862/37615#AiAnalysisResult)

	* 新增成员：DeLogoTask


### 第 74 次发布

发布时间：2023-10-10 01:42:36

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [AIRecognitionTemplateItem](https://cloud.tencent.com/document/api/862/37615#AIRecognitionTemplateItem)

	* 新增成员：TranslateConfigure


### 第 73 次发布

发布时间：2023-09-28 01:18:13

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [CreateInput](https://cloud.tencent.com/document/api/862/37615#CreateInput)

	* 新增成员：SecurityGroupIds

* [CreateOutputInfo](https://cloud.tencent.com/document/api/862/37615#CreateOutputInfo)

	* 新增成员：SecurityGroupIds

* [DescribeInput](https://cloud.tencent.com/document/api/862/37615#DescribeInput)

	* 新增成员：SecurityGroupIds

* [DescribeOutput](https://cloud.tencent.com/document/api/862/37615#DescribeOutput)

	* 新增成员：SecurityGroupIds

	* <font color="#dd0000">**修改成员**：</font>MaxConcurrent

* [ModifyInput](https://cloud.tencent.com/document/api/862/37615#ModifyInput)

	* 新增成员：SecurityGroupIds

* [ModifyOutputInfo](https://cloud.tencent.com/document/api/862/37615#ModifyOutputInfo)

	* 新增成员：SecurityGroupIds


### 第 72 次发布

发布时间：2023-09-21 04:51:12

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [ParseNotification](https://cloud.tencent.com/document/api/862/39228)

	* 新增出参：Timestamp, Sign


### 第 71 次发布

发布时间：2023-09-20 01:41:08

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [TaskNotifyConfig](https://cloud.tencent.com/document/api/862/37615#TaskNotifyConfig)

	* 新增成员：NotifyKey


### 第 70 次发布

发布时间：2023-09-19 01:19:29

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeTaskDetail](https://cloud.tencent.com/document/api/862/37614)

	* 新增出参：LiveScheduleTask

* [EditMedia](https://cloud.tencent.com/document/api/862/43010)

	* 新增入参：ComposeConfig

* [ProcessLiveStream](https://cloud.tencent.com/document/api/862/39227)

	* 新增入参：ScheduleId


新增数据结构：

* [ComposeAudioItem](https://cloud.tencent.com/document/api/862/37615#ComposeAudioItem)
* [ComposeAudioOperation](https://cloud.tencent.com/document/api/862/37615#ComposeAudioOperation)
* [ComposeAudioStream](https://cloud.tencent.com/document/api/862/37615#ComposeAudioStream)
* [ComposeCanvas](https://cloud.tencent.com/document/api/862/37615#ComposeCanvas)
* [ComposeEmptyItem](https://cloud.tencent.com/document/api/862/37615#ComposeEmptyItem)
* [ComposeImageItem](https://cloud.tencent.com/document/api/862/37615#ComposeImageItem)
* [ComposeImageOperation](https://cloud.tencent.com/document/api/862/37615#ComposeImageOperation)
* [ComposeMediaConfig](https://cloud.tencent.com/document/api/862/37615#ComposeMediaConfig)
* [ComposeMediaItem](https://cloud.tencent.com/document/api/862/37615#ComposeMediaItem)
* [ComposeMediaTrack](https://cloud.tencent.com/document/api/862/37615#ComposeMediaTrack)
* [ComposeSourceMedia](https://cloud.tencent.com/document/api/862/37615#ComposeSourceMedia)
* [ComposeStyles](https://cloud.tencent.com/document/api/862/37615#ComposeStyles)
* [ComposeSubtitleItem](https://cloud.tencent.com/document/api/862/37615#ComposeSubtitleItem)
* [ComposeSubtitleStyle](https://cloud.tencent.com/document/api/862/37615#ComposeSubtitleStyle)
* [ComposeTargetInfo](https://cloud.tencent.com/document/api/862/37615#ComposeTargetInfo)
* [ComposeTrackTime](https://cloud.tencent.com/document/api/862/37615#ComposeTrackTime)
* [ComposeTransitionItem](https://cloud.tencent.com/document/api/862/37615#ComposeTransitionItem)
* [ComposeTransitionOperation](https://cloud.tencent.com/document/api/862/37615#ComposeTransitionOperation)
* [ComposeVideoItem](https://cloud.tencent.com/document/api/862/37615#ComposeVideoItem)
* [ComposeVideoStream](https://cloud.tencent.com/document/api/862/37615#ComposeVideoStream)
* [LiveActivityResItem](https://cloud.tencent.com/document/api/862/37615#LiveActivityResItem)
* [LiveActivityResult](https://cloud.tencent.com/document/api/862/37615#LiveActivityResult)
* [LiveRecordFile](https://cloud.tencent.com/document/api/862/37615#LiveRecordFile)
* [LiveRecordResult](https://cloud.tencent.com/document/api/862/37615#LiveRecordResult)
* [LiveRecordTaskInput](https://cloud.tencent.com/document/api/862/37615#LiveRecordTaskInput)
* [LiveScheduleLiveRecordTaskResult](https://cloud.tencent.com/document/api/862/37615#LiveScheduleLiveRecordTaskResult)
* [LiveScheduleTask](https://cloud.tencent.com/document/api/862/37615#LiveScheduleTask)

修改数据结构：

* [ActivityResItem](https://cloud.tencent.com/document/api/862/37615#ActivityResItem)

	* <font color="#dd0000">**修改成员**：</font>SnapshotByTimeOffsetTask

* [AiRecognitionTaskAsrFullTextResultOutput](https://cloud.tencent.com/document/api/862/37615#AiRecognitionTaskAsrFullTextResultOutput)

* [AiRecognitionTaskTransTextResultOutput](https://cloud.tencent.com/document/api/862/37615#AiRecognitionTaskTransTextResultOutput)

	* <font color="#dd0000">**删除成员**：</font>OutputStorage

* [AudioTemplateInfo](https://cloud.tencent.com/document/api/862/37615#AudioTemplateInfo)

	* <font color="#dd0000">**修改成员**：</font>Bitrate

* [AudioTemplateInfoForUpdate](https://cloud.tencent.com/document/api/862/37615#AudioTemplateInfoForUpdate)

	* <font color="#dd0000">**修改成员**：</font>Bitrate

* [EditMediaFileInfo](https://cloud.tencent.com/document/api/862/37615#EditMediaFileInfo)

	* 新增成员：Id

* [MediaProcessTaskSampleSnapshotResult](https://cloud.tencent.com/document/api/862/37615#MediaProcessTaskSampleSnapshotResult)

	* <font color="#dd0000">**修改成员**：</font>BeginProcessTime, FinishTime

* [MediaProcessTaskSnapshotByTimeOffsetResult](https://cloud.tencent.com/document/api/862/37615#MediaProcessTaskSnapshotByTimeOffsetResult)

	* <font color="#dd0000">**修改成员**：</font>BeginProcessTime, FinishTime

* [ScheduleRecognitionTaskResult](https://cloud.tencent.com/document/api/862/37615#ScheduleRecognitionTaskResult)

	* <font color="#dd0000">**修改成员**：</font>BeginProcessTime, FinishTime

* [ScheduleReviewTaskResult](https://cloud.tencent.com/document/api/862/37615#ScheduleReviewTaskResult)

	* <font color="#dd0000">**修改成员**：</font>BeginProcessTime, FinishTime

* [SchedulesInfo](https://cloud.tencent.com/document/api/862/37615#SchedulesInfo)

	* 新增成员：Type

* [TEHDConfig](https://cloud.tencent.com/document/api/862/37615#TEHDConfig)

	* <font color="#dd0000">**修改成员**：</font>MaxVideoBitrate

* [TEHDConfigForUpdate](https://cloud.tencent.com/document/api/862/37615#TEHDConfigForUpdate)

	* <font color="#dd0000">**修改成员**：</font>MaxVideoBitrate

* [VideoTemplateInfo](https://cloud.tencent.com/document/api/862/37615#VideoTemplateInfo)

	* <font color="#dd0000">**修改成员**：</font>Fps, Bitrate

* [VideoTemplateInfoForUpdate](https://cloud.tencent.com/document/api/862/37615#VideoTemplateInfoForUpdate)

	* <font color="#dd0000">**修改成员**：</font>Fps, Bitrate


### 第 69 次发布

发布时间：2023-09-04 02:12:09

本次发布包含了以下内容：

改善已有的文档。

新增数据结构：

* [AudioBeautifyConfig](https://cloud.tencent.com/document/api/862/37615#AudioBeautifyConfig)
* [AudioDenoiseConfig](https://cloud.tencent.com/document/api/862/37615#AudioDenoiseConfig)
* [AudioEnhanceConfig](https://cloud.tencent.com/document/api/862/37615#AudioEnhanceConfig)
* [AudioSeparateConfig](https://cloud.tencent.com/document/api/862/37615#AudioSeparateConfig)
* [VolumeBalanceConfig](https://cloud.tencent.com/document/api/862/37615#VolumeBalanceConfig)

修改数据结构：

* [EnhanceConfig](https://cloud.tencent.com/document/api/862/37615#EnhanceConfig)

	* 新增成员：AudioEnhance


### 第 68 次发布

发布时间：2023-09-01 01:18:55

本次发布包含了以下内容：

改善已有的文档。

新增数据结构：

* [DrmInfo](https://cloud.tencent.com/document/api/862/37615#DrmInfo)
* [SimpleAesDrm](https://cloud.tencent.com/document/api/862/37615#SimpleAesDrm)

修改数据结构：

* [AdaptiveDynamicStreamingTaskInput](https://cloud.tencent.com/document/api/862/37615#AdaptiveDynamicStreamingTaskInput)

	* 新增成员：DrmInfo


### 第 67 次发布

发布时间：2023-08-22 01:16:40

本次发布包含了以下内容：

改善已有的文档。

新增数据结构：

* [LiveStreamTagRecognitionResult](https://cloud.tencent.com/document/api/862/37615#LiveStreamTagRecognitionResult)

修改数据结构：

* [LiveStreamAiRecognitionResultItem](https://cloud.tencent.com/document/api/862/37615#LiveStreamAiRecognitionResultItem)

	* 新增成员：TagRecognitionResultSet


### 第 66 次发布

发布时间：2023-08-18 01:14:58

本次发布包含了以下内容：

改善已有的文档。

新增数据结构：

* [AddOnSubtitle](https://cloud.tencent.com/document/api/862/37615#AddOnSubtitle)

修改数据结构：

* [AdaptiveDynamicStreamingTaskInput](https://cloud.tencent.com/document/api/862/37615#AdaptiveDynamicStreamingTaskInput)

	* 新增成员：AddOnSubtitles

* [MediaAudioStreamItem](https://cloud.tencent.com/document/api/862/37615#MediaAudioStreamItem)

	* <font color="#dd0000">**修改成员**：</font>Codecs, Loudness

* [MediaVideoStreamItem](https://cloud.tencent.com/document/api/862/37615#MediaVideoStreamItem)

	* <font color="#dd0000">**修改成员**：</font>Codecs

* [OverrideTranscodeParameter](https://cloud.tencent.com/document/api/862/37615#OverrideTranscodeParameter)

	* 新增成员：AddOnSubtitles


### 第 65 次发布

发布时间：2023-08-01 01:33:24

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [OverrideTranscodeParameter](https://cloud.tencent.com/document/api/862/37615#OverrideTranscodeParameter)

	* 新增成员：StdExtInfo


### 第 64 次发布

发布时间：2023-06-12 01:29:43

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [BatchDeleteStreamLinkFlow](https://cloud.tencent.com/document/api/862/93426)
* [BatchStartStreamLinkFlow](https://cloud.tencent.com/document/api/862/93425)
* [BatchStopStreamLinkFlow](https://cloud.tencent.com/document/api/862/93424)
* [CreateStreamLinkEvent](https://cloud.tencent.com/document/api/862/93422)
* [DeleteStreamLinkEvent](https://cloud.tencent.com/document/api/862/93421)
* [DescribeStreamLinkEvent](https://cloud.tencent.com/document/api/862/93420)
* [DescribeStreamLinkEventAttachedFlows](https://cloud.tencent.com/document/api/862/93423)
* [DescribeStreamLinkEvents](https://cloud.tencent.com/document/api/862/93419)
* [ModifyStreamLinkEvent](https://cloud.tencent.com/document/api/862/93418)

新增数据结构：

* [DescribeEvent](https://cloud.tencent.com/document/api/862/37615#DescribeEvent)
* [DescribeFlowId](https://cloud.tencent.com/document/api/862/37615#DescribeFlowId)

### 第 63 次发布

发布时间：2023-06-09 01:30:06

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateAIRecognitionTemplate](https://cloud.tencent.com/document/api/862/39436)

	* 新增入参：TranslateConfigure

* [ModifyAIRecognitionTemplate](https://cloud.tencent.com/document/api/862/39430)

	* 新增入参：TranslateConfigure


新增数据结构：

* [TranslateConfigureInfo](https://cloud.tencent.com/document/api/862/37615#TranslateConfigureInfo)
* [TranslateConfigureInfoForUpdate](https://cloud.tencent.com/document/api/862/37615#TranslateConfigureInfoForUpdate)

修改数据结构：

* [AsrFullTextConfigureInfo](https://cloud.tencent.com/document/api/862/37615#AsrFullTextConfigureInfo)

	* 新增成员：SourceLanguage

* [AsrFullTextConfigureInfoForUpdate](https://cloud.tencent.com/document/api/862/37615#AsrFullTextConfigureInfoForUpdate)

	* 新增成员：SourceLanguage


### 第 62 次发布

发布时间：2023-06-07 01:36:46

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateStreamLinkInput](https://cloud.tencent.com/document/api/862/93215)

### 第 61 次发布

发布时间：2023-06-06 12:16:27

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [ProcessLiveStream](https://cloud.tencent.com/document/api/862/39227)

	* 新增入参：AiQualityControlTask


### 第 60 次发布

发布时间：2023-05-30 01:26:54

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [ParseLiveStreamProcessNotification](https://cloud.tencent.com/document/api/862/39229)

	* 新增出参：AiAnalysisResultInfo, AiQualityControlResultInfo


新增数据结构：

* [DiagnoseResult](https://cloud.tencent.com/document/api/862/37615#DiagnoseResult)
* [LiveStreamAiAnalysisResultInfo](https://cloud.tencent.com/document/api/862/37615#LiveStreamAiAnalysisResultInfo)
* [LiveStreamAiAnalysisResultItem](https://cloud.tencent.com/document/api/862/37615#LiveStreamAiAnalysisResultItem)
* [LiveStreamAiQualityControlResultInfo](https://cloud.tencent.com/document/api/862/37615#LiveStreamAiQualityControlResultInfo)
* [SegmentRecognitionItem](https://cloud.tencent.com/document/api/862/37615#SegmentRecognitionItem)

修改数据结构：

* [LiveStreamAsrFullTextRecognitionResult](https://cloud.tencent.com/document/api/862/37615#LiveStreamAsrFullTextRecognitionResult)

	* 新增成员：StartTime, EndTime, SteadyState

* [LiveStreamTransTextRecognitionResult](https://cloud.tencent.com/document/api/862/37615#LiveStreamTransTextRecognitionResult)

	* 新增成员：StartTime, EndTime, SteadyState


### 第 59 次发布

发布时间：2023-05-17 01:46:57

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [EditMediaTaskOutput](https://cloud.tencent.com/document/api/862/37615#EditMediaTaskOutput)

	* 新增成员：MetaData

* [MediaAudioStreamItem](https://cloud.tencent.com/document/api/862/37615#MediaAudioStreamItem)

	* 新增成员：Codecs, Loudness

* [MediaProcessTaskAdaptiveDynamicStreamingResult](https://cloud.tencent.com/document/api/862/37615#MediaProcessTaskAdaptiveDynamicStreamingResult)

	* 新增成员：BeginProcessTime, FinishTime

* [MediaProcessTaskAnimatedGraphicResult](https://cloud.tencent.com/document/api/862/37615#MediaProcessTaskAnimatedGraphicResult)

	* 新增成员：BeginProcessTime, FinishTime

* [MediaProcessTaskImageSpriteResult](https://cloud.tencent.com/document/api/862/37615#MediaProcessTaskImageSpriteResult)

	* 新增成员：BeginProcessTime, FinishTime

* [MediaProcessTaskSampleSnapshotResult](https://cloud.tencent.com/document/api/862/37615#MediaProcessTaskSampleSnapshotResult)

	* 新增成员：BeginProcessTime, FinishTime

* [MediaProcessTaskSnapshotByTimeOffsetResult](https://cloud.tencent.com/document/api/862/37615#MediaProcessTaskSnapshotByTimeOffsetResult)

	* 新增成员：BeginProcessTime, FinishTime

* [MediaVideoStreamItem](https://cloud.tencent.com/document/api/862/37615#MediaVideoStreamItem)

	* 新增成员：Codecs

* [ScheduleAnalysisTaskResult](https://cloud.tencent.com/document/api/862/37615#ScheduleAnalysisTaskResult)

	* 新增成员：BeginProcessTime, FinishTime

* [ScheduleRecognitionTaskResult](https://cloud.tencent.com/document/api/862/37615#ScheduleRecognitionTaskResult)

	* 新增成员：BeginProcessTime, FinishTime

* [ScheduleReviewTaskResult](https://cloud.tencent.com/document/api/862/37615#ScheduleReviewTaskResult)

	* 新增成员：BeginProcessTime, FinishTime


### 第 58 次发布

发布时间：2023-04-28 01:31:27

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [ProcessLiveStream](https://cloud.tencent.com/document/api/862/39227)

	* 新增入参：AiAnalysisTask


### 第 57 次发布

发布时间：2023-04-25 01:38:38

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [SchedulesInfo](https://cloud.tencent.com/document/api/862/37615#SchedulesInfo)

	* <font color="#dd0000">**修改成员**：</font>Status


### 第 56 次发布

发布时间：2023-04-07 02:02:58

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeSchedules](https://cloud.tencent.com/document/api/862/88059)

	* 新增入参：TriggerType

* [ProcessMedia](https://cloud.tencent.com/document/api/862/37578)

	* 新增入参：AiQualityControlTask


新增数据结构：

* [AiAnalysisTaskHighlightInput](https://cloud.tencent.com/document/api/862/37615#AiAnalysisTaskHighlightInput)
* [AiAnalysisTaskHighlightOutput](https://cloud.tencent.com/document/api/862/37615#AiAnalysisTaskHighlightOutput)
* [AiAnalysisTaskHighlightResult](https://cloud.tencent.com/document/api/862/37615#AiAnalysisTaskHighlightResult)
* [AiQualityControlTaskInput](https://cloud.tencent.com/document/api/862/37615#AiQualityControlTaskInput)
* [HighlightSegmentItem](https://cloud.tencent.com/document/api/862/37615#HighlightSegmentItem)
* [MediaAiAnalysisHighlightItem](https://cloud.tencent.com/document/api/862/37615#MediaAiAnalysisHighlightItem)
* [QualityControlData](https://cloud.tencent.com/document/api/862/37615#QualityControlData)
* [QualityControlItem](https://cloud.tencent.com/document/api/862/37615#QualityControlItem)
* [QualityControlResult](https://cloud.tencent.com/document/api/862/37615#QualityControlResult)
* [ScheduleQualityControlTaskResult](https://cloud.tencent.com/document/api/862/37615#ScheduleQualityControlTaskResult)

修改数据结构：

* [AiAnalysisResult](https://cloud.tencent.com/document/api/862/37615#AiAnalysisResult)

	* 新增成员：HighlightTask

* [ScheduleTask](https://cloud.tencent.com/document/api/862/37615#ScheduleTask)

	* 新增成员：ErrCode, Message

* [WorkflowTask](https://cloud.tencent.com/document/api/862/37615#WorkflowTask)

	* 新增成员：AiQualityControlTaskResult


### 第 55 次发布

发布时间：2023-03-23 01:54:54

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [CreateOutputInfo](https://cloud.tencent.com/document/api/862/37615#CreateOutputInfo)

	* 新增成员：MaxConcurrent

* [DescribeOutput](https://cloud.tencent.com/document/api/862/37615#DescribeOutput)

	* 新增成员：MaxConcurrent

* [ModifyOutputInfo](https://cloud.tencent.com/document/api/862/37615#ModifyOutputInfo)

	* 新增成员：MaxConcurrent


### 第 54 次发布

发布时间：2023-03-20 01:43:46

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [OverrideTranscodeParameter](https://cloud.tencent.com/document/api/862/37615#OverrideTranscodeParameter)

	* 新增成员：AddonAudioStream


### 第 53 次发布

发布时间：2023-03-09 14:45:43

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateSchedule](https://cloud.tencent.com/document/api/862/88061)
* [DeleteSchedule](https://cloud.tencent.com/document/api/862/88060)
* [DescribeSchedules](https://cloud.tencent.com/document/api/862/88059)
* [DisableSchedule](https://cloud.tencent.com/document/api/862/88058)
* [EnableSchedule](https://cloud.tencent.com/document/api/862/88057)
* [ModifySchedule](https://cloud.tencent.com/document/api/862/88056)

新增数据结构：

* [Activity](https://cloud.tencent.com/document/api/862/37615#Activity)
* [ActivityPara](https://cloud.tencent.com/document/api/862/37615#ActivityPara)
* [SchedulesInfo](https://cloud.tencent.com/document/api/862/37615#SchedulesInfo)

### 第 52 次发布

发布时间：2023-03-09 01:39:34

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [WithdrawsWatermark](https://cloud.tencent.com/document/api/862/87934)

新增数据结构：

* [AwsS3FileUploadTrigger](https://cloud.tencent.com/document/api/862/37615#AwsS3FileUploadTrigger)
* [AwsSQS](https://cloud.tencent.com/document/api/862/37615#AwsSQS)
* [S3InputInfo](https://cloud.tencent.com/document/api/862/37615#S3InputInfo)
* [S3OutputStorage](https://cloud.tencent.com/document/api/862/37615#S3OutputStorage)

修改数据结构：

* [MediaInputInfo](https://cloud.tencent.com/document/api/862/37615#MediaInputInfo)

	* 新增成员：S3InputInfo

* [TaskNotifyConfig](https://cloud.tencent.com/document/api/862/37615#TaskNotifyConfig)

	* 新增成员：AwsSQS

* [TaskOutputStorage](https://cloud.tencent.com/document/api/862/37615#TaskOutputStorage)

	* 新增成员：S3OutputStorage

* [WorkflowTrigger](https://cloud.tencent.com/document/api/862/37615#WorkflowTrigger)

	* 新增成员：AwsS3FileUploadTrigger


### 第 51 次发布

发布时间：2023-02-02 01:40:19

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateStreamLinkFlow](https://cloud.tencent.com/document/api/862/82445)

	* 新增入参：EventId

	* <font color="#dd0000">**修改入参**：</font>InputGroup


修改数据结构：

* [DescribeFlow](https://cloud.tencent.com/document/api/862/37615#DescribeFlow)

	* 新增成员：EventId, Region


### 第 50 次发布

发布时间：2023-01-13 01:39:05

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [AiAnalysisTaskInput](https://cloud.tencent.com/document/api/862/37615#AiAnalysisTaskInput)

	* 新增成员：ExtendedParameter


### 第 49 次发布

发布时间：2022-12-16 01:33:15

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [ProcessMedia](https://cloud.tencent.com/document/api/862/37578)

	* 新增入参：TaskType


修改数据结构：

* [TaskNotifyConfig](https://cloud.tencent.com/document/api/862/37615#TaskNotifyConfig)

	* <font color="#dd0000">**修改成员**：</font>CmqModel, CmqRegion


### 第 48 次发布

发布时间：2022-11-23 06:41:18

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [LiveStreamTaskNotifyConfig](https://cloud.tencent.com/document/api/862/37615#LiveStreamTaskNotifyConfig)

	* <font color="#dd0000">**修改成员**：</font>CmqModel, CmqRegion


### 第 47 次发布

发布时间：2022-11-22 06:43:53

本次发布包含了以下内容：

改善已有的文档。

新增数据结构：

* [ResilientStreamConf](https://cloud.tencent.com/document/api/862/37615#ResilientStreamConf)

修改数据结构：

* [CreateInput](https://cloud.tencent.com/document/api/862/37615#CreateInput)

	* 新增成员：ResilientStream

* [DescribeInput](https://cloud.tencent.com/document/api/862/37615#DescribeInput)

	* 新增成员：ResilientStream

* [ModifyInput](https://cloud.tencent.com/document/api/862/37615#ModifyInput)

	* 新增成员：ResilientStream


### 第 46 次发布

发布时间：2022-11-18 06:39:04

本次发布包含了以下内容：

改善已有的文档。

新增数据结构：

* [CreateInputHLSPullSettings](https://cloud.tencent.com/document/api/862/37615#CreateInputHLSPullSettings)
* [DescribeHLSPullSourceAddress](https://cloud.tencent.com/document/api/862/37615#DescribeHLSPullSourceAddress)
* [DescribeInputHLSPullSettings](https://cloud.tencent.com/document/api/862/37615#DescribeInputHLSPullSettings)
* [DescribeOutputHLSPullServerUrl](https://cloud.tencent.com/document/api/862/37615#DescribeOutputHLSPullServerUrl)
* [DescribeOutputHLSPullSettings](https://cloud.tencent.com/document/api/862/37615#DescribeOutputHLSPullSettings)
* [HLSPullSourceAddress](https://cloud.tencent.com/document/api/862/37615#HLSPullSourceAddress)

修改数据结构：

* [CreateInput](https://cloud.tencent.com/document/api/862/37615#CreateInput)

	* 新增成员：HLSPullSettings

* [DescribeInput](https://cloud.tencent.com/document/api/862/37615#DescribeInput)

	* 新增成员：HLSPullSettings

* [DescribeOutput](https://cloud.tencent.com/document/api/862/37615#DescribeOutput)

	* 新增成员：HLSPullSettings

* [ModifyInput](https://cloud.tencent.com/document/api/862/37615#ModifyInput)

	* 新增成员：HLSPullSettings


### 第 45 次发布

发布时间：2022-11-09 06:42:12

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [AudioTemplateInfoForUpdate](https://cloud.tencent.com/document/api/862/37615#AudioTemplateInfoForUpdate)

	* 新增成员：StreamSelects

* [SubtitleTemplate](https://cloud.tencent.com/document/api/862/37615#SubtitleTemplate)

	* 新增成员：Path, StreamIndex, FontType, FontSize, FontColor, FontAlpha


### 第 44 次发布

发布时间：2022-11-07 06:28:34

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateStreamLinkFlow](https://cloud.tencent.com/document/api/862/82445)
* [CreateStreamLinkOutputInfo](https://cloud.tencent.com/document/api/862/82444)
* [DeleteStreamLinkFlow](https://cloud.tencent.com/document/api/862/82443)
* [DeleteStreamLinkOutput](https://cloud.tencent.com/document/api/862/82442)
* [DescribeStreamLinkActivateState](https://cloud.tencent.com/document/api/862/82441)
* [DescribeStreamLinkFlow](https://cloud.tencent.com/document/api/862/82440)
* [DescribeStreamLinkFlowLogs](https://cloud.tencent.com/document/api/862/82439)
* [DescribeStreamLinkFlowMediaStatistics](https://cloud.tencent.com/document/api/862/82438)
* [DescribeStreamLinkFlowRealtimeStatus](https://cloud.tencent.com/document/api/862/82437)
* [DescribeStreamLinkFlowSRTStatistics](https://cloud.tencent.com/document/api/862/82436)
* [DescribeStreamLinkFlowStatistics](https://cloud.tencent.com/document/api/862/82435)
* [DescribeStreamLinkFlows](https://cloud.tencent.com/document/api/862/82434)
* [DescribeStreamLinkRegions](https://cloud.tencent.com/document/api/862/82433)
* [ModifyStreamLinkFlow](https://cloud.tencent.com/document/api/862/82432)
* [ModifyStreamLinkInput](https://cloud.tencent.com/document/api/862/82431)
* [ModifyStreamLinkOutputInfo](https://cloud.tencent.com/document/api/862/82430)
* [StartStreamLinkFlow](https://cloud.tencent.com/document/api/862/82429)
* [StopStreamLinkFlow](https://cloud.tencent.com/document/api/862/82428)

新增数据结构：

* [CreateInput](https://cloud.tencent.com/document/api/862/37615#CreateInput)
* [CreateInputRTMPPullSettings](https://cloud.tencent.com/document/api/862/37615#CreateInputRTMPPullSettings)
* [CreateInputRTPSettings](https://cloud.tencent.com/document/api/862/37615#CreateInputRTPSettings)
* [CreateInputRTSPPullSettings](https://cloud.tencent.com/document/api/862/37615#CreateInputRTSPPullSettings)
* [CreateInputSRTSettings](https://cloud.tencent.com/document/api/862/37615#CreateInputSRTSettings)
* [CreateOutputInfo](https://cloud.tencent.com/document/api/862/37615#CreateOutputInfo)
* [CreateOutputInfoRTPSettings](https://cloud.tencent.com/document/api/862/37615#CreateOutputInfoRTPSettings)
* [CreateOutputRTMPSettings](https://cloud.tencent.com/document/api/862/37615#CreateOutputRTMPSettings)
* [CreateOutputRTPSettingsDestinations](https://cloud.tencent.com/document/api/862/37615#CreateOutputRTPSettingsDestinations)
* [CreateOutputRtmpSettingsDestinations](https://cloud.tencent.com/document/api/862/37615#CreateOutputRtmpSettingsDestinations)
* [CreateOutputSRTSettings](https://cloud.tencent.com/document/api/862/37615#CreateOutputSRTSettings)
* [CreateOutputSRTSettingsDestinations](https://cloud.tencent.com/document/api/862/37615#CreateOutputSRTSettingsDestinations)
* [DescribeFlow](https://cloud.tencent.com/document/api/862/37615#DescribeFlow)
* [DescribeInput](https://cloud.tencent.com/document/api/862/37615#DescribeInput)
* [DescribeInputRTMPPullSettings](https://cloud.tencent.com/document/api/862/37615#DescribeInputRTMPPullSettings)
* [DescribeInputRTMPSettings](https://cloud.tencent.com/document/api/862/37615#DescribeInputRTMPSettings)
* [DescribeInputRTPSettings](https://cloud.tencent.com/document/api/862/37615#DescribeInputRTPSettings)
* [DescribeInputRTSPPullSettings](https://cloud.tencent.com/document/api/862/37615#DescribeInputRTSPPullSettings)
* [DescribeInputSRTSettings](https://cloud.tencent.com/document/api/862/37615#DescribeInputSRTSettings)
* [DescribeOutput](https://cloud.tencent.com/document/api/862/37615#DescribeOutput)
* [DescribeOutputRTMPPullServerUrl](https://cloud.tencent.com/document/api/862/37615#DescribeOutputRTMPPullServerUrl)
* [DescribeOutputRTMPPullSettings](https://cloud.tencent.com/document/api/862/37615#DescribeOutputRTMPPullSettings)
* [DescribeOutputRTMPSettings](https://cloud.tencent.com/document/api/862/37615#DescribeOutputRTMPSettings)
* [DescribeOutputRTPSettings](https://cloud.tencent.com/document/api/862/37615#DescribeOutputRTPSettings)
* [DescribeOutputRTSPPullServerUrl](https://cloud.tencent.com/document/api/862/37615#DescribeOutputRTSPPullServerUrl)
* [DescribeOutputRTSPPullSettings](https://cloud.tencent.com/document/api/862/37615#DescribeOutputRTSPPullSettings)
* [DescribeOutputSRTSettings](https://cloud.tencent.com/document/api/862/37615#DescribeOutputSRTSettings)
* [DescribeRTMPPullSourceAddress](https://cloud.tencent.com/document/api/862/37615#DescribeRTMPPullSourceAddress)
* [DescribeRTSPPullSourceAddress](https://cloud.tencent.com/document/api/862/37615#DescribeRTSPPullSourceAddress)
* [FlowAudio](https://cloud.tencent.com/document/api/862/37615#FlowAudio)
* [FlowLogInfo](https://cloud.tencent.com/document/api/862/37615#FlowLogInfo)
* [FlowMediaAudio](https://cloud.tencent.com/document/api/862/37615#FlowMediaAudio)
* [FlowMediaInfo](https://cloud.tencent.com/document/api/862/37615#FlowMediaInfo)
* [FlowMediaVideo](https://cloud.tencent.com/document/api/862/37615#FlowMediaVideo)
* [FlowRealtimeStatusCommon](https://cloud.tencent.com/document/api/862/37615#FlowRealtimeStatusCommon)
* [FlowRealtimeStatusItem](https://cloud.tencent.com/document/api/862/37615#FlowRealtimeStatusItem)
* [FlowRealtimeStatusRTMP](https://cloud.tencent.com/document/api/862/37615#FlowRealtimeStatusRTMP)
* [FlowRealtimeStatusRTP](https://cloud.tencent.com/document/api/862/37615#FlowRealtimeStatusRTP)
* [FlowRealtimeStatusSRT](https://cloud.tencent.com/document/api/862/37615#FlowRealtimeStatusSRT)
* [FlowSRTInfo](https://cloud.tencent.com/document/api/862/37615#FlowSRTInfo)
* [FlowStatistics](https://cloud.tencent.com/document/api/862/37615#FlowStatistics)
* [FlowStatisticsArray](https://cloud.tencent.com/document/api/862/37615#FlowStatisticsArray)
* [FlowVideo](https://cloud.tencent.com/document/api/862/37615#FlowVideo)
* [InputAddress](https://cloud.tencent.com/document/api/862/37615#InputAddress)
* [ModifyInput](https://cloud.tencent.com/document/api/862/37615#ModifyInput)
* [ModifyOutputInfo](https://cloud.tencent.com/document/api/862/37615#ModifyOutputInfo)
* [OutputAddress](https://cloud.tencent.com/document/api/862/37615#OutputAddress)
* [OutputSRTSourceAddressResp](https://cloud.tencent.com/document/api/862/37615#OutputSRTSourceAddressResp)
* [RTMPAddressDestination](https://cloud.tencent.com/document/api/862/37615#RTMPAddressDestination)
* [RTMPPullSourceAddress](https://cloud.tencent.com/document/api/862/37615#RTMPPullSourceAddress)
* [RTPAddressDestination](https://cloud.tencent.com/document/api/862/37615#RTPAddressDestination)
* [RTSPPullSourceAddress](https://cloud.tencent.com/document/api/862/37615#RTSPPullSourceAddress)
* [RegionInfo](https://cloud.tencent.com/document/api/862/37615#RegionInfo)
* [SRTAddressDestination](https://cloud.tencent.com/document/api/862/37615#SRTAddressDestination)
* [SRTSourceAddressReq](https://cloud.tencent.com/document/api/862/37615#SRTSourceAddressReq)
* [SRTSourceAddressResp](https://cloud.tencent.com/document/api/862/37615#SRTSourceAddressResp)
* [StreamLinkRegionInfo](https://cloud.tencent.com/document/api/862/37615#StreamLinkRegionInfo)

### 第 43 次发布

发布时间：2022-11-03 06:32:33

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateImageSpriteTemplate](https://cloud.tencent.com/document/api/862/37608)

	* 新增入参：Format

* [ModifyImageSpriteTemplate](https://cloud.tencent.com/document/api/862/37590)

	* 新增入参：Format


新增数据结构：

* [AiRecognitionTaskTransTextResult](https://cloud.tencent.com/document/api/862/37615#AiRecognitionTaskTransTextResult)
* [AiRecognitionTaskTransTextResultInput](https://cloud.tencent.com/document/api/862/37615#AiRecognitionTaskTransTextResultInput)
* [AiRecognitionTaskTransTextResultOutput](https://cloud.tencent.com/document/api/862/37615#AiRecognitionTaskTransTextResultOutput)
* [AiRecognitionTaskTransTextSegmentItem](https://cloud.tencent.com/document/api/862/37615#AiRecognitionTaskTransTextSegmentItem)
* [LiveStreamTransTextRecognitionResult](https://cloud.tencent.com/document/api/862/37615#LiveStreamTransTextRecognitionResult)
* [SubtitleTemplate](https://cloud.tencent.com/document/api/862/37615#SubtitleTemplate)

修改数据结构：

* [AiRecognitionResult](https://cloud.tencent.com/document/api/862/37615#AiRecognitionResult)

	* 新增成员：TransTextTask

* [ImageSpriteTemplate](https://cloud.tencent.com/document/api/862/37615#ImageSpriteTemplate)

	* 新增成员：Format

* [LiveStreamAiRecognitionResultItem](https://cloud.tencent.com/document/api/862/37615#LiveStreamAiRecognitionResultItem)

	* 新增成员：TransTextRecognitionResultSet

* [OverrideTranscodeParameter](https://cloud.tencent.com/document/api/862/37615#OverrideTranscodeParameter)

	* 新增成员：SubtitleTemplate


### 第 42 次发布

发布时间：2022-09-20 06:38:58

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [TaskSimpleInfo](https://cloud.tencent.com/document/api/862/37615#TaskSimpleInfo)

	* 新增成员：SubTaskTypes


### 第 41 次发布

发布时间：2022-09-15 06:32:33

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [EditMediaOutputConfig](https://cloud.tencent.com/document/api/862/37615#EditMediaOutputConfig)

	* 新增成员：Type


### 第 40 次发布

发布时间：2022-07-16 09:45:55

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateTranscodeTemplate](https://cloud.tencent.com/document/api/862/37605)

	* 新增入参：EnhanceConfig

* [DescribeTaskDetail](https://cloud.tencent.com/document/api/862/37614)

	* 新增出参：ScheduleTask

* [DescribeTasks](https://cloud.tencent.com/document/api/862/37613)

	* 新增出参：TotalCount

* [DescribeTranscodeTemplates](https://cloud.tencent.com/document/api/862/37593)

	* 新增入参：TranscodeType

* [ModifyTranscodeTemplate](https://cloud.tencent.com/document/api/862/37587)

	* 新增入参：EnhanceConfig

* [ParseNotification](https://cloud.tencent.com/document/api/862/39228)

	* 新增出参：ScheduleTaskEvent

* [ProcessMedia](https://cloud.tencent.com/document/api/862/37578)

	* 新增入参：ScheduleId


新增数据结构：

* [ActivityResItem](https://cloud.tencent.com/document/api/862/37615#ActivityResItem)
* [ActivityResult](https://cloud.tencent.com/document/api/862/37615#ActivityResult)
* [ArtifactRepairConfig](https://cloud.tencent.com/document/api/862/37615#ArtifactRepairConfig)
* [ColorEnhanceConfig](https://cloud.tencent.com/document/api/862/37615#ColorEnhanceConfig)
* [EnhanceConfig](https://cloud.tencent.com/document/api/862/37615#EnhanceConfig)
* [FaceEnhanceConfig](https://cloud.tencent.com/document/api/862/37615#FaceEnhanceConfig)
* [FrameRateConfig](https://cloud.tencent.com/document/api/862/37615#FrameRateConfig)
* [HdrConfig](https://cloud.tencent.com/document/api/862/37615#HdrConfig)
* [ImageQualityEnhanceConfig](https://cloud.tencent.com/document/api/862/37615#ImageQualityEnhanceConfig)
* [LowLightEnhanceConfig](https://cloud.tencent.com/document/api/862/37615#LowLightEnhanceConfig)
* [ScheduleAnalysisTaskResult](https://cloud.tencent.com/document/api/862/37615#ScheduleAnalysisTaskResult)
* [ScheduleRecognitionTaskResult](https://cloud.tencent.com/document/api/862/37615#ScheduleRecognitionTaskResult)
* [ScheduleReviewTaskResult](https://cloud.tencent.com/document/api/862/37615#ScheduleReviewTaskResult)
* [ScheduleTask](https://cloud.tencent.com/document/api/862/37615#ScheduleTask)
* [ScratchRepairConfig](https://cloud.tencent.com/document/api/862/37615#ScratchRepairConfig)
* [SharpEnhanceConfig](https://cloud.tencent.com/document/api/862/37615#SharpEnhanceConfig)
* [SuperResolutionConfig](https://cloud.tencent.com/document/api/862/37615#SuperResolutionConfig)
* [VideoDenoiseConfig](https://cloud.tencent.com/document/api/862/37615#VideoDenoiseConfig)
* [VideoEnhanceConfig](https://cloud.tencent.com/document/api/862/37615#VideoEnhanceConfig)

修改数据结构：

* [TranscodeTemplate](https://cloud.tencent.com/document/api/862/37615#TranscodeTemplate)

	* 新增成员：EnhanceConfig


### 第 39 次发布

发布时间：2022-05-24 06:15:50

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [AiRecognitionTaskFaceResultItem](https://cloud.tencent.com/document/api/862/37615#AiRecognitionTaskFaceResultItem)

	* 新增成员：Gender, Birthday, Profession, SchoolOfGraduation, Abstract, PlaceOfBirth, PersonType, Remark, Url


### 第 38 次发布

发布时间：2022-05-11 06:13:00

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeAIAnalysisTemplates](https://cloud.tencent.com/document/api/862/40247)

	* 新增入参：Type

* [DescribeAIRecognitionTemplates](https://cloud.tencent.com/document/api/862/39432)

	* 新增入参：Type

* [DescribeContentReviewTemplates](https://cloud.tencent.com/document/api/862/39431)

	* 新增入参：Type


修改数据结构：

* [AIAnalysisTemplateItem](https://cloud.tencent.com/document/api/862/37615#AIAnalysisTemplateItem)

	* 新增成员：Type

* [AIRecognitionTemplateItem](https://cloud.tencent.com/document/api/862/37615#AIRecognitionTemplateItem)

	* 新增成员：Type

* [ContentReviewTemplateItem](https://cloud.tencent.com/document/api/862/37615#ContentReviewTemplateItem)

	* 新增成员：Type


### 第 37 次发布

发布时间：2022-05-09 06:11:15

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [VideoTemplateInfoForUpdate](https://cloud.tencent.com/document/api/862/37615#VideoTemplateInfoForUpdate)

	* 新增成员：ContentAdaptStream


### 第 36 次发布

发布时间：2021-11-24 08:11:23

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [MediaProcessTaskTranscodeResult](https://cloud.tencent.com/document/api/862/37615#MediaProcessTaskTranscodeResult)

	* 新增成员：Progress


### 第 35 次发布

发布时间：2021-10-13 08:09:46

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [MediaVideoStreamItem](https://cloud.tencent.com/document/api/862/37615#MediaVideoStreamItem)

	* 新增成员：HdrType


### 第 34 次发布

发布时间：2021-10-12 08:08:34

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [LiveStreamTaskNotifyConfig](https://cloud.tencent.com/document/api/862/37615#LiveStreamTaskNotifyConfig)

	* 新增成员：NotifyType, NotifyUrl


### 第 33 次发布

发布时间：2021-08-10 08:08:43

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [MediaAudioStreamItem](https://cloud.tencent.com/document/api/862/37615#MediaAudioStreamItem)

	* 新增成员：Channel

* [MediaVideoStreamItem](https://cloud.tencent.com/document/api/862/37615#MediaVideoStreamItem)

	* 新增成员：ColorPrimaries, ColorSpace, ColorTransfer


### 第 32 次发布

发布时间：2021-07-23 08:07:25

本次发布包含了以下内容：

改善已有的文档。

新增数据结构：

* [HeadTailParameter](https://cloud.tencent.com/document/api/862/37615#HeadTailParameter)

修改数据结构：

* [TaskNotifyConfig](https://cloud.tencent.com/document/api/862/37615#TaskNotifyConfig)

	* 新增成员：NotifyType, NotifyUrl

* [TranscodeTaskInput](https://cloud.tencent.com/document/api/862/37615#TranscodeTaskInput)

	* 新增成员：HeadTailParameter


### 第 31 次发布

发布时间：2021-07-15 08:07:08

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [EditMedia](https://cloud.tencent.com/document/api/862/43010)

	* 新增入参：OutputConfig


新增数据结构：

* [EditMediaOutputConfig](https://cloud.tencent.com/document/api/862/37615#EditMediaOutputConfig)

### 第 30 次发布

发布时间：2021-05-21 08:06:33

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [RawImageWatermarkInput](https://cloud.tencent.com/document/api/862/37615#RawImageWatermarkInput)

	* 新增成员：RepeatType


### 第 29 次发布

发布时间：2021-01-19 08:06:50

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [RecognizeMediaForZhiXue](https://cloud.tencent.com/document/api/862/52172)

新增数据结构：

* [ActionConfigInfo](https://cloud.tencent.com/document/api/862/37615#ActionConfigInfo)
* [ExpressionConfigInfo](https://cloud.tencent.com/document/api/862/37615#ExpressionConfigInfo)

### 第 28 次发布

发布时间：2021-01-15 08:05:53

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [ImageWatermarkInput](https://cloud.tencent.com/document/api/862/37615#ImageWatermarkInput)

	* 新增成员：RepeatType

* [ImageWatermarkInputForUpdate](https://cloud.tencent.com/document/api/862/37615#ImageWatermarkInputForUpdate)

	* 新增成员：RepeatType

* [ImageWatermarkTemplate](https://cloud.tencent.com/document/api/862/37615#ImageWatermarkTemplate)

	* 新增成员：RepeatType


### 第 27 次发布

发布时间：2020-12-30 08:05:36

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [TranscodeTaskInput](https://cloud.tencent.com/document/api/862/37615#TranscodeTaskInput)

	* 新增成员：StartTimeOffset, EndTimeOffset


### 第 26 次发布

发布时间：2020-12-03 08:05:27

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [AiAnalysisTaskClassificationResult](https://cloud.tencent.com/document/api/862/37615#AiAnalysisTaskClassificationResult)

	* 新增成员：ErrCodeExt

* [AiAnalysisTaskCoverResult](https://cloud.tencent.com/document/api/862/37615#AiAnalysisTaskCoverResult)

	* 新增成员：ErrCodeExt

* [AiAnalysisTaskFrameTagResult](https://cloud.tencent.com/document/api/862/37615#AiAnalysisTaskFrameTagResult)

	* 新增成员：ErrCodeExt

* [AiAnalysisTaskTagResult](https://cloud.tencent.com/document/api/862/37615#AiAnalysisTaskTagResult)

	* 新增成员：ErrCodeExt

* [AiRecognitionTaskAsrFullTextResult](https://cloud.tencent.com/document/api/862/37615#AiRecognitionTaskAsrFullTextResult)

	* 新增成员：ErrCodeExt

* [AiRecognitionTaskAsrWordsResult](https://cloud.tencent.com/document/api/862/37615#AiRecognitionTaskAsrWordsResult)

	* 新增成员：ErrCodeExt

* [AiRecognitionTaskFaceResult](https://cloud.tencent.com/document/api/862/37615#AiRecognitionTaskFaceResult)

	* 新增成员：ErrCodeExt

* [AiRecognitionTaskOcrFullTextResult](https://cloud.tencent.com/document/api/862/37615#AiRecognitionTaskOcrFullTextResult)

	* 新增成员：ErrCodeExt

* [AiRecognitionTaskOcrWordsResult](https://cloud.tencent.com/document/api/862/37615#AiRecognitionTaskOcrWordsResult)

	* 新增成员：ErrCodeExt

* [AiReviewTaskPoliticalAsrResult](https://cloud.tencent.com/document/api/862/37615#AiReviewTaskPoliticalAsrResult)

	* 新增成员：ErrCodeExt

* [AiReviewTaskPoliticalOcrResult](https://cloud.tencent.com/document/api/862/37615#AiReviewTaskPoliticalOcrResult)

	* 新增成员：ErrCodeExt

* [AiReviewTaskPoliticalResult](https://cloud.tencent.com/document/api/862/37615#AiReviewTaskPoliticalResult)

	* 新增成员：ErrCodeExt

* [AiReviewTaskPornAsrResult](https://cloud.tencent.com/document/api/862/37615#AiReviewTaskPornAsrResult)

	* 新增成员：ErrCodeExt

* [AiReviewTaskPornOcrResult](https://cloud.tencent.com/document/api/862/37615#AiReviewTaskPornOcrResult)

	* 新增成员：ErrCodeExt

* [AiReviewTaskPornResult](https://cloud.tencent.com/document/api/862/37615#AiReviewTaskPornResult)

	* 新增成员：ErrCodeExt

* [AiReviewTaskProhibitedAsrResult](https://cloud.tencent.com/document/api/862/37615#AiReviewTaskProhibitedAsrResult)

	* 新增成员：ErrCodeExt

* [AiReviewTaskProhibitedOcrResult](https://cloud.tencent.com/document/api/862/37615#AiReviewTaskProhibitedOcrResult)

	* 新增成员：ErrCodeExt

* [AiReviewTaskTerrorismOcrResult](https://cloud.tencent.com/document/api/862/37615#AiReviewTaskTerrorismOcrResult)

	* 新增成员：ErrCodeExt

* [AiReviewTaskTerrorismResult](https://cloud.tencent.com/document/api/862/37615#AiReviewTaskTerrorismResult)

	* 新增成员：ErrCodeExt

* [MediaProcessTaskAdaptiveDynamicStreamingResult](https://cloud.tencent.com/document/api/862/37615#MediaProcessTaskAdaptiveDynamicStreamingResult)

	* 新增成员：ErrCodeExt

* [MediaProcessTaskAnimatedGraphicResult](https://cloud.tencent.com/document/api/862/37615#MediaProcessTaskAnimatedGraphicResult)

	* 新增成员：ErrCodeExt

* [MediaProcessTaskImageSpriteResult](https://cloud.tencent.com/document/api/862/37615#MediaProcessTaskImageSpriteResult)

	* 新增成员：ErrCodeExt

* [MediaProcessTaskSampleSnapshotResult](https://cloud.tencent.com/document/api/862/37615#MediaProcessTaskSampleSnapshotResult)

	* 新增成员：ErrCodeExt

* [MediaProcessTaskSnapshotByTimeOffsetResult](https://cloud.tencent.com/document/api/862/37615#MediaProcessTaskSnapshotByTimeOffsetResult)

	* 新增成员：ErrCodeExt

* [MediaProcessTaskTranscodeResult](https://cloud.tencent.com/document/api/862/37615#MediaProcessTaskTranscodeResult)

	* 新增成员：ErrCodeExt


### 第 25 次发布

发布时间：2020-11-04 08:05:03

本次发布包含了以下内容：

改善已有的文档。

新增数据结构：

* [OverrideTranscodeParameter](https://cloud.tencent.com/document/api/862/37615#OverrideTranscodeParameter)

修改数据结构：

* [TranscodeTaskInput](https://cloud.tencent.com/document/api/862/37615#TranscodeTaskInput)

	* 新增成员：OverrideParameter


### 第 24 次发布

发布时间：2020-10-21 08:05:14

本次发布包含了以下内容：

改善已有的文档。

新增数据结构：

* [UrlInputInfo](https://cloud.tencent.com/document/api/862/37615#UrlInputInfo)

修改数据结构：

* [MediaInputInfo](https://cloud.tencent.com/document/api/862/37615#MediaInputInfo)

	* 新增成员：UrlInputInfo

* [VideoTemplateInfo](https://cloud.tencent.com/document/api/862/37615#VideoTemplateInfo)

	* 新增成员：Vcrf

* [VideoTemplateInfoForUpdate](https://cloud.tencent.com/document/api/862/37615#VideoTemplateInfoForUpdate)

	* 新增成员：Vcrf


### 第 23 次发布

发布时间：2020-09-16 08:04:34

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [ExecuteFunction](https://cloud.tencent.com/document/api/862/48427)

### 第 22 次发布

发布时间：2020-08-25 08:05:52

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [MediaAiAnalysisFrameTagItem](https://cloud.tencent.com/document/api/862/37615#MediaAiAnalysisFrameTagItem)

	* 新增成员：CategorySet


### 第 21 次发布

发布时间：2020-08-03 08:16:09

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeTaskDetail](https://cloud.tencent.com/document/api/862/37614)

	* 新增出参：ExtInfo


### 第 20 次发布

发布时间：2020-06-24 08:14:30

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateAdaptiveDynamicStreamingTemplate](https://cloud.tencent.com/document/api/862/45749)
* [DeleteAdaptiveDynamicStreamingTemplate](https://cloud.tencent.com/document/api/862/45748)
* [DescribeAdaptiveDynamicStreamingTemplates](https://cloud.tencent.com/document/api/862/45747)
* [ModifyAdaptiveDynamicStreamingTemplate](https://cloud.tencent.com/document/api/862/45746)

新增数据结构：

* [AdaptiveDynamicStreamingInfoItem](https://cloud.tencent.com/document/api/862/37615#AdaptiveDynamicStreamingInfoItem)
* [AdaptiveDynamicStreamingTaskInput](https://cloud.tencent.com/document/api/862/37615#AdaptiveDynamicStreamingTaskInput)
* [AdaptiveDynamicStreamingTemplate](https://cloud.tencent.com/document/api/862/37615#AdaptiveDynamicStreamingTemplate)
* [AdaptiveStreamTemplate](https://cloud.tencent.com/document/api/862/37615#AdaptiveStreamTemplate)
* [MediaProcessTaskAdaptiveDynamicStreamingResult](https://cloud.tencent.com/document/api/862/37615#MediaProcessTaskAdaptiveDynamicStreamingResult)

修改数据结构：

* [MediaProcessTaskInput](https://cloud.tencent.com/document/api/862/37615#MediaProcessTaskInput)

	* 新增成员：AdaptiveDynamicStreamingTaskSet

* [MediaProcessTaskResult](https://cloud.tencent.com/document/api/862/37615#MediaProcessTaskResult)

	* 新增成员：AdaptiveDynamicStreamingTask


### 第 19 次发布

发布时间：2020-05-01 08:12:45

本次发布包含了以下内容：

改善已有的文档。

新增数据结构：

* [MosaicInput](https://cloud.tencent.com/document/api/862/37615#MosaicInput)

修改数据结构：

* [SnapshotByTimeOffsetTaskInput](https://cloud.tencent.com/document/api/862/37615#SnapshotByTimeOffsetTaskInput)

	* 新增成员：ExtTimeOffsetSet

	* <font color="#dd0000">**修改成员**：</font>TimeOffsetSet

* [TranscodeTaskInput](https://cloud.tencent.com/document/api/862/37615#TranscodeTaskInput)

	* 新增成员：MosaicSet


### 第 18 次发布

发布时间：2020-04-27 08:12:37

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateImageSpriteTemplate](https://cloud.tencent.com/document/api/862/37608)

	* 新增入参：Comment

* [ModifyImageSpriteTemplate](https://cloud.tencent.com/document/api/862/37590)

	* 新增入参：Comment


### 第 17 次发布

发布时间：2020-04-24 08:12:21

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [ImageSpriteTemplate](https://cloud.tencent.com/document/api/862/37615#ImageSpriteTemplate)

	* 新增成员：Comment


### 第 16 次发布

发布时间：2020-03-31 08:10:29

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [EditMedia](https://cloud.tencent.com/document/api/862/43010)

修改接口：

* [DescribeTaskDetail](https://cloud.tencent.com/document/api/862/37614)

	* 新增出参：EditMediaTask

* [ParseNotification](https://cloud.tencent.com/document/api/862/39228)

	* 新增出参：EditMediaTaskEvent


新增数据结构：

* [EditMediaFileInfo](https://cloud.tencent.com/document/api/862/37615#EditMediaFileInfo)
* [EditMediaTask](https://cloud.tencent.com/document/api/862/37615#EditMediaTask)
* [EditMediaTaskInput](https://cloud.tencent.com/document/api/862/37615#EditMediaTaskInput)
* [EditMediaTaskOutput](https://cloud.tencent.com/document/api/862/37615#EditMediaTaskOutput)

### 第 15 次发布

发布时间：2020-03-25 08:11:26

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreatePersonSample](https://cloud.tencent.com/document/api/862/39445)

	* <font color="#dd0000">**修改入参**：</font>FaceContents


### 第 14 次发布

发布时间：2020-02-24 10:07:55

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateContentReviewTemplate](https://cloud.tencent.com/document/api/862/39435)

	* 新增入参：ProhibitedConfigure

* [ModifyContentReviewTemplate](https://cloud.tencent.com/document/api/862/39429)

	* 新增入参：ProhibitedConfigure


新增数据结构：

* [ProhibitedAsrReviewTemplateInfoForUpdate](https://cloud.tencent.com/document/api/862/37615#ProhibitedAsrReviewTemplateInfoForUpdate)
* [ProhibitedConfigureInfoForUpdate](https://cloud.tencent.com/document/api/862/37615#ProhibitedConfigureInfoForUpdate)
* [ProhibitedOcrReviewTemplateInfoForUpdate](https://cloud.tencent.com/document/api/862/37615#ProhibitedOcrReviewTemplateInfoForUpdate)

### 第 13 次发布

发布时间：2020-02-13 14:35:41

本次发布包含了以下内容：

改善已有的文档。

新增数据结构：

* [AiReviewProhibitedAsrTaskInput](https://cloud.tencent.com/document/api/862/37615#AiReviewProhibitedAsrTaskInput)
* [AiReviewProhibitedAsrTaskOutput](https://cloud.tencent.com/document/api/862/37615#AiReviewProhibitedAsrTaskOutput)
* [AiReviewProhibitedOcrTaskInput](https://cloud.tencent.com/document/api/862/37615#AiReviewProhibitedOcrTaskInput)
* [AiReviewProhibitedOcrTaskOutput](https://cloud.tencent.com/document/api/862/37615#AiReviewProhibitedOcrTaskOutput)
* [AiReviewTaskProhibitedAsrResult](https://cloud.tencent.com/document/api/862/37615#AiReviewTaskProhibitedAsrResult)
* [AiReviewTaskProhibitedOcrResult](https://cloud.tencent.com/document/api/862/37615#AiReviewTaskProhibitedOcrResult)
* [AiReviewTaskTerrorismOcrResult](https://cloud.tencent.com/document/api/862/37615#AiReviewTaskTerrorismOcrResult)
* [AiReviewTerrorismOcrTaskInput](https://cloud.tencent.com/document/api/862/37615#AiReviewTerrorismOcrTaskInput)
* [AiReviewTerrorismOcrTaskOutput](https://cloud.tencent.com/document/api/862/37615#AiReviewTerrorismOcrTaskOutput)
* [ProhibitedAsrReviewTemplateInfo](https://cloud.tencent.com/document/api/862/37615#ProhibitedAsrReviewTemplateInfo)
* [ProhibitedConfigureInfo](https://cloud.tencent.com/document/api/862/37615#ProhibitedConfigureInfo)
* [ProhibitedOcrReviewTemplateInfo](https://cloud.tencent.com/document/api/862/37615#ProhibitedOcrReviewTemplateInfo)
* [RawImageWatermarkInput](https://cloud.tencent.com/document/api/862/37615#RawImageWatermarkInput)
* [RawWatermarkParameter](https://cloud.tencent.com/document/api/862/37615#RawWatermarkParameter)
* [TerrorismOcrReviewTemplateInfo](https://cloud.tencent.com/document/api/862/37615#TerrorismOcrReviewTemplateInfo)
* [TerrorismOcrReviewTemplateInfoForUpdate](https://cloud.tencent.com/document/api/862/37615#TerrorismOcrReviewTemplateInfoForUpdate)

修改数据结构：

* [AiContentReviewResult](https://cloud.tencent.com/document/api/862/37615#AiContentReviewResult)

	* 新增成员：TerrorismOcrTask, ProhibitedAsrTask, ProhibitedOcrTask

* [ContentReviewTemplateItem](https://cloud.tencent.com/document/api/862/37615#ContentReviewTemplateItem)

	* 新增成员：ProhibitedConfigure

* [TerrorismConfigureInfo](https://cloud.tencent.com/document/api/862/37615#TerrorismConfigureInfo)

	* 新增成员：OcrReviewInfo

* [TerrorismConfigureInfoForUpdate](https://cloud.tencent.com/document/api/862/37615#TerrorismConfigureInfoForUpdate)

	* 新增成员：OcrReviewInfo

* [WatermarkInput](https://cloud.tencent.com/document/api/862/37615#WatermarkInput)

	* 新增成员：RawParameter


### 第 12 次发布

发布时间：2020-01-15 19:37:36

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [VideoTemplateInfoForUpdate](https://cloud.tencent.com/document/api/862/37615#VideoTemplateInfoForUpdate)

	* <font color="#dd0000">**修改成员**：</font>Gop


### 第 11 次发布

发布时间：2020-01-09 15:05:14

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [ManageTask](https://cloud.tencent.com/document/api/862/40947)

修改数据结构：

* [VideoTemplateInfo](https://cloud.tencent.com/document/api/862/37615#VideoTemplateInfo)

	* 新增成员：Gop

* [VideoTemplateInfoForUpdate](https://cloud.tencent.com/document/api/862/37615#VideoTemplateInfoForUpdate)

	* 新增成员：Gop


### 第 10 次发布

发布时间：2020-01-06 15:44:23

本次发布包含了以下内容：

改善已有的文档。

新增数据结构：

* [RawTranscodeParameter](https://cloud.tencent.com/document/api/862/37615#RawTranscodeParameter)

修改数据结构：

* [TranscodeTaskInput](https://cloud.tencent.com/document/api/862/37615#TranscodeTaskInput)

	* 新增成员：RawParameter


### 第 9 次发布

发布时间：2020-01-02 16:46:37

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateAnimatedGraphicsTemplate](https://cloud.tencent.com/document/api/862/37609)

	* 新增入参：ResolutionAdaptive

	* <font color="#dd0000">**修改入参**：</font>Width, Height

* [CreateImageSpriteTemplate](https://cloud.tencent.com/document/api/862/37608)

	* 新增入参：ResolutionAdaptive, FillType

	* <font color="#dd0000">**修改入参**：</font>Width, Height

* [CreateSampleSnapshotTemplate](https://cloud.tencent.com/document/api/862/37607)

	* 新增入参：ResolutionAdaptive, FillType

	* <font color="#dd0000">**修改入参**：</font>Width, Height

* [CreateSnapshotByTimeOffsetTemplate](https://cloud.tencent.com/document/api/862/37606)

	* 新增入参：ResolutionAdaptive, FillType

	* <font color="#dd0000">**修改入参**：</font>Width, Height

* [ModifyAnimatedGraphicsTemplate](https://cloud.tencent.com/document/api/862/37591)

	* 新增入参：ResolutionAdaptive

* [ModifyImageSpriteTemplate](https://cloud.tencent.com/document/api/862/37590)

	* 新增入参：ResolutionAdaptive, FillType

* [ModifySampleSnapshotTemplate](https://cloud.tencent.com/document/api/862/37589)

	* 新增入参：ResolutionAdaptive, FillType

* [ModifySnapshotByTimeOffsetTemplate](https://cloud.tencent.com/document/api/862/37588)

	* 新增入参：ResolutionAdaptive, FillType


### 第 8 次发布

发布时间：2020-01-02 16:26:51

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeMediaMetaData](https://cloud.tencent.com/document/api/862/40637)

修改数据结构：

* [AiContentReviewResult](https://cloud.tencent.com/document/api/862/37615#AiContentReviewResult)

	* 新增成员：SampleRate, Duration


### 第 7 次发布

发布时间：2019-12-15 20:58:10

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateAIAnalysisTemplate](https://cloud.tencent.com/document/api/862/40249)
* [DeleteAIAnalysisTemplate](https://cloud.tencent.com/document/api/862/40248)
* [DescribeAIAnalysisTemplates](https://cloud.tencent.com/document/api/862/40247)
* [ModifyAIAnalysisTemplate](https://cloud.tencent.com/document/api/862/40246)

修改接口：

* [CreateWorkflow](https://cloud.tencent.com/document/api/862/37583)

	* 新增入参：AiAnalysisTask

* [ProcessMedia](https://cloud.tencent.com/document/api/862/37578)

	* 新增入参：AiAnalysisTask

* [ResetWorkflow](https://cloud.tencent.com/document/api/862/37585)

	* 新增入参：AiAnalysisTask

	* <font color="#dd0000">**修改入参**：</font>AiContentReviewTask


新增数据结构：

* [AIAnalysisTemplateItem](https://cloud.tencent.com/document/api/862/37615#AIAnalysisTemplateItem)
* [AiAnalysisResult](https://cloud.tencent.com/document/api/862/37615#AiAnalysisResult)
* [AiAnalysisTaskClassificationInput](https://cloud.tencent.com/document/api/862/37615#AiAnalysisTaskClassificationInput)
* [AiAnalysisTaskClassificationOutput](https://cloud.tencent.com/document/api/862/37615#AiAnalysisTaskClassificationOutput)
* [AiAnalysisTaskClassificationResult](https://cloud.tencent.com/document/api/862/37615#AiAnalysisTaskClassificationResult)
* [AiAnalysisTaskCoverInput](https://cloud.tencent.com/document/api/862/37615#AiAnalysisTaskCoverInput)
* [AiAnalysisTaskCoverOutput](https://cloud.tencent.com/document/api/862/37615#AiAnalysisTaskCoverOutput)
* [AiAnalysisTaskCoverResult](https://cloud.tencent.com/document/api/862/37615#AiAnalysisTaskCoverResult)
* [AiAnalysisTaskFrameTagInput](https://cloud.tencent.com/document/api/862/37615#AiAnalysisTaskFrameTagInput)
* [AiAnalysisTaskFrameTagOutput](https://cloud.tencent.com/document/api/862/37615#AiAnalysisTaskFrameTagOutput)
* [AiAnalysisTaskFrameTagResult](https://cloud.tencent.com/document/api/862/37615#AiAnalysisTaskFrameTagResult)
* [AiAnalysisTaskInput](https://cloud.tencent.com/document/api/862/37615#AiAnalysisTaskInput)
* [AiAnalysisTaskTagInput](https://cloud.tencent.com/document/api/862/37615#AiAnalysisTaskTagInput)
* [AiAnalysisTaskTagOutput](https://cloud.tencent.com/document/api/862/37615#AiAnalysisTaskTagOutput)
* [AiAnalysisTaskTagResult](https://cloud.tencent.com/document/api/862/37615#AiAnalysisTaskTagResult)
* [ClassificationConfigureInfo](https://cloud.tencent.com/document/api/862/37615#ClassificationConfigureInfo)
* [ClassificationConfigureInfoForUpdate](https://cloud.tencent.com/document/api/862/37615#ClassificationConfigureInfoForUpdate)
* [CoverConfigureInfo](https://cloud.tencent.com/document/api/862/37615#CoverConfigureInfo)
* [CoverConfigureInfoForUpdate](https://cloud.tencent.com/document/api/862/37615#CoverConfigureInfoForUpdate)
* [FrameTagConfigureInfo](https://cloud.tencent.com/document/api/862/37615#FrameTagConfigureInfo)
* [FrameTagConfigureInfoForUpdate](https://cloud.tencent.com/document/api/862/37615#FrameTagConfigureInfoForUpdate)
* [MediaAiAnalysisClassificationItem](https://cloud.tencent.com/document/api/862/37615#MediaAiAnalysisClassificationItem)
* [MediaAiAnalysisCoverItem](https://cloud.tencent.com/document/api/862/37615#MediaAiAnalysisCoverItem)
* [MediaAiAnalysisFrameTagItem](https://cloud.tencent.com/document/api/862/37615#MediaAiAnalysisFrameTagItem)
* [MediaAiAnalysisFrameTagSegmentItem](https://cloud.tencent.com/document/api/862/37615#MediaAiAnalysisFrameTagSegmentItem)
* [MediaAiAnalysisTagItem](https://cloud.tencent.com/document/api/862/37615#MediaAiAnalysisTagItem)
* [TagConfigureInfo](https://cloud.tencent.com/document/api/862/37615#TagConfigureInfo)
* [TagConfigureInfoForUpdate](https://cloud.tencent.com/document/api/862/37615#TagConfigureInfoForUpdate)

<font color="#dd0000">**删除数据结构**：</font>

* AiClassificationTaskInput

修改数据结构：

* [ImageSpriteTemplate](https://cloud.tencent.com/document/api/862/37615#ImageSpriteTemplate)

	* 新增成员：ResolutionAdaptive

* [WorkflowInfo](https://cloud.tencent.com/document/api/862/37615#WorkflowInfo)

	* 新增成员：AiAnalysisTask

* [WorkflowTask](https://cloud.tencent.com/document/api/862/37615#WorkflowTask)

	* 新增成员：AiAnalysisResultSet


### 第 6 次发布

发布时间：2019-11-28 22:19:24

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [ParseLiveStreamProcessNotification](https://cloud.tencent.com/document/api/862/39229)

	* 新增出参：AiRecognitionResultInfo

* [ProcessLiveStream](https://cloud.tencent.com/document/api/862/39227)

	* 新增入参：AiRecognitionTask


新增数据结构：

* [LiveStreamAiRecognitionResultInfo](https://cloud.tencent.com/document/api/862/37615#LiveStreamAiRecognitionResultInfo)
* [LiveStreamAiRecognitionResultItem](https://cloud.tencent.com/document/api/862/37615#LiveStreamAiRecognitionResultItem)
* [LiveStreamAsrFullTextRecognitionResult](https://cloud.tencent.com/document/api/862/37615#LiveStreamAsrFullTextRecognitionResult)
* [LiveStreamAsrWordsRecognitionResult](https://cloud.tencent.com/document/api/862/37615#LiveStreamAsrWordsRecognitionResult)
* [LiveStreamFaceRecognitionResult](https://cloud.tencent.com/document/api/862/37615#LiveStreamFaceRecognitionResult)
* [LiveStreamOcrFullTextRecognitionResult](https://cloud.tencent.com/document/api/862/37615#LiveStreamOcrFullTextRecognitionResult)
* [LiveStreamOcrWordsRecognitionResult](https://cloud.tencent.com/document/api/862/37615#LiveStreamOcrWordsRecognitionResult)

### 第 5 次发布

发布时间：2019-11-21 19:44:42

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateAIRecognitionTemplate](https://cloud.tencent.com/document/api/862/39436)
* [CreateContentReviewTemplate](https://cloud.tencent.com/document/api/862/39435)
* [CreatePersonSample](https://cloud.tencent.com/document/api/862/39445)
* [CreateWordSamples](https://cloud.tencent.com/document/api/862/39444)
* [DeleteAIRecognitionTemplate](https://cloud.tencent.com/document/api/862/39434)
* [DeleteContentReviewTemplate](https://cloud.tencent.com/document/api/862/39433)
* [DeletePersonSample](https://cloud.tencent.com/document/api/862/39443)
* [DeleteWordSamples](https://cloud.tencent.com/document/api/862/39442)
* [DescribeAIRecognitionTemplates](https://cloud.tencent.com/document/api/862/39432)
* [DescribeContentReviewTemplates](https://cloud.tencent.com/document/api/862/39431)
* [DescribePersonSamples](https://cloud.tencent.com/document/api/862/39441)
* [DescribeWordSamples](https://cloud.tencent.com/document/api/862/39440)
* [ModifyAIRecognitionTemplate](https://cloud.tencent.com/document/api/862/39430)
* [ModifyContentReviewTemplate](https://cloud.tencent.com/document/api/862/39429)
* [ModifyPersonSample](https://cloud.tencent.com/document/api/862/39439)
* [ModifyWordSample](https://cloud.tencent.com/document/api/862/39438)

<font color="#dd0000">**删除接口**：</font>

* ProcessLiveMedia

修改接口：

* [CreateWorkflow](https://cloud.tencent.com/document/api/862/37583)

	* 新增入参：AiContentReviewTask, AiRecognitionTask

* [ProcessMedia](https://cloud.tencent.com/document/api/862/37578)

	* 新增入参：AiContentReviewTask, AiRecognitionTask

* [ResetWorkflow](https://cloud.tencent.com/document/api/862/37585)

	* 新增入参：AiContentReviewTask, AiRecognitionTask


新增数据结构：

* [AIRecognitionTemplateItem](https://cloud.tencent.com/document/api/862/37615#AIRecognitionTemplateItem)
* [AiClassificationTaskInput](https://cloud.tencent.com/document/api/862/37615#AiClassificationTaskInput)
* [AiSampleFaceInfo](https://cloud.tencent.com/document/api/862/37615#AiSampleFaceInfo)
* [AiSampleFaceOperation](https://cloud.tencent.com/document/api/862/37615#AiSampleFaceOperation)
* [AiSampleFailFaceInfo](https://cloud.tencent.com/document/api/862/37615#AiSampleFailFaceInfo)
* [AiSamplePerson](https://cloud.tencent.com/document/api/862/37615#AiSamplePerson)
* [AiSampleTagOperation](https://cloud.tencent.com/document/api/862/37615#AiSampleTagOperation)
* [AiSampleWord](https://cloud.tencent.com/document/api/862/37615#AiSampleWord)
* [AiSampleWordInfo](https://cloud.tencent.com/document/api/862/37615#AiSampleWordInfo)
* [AsrFullTextConfigureInfo](https://cloud.tencent.com/document/api/862/37615#AsrFullTextConfigureInfo)
* [AsrFullTextConfigureInfoForUpdate](https://cloud.tencent.com/document/api/862/37615#AsrFullTextConfigureInfoForUpdate)
* [AsrWordsConfigureInfo](https://cloud.tencent.com/document/api/862/37615#AsrWordsConfigureInfo)
* [AsrWordsConfigureInfoForUpdate](https://cloud.tencent.com/document/api/862/37615#AsrWordsConfigureInfoForUpdate)
* [ContentReviewTemplateItem](https://cloud.tencent.com/document/api/862/37615#ContentReviewTemplateItem)
* [FaceConfigureInfo](https://cloud.tencent.com/document/api/862/37615#FaceConfigureInfo)
* [FaceConfigureInfoForUpdate](https://cloud.tencent.com/document/api/862/37615#FaceConfigureInfoForUpdate)
* [OcrFullTextConfigureInfo](https://cloud.tencent.com/document/api/862/37615#OcrFullTextConfigureInfo)
* [OcrFullTextConfigureInfoForUpdate](https://cloud.tencent.com/document/api/862/37615#OcrFullTextConfigureInfoForUpdate)
* [OcrWordsConfigureInfo](https://cloud.tencent.com/document/api/862/37615#OcrWordsConfigureInfo)
* [OcrWordsConfigureInfoForUpdate](https://cloud.tencent.com/document/api/862/37615#OcrWordsConfigureInfoForUpdate)
* [PoliticalAsrReviewTemplateInfo](https://cloud.tencent.com/document/api/862/37615#PoliticalAsrReviewTemplateInfo)
* [PoliticalAsrReviewTemplateInfoForUpdate](https://cloud.tencent.com/document/api/862/37615#PoliticalAsrReviewTemplateInfoForUpdate)
* [PoliticalConfigureInfo](https://cloud.tencent.com/document/api/862/37615#PoliticalConfigureInfo)
* [PoliticalConfigureInfoForUpdate](https://cloud.tencent.com/document/api/862/37615#PoliticalConfigureInfoForUpdate)
* [PoliticalImgReviewTemplateInfo](https://cloud.tencent.com/document/api/862/37615#PoliticalImgReviewTemplateInfo)
* [PoliticalImgReviewTemplateInfoForUpdate](https://cloud.tencent.com/document/api/862/37615#PoliticalImgReviewTemplateInfoForUpdate)
* [PoliticalOcrReviewTemplateInfo](https://cloud.tencent.com/document/api/862/37615#PoliticalOcrReviewTemplateInfo)
* [PoliticalOcrReviewTemplateInfoForUpdate](https://cloud.tencent.com/document/api/862/37615#PoliticalOcrReviewTemplateInfoForUpdate)
* [PornAsrReviewTemplateInfo](https://cloud.tencent.com/document/api/862/37615#PornAsrReviewTemplateInfo)
* [PornAsrReviewTemplateInfoForUpdate](https://cloud.tencent.com/document/api/862/37615#PornAsrReviewTemplateInfoForUpdate)
* [PornConfigureInfo](https://cloud.tencent.com/document/api/862/37615#PornConfigureInfo)
* [PornConfigureInfoForUpdate](https://cloud.tencent.com/document/api/862/37615#PornConfigureInfoForUpdate)
* [PornImgReviewTemplateInfo](https://cloud.tencent.com/document/api/862/37615#PornImgReviewTemplateInfo)
* [PornImgReviewTemplateInfoForUpdate](https://cloud.tencent.com/document/api/862/37615#PornImgReviewTemplateInfoForUpdate)
* [PornOcrReviewTemplateInfo](https://cloud.tencent.com/document/api/862/37615#PornOcrReviewTemplateInfo)
* [PornOcrReviewTemplateInfoForUpdate](https://cloud.tencent.com/document/api/862/37615#PornOcrReviewTemplateInfoForUpdate)
* [TerrorismConfigureInfo](https://cloud.tencent.com/document/api/862/37615#TerrorismConfigureInfo)
* [TerrorismConfigureInfoForUpdate](https://cloud.tencent.com/document/api/862/37615#TerrorismConfigureInfoForUpdate)
* [TerrorismImgReviewTemplateInfo](https://cloud.tencent.com/document/api/862/37615#TerrorismImgReviewTemplateInfo)
* [TerrorismImgReviewTemplateInfoForUpdate](https://cloud.tencent.com/document/api/862/37615#TerrorismImgReviewTemplateInfoForUpdate)
* [UserDefineAsrTextReviewTemplateInfo](https://cloud.tencent.com/document/api/862/37615#UserDefineAsrTextReviewTemplateInfo)
* [UserDefineAsrTextReviewTemplateInfoForUpdate](https://cloud.tencent.com/document/api/862/37615#UserDefineAsrTextReviewTemplateInfoForUpdate)
* [UserDefineConfigureInfo](https://cloud.tencent.com/document/api/862/37615#UserDefineConfigureInfo)
* [UserDefineConfigureInfoForUpdate](https://cloud.tencent.com/document/api/862/37615#UserDefineConfigureInfoForUpdate)
* [UserDefineFaceReviewTemplateInfo](https://cloud.tencent.com/document/api/862/37615#UserDefineFaceReviewTemplateInfo)
* [UserDefineFaceReviewTemplateInfoForUpdate](https://cloud.tencent.com/document/api/862/37615#UserDefineFaceReviewTemplateInfoForUpdate)
* [UserDefineOcrTextReviewTemplateInfo](https://cloud.tencent.com/document/api/862/37615#UserDefineOcrTextReviewTemplateInfo)
* [UserDefineOcrTextReviewTemplateInfoForUpdate](https://cloud.tencent.com/document/api/862/37615#UserDefineOcrTextReviewTemplateInfoForUpdate)

<font color="#dd0000">**删除数据结构**：</font>

* AiAnalysisTaskInput

修改数据结构：

* [ImageSpriteTemplate](https://cloud.tencent.com/document/api/862/37615#ImageSpriteTemplate)

	* 新增成员：FillType

* [SampleSnapshotTemplate](https://cloud.tencent.com/document/api/862/37615#SampleSnapshotTemplate)

	* 新增成员：FillType

* [SnapshotByTimeOffsetTemplate](https://cloud.tencent.com/document/api/862/37615#SnapshotByTimeOffsetTemplate)

	* 新增成员：FillType

* [WatermarkInput](https://cloud.tencent.com/document/api/862/37615#WatermarkInput)

	* 新增成员：StartTimeOffset, EndTimeOffset

* [WorkflowInfo](https://cloud.tencent.com/document/api/862/37615#WorkflowInfo)

	* <font color="#dd0000">**删除成员**：</font>AiAnalysisTask


### 第 4 次发布

发布时间：2019-11-14 19:29:58

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [ParseLiveStreamProcessNotification](https://cloud.tencent.com/document/api/862/39229)
* [ParseNotification](https://cloud.tencent.com/document/api/862/39228)
* [ProcessLiveStream](https://cloud.tencent.com/document/api/862/39227)

<font color="#dd0000">**删除接口**：</font>

* DescribeUserInfo

修改接口：

* [DescribeTaskDetail](https://cloud.tencent.com/document/api/862/37614)

	* 新增出参：LiveStreamProcessTask


新增数据结构：

* [AiContentReviewResult](https://cloud.tencent.com/document/api/862/37615#AiContentReviewResult)
* [AiRecognitionResult](https://cloud.tencent.com/document/api/862/37615#AiRecognitionResult)
* [AiRecognitionTaskAsrFullTextResult](https://cloud.tencent.com/document/api/862/37615#AiRecognitionTaskAsrFullTextResult)
* [AiRecognitionTaskAsrFullTextResultInput](https://cloud.tencent.com/document/api/862/37615#AiRecognitionTaskAsrFullTextResultInput)
* [AiRecognitionTaskAsrFullTextResultOutput](https://cloud.tencent.com/document/api/862/37615#AiRecognitionTaskAsrFullTextResultOutput)
* [AiRecognitionTaskAsrFullTextSegmentItem](https://cloud.tencent.com/document/api/862/37615#AiRecognitionTaskAsrFullTextSegmentItem)
* [AiRecognitionTaskAsrWordsResult](https://cloud.tencent.com/document/api/862/37615#AiRecognitionTaskAsrWordsResult)
* [AiRecognitionTaskAsrWordsResultInput](https://cloud.tencent.com/document/api/862/37615#AiRecognitionTaskAsrWordsResultInput)
* [AiRecognitionTaskAsrWordsResultItem](https://cloud.tencent.com/document/api/862/37615#AiRecognitionTaskAsrWordsResultItem)
* [AiRecognitionTaskAsrWordsResultOutput](https://cloud.tencent.com/document/api/862/37615#AiRecognitionTaskAsrWordsResultOutput)
* [AiRecognitionTaskAsrWordsSegmentItem](https://cloud.tencent.com/document/api/862/37615#AiRecognitionTaskAsrWordsSegmentItem)
* [AiRecognitionTaskFaceResult](https://cloud.tencent.com/document/api/862/37615#AiRecognitionTaskFaceResult)
* [AiRecognitionTaskFaceResultInput](https://cloud.tencent.com/document/api/862/37615#AiRecognitionTaskFaceResultInput)
* [AiRecognitionTaskFaceResultItem](https://cloud.tencent.com/document/api/862/37615#AiRecognitionTaskFaceResultItem)
* [AiRecognitionTaskFaceResultOutput](https://cloud.tencent.com/document/api/862/37615#AiRecognitionTaskFaceResultOutput)
* [AiRecognitionTaskFaceSegmentItem](https://cloud.tencent.com/document/api/862/37615#AiRecognitionTaskFaceSegmentItem)
* [AiRecognitionTaskOcrFullTextResult](https://cloud.tencent.com/document/api/862/37615#AiRecognitionTaskOcrFullTextResult)
* [AiRecognitionTaskOcrFullTextResultInput](https://cloud.tencent.com/document/api/862/37615#AiRecognitionTaskOcrFullTextResultInput)
* [AiRecognitionTaskOcrFullTextResultOutput](https://cloud.tencent.com/document/api/862/37615#AiRecognitionTaskOcrFullTextResultOutput)
* [AiRecognitionTaskOcrFullTextSegmentItem](https://cloud.tencent.com/document/api/862/37615#AiRecognitionTaskOcrFullTextSegmentItem)
* [AiRecognitionTaskOcrFullTextSegmentTextItem](https://cloud.tencent.com/document/api/862/37615#AiRecognitionTaskOcrFullTextSegmentTextItem)
* [AiRecognitionTaskOcrWordsResult](https://cloud.tencent.com/document/api/862/37615#AiRecognitionTaskOcrWordsResult)
* [AiRecognitionTaskOcrWordsResultInput](https://cloud.tencent.com/document/api/862/37615#AiRecognitionTaskOcrWordsResultInput)
* [AiRecognitionTaskOcrWordsResultItem](https://cloud.tencent.com/document/api/862/37615#AiRecognitionTaskOcrWordsResultItem)
* [AiRecognitionTaskOcrWordsResultOutput](https://cloud.tencent.com/document/api/862/37615#AiRecognitionTaskOcrWordsResultOutput)
* [AiRecognitionTaskOcrWordsSegmentItem](https://cloud.tencent.com/document/api/862/37615#AiRecognitionTaskOcrWordsSegmentItem)
* [AiReviewPoliticalAsrTaskInput](https://cloud.tencent.com/document/api/862/37615#AiReviewPoliticalAsrTaskInput)
* [AiReviewPoliticalAsrTaskOutput](https://cloud.tencent.com/document/api/862/37615#AiReviewPoliticalAsrTaskOutput)
* [AiReviewPoliticalOcrTaskInput](https://cloud.tencent.com/document/api/862/37615#AiReviewPoliticalOcrTaskInput)
* [AiReviewPoliticalOcrTaskOutput](https://cloud.tencent.com/document/api/862/37615#AiReviewPoliticalOcrTaskOutput)
* [AiReviewPoliticalTaskInput](https://cloud.tencent.com/document/api/862/37615#AiReviewPoliticalTaskInput)
* [AiReviewPoliticalTaskOutput](https://cloud.tencent.com/document/api/862/37615#AiReviewPoliticalTaskOutput)
* [AiReviewPornAsrTaskInput](https://cloud.tencent.com/document/api/862/37615#AiReviewPornAsrTaskInput)
* [AiReviewPornAsrTaskOutput](https://cloud.tencent.com/document/api/862/37615#AiReviewPornAsrTaskOutput)
* [AiReviewPornOcrTaskInput](https://cloud.tencent.com/document/api/862/37615#AiReviewPornOcrTaskInput)
* [AiReviewPornOcrTaskOutput](https://cloud.tencent.com/document/api/862/37615#AiReviewPornOcrTaskOutput)
* [AiReviewPornTaskInput](https://cloud.tencent.com/document/api/862/37615#AiReviewPornTaskInput)
* [AiReviewPornTaskOutput](https://cloud.tencent.com/document/api/862/37615#AiReviewPornTaskOutput)
* [AiReviewTaskPoliticalAsrResult](https://cloud.tencent.com/document/api/862/37615#AiReviewTaskPoliticalAsrResult)
* [AiReviewTaskPoliticalOcrResult](https://cloud.tencent.com/document/api/862/37615#AiReviewTaskPoliticalOcrResult)
* [AiReviewTaskPoliticalResult](https://cloud.tencent.com/document/api/862/37615#AiReviewTaskPoliticalResult)
* [AiReviewTaskPornAsrResult](https://cloud.tencent.com/document/api/862/37615#AiReviewTaskPornAsrResult)
* [AiReviewTaskPornOcrResult](https://cloud.tencent.com/document/api/862/37615#AiReviewTaskPornOcrResult)
* [AiReviewTaskPornResult](https://cloud.tencent.com/document/api/862/37615#AiReviewTaskPornResult)
* [AiReviewTaskTerrorismResult](https://cloud.tencent.com/document/api/862/37615#AiReviewTaskTerrorismResult)
* [AiReviewTerrorismTaskInput](https://cloud.tencent.com/document/api/862/37615#AiReviewTerrorismTaskInput)
* [AiReviewTerrorismTaskOutput](https://cloud.tencent.com/document/api/862/37615#AiReviewTerrorismTaskOutput)
* [LiveStreamAiReviewImagePoliticalResult](https://cloud.tencent.com/document/api/862/37615#LiveStreamAiReviewImagePoliticalResult)
* [LiveStreamAiReviewImagePornResult](https://cloud.tencent.com/document/api/862/37615#LiveStreamAiReviewImagePornResult)
* [LiveStreamAiReviewImageTerrorismResult](https://cloud.tencent.com/document/api/862/37615#LiveStreamAiReviewImageTerrorismResult)
* [LiveStreamAiReviewResultInfo](https://cloud.tencent.com/document/api/862/37615#LiveStreamAiReviewResultInfo)
* [LiveStreamAiReviewResultItem](https://cloud.tencent.com/document/api/862/37615#LiveStreamAiReviewResultItem)
* [LiveStreamAiReviewVoicePornResult](https://cloud.tencent.com/document/api/862/37615#LiveStreamAiReviewVoicePornResult)
* [LiveStreamProcessErrorInfo](https://cloud.tencent.com/document/api/862/37615#LiveStreamProcessErrorInfo)
* [LiveStreamProcessTask](https://cloud.tencent.com/document/api/862/37615#LiveStreamProcessTask)
* [LiveStreamTaskNotifyConfig](https://cloud.tencent.com/document/api/862/37615#LiveStreamTaskNotifyConfig)
* [MediaContentReviewAsrTextSegmentItem](https://cloud.tencent.com/document/api/862/37615#MediaContentReviewAsrTextSegmentItem)
* [MediaContentReviewOcrTextSegmentItem](https://cloud.tencent.com/document/api/862/37615#MediaContentReviewOcrTextSegmentItem)
* [MediaContentReviewPoliticalSegmentItem](https://cloud.tencent.com/document/api/862/37615#MediaContentReviewPoliticalSegmentItem)
* [MediaContentReviewSegmentItem](https://cloud.tencent.com/document/api/862/37615#MediaContentReviewSegmentItem)

<font color="#dd0000">**删除数据结构**：</font>

* AdaptiveDynamicStreamingTaskInput

修改数据结构：

* [AnimatedGraphicsTemplate](https://cloud.tencent.com/document/api/862/37615#AnimatedGraphicsTemplate)

	* 新增成员：ResolutionAdaptive

* [MediaProcessTaskInput](https://cloud.tencent.com/document/api/862/37615#MediaProcessTaskInput)

	* <font color="#dd0000">**删除成员**：</font>AdaptiveDynamicStreamingTaskSet

* [SampleSnapshotTemplate](https://cloud.tencent.com/document/api/862/37615#SampleSnapshotTemplate)

	* 新增成员：ResolutionAdaptive

* [SnapshotByTimeOffsetTemplate](https://cloud.tencent.com/document/api/862/37615#SnapshotByTimeOffsetTemplate)

	* 新增成员：ResolutionAdaptive

* [WorkflowTask](https://cloud.tencent.com/document/api/862/37615#WorkflowTask)

	* 新增成员：AiContentReviewResultSet, AiRecognitionResultSet


### 第 3 次发布

发布时间：2019-09-26 21:52:30

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeUserInfo](https://cloud.tencent.com/document/api/862/37611)

	* 新增出参：OldMpsUser


新增数据结构：

* [AdaptiveDynamicStreamingTaskInput](https://cloud.tencent.com/document/api/862/37615#AdaptiveDynamicStreamingTaskInput)

修改数据结构：

* [MediaProcessTaskInput](https://cloud.tencent.com/document/api/862/37615#MediaProcessTaskInput)

	* 新增成员：AdaptiveDynamicStreamingTaskSet


### 第 2 次发布

发布时间：2019-09-05 17:45:18

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [ProcessLiveMedia](https://cloud.tencent.com/document/api/862/37802)

修改接口：

* [CreateTranscodeTemplate](https://cloud.tencent.com/document/api/862/37605)

	* 新增入参：TEHDConfig

* [DescribeTranscodeTemplates](https://cloud.tencent.com/document/api/862/37593)

	* 新增入参：TEHDType

* [ModifyTranscodeTemplate](https://cloud.tencent.com/document/api/862/37587)

	* 新增入参：TEHDConfig


新增数据结构：

* [TEHDConfig](https://cloud.tencent.com/document/api/862/37615#TEHDConfig)
* [TEHDConfigForUpdate](https://cloud.tencent.com/document/api/862/37615#TEHDConfigForUpdate)

<font color="#dd0000">**删除数据结构**：</font>

* AdaptiveDynamicStreamingTaskInput

修改数据结构：

* [MediaProcessTaskInput](https://cloud.tencent.com/document/api/862/37615#MediaProcessTaskInput)

	* <font color="#dd0000">**删除成员**：</font>AdaptiveDynamicStreamingTaskSet

* [TranscodeTemplate](https://cloud.tencent.com/document/api/862/37615#TranscodeTemplate)

	* 新增成员：TEHDConfig


### 第 1 次发布

发布时间：2019-08-27 15:11:53

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateAnimatedGraphicsTemplate](https://cloud.tencent.com/document/api/862/37609)
* [CreateImageSpriteTemplate](https://cloud.tencent.com/document/api/862/37608)
* [CreateSampleSnapshotTemplate](https://cloud.tencent.com/document/api/862/37607)
* [CreateSnapshotByTimeOffsetTemplate](https://cloud.tencent.com/document/api/862/37606)
* [CreateTranscodeTemplate](https://cloud.tencent.com/document/api/862/37605)
* [CreateWatermarkTemplate](https://cloud.tencent.com/document/api/862/37604)
* [CreateWorkflow](https://cloud.tencent.com/document/api/862/37583)
* [DeleteAnimatedGraphicsTemplate](https://cloud.tencent.com/document/api/862/37603)
* [DeleteImageSpriteTemplate](https://cloud.tencent.com/document/api/862/37602)
* [DeleteSampleSnapshotTemplate](https://cloud.tencent.com/document/api/862/37601)
* [DeleteSnapshotByTimeOffsetTemplate](https://cloud.tencent.com/document/api/862/37600)
* [DeleteTranscodeTemplate](https://cloud.tencent.com/document/api/862/37599)
* [DeleteWatermarkTemplate](https://cloud.tencent.com/document/api/862/37598)
* [DeleteWorkflow](https://cloud.tencent.com/document/api/862/37582)
* [DescribeAnimatedGraphicsTemplates](https://cloud.tencent.com/document/api/862/37597)
* [DescribeImageSpriteTemplates](https://cloud.tencent.com/document/api/862/37596)
* [DescribeSampleSnapshotTemplates](https://cloud.tencent.com/document/api/862/37595)
* [DescribeSnapshotByTimeOffsetTemplates](https://cloud.tencent.com/document/api/862/37594)
* [DescribeTaskDetail](https://cloud.tencent.com/document/api/862/37614)
* [DescribeTasks](https://cloud.tencent.com/document/api/862/37613)
* [DescribeTranscodeTemplates](https://cloud.tencent.com/document/api/862/37593)
* [DescribeUserInfo](https://cloud.tencent.com/document/api/862/37611)
* [DescribeWatermarkTemplates](https://cloud.tencent.com/document/api/862/37592)
* [DescribeWorkflows](https://cloud.tencent.com/document/api/862/37581)
* [DisableWorkflow](https://cloud.tencent.com/document/api/862/37580)
* [EnableWorkflow](https://cloud.tencent.com/document/api/862/37579)
* [ModifyAnimatedGraphicsTemplate](https://cloud.tencent.com/document/api/862/37591)
* [ModifyImageSpriteTemplate](https://cloud.tencent.com/document/api/862/37590)
* [ModifySampleSnapshotTemplate](https://cloud.tencent.com/document/api/862/37589)
* [ModifySnapshotByTimeOffsetTemplate](https://cloud.tencent.com/document/api/862/37588)
* [ModifyTranscodeTemplate](https://cloud.tencent.com/document/api/862/37587)
* [ModifyWatermarkTemplate](https://cloud.tencent.com/document/api/862/37586)
* [ProcessMedia](https://cloud.tencent.com/document/api/862/37578)
* [ResetWorkflow](https://cloud.tencent.com/document/api/862/37585)

新增数据结构：

* [AdaptiveDynamicStreamingTaskInput](https://cloud.tencent.com/document/api/862/37615#AdaptiveDynamicStreamingTaskInput)
* [AiAnalysisTaskInput](https://cloud.tencent.com/document/api/862/37615#AiAnalysisTaskInput)
* [AiContentReviewTaskInput](https://cloud.tencent.com/document/api/862/37615#AiContentReviewTaskInput)
* [AiRecognitionTaskInput](https://cloud.tencent.com/document/api/862/37615#AiRecognitionTaskInput)
* [AnimatedGraphicTaskInput](https://cloud.tencent.com/document/api/862/37615#AnimatedGraphicTaskInput)
* [AnimatedGraphicsTemplate](https://cloud.tencent.com/document/api/862/37615#AnimatedGraphicsTemplate)
* [AudioTemplateInfo](https://cloud.tencent.com/document/api/862/37615#AudioTemplateInfo)
* [AudioTemplateInfoForUpdate](https://cloud.tencent.com/document/api/862/37615#AudioTemplateInfoForUpdate)
* [CosFileUploadTrigger](https://cloud.tencent.com/document/api/862/37615#CosFileUploadTrigger)
* [CosInputInfo](https://cloud.tencent.com/document/api/862/37615#CosInputInfo)
* [CosOutputStorage](https://cloud.tencent.com/document/api/862/37615#CosOutputStorage)
* [ImageSpriteTaskInput](https://cloud.tencent.com/document/api/862/37615#ImageSpriteTaskInput)
* [ImageSpriteTemplate](https://cloud.tencent.com/document/api/862/37615#ImageSpriteTemplate)
* [ImageWatermarkInput](https://cloud.tencent.com/document/api/862/37615#ImageWatermarkInput)
* [ImageWatermarkInputForUpdate](https://cloud.tencent.com/document/api/862/37615#ImageWatermarkInputForUpdate)
* [ImageWatermarkTemplate](https://cloud.tencent.com/document/api/862/37615#ImageWatermarkTemplate)
* [MediaAnimatedGraphicsItem](https://cloud.tencent.com/document/api/862/37615#MediaAnimatedGraphicsItem)
* [MediaAudioStreamItem](https://cloud.tencent.com/document/api/862/37615#MediaAudioStreamItem)
* [MediaImageSpriteItem](https://cloud.tencent.com/document/api/862/37615#MediaImageSpriteItem)
* [MediaInputInfo](https://cloud.tencent.com/document/api/862/37615#MediaInputInfo)
* [MediaMetaData](https://cloud.tencent.com/document/api/862/37615#MediaMetaData)
* [MediaProcessTaskAnimatedGraphicResult](https://cloud.tencent.com/document/api/862/37615#MediaProcessTaskAnimatedGraphicResult)
* [MediaProcessTaskImageSpriteResult](https://cloud.tencent.com/document/api/862/37615#MediaProcessTaskImageSpriteResult)
* [MediaProcessTaskInput](https://cloud.tencent.com/document/api/862/37615#MediaProcessTaskInput)
* [MediaProcessTaskResult](https://cloud.tencent.com/document/api/862/37615#MediaProcessTaskResult)
* [MediaProcessTaskSampleSnapshotResult](https://cloud.tencent.com/document/api/862/37615#MediaProcessTaskSampleSnapshotResult)
* [MediaProcessTaskSnapshotByTimeOffsetResult](https://cloud.tencent.com/document/api/862/37615#MediaProcessTaskSnapshotByTimeOffsetResult)
* [MediaProcessTaskTranscodeResult](https://cloud.tencent.com/document/api/862/37615#MediaProcessTaskTranscodeResult)
* [MediaSampleSnapshotItem](https://cloud.tencent.com/document/api/862/37615#MediaSampleSnapshotItem)
* [MediaSnapshotByTimeOffsetItem](https://cloud.tencent.com/document/api/862/37615#MediaSnapshotByTimeOffsetItem)
* [MediaSnapshotByTimePicInfoItem](https://cloud.tencent.com/document/api/862/37615#MediaSnapshotByTimePicInfoItem)
* [MediaTranscodeItem](https://cloud.tencent.com/document/api/862/37615#MediaTranscodeItem)
* [MediaVideoStreamItem](https://cloud.tencent.com/document/api/862/37615#MediaVideoStreamItem)
* [NumberFormat](https://cloud.tencent.com/document/api/862/37615#NumberFormat)
* [SampleSnapshotTaskInput](https://cloud.tencent.com/document/api/862/37615#SampleSnapshotTaskInput)
* [SampleSnapshotTemplate](https://cloud.tencent.com/document/api/862/37615#SampleSnapshotTemplate)
* [SnapshotByTimeOffsetTaskInput](https://cloud.tencent.com/document/api/862/37615#SnapshotByTimeOffsetTaskInput)
* [SnapshotByTimeOffsetTemplate](https://cloud.tencent.com/document/api/862/37615#SnapshotByTimeOffsetTemplate)
* [SvgWatermarkInput](https://cloud.tencent.com/document/api/862/37615#SvgWatermarkInput)
* [SvgWatermarkInputForUpdate](https://cloud.tencent.com/document/api/862/37615#SvgWatermarkInputForUpdate)
* [TaskNotifyConfig](https://cloud.tencent.com/document/api/862/37615#TaskNotifyConfig)
* [TaskOutputStorage](https://cloud.tencent.com/document/api/862/37615#TaskOutputStorage)
* [TaskSimpleInfo](https://cloud.tencent.com/document/api/862/37615#TaskSimpleInfo)
* [TextWatermarkTemplateInput](https://cloud.tencent.com/document/api/862/37615#TextWatermarkTemplateInput)
* [TextWatermarkTemplateInputForUpdate](https://cloud.tencent.com/document/api/862/37615#TextWatermarkTemplateInputForUpdate)
* [TranscodeTaskInput](https://cloud.tencent.com/document/api/862/37615#TranscodeTaskInput)
* [TranscodeTemplate](https://cloud.tencent.com/document/api/862/37615#TranscodeTemplate)
* [VideoTemplateInfo](https://cloud.tencent.com/document/api/862/37615#VideoTemplateInfo)
* [VideoTemplateInfoForUpdate](https://cloud.tencent.com/document/api/862/37615#VideoTemplateInfoForUpdate)
* [WatermarkInput](https://cloud.tencent.com/document/api/862/37615#WatermarkInput)
* [WatermarkTemplate](https://cloud.tencent.com/document/api/862/37615#WatermarkTemplate)
* [WorkflowInfo](https://cloud.tencent.com/document/api/862/37615#WorkflowInfo)
* [WorkflowTask](https://cloud.tencent.com/document/api/862/37615#WorkflowTask)
* [WorkflowTrigger](https://cloud.tencent.com/document/api/862/37615#WorkflowTrigger)




## 医疗报告结构化(mrs) 版本：2020-09-10

### 第 26 次发布

发布时间：2024-06-14 02:16:42

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [BirthCert](https://cloud.tencent.com/document/api/1314/56230#BirthCert)

	* 新增成员：Page

	* <font color="#dd0000">**修改成员**：</font>NeonatalInfo, MotherInfo, FatherInfo, IssueInfo

* [BloodPressureItem](https://cloud.tencent.com/document/api/1314/56230#BloodPressureItem)

	* 新增成员：Page

* [Check](https://cloud.tencent.com/document/api/1314/56230#Check)

	* 新增成员：Page

* [CovidItemsInfo](https://cloud.tencent.com/document/api/1314/56230#CovidItemsInfo)

	* 新增成员：Page

	* <font color="#dd0000">**修改成员**：</font>CovidItems, Version

* [DiagCert](https://cloud.tencent.com/document/api/1314/56230#DiagCert)

	* 新增成员：Page

* [DischargeInfoBlock](https://cloud.tencent.com/document/api/1314/56230#DischargeInfoBlock)

	* 新增成员：Page

	* <font color="#dd0000">**修改成员**：</font>DiseaseHistory, PersonalHistory, DrugHistory, TreatmentRecord, ParagraphBlock

* [Electrocardiogram](https://cloud.tencent.com/document/api/1314/56230#Electrocardiogram)

	* 新增成员：Page

* [Endoscopy](https://cloud.tencent.com/document/api/1314/56230#Endoscopy)

	* 新增成员：Page

* [EyeItemsInfo](https://cloud.tencent.com/document/api/1314/56230#EyeItemsInfo)

	* 新增成员：Page

	* <font color="#dd0000">**修改成员**：</font>EyeItems, Version

* [FirstPage](https://cloud.tencent.com/document/api/1314/56230#FirstPage)

	* 新增成员：Page

	* <font color="#dd0000">**修改成员**：</font>DischargeDiagnosis, PathologicalDiagnosis, ClinicalDiagnosis, DamagePoi, Fp2NdItems

* [Hospitalization](https://cloud.tencent.com/document/api/1314/56230#Hospitalization)

	* 新增成员：Page

* [Indicator](https://cloud.tencent.com/document/api/1314/56230#Indicator)

	* 新增成员：Page

* [IndicatorV3](https://cloud.tencent.com/document/api/1314/56230#IndicatorV3)

	* 新增成员：Page

* [KeyValueItem](https://cloud.tencent.com/document/api/1314/56230#KeyValueItem)

	* 新增成员：Page

* [Maternity](https://cloud.tencent.com/document/api/1314/56230#Maternity)

	* 新增成员：Page

	* <font color="#dd0000">**修改成员**：</font>Desc, Summary, OcrText

* [MedDoc](https://cloud.tencent.com/document/api/1314/56230#MedDoc)

	* 新增成员：Page

	* <font color="#dd0000">**修改成员**：</font>Advice, Diagnosis, DiseaseMedicalHistory, PersonalMedicalHistory, ObstericalMedicalHistory, FamilyMedicalHistory, MenstrualMedicalHistory, TreatmentRecord

* [MedicalRecordInfo](https://cloud.tencent.com/document/api/1314/56230#MedicalRecordInfo)

	* 新增成员：Page

* [PathologyV2](https://cloud.tencent.com/document/api/1314/56230#PathologyV2)

	* 新增成员：Page

	* <font color="#dd0000">**修改成员**：</font>PathologicalReportType, Desc, Summary, ReportText, LymphTotal, LymphNodes, Ihc, Clinical, Precancer, Malignant, Benigntumor, SampleType, LymphSize, Molecular

* [Prescription](https://cloud.tencent.com/document/api/1314/56230#Prescription)

	* 新增成员：Page

* [ResultInfo](https://cloud.tencent.com/document/api/1314/56230#ResultInfo)

	* 新增成员：Page

	* <font color="#dd0000">**修改成员**：</font>Text, Items

* [Surgery](https://cloud.tencent.com/document/api/1314/56230#Surgery)

	* 新增成员：Page

	* <font color="#dd0000">**修改成员**：</font>SurgeryHistory, OtherInfo

* [TextTypeListBlock](https://cloud.tencent.com/document/api/1314/56230#TextTypeListBlock)

	* 新增成员：Page

* [TimelineInformation](https://cloud.tencent.com/document/api/1314/56230#TimelineInformation)

	* 新增成员：Page

	* <font color="#dd0000">**修改成员**：</font>Timeline

* [VaccineCertificate](https://cloud.tencent.com/document/api/1314/56230#VaccineCertificate)

	* 新增成员：Page

* [ValueUnitItem](https://cloud.tencent.com/document/api/1314/56230#ValueUnitItem)

	* 新增成员：Page


### 第 25 次发布

发布时间：2024-05-09 01:20:07

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DrugInstructionObject](https://cloud.tencent.com/document/api/1314/105921)

新增数据结构：

* [BiologicalProductInfo](https://cloud.tencent.com/document/api/1314/56230#BiologicalProductInfo)
* [BiologicalProductInfoAdverseReaction](https://cloud.tencent.com/document/api/1314/56230#BiologicalProductInfoAdverseReaction)
* [BiologicalProductInfoApproval](https://cloud.tencent.com/document/api/1314/56230#BiologicalProductInfoApproval)
* [BiologicalProductInfoBrochure](https://cloud.tencent.com/document/api/1314/56230#BiologicalProductInfoBrochure)
* [BiologicalProductInfoContraindications](https://cloud.tencent.com/document/api/1314/56230#BiologicalProductInfoContraindications)
* [BiologicalProductInfoDosage](https://cloud.tencent.com/document/api/1314/56230#BiologicalProductInfoDosage)
* [BiologicalProductInfoExecutiveStandards](https://cloud.tencent.com/document/api/1314/56230#BiologicalProductInfoExecutiveStandards)
* [BiologicalProductInfoIndications](https://cloud.tencent.com/document/api/1314/56230#BiologicalProductInfoIndications)
* [BiologicalProductInfoIngredientAndAppearance](https://cloud.tencent.com/document/api/1314/56230#BiologicalProductInfoIngredientAndAppearance)
* [BiologicalProductInfoManufacturer](https://cloud.tencent.com/document/api/1314/56230#BiologicalProductInfoManufacturer)
* [BiologicalProductInfoName](https://cloud.tencent.com/document/api/1314/56230#BiologicalProductInfoName)
* [BiologicalProductInfoPackaging](https://cloud.tencent.com/document/api/1314/56230#BiologicalProductInfoPackaging)
* [BiologicalProductInfoPrecautions](https://cloud.tencent.com/document/api/1314/56230#BiologicalProductInfoPrecautions)
* [BiologicalProductInfoStorage](https://cloud.tencent.com/document/api/1314/56230#BiologicalProductInfoStorage)
* [BiologicalProductInfoVaccinationTarget](https://cloud.tencent.com/document/api/1314/56230#BiologicalProductInfoVaccinationTarget)
* [BiologicalProductInfoValidityPeriod](https://cloud.tencent.com/document/api/1314/56230#BiologicalProductInfoValidityPeriod)
* [ChemicalProductInfo](https://cloud.tencent.com/document/api/1314/56230#ChemicalProductInfo)
* [ChemicalProductInfoActiveIngredient](https://cloud.tencent.com/document/api/1314/56230#ChemicalProductInfoActiveIngredient)
* [ChemicalProductInfoAdverseReaction](https://cloud.tencent.com/document/api/1314/56230#ChemicalProductInfoAdverseReaction)
* [ChemicalProductInfoAppearance](https://cloud.tencent.com/document/api/1314/56230#ChemicalProductInfoAppearance)
* [ChemicalProductInfoApproval](https://cloud.tencent.com/document/api/1314/56230#ChemicalProductInfoApproval)
* [ChemicalProductInfoBrochure](https://cloud.tencent.com/document/api/1314/56230#ChemicalProductInfoBrochure)
* [ChemicalProductInfoClinicalTrial](https://cloud.tencent.com/document/api/1314/56230#ChemicalProductInfoClinicalTrial)
* [ChemicalProductInfoContraindications](https://cloud.tencent.com/document/api/1314/56230#ChemicalProductInfoContraindications)
* [ChemicalProductInfoDosage](https://cloud.tencent.com/document/api/1314/56230#ChemicalProductInfoDosage)
* [ChemicalProductInfoExecutiveStandards](https://cloud.tencent.com/document/api/1314/56230#ChemicalProductInfoExecutiveStandards)
* [ChemicalProductInfoGeriatricUse](https://cloud.tencent.com/document/api/1314/56230#ChemicalProductInfoGeriatricUse)
* [ChemicalProductInfoIndications](https://cloud.tencent.com/document/api/1314/56230#ChemicalProductInfoIndications)
* [ChemicalProductInfoInteractions](https://cloud.tencent.com/document/api/1314/56230#ChemicalProductInfoInteractions)
* [ChemicalProductInfoManufacturer](https://cloud.tencent.com/document/api/1314/56230#ChemicalProductInfoManufacturer)
* [ChemicalProductInfoName](https://cloud.tencent.com/document/api/1314/56230#ChemicalProductInfoName)
* [ChemicalProductInfoOverdose](https://cloud.tencent.com/document/api/1314/56230#ChemicalProductInfoOverdose)
* [ChemicalProductInfoPackaging](https://cloud.tencent.com/document/api/1314/56230#ChemicalProductInfoPackaging)
* [ChemicalProductInfoPediatricUse](https://cloud.tencent.com/document/api/1314/56230#ChemicalProductInfoPediatricUse)
* [ChemicalProductInfoPharmacokinetics](https://cloud.tencent.com/document/api/1314/56230#ChemicalProductInfoPharmacokinetics)
* [ChemicalProductInfoPharmacologyToxicology](https://cloud.tencent.com/document/api/1314/56230#ChemicalProductInfoPharmacologyToxicology)
* [ChemicalProductInfoPrecautions](https://cloud.tencent.com/document/api/1314/56230#ChemicalProductInfoPrecautions)
* [ChemicalProductInfoPregnancyLactationUse](https://cloud.tencent.com/document/api/1314/56230#ChemicalProductInfoPregnancyLactationUse)
* [ChemicalProductInfoStorage](https://cloud.tencent.com/document/api/1314/56230#ChemicalProductInfoStorage)
* [ChemicalProductInfoValidityPeriod](https://cloud.tencent.com/document/api/1314/56230#ChemicalProductInfoValidityPeriod)

### 第 24 次发布

发布时间：2024-03-08 09:57:15

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [TurnPDFToObject](https://cloud.tencent.com/document/api/1314/97928)

	* 新增入参：TextBasedPdfFlag

* [TurnPDFToObjectAsync](https://cloud.tencent.com/document/api/1314/101007)

	* 新增入参：TextBasedPdfFlag


### 第 23 次发布

发布时间：2024-01-08 00:14:42

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [PatientInfo](https://cloud.tencent.com/document/api/1314/56230#PatientInfo)


### 第 22 次发布

发布时间：2024-01-04 01:19:26

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [ImageMaskAsync](https://cloud.tencent.com/document/api/1314/102821)
* [ImageMaskAsyncGetResult](https://cloud.tencent.com/document/api/1314/102820)

### 第 21 次发布

发布时间：2023-12-08 02:10:30

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [ImageMask](https://cloud.tencent.com/document/api/1314/102293)

新增数据结构：

* [ImageMaskFlags](https://cloud.tencent.com/document/api/1314/56230#ImageMaskFlags)

### 第 20 次发布

发布时间：2023-11-30 05:22:15

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [Hospitalization](https://cloud.tencent.com/document/api/1314/56230#Hospitalization)

	* 新增成员：AdmissionDiagnosis

* [IndicatorV3](https://cloud.tencent.com/document/api/1314/56230#IndicatorV3)

	* 新增成员：TableIndicators

	* <font color="#dd0000">**修改成员**：</font>TableIndictors, Version

* [TreatmentRecord](https://cloud.tencent.com/document/api/1314/56230#TreatmentRecord)

	* 新增成员：AdmissionCondition


### 第 19 次发布

发布时间：2023-11-01 01:18:18

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [TurnPDFToObjectAsync](https://cloud.tencent.com/document/api/1314/101007)
* [TurnPDFToObjectAsyncGetResult](https://cloud.tencent.com/document/api/1314/101006)

### 第 18 次发布

发布时间：2023-10-23 00:16:02

本次发布包含了以下内容：

改善已有的文档。

新增数据结构：

* [BlockTitle](https://cloud.tencent.com/document/api/1314/56230#BlockTitle)

修改数据结构：

* [Check](https://cloud.tencent.com/document/api/1314/56230#Check)

	* 新增成员：BlockTitle

* [Indicator](https://cloud.tencent.com/document/api/1314/56230#Indicator)

	* 新增成员：BlockTitle


### 第 17 次发布

发布时间：2023-09-11 11:36:02

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [TurnPDFToObject](https://cloud.tencent.com/document/api/1314/97928)

新增数据结构：

* [Block](https://cloud.tencent.com/document/api/1314/56230#Block)
* [BloodPressureItem](https://cloud.tencent.com/document/api/1314/56230#BloodPressureItem)
* [ChestCircumferenceItem](https://cloud.tencent.com/document/api/1314/56230#ChestCircumferenceItem)
* [GeneralExaminationBaseItem](https://cloud.tencent.com/document/api/1314/56230#GeneralExaminationBaseItem)
* [GeneralExaminationBriefSummary](https://cloud.tencent.com/document/api/1314/56230#GeneralExaminationBriefSummary)
* [GeneralExaminationOthers](https://cloud.tencent.com/document/api/1314/56230#GeneralExaminationOthers)
* [GeneralExaminationVitalSign](https://cloud.tencent.com/document/api/1314/56230#GeneralExaminationVitalSign)
* [GeneralExaminationVitalSignBloodPressure](https://cloud.tencent.com/document/api/1314/56230#GeneralExaminationVitalSignBloodPressure)
* [GynaecologyAdnexal](https://cloud.tencent.com/document/api/1314/56230#GynaecologyAdnexal)
* [GynaecologyBaseItem](https://cloud.tencent.com/document/api/1314/56230#GynaecologyBaseItem)
* [GynaecologyBriefSummary](https://cloud.tencent.com/document/api/1314/56230#GynaecologyBriefSummary)
* [GynaecologyCervix](https://cloud.tencent.com/document/api/1314/56230#GynaecologyCervix)
* [GynaecologyMenstrualHistory](https://cloud.tencent.com/document/api/1314/56230#GynaecologyMenstrualHistory)
* [GynaecologyPelvicCavity](https://cloud.tencent.com/document/api/1314/56230#GynaecologyPelvicCavity)
* [GynaecologyUterus](https://cloud.tencent.com/document/api/1314/56230#GynaecologyUterus)
* [GynaecologyVagina](https://cloud.tencent.com/document/api/1314/56230#GynaecologyVagina)
* [GynaecologyVulva](https://cloud.tencent.com/document/api/1314/56230#GynaecologyVulva)
* [HearingItem](https://cloud.tencent.com/document/api/1314/56230#HearingItem)
* [InternalMedicineAbdomen](https://cloud.tencent.com/document/api/1314/56230#InternalMedicineAbdomen)
* [InternalMedicineAbdomenGallBladder](https://cloud.tencent.com/document/api/1314/56230#InternalMedicineAbdomenGallBladder)
* [InternalMedicineAbdomenKidney](https://cloud.tencent.com/document/api/1314/56230#InternalMedicineAbdomenKidney)
* [InternalMedicineAbdomenLiver](https://cloud.tencent.com/document/api/1314/56230#InternalMedicineAbdomenLiver)
* [InternalMedicineAbdomenPancreas](https://cloud.tencent.com/document/api/1314/56230#InternalMedicineAbdomenPancreas)
* [InternalMedicineAbdomenSpleen](https://cloud.tencent.com/document/api/1314/56230#InternalMedicineAbdomenSpleen)
* [InternalMedicineBaseItem](https://cloud.tencent.com/document/api/1314/56230#InternalMedicineBaseItem)
* [InternalMedicineBriefSummary](https://cloud.tencent.com/document/api/1314/56230#InternalMedicineBriefSummary)
* [InternalMedicineHeart](https://cloud.tencent.com/document/api/1314/56230#InternalMedicineHeart)
* [InternalMedicineRespiratorySystem](https://cloud.tencent.com/document/api/1314/56230#InternalMedicineRespiratorySystem)
* [InternalMedicineVessel](https://cloud.tencent.com/document/api/1314/56230#InternalMedicineVessel)
* [KeyValueItem](https://cloud.tencent.com/document/api/1314/56230#KeyValueItem)
* [OphthalmologyBareEyeSight](https://cloud.tencent.com/document/api/1314/56230#OphthalmologyBareEyeSight)
* [OphthalmologyBaseItem](https://cloud.tencent.com/document/api/1314/56230#OphthalmologyBaseItem)
* [OphthalmologyBriefSummary](https://cloud.tencent.com/document/api/1314/56230#OphthalmologyBriefSummary)
* [OphthalmologyColourVision](https://cloud.tencent.com/document/api/1314/56230#OphthalmologyColourVision)
* [OphthalmologyCorrectedVisualAcuity](https://cloud.tencent.com/document/api/1314/56230#OphthalmologyCorrectedVisualAcuity)
* [OphthalmologyFundoscopy](https://cloud.tencent.com/document/api/1314/56230#OphthalmologyFundoscopy)
* [OtolaryngologyBaseItem](https://cloud.tencent.com/document/api/1314/56230#OtolaryngologyBaseItem)
* [OtolaryngologyBriefSummary](https://cloud.tencent.com/document/api/1314/56230#OtolaryngologyBriefSummary)
* [OtolaryngologyEar](https://cloud.tencent.com/document/api/1314/56230#OtolaryngologyEar)
* [OtolaryngologyLarynx](https://cloud.tencent.com/document/api/1314/56230#OtolaryngologyLarynx)
* [OtolaryngologyNose](https://cloud.tencent.com/document/api/1314/56230#OtolaryngologyNose)
* [PdfInfo](https://cloud.tencent.com/document/api/1314/56230#PdfInfo)
* [PhysicalBaseItem](https://cloud.tencent.com/document/api/1314/56230#PhysicalBaseItem)
* [PhysicalExamination](https://cloud.tencent.com/document/api/1314/56230#PhysicalExamination)
* [PhysicalExaminationV1](https://cloud.tencent.com/document/api/1314/56230#PhysicalExaminationV1)
* [StomatologyBaseItem](https://cloud.tencent.com/document/api/1314/56230#StomatologyBaseItem)
* [StomatologyBriefSummary](https://cloud.tencent.com/document/api/1314/56230#StomatologyBriefSummary)
* [StomatologyGingiva](https://cloud.tencent.com/document/api/1314/56230#StomatologyGingiva)
* [StomatologyPeriodontics](https://cloud.tencent.com/document/api/1314/56230#StomatologyPeriodontics)
* [StomatologyToothDecay](https://cloud.tencent.com/document/api/1314/56230#StomatologyToothDecay)
* [SurgeryAnorectal](https://cloud.tencent.com/document/api/1314/56230#SurgeryAnorectal)
* [SurgeryBaseItem](https://cloud.tencent.com/document/api/1314/56230#SurgeryBaseItem)
* [SurgeryBreast](https://cloud.tencent.com/document/api/1314/56230#SurgeryBreast)
* [SurgeryBriefSummary](https://cloud.tencent.com/document/api/1314/56230#SurgeryBriefSummary)
* [SurgeryHeadNeck](https://cloud.tencent.com/document/api/1314/56230#SurgeryHeadNeck)
* [SurgeryLymphNode](https://cloud.tencent.com/document/api/1314/56230#SurgeryLymphNode)
* [SurgerySkin](https://cloud.tencent.com/document/api/1314/56230#SurgerySkin)
* [SurgerySpinalExtremities](https://cloud.tencent.com/document/api/1314/56230#SurgerySpinalExtremities)
* [SurgeryThyroid](https://cloud.tencent.com/document/api/1314/56230#SurgeryThyroid)
* [SurgeryUrogenitalSystem](https://cloud.tencent.com/document/api/1314/56230#SurgeryUrogenitalSystem)
* [TextTypeListBlock](https://cloud.tencent.com/document/api/1314/56230#TextTypeListBlock)
* [ValueUnitItem](https://cloud.tencent.com/document/api/1314/56230#ValueUnitItem)

### 第 16 次发布

发布时间：2023-09-07 02:12:57

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [Organ](https://cloud.tencent.com/document/api/1314/56230#Organ)

	* 新增成员：IsthmusThickness

	* <font color="#dd0000">**修改成员**：</font>Part, Size, Envelope, Edge, InnerEcho, Gland, Shape, Thickness, ShapeAttr, CDFI, SymDesc, SizeStatus, Outline, Structure, Density, Vas, Cysticwall, Capsule, IsthmusThicknese, InnerEchoDistribution, Src, Index, Transparent, MriAdc, MriDwi, MriT1, MriT2, CtHu, Suvmax, Metabolism, RadioactiveUptake, LymphEnlargement, ImageFeature, Duct, Trend, Operation, Coords

* [ParagraphBlock](https://cloud.tencent.com/document/api/1314/56230#ParagraphBlock)

	* 新增成员：MenstrualHistoryText

	* <font color="#dd0000">**修改成员**：</font>IncisionHealingText, AuxiliaryExaminationText, SpecialExamText, OutpatientDiagnosisText, AdmissionConditionText, CheckAndTreatmentProcessText, SymptomsAndSignsText, DischargeInstructionsText, AdmissionDiagnosisText, SurgeryConditionText, PathologicalDiagnosisText, DischargeConditionText, CheckRecordText, ChiefComplaintText, DischargeDiagnosisText, MainDiseaseHistoryText, DiseasePresentText, PersonalHistoryText, MenstruallHistoryText, ObstericalHistoryText, FamilyHistoryText, AllergyHistoryText, DiseaseHistoryText, OtherDiagnosisText, BodyExaminationText, SpecialistExaminationText, TreatmentResultText

* [ReportInfo](https://cloud.tencent.com/document/api/1314/56230#ReportInfo)

	* 新增成员：BedNo

* [TuberInfo](https://cloud.tencent.com/document/api/1314/56230#TuberInfo)

	* 新增成员：IsthmusThickness

	* <font color="#dd0000">**修改成员**：</font>Type, Part, Size, Multiple, AspectRatio, Edge, InnerEcho, RearEcho, Elastic, Shape, ShapeAttr, SkinMedulla, Trend, Calcification, Envelope, Enhancement, LymphEnlargement, LymphDoor, Activity, Operation, CDFI, Index, SizeStatus, InnerEchoDistribution, InnerEchoType, Outline, Structure, Density, Vas, Cysticwall, Capsule, IsthmusThicknese, Src, Transparent, MriAdc, MriDwi, MriT1, MriT2, CtHu, Suvmax, Metabolism, RadioactiveUptake, SymDesc, ImageFeature, Coords


### 第 15 次发布

发布时间：2023-03-02 01:30:06

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [ImageToObject](https://cloud.tencent.com/document/api/1314/56228)

	* 新增入参：ReportTypeVersion

* [TextToObject](https://cloud.tencent.com/document/api/1314/56226)

	* 新增入参：ReportTypeVersion


新增数据结构：

* [AdmissionConditionBlock](https://cloud.tencent.com/document/api/1314/56230#AdmissionConditionBlock)
* [AdmissionDiagnosisBlock](https://cloud.tencent.com/document/api/1314/56230#AdmissionDiagnosisBlock)
* [BaseInfo](https://cloud.tencent.com/document/api/1314/56230#BaseInfo)
* [BaseItem](https://cloud.tencent.com/document/api/1314/56230#BaseItem)
* [BaseItem2](https://cloud.tencent.com/document/api/1314/56230#BaseItem2)
* [BaseItem3](https://cloud.tencent.com/document/api/1314/56230#BaseItem3)
* [BirthCert](https://cloud.tencent.com/document/api/1314/56230#BirthCert)
* [BirthPlaceBlock](https://cloud.tencent.com/document/api/1314/56230#BirthPlaceBlock)
* [BlockInfoV2](https://cloud.tencent.com/document/api/1314/56230#BlockInfoV2)
* [BloodPressureBlock](https://cloud.tencent.com/document/api/1314/56230#BloodPressureBlock)
* [BodyExaminationBlock](https://cloud.tencent.com/document/api/1314/56230#BodyExaminationBlock)
* [BodyTemperatureBlock](https://cloud.tencent.com/document/api/1314/56230#BodyTemperatureBlock)
* [ChiefComplaintBlock](https://cloud.tencent.com/document/api/1314/56230#ChiefComplaintBlock)
* [ChiefComplaintDetailBlock](https://cloud.tencent.com/document/api/1314/56230#ChiefComplaintDetailBlock)
* [ClinicalStaging](https://cloud.tencent.com/document/api/1314/56230#ClinicalStaging)
* [Coord](https://cloud.tencent.com/document/api/1314/56230#Coord)
* [CovidItem](https://cloud.tencent.com/document/api/1314/56230#CovidItem)
* [CovidItemsInfo](https://cloud.tencent.com/document/api/1314/56230#CovidItemsInfo)
* [DeathDateBlock](https://cloud.tencent.com/document/api/1314/56230#DeathDateBlock)
* [DescInfo](https://cloud.tencent.com/document/api/1314/56230#DescInfo)
* [DetailInformation](https://cloud.tencent.com/document/api/1314/56230#DetailInformation)
* [DischargeConditionBlock](https://cloud.tencent.com/document/api/1314/56230#DischargeConditionBlock)
* [DischargeDiagnosisBlock](https://cloud.tencent.com/document/api/1314/56230#DischargeDiagnosisBlock)
* [DischargeInfoBlock](https://cloud.tencent.com/document/api/1314/56230#DischargeInfoBlock)
* [DiseaseHistoryBlock](https://cloud.tencent.com/document/api/1314/56230#DiseaseHistoryBlock)
* [DiseasePresentBlock](https://cloud.tencent.com/document/api/1314/56230#DiseasePresentBlock)
* [DosageBlock](https://cloud.tencent.com/document/api/1314/56230#DosageBlock)
* [DrugHistoryBlock](https://cloud.tencent.com/document/api/1314/56230#DrugHistoryBlock)
* [DrugListBlock](https://cloud.tencent.com/document/api/1314/56230#DrugListBlock)
* [Exame](https://cloud.tencent.com/document/api/1314/56230#Exame)
* [EyeChildItem](https://cloud.tencent.com/document/api/1314/56230#EyeChildItem)
* [EyeItem](https://cloud.tencent.com/document/api/1314/56230#EyeItem)
* [EyeItemsInfo](https://cloud.tencent.com/document/api/1314/56230#EyeItemsInfo)
* [FamilyHistoryBlock](https://cloud.tencent.com/document/api/1314/56230#FamilyHistoryBlock)
* [FertilityHistoryBlock](https://cloud.tencent.com/document/api/1314/56230#FertilityHistoryBlock)
* [Fetus](https://cloud.tencent.com/document/api/1314/56230#Fetus)
* [FieldInfo](https://cloud.tencent.com/document/api/1314/56230#FieldInfo)
* [Fp2NdItem](https://cloud.tencent.com/document/api/1314/56230#Fp2NdItem)
* [GeneticHistoryBlock](https://cloud.tencent.com/document/api/1314/56230#GeneticHistoryBlock)
* [HistologyClass](https://cloud.tencent.com/document/api/1314/56230#HistologyClass)
* [HistologyTypeV2](https://cloud.tencent.com/document/api/1314/56230#HistologyTypeV2)
* [IHCBlock](https://cloud.tencent.com/document/api/1314/56230#IHCBlock)
* [IHCV2](https://cloud.tencent.com/document/api/1314/56230#IHCV2)
* [ImmunohistochemistryBlock](https://cloud.tencent.com/document/api/1314/56230#ImmunohistochemistryBlock)
* [IndicatorItemV2](https://cloud.tencent.com/document/api/1314/56230#IndicatorItemV2)
* [IndicatorV3](https://cloud.tencent.com/document/api/1314/56230#IndicatorV3)
* [InvasiveV2](https://cloud.tencent.com/document/api/1314/56230#InvasiveV2)
* [IssueInfo](https://cloud.tencent.com/document/api/1314/56230#IssueInfo)
* [LastMenstrualPeriodBlock](https://cloud.tencent.com/document/api/1314/56230#LastMenstrualPeriodBlock)
* [LymphNode](https://cloud.tencent.com/document/api/1314/56230#LymphNode)
* [LymphTotal](https://cloud.tencent.com/document/api/1314/56230#LymphTotal)
* [MainDiseaseHistoryBlock](https://cloud.tencent.com/document/api/1314/56230#MainDiseaseHistoryBlock)
* [Maternity](https://cloud.tencent.com/document/api/1314/56230#Maternity)
* [MaternityDesc](https://cloud.tencent.com/document/api/1314/56230#MaternityDesc)
* [MaternitySummary](https://cloud.tencent.com/document/api/1314/56230#MaternitySummary)
* [MenstrualFlowBlock](https://cloud.tencent.com/document/api/1314/56230#MenstrualFlowBlock)
* [MenstrualHistoryBlock](https://cloud.tencent.com/document/api/1314/56230#MenstrualHistoryBlock)
* [MenstrualHistoryDetailBlock](https://cloud.tencent.com/document/api/1314/56230#MenstrualHistoryDetailBlock)
* [MenstrualPeriodBlock](https://cloud.tencent.com/document/api/1314/56230#MenstrualPeriodBlock)
* [MenstruationOrNotBlock](https://cloud.tencent.com/document/api/1314/56230#MenstruationOrNotBlock)
* [Molecular](https://cloud.tencent.com/document/api/1314/56230#Molecular)
* [MolecularValue](https://cloud.tencent.com/document/api/1314/56230#MolecularValue)
* [NeglistBlock](https://cloud.tencent.com/document/api/1314/56230#NeglistBlock)
* [NeonatalInfo](https://cloud.tencent.com/document/api/1314/56230#NeonatalInfo)
* [NumValue](https://cloud.tencent.com/document/api/1314/56230#NumValue)
* [ObstetricalHistoryBlock](https://cloud.tencent.com/document/api/1314/56230#ObstetricalHistoryBlock)
* [OtherInfo](https://cloud.tencent.com/document/api/1314/56230#OtherInfo)
* [PTNM](https://cloud.tencent.com/document/api/1314/56230#PTNM)
* [PTNMBlock](https://cloud.tencent.com/document/api/1314/56230#PTNMBlock)
* [ParagraphBlock](https://cloud.tencent.com/document/api/1314/56230#ParagraphBlock)
* [ParentInfo](https://cloud.tencent.com/document/api/1314/56230#ParentInfo)
* [PartDesc](https://cloud.tencent.com/document/api/1314/56230#PartDesc)
* [PathologicalDiagnosisBlock](https://cloud.tencent.com/document/api/1314/56230#PathologicalDiagnosisBlock)
* [PathologicalDiagnosisDetailBlock](https://cloud.tencent.com/document/api/1314/56230#PathologicalDiagnosisDetailBlock)
* [PathologyV2](https://cloud.tencent.com/document/api/1314/56230#PathologyV2)
* [PersonalHistoryBlock](https://cloud.tencent.com/document/api/1314/56230#PersonalHistoryBlock)
* [Point](https://cloud.tencent.com/document/api/1314/56230#Point)
* [PoslistBlock](https://cloud.tencent.com/document/api/1314/56230#PoslistBlock)
* [Rectangle](https://cloud.tencent.com/document/api/1314/56230#Rectangle)
* [RelapseDateBlock](https://cloud.tencent.com/document/api/1314/56230#RelapseDateBlock)
* [RelativeCancerHistoryBlock](https://cloud.tencent.com/document/api/1314/56230#RelativeCancerHistoryBlock)
* [RelativeHistoryBlock](https://cloud.tencent.com/document/api/1314/56230#RelativeHistoryBlock)
* [RelativeHistoryDetailBlock](https://cloud.tencent.com/document/api/1314/56230#RelativeHistoryDetailBlock)
* [Report](https://cloud.tencent.com/document/api/1314/56230#Report)
* [ReportTypeVersion](https://cloud.tencent.com/document/api/1314/56230#ReportTypeVersion)
* [ResultInfo](https://cloud.tencent.com/document/api/1314/56230#ResultInfo)
* [SmokeHistoryBlock](https://cloud.tencent.com/document/api/1314/56230#SmokeHistoryBlock)
* [SummaryInfo](https://cloud.tencent.com/document/api/1314/56230#SummaryInfo)
* [SurgeryConditionBlock](https://cloud.tencent.com/document/api/1314/56230#SurgeryConditionBlock)
* [SurgeryHistoryBlock](https://cloud.tencent.com/document/api/1314/56230#SurgeryHistoryBlock)
* [SurgeryListBlock](https://cloud.tencent.com/document/api/1314/56230#SurgeryListBlock)
* [TableIndicators](https://cloud.tencent.com/document/api/1314/56230#TableIndicators)
* [TimelineEvent](https://cloud.tencent.com/document/api/1314/56230#TimelineEvent)
* [TimelineInformation](https://cloud.tencent.com/document/api/1314/56230#TimelineInformation)
* [TransfusionHistoryBlock](https://cloud.tencent.com/document/api/1314/56230#TransfusionHistoryBlock)
* [TreatmentRecordBlock](https://cloud.tencent.com/document/api/1314/56230#TreatmentRecordBlock)
* [ValueBlock](https://cloud.tencent.com/document/api/1314/56230#ValueBlock)

修改数据结构：

* [BiopsyPart](https://cloud.tencent.com/document/api/1314/56230#BiopsyPart)

	* 新增成员：Coords

	* <font color="#dd0000">**修改成员**：</font>Value, Src

* [BlockInfo](https://cloud.tencent.com/document/api/1314/56230#BlockInfo)

	* 新增成员：Size

	* <font color="#dd0000">**修改成员**：</font>Index, Positive, Src, Value, Type, Name

* [Desc](https://cloud.tencent.com/document/api/1314/56230#Desc)

	* 新增成员：Coords

	* <font color="#dd0000">**修改成员**：</font>Text, Organ, Tuber

* [EndoscopyDesc](https://cloud.tencent.com/document/api/1314/56230#EndoscopyDesc)

	* 新增成员：Coords

	* <font color="#dd0000">**修改成员**：</font>Text, Organ

* [EndoscopyOrgan](https://cloud.tencent.com/document/api/1314/56230#EndoscopyOrgan)

	* 新增成员：Coords

	* <font color="#dd0000">**修改成员**：</font>Part, Index, Src, PartAlias, SymDescList

* [FirstPage](https://cloud.tencent.com/document/api/1314/56230#FirstPage)

	* 新增成员：DamagePoi, Fp2NdItems

	* <font color="#dd0000">**修改成员**：</font>DischargeDiagnosis, PathologicalDiagnosis, ClinicalDiagnosis

* [IndicatorItem](https://cloud.tencent.com/document/api/1314/56230#IndicatorItem)

	* 新增成员：InferNormal

* [NormPart](https://cloud.tencent.com/document/api/1314/56230#NormPart)

	* 新增成员：PartDetail

	* <font color="#dd0000">**修改成员**：</font>Part, PartDirection, Tissue, TissueDirection, Upper

* [NormSize](https://cloud.tencent.com/document/api/1314/56230#NormSize)

	* 新增成员：Impl

	* <font color="#dd0000">**修改成员**：</font>Number, Type, Unit

* [Organ](https://cloud.tencent.com/document/api/1314/56230#Organ)

	* 新增成员：Transparent, MriAdc, MriDwi, MriT1, MriT2, CtHu, Suvmax, Metabolism, RadioactiveUptake, LymphEnlargement, ImageFeature, Duct, Trend, Operation, Coords

	* <font color="#dd0000">**修改成员**：</font>Part, Size, Envelope, Edge, InnerEcho, Gland, Shape, Thickness, ShapeAttr, CDFI, SymDesc, SizeStatus, Outline, Structure, Density, Vas, Cysticwall, Capsule, IsthmusThicknese, InnerEchoDistribution, Src, Index

* [Part](https://cloud.tencent.com/document/api/1314/56230#Part)

	* 新增成员：ValueBrief

	* <font color="#dd0000">**修改成员**：</font>Index, NormPart, Src, Value, Name

* [Size](https://cloud.tencent.com/document/api/1314/56230#Size)

	* 新增成员：Name

	* <font color="#dd0000">**修改成员**：</font>Index, NormSize, Src, Value

* [Summary](https://cloud.tencent.com/document/api/1314/56230#Summary)

	* 新增成员：Coords

	* <font color="#dd0000">**修改成员**：</font>Symptom, Text

* [Surgery](https://cloud.tencent.com/document/api/1314/56230#Surgery)

	* 新增成员：OtherInfo

	* <font color="#dd0000">**修改成员**：</font>SurgeryHistory

* [SymptomInfo](https://cloud.tencent.com/document/api/1314/56230#SymptomInfo)

	* 新增成员：Coords

	* <font color="#dd0000">**修改成员**：</font>Grade, Part, Index, Symptom, Attrs, Src

* [Template](https://cloud.tencent.com/document/api/1314/56230#Template)

	* 新增成员：ReportTypeDesc, PathologyV2, C14, Exame, MedDocV2, IndicatorV3, Covid, Maternity, Eye, BirthCert, Timeline

	* <font color="#dd0000">**修改成员**：</font>PatientInfo, ReportInfo, Check, Pathology, MedDoc, DiagCert, FirstPage, Indicator, ReportType, MedicalRecordInfo, Hospitalization, Surgery, Electrocardiogram, Endoscopy, Prescription, VaccineCertificate, OcrText, OcrResult

* [TuberInfo](https://cloud.tencent.com/document/api/1314/56230#TuberInfo)

	* 新增成员：Transparent, MriAdc, MriDwi, MriT1, MriT2, CtHu, Suvmax, Metabolism, RadioactiveUptake, SymDesc, ImageFeature, Coords

	* <font color="#dd0000">**修改成员**：</font>Type, Part, Size, Multiple, AspectRatio, Edge, InnerEcho, RearEcho, Elastic, Shape, ShapeAttr, SkinMedulla, Trend, Calcification, Envelope, Enhancement, LymphEnlargement, LymphDoor, Activity, Operation, CDFI, Index, SizeStatus, InnerEchoDistribution, InnerEchoType, Outline, Structure, Density, Vas, Cysticwall, Capsule, IsthmusThicknese, Src

* [Vaccination](https://cloud.tencent.com/document/api/1314/56230#Vaccination)

	* 新增成员：Lot

	* <font color="#dd0000">**修改成员**：</font>Id, Vaccine, Dose, Date, LotNumber, Manufacturer, Clinic, Site, Provider


### 第 14 次发布

发布时间：2022-12-08 01:38:36

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [ImageToClass](https://cloud.tencent.com/document/api/1314/56229)

	* 新增入参：UserType

* [ImageToObject](https://cloud.tencent.com/document/api/1314/56228)

	* 新增入参：UserType

* [TextToClass](https://cloud.tencent.com/document/api/1314/56227)

	* 新增入参：UserType

* [TextToObject](https://cloud.tencent.com/document/api/1314/56226)

	* 新增入参：UserType


修改数据结构：

* [MedDoc](https://cloud.tencent.com/document/api/1314/56230#MedDoc)

	* <font color="#dd0000">**修改成员**：</font>Advice, Diagnosis, DiseaseMedicalHistory, PersonalMedicalHistory, ObstericalMedicalHistory, FamilyMedicalHistory, MenstrualMedicalHistory, TreatmentRecord


### 第 13 次发布

发布时间：2022-06-28 06:14:04

本次发布包含了以下内容：

改善已有的文档。

新增数据结构：

* [Coordinate](https://cloud.tencent.com/document/api/1314/56230#Coordinate)

修改数据结构：

* [IndicatorItem](https://cloud.tencent.com/document/api/1314/56230#IndicatorItem)

	* 新增成员：Id, Coords


### 第 12 次发布

发布时间：2022-06-24 06:15:32

本次发布包含了以下内容：

改善已有的文档。

新增数据结构：

* [Time](https://cloud.tencent.com/document/api/1314/56230#Time)

修改数据结构：

* [PatientInfo](https://cloud.tencent.com/document/api/1314/56230#PatientInfo)

	* 新增成员：BedNo

* [ReportInfo](https://cloud.tencent.com/document/api/1314/56230#ReportInfo)

	* 新增成员：CheckItem, CheckMethod, DiagnoseTime, HealthCheckupNum, OtherTime, PrintTime, Times


### 第 11 次发布

发布时间：2022-06-08 06:12:58

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [ImageToObject](https://cloud.tencent.com/document/api/1314/56228)

	* 新增出参：TextTypeList


### 第 10 次发布

发布时间：2021-12-14 08:12:50

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [Template](https://cloud.tencent.com/document/api/1314/56230#Template)

	* 新增成员：OcrResult


### 第 9 次发布

发布时间：2021-12-10 08:09:11

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [Template](https://cloud.tencent.com/document/api/1314/56230#Template)

	* 新增成员：OcrText


### 第 8 次发布

发布时间：2021-11-30 08:10:05

本次发布包含了以下内容：

改善已有的文档。

新增数据结构：

* [Vaccination](https://cloud.tencent.com/document/api/1314/56230#Vaccination)
* [VaccineCertificate](https://cloud.tencent.com/document/api/1314/56230#VaccineCertificate)

修改数据结构：

* [Template](https://cloud.tencent.com/document/api/1314/56230#Template)

	* 新增成员：VaccineCertificate


### 第 7 次发布

发布时间：2021-11-16 08:13:00

本次发布包含了以下内容：

改善已有的文档。

新增数据结构：

* [BiopsyPart](https://cloud.tencent.com/document/api/1314/56230#BiopsyPart)
* [Endoscopy](https://cloud.tencent.com/document/api/1314/56230#Endoscopy)
* [EndoscopyDesc](https://cloud.tencent.com/document/api/1314/56230#EndoscopyDesc)
* [EndoscopyOrgan](https://cloud.tencent.com/document/api/1314/56230#EndoscopyOrgan)
* [Medicine](https://cloud.tencent.com/document/api/1314/56230#Medicine)
* [Prescription](https://cloud.tencent.com/document/api/1314/56230#Prescription)

修改数据结构：

* [Template](https://cloud.tencent.com/document/api/1314/56230#Template)

	* 新增成员：Endoscopy, Prescription


### 第 6 次发布

发布时间：2021-10-21 11:32:09

本次发布包含了以下内容：

改善已有的文档。

新增数据结构：

* [EcgDescription](https://cloud.tencent.com/document/api/1314/56230#EcgDescription)
* [EcgDiagnosis](https://cloud.tencent.com/document/api/1314/56230#EcgDiagnosis)
* [EcgItem](https://cloud.tencent.com/document/api/1314/56230#EcgItem)
* [Electrocardiogram](https://cloud.tencent.com/document/api/1314/56230#Electrocardiogram)

修改数据结构：

* [PatientInfo](https://cloud.tencent.com/document/api/1314/56230#PatientInfo)

	* 新增成员：AgeNorm, Nation, MarriedCode, ProfessionCode, MedicalInsuranceTypeCode

* [Template](https://cloud.tencent.com/document/api/1314/56230#Template)

	* 新增成员：Electrocardiogram


### 第 5 次发布

发布时间：2021-08-16 14:44:07

本次发布包含了以下内容：

改善已有的文档。

<font color="#dd0000">**删除接口**：</font>

* ReportImageStructured
* ReportTextStructured

<font color="#dd0000">**删除数据结构**：</font>

* Attribute
* BasicInfo
* Case
* CaseHistory
* Conclusion
* DiseaseHistory
* FamilyHistory
* Finding
* HealthHistory
* IHC
* ImageReport
* ImageText
* Inspection
* Invasive
* KindItem
* MarryHistory
* MenstrualHistory
* Metastasis
* Pathology
* PersonalHistory
* PersonalInfo
* Symptom
* TestItem
* TextReport
* Treatment
* Tuber

### 第 4 次发布

发布时间：2021-07-07 09:54:41

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [IndicatorItem](https://cloud.tencent.com/document/api/1314/56230#IndicatorItem)

	* 新增成员：ItemString


### 第 3 次发布

发布时间：2021-07-02 08:00:20

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [ReportImageStructured](https://cloud.tencent.com/document/api/1314/58113)
* [ReportTextStructured](https://cloud.tencent.com/document/api/1314/58112)

新增数据结构：

* [Attribute](https://cloud.tencent.com/document/api/1314/56230#Attribute)
* [BasicInfo](https://cloud.tencent.com/document/api/1314/56230#BasicInfo)
* [Case](https://cloud.tencent.com/document/api/1314/56230#Case)
* [CaseHistory](https://cloud.tencent.com/document/api/1314/56230#CaseHistory)
* [Conclusion](https://cloud.tencent.com/document/api/1314/56230#Conclusion)
* [DiseaseHistory](https://cloud.tencent.com/document/api/1314/56230#DiseaseHistory)
* [FamilyHistory](https://cloud.tencent.com/document/api/1314/56230#FamilyHistory)
* [Finding](https://cloud.tencent.com/document/api/1314/56230#Finding)
* [HealthHistory](https://cloud.tencent.com/document/api/1314/56230#HealthHistory)
* [IHC](https://cloud.tencent.com/document/api/1314/56230#IHC)
* [ImageReport](https://cloud.tencent.com/document/api/1314/56230#ImageReport)
* [ImageText](https://cloud.tencent.com/document/api/1314/56230#ImageText)
* [Inspection](https://cloud.tencent.com/document/api/1314/56230#Inspection)
* [Invasive](https://cloud.tencent.com/document/api/1314/56230#Invasive)
* [KindItem](https://cloud.tencent.com/document/api/1314/56230#KindItem)
* [MarryHistory](https://cloud.tencent.com/document/api/1314/56230#MarryHistory)
* [MenstrualHistory](https://cloud.tencent.com/document/api/1314/56230#MenstrualHistory)
* [Metastasis](https://cloud.tencent.com/document/api/1314/56230#Metastasis)
* [Pathology](https://cloud.tencent.com/document/api/1314/56230#Pathology)
* [PersonalHistory](https://cloud.tencent.com/document/api/1314/56230#PersonalHistory)
* [PersonalInfo](https://cloud.tencent.com/document/api/1314/56230#PersonalInfo)
* [Symptom](https://cloud.tencent.com/document/api/1314/56230#Symptom)
* [TestItem](https://cloud.tencent.com/document/api/1314/56230#TestItem)
* [TextReport](https://cloud.tencent.com/document/api/1314/56230#TextReport)
* [Treatment](https://cloud.tencent.com/document/api/1314/56230#Treatment)
* [Tuber](https://cloud.tencent.com/document/api/1314/56230#Tuber)

### 第 2 次发布

发布时间：2021-06-16 08:00:15

本次发布包含了以下内容：

改善已有的文档。

新增数据结构：

* [Hospitalization](https://cloud.tencent.com/document/api/1314/56230#Hospitalization)
* [MedicalRecordInfo](https://cloud.tencent.com/document/api/1314/56230#MedicalRecordInfo)
* [Surgery](https://cloud.tencent.com/document/api/1314/56230#Surgery)
* [SurgeryAttr](https://cloud.tencent.com/document/api/1314/56230#SurgeryAttr)
* [SurgeryHistory](https://cloud.tencent.com/document/api/1314/56230#SurgeryHistory)

修改数据结构：

* [PatientInfo](https://cloud.tencent.com/document/api/1314/56230#PatientInfo)

	* 新增成员：HealthCardNo, SocialSecurityCardNo, Birthday, Ethnicity, Married, Profession, EducationBackground, Nationality, BirthPlace, MedicalInsuranceType

* [ReportInfo](https://cloud.tencent.com/document/api/1314/56230#ReportInfo)

	* 新增成员：Diagnose

* [Template](https://cloud.tencent.com/document/api/1314/56230#Template)

	* 新增成员：MedicalRecordInfo, Hospitalization, Surgery


### 第 1 次发布

发布时间：2021-05-25 08:00:05

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [ImageToClass](https://cloud.tencent.com/document/api/1314/56229)
* [ImageToObject](https://cloud.tencent.com/document/api/1314/56228)
* [TextToClass](https://cloud.tencent.com/document/api/1314/56227)
* [TextToObject](https://cloud.tencent.com/document/api/1314/56226)

新增数据结构：

* [Advice](https://cloud.tencent.com/document/api/1314/56230#Advice)
* [AspectRatio](https://cloud.tencent.com/document/api/1314/56230#AspectRatio)
* [BlockInfo](https://cloud.tencent.com/document/api/1314/56230#BlockInfo)
* [Check](https://cloud.tencent.com/document/api/1314/56230#Check)
* [Desc](https://cloud.tencent.com/document/api/1314/56230#Desc)
* [DiagCert](https://cloud.tencent.com/document/api/1314/56230#DiagCert)
* [DiagCertItem](https://cloud.tencent.com/document/api/1314/56230#DiagCertItem)
* [DischargeDiagnosis](https://cloud.tencent.com/document/api/1314/56230#DischargeDiagnosis)
* [DiseaseMedicalHistory](https://cloud.tencent.com/document/api/1314/56230#DiseaseMedicalHistory)
* [Elastic](https://cloud.tencent.com/document/api/1314/56230#Elastic)
* [FamilyMedicalHistory](https://cloud.tencent.com/document/api/1314/56230#FamilyMedicalHistory)
* [FirstPage](https://cloud.tencent.com/document/api/1314/56230#FirstPage)
* [HandleParam](https://cloud.tencent.com/document/api/1314/56230#HandleParam)
* [HistologyLevel](https://cloud.tencent.com/document/api/1314/56230#HistologyLevel)
* [HistologyType](https://cloud.tencent.com/document/api/1314/56230#HistologyType)
* [IHCInfo](https://cloud.tencent.com/document/api/1314/56230#IHCInfo)
* [ImageInfo](https://cloud.tencent.com/document/api/1314/56230#ImageInfo)
* [Indicator](https://cloud.tencent.com/document/api/1314/56230#Indicator)
* [IndicatorItem](https://cloud.tencent.com/document/api/1314/56230#IndicatorItem)
* [Invas](https://cloud.tencent.com/document/api/1314/56230#Invas)
* [Lymph](https://cloud.tencent.com/document/api/1314/56230#Lymph)
* [MedDoc](https://cloud.tencent.com/document/api/1314/56230#MedDoc)
* [MenstrualMedicalHistory](https://cloud.tencent.com/document/api/1314/56230#MenstrualMedicalHistory)
* [Multiple](https://cloud.tencent.com/document/api/1314/56230#Multiple)
* [NormPart](https://cloud.tencent.com/document/api/1314/56230#NormPart)
* [NormSize](https://cloud.tencent.com/document/api/1314/56230#NormSize)
* [ObstericalMedicalHistory](https://cloud.tencent.com/document/api/1314/56230#ObstericalMedicalHistory)
* [Organ](https://cloud.tencent.com/document/api/1314/56230#Organ)
* [Part](https://cloud.tencent.com/document/api/1314/56230#Part)
* [PathologyReport](https://cloud.tencent.com/document/api/1314/56230#PathologyReport)
* [PatientInfo](https://cloud.tencent.com/document/api/1314/56230#PatientInfo)
* [PersonalMedicalHistory](https://cloud.tencent.com/document/api/1314/56230#PersonalMedicalHistory)
* [ReportInfo](https://cloud.tencent.com/document/api/1314/56230#ReportInfo)
* [Size](https://cloud.tencent.com/document/api/1314/56230#Size)
* [Summary](https://cloud.tencent.com/document/api/1314/56230#Summary)
* [SymptomInfo](https://cloud.tencent.com/document/api/1314/56230#SymptomInfo)
* [Template](https://cloud.tencent.com/document/api/1314/56230#Template)
* [TextType](https://cloud.tencent.com/document/api/1314/56230#TextType)
* [TreatmentRecord](https://cloud.tencent.com/document/api/1314/56230#TreatmentRecord)
* [TuberInfo](https://cloud.tencent.com/document/api/1314/56230#TuberInfo)
* [Value](https://cloud.tencent.com/document/api/1314/56230#Value)




## 移动应用安全(ms) 版本：2018-04-08

### 第 20 次发布

发布时间：2023-12-05 02:07:42

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DestroyResourceInstances](https://cloud.tencent.com/document/api/283/102194)

### 第 19 次发布

发布时间：2023-11-15 02:10:37

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [PlanInfo](https://cloud.tencent.com/document/api/283/17759#PlanInfo)

	* 新增成员：SetFile, FileSign, AntiRoot


### 第 18 次发布

发布时间：2023-10-17 01:22:38

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateEncryptInstance](https://cloud.tencent.com/document/api/283/95528)

	* 新增入参：IOSInfo


新增数据结构：

* [IOSInfo](https://cloud.tencent.com/document/api/283/17759#IOSInfo)

修改数据结构：

* [IOSResult](https://cloud.tencent.com/document/api/283/17759#IOSResult)

	* 新增成员：OpUin, EncryptType, ResourceId, EncryptState, EncryptErrno, EncryptErrDesc, CreatTime, StartTime, EndTime, CostTime, EncryptPkgUrl

	* <font color="#dd0000">**修改成员**：</font>ResultId


### 第 17 次发布

发布时间：2023-08-17 04:17:58

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [RequestLocalTask](https://cloud.tencent.com/document/api/283/96276)
* [UpdateClientState](https://cloud.tencent.com/document/api/283/96275)
* [UpdateLocalTaskResult](https://cloud.tencent.com/document/api/283/96274)

### 第 16 次发布

发布时间：2023-08-02 01:19:05

本次发布包含了以下内容：

改善已有的文档。

<font color="#dd0000">**预下线接口**：</font>

* CancelEncryptTask
* CreateEncryptInstance
* CreateOrderInstance
* DescribeEncryptInstances
* DescribeOrderInstances

修改数据结构：

* [AndroidResult](https://cloud.tencent.com/document/api/283/17759#AndroidResult)

	* <font color="#dd0000">**修改成员**：</font>ResultId, OrderId, ResourceId, OpUin, AppType, AppPkgName, BindAppPkgName, EncryptState, EncryptStateDesc, EncryptErrCode, EncryptErrDesc, EncryptErrRef, CreatTime, StartTime, EndTime, CostTime, AppUrl, AppMd5, AppName, AppVersion, AppSize, OnlineToolVersion, EncryptAppMd5, EncryptAppSize, EncryptPkgUrl, OutputToolVersion, OutputToolSize, ToolOutputTime, ToolExpireTime, OutputToolUrl, AndroidPlan

* [EncryptResults](https://cloud.tencent.com/document/api/283/17759#EncryptResults)

	* <font color="#dd0000">**修改成员**：</font>PlatformType, PlatformDesc, OrderType, OrderTypeDesc, EncryptOpType, EncryptOpTypeDesc, ResourceId, OrderId, AndroidResult, IOSResult, SDKResult, AppletResult

* [Orders](https://cloud.tencent.com/document/api/283/17759#Orders)

	* <font color="#dd0000">**修改成员**：</font>OrderId, PlatformType, PlatformTypeDesc, OrderType, OrderTypeDesc, AppPkgName, ResourceId, ResourceStatus, ResourceStatusDesc, TestTimes, ValidTime, ExpireTime, CreateTime, Approver, ApprovalStatus, ApprovalStatusDesc, ApprovalTime, TimesTaskTotalCount, TimesTaskSuccessCount, TimesTaskFailCount


### 第 15 次发布

发布时间：2023-07-26 01:29:37

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CancelEncryptTask](https://cloud.tencent.com/document/api/283/95529)
* [CreateEncryptInstance](https://cloud.tencent.com/document/api/283/95528)
* [CreateOrderInstance](https://cloud.tencent.com/document/api/283/95527)
* [DescribeEncryptInstances](https://cloud.tencent.com/document/api/283/95526)
* [DescribeEncryptPlan](https://cloud.tencent.com/document/api/283/95525)
* [DescribeOrderInstances](https://cloud.tencent.com/document/api/283/95524)

新增数据结构：

* [AndroidAppInfo](https://cloud.tencent.com/document/api/283/17759#AndroidAppInfo)
* [AndroidPlan](https://cloud.tencent.com/document/api/283/17759#AndroidPlan)
* [AndroidResult](https://cloud.tencent.com/document/api/283/17759#AndroidResult)
* [AppletInfo](https://cloud.tencent.com/document/api/283/17759#AppletInfo)
* [AppletPlan](https://cloud.tencent.com/document/api/283/17759#AppletPlan)
* [AppletResult](https://cloud.tencent.com/document/api/283/17759#AppletResult)
* [EncryptResults](https://cloud.tencent.com/document/api/283/17759#EncryptResults)
* [IOSPlan](https://cloud.tencent.com/document/api/283/17759#IOSPlan)
* [IOSResult](https://cloud.tencent.com/document/api/283/17759#IOSResult)
* [Orders](https://cloud.tencent.com/document/api/283/17759#Orders)
* [SDKPlan](https://cloud.tencent.com/document/api/283/17759#SDKPlan)
* [SDKResult](https://cloud.tencent.com/document/api/283/17759#SDKResult)

### 第 14 次发布

发布时间：2023-06-15 01:29:09

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateCosSecKeyInstance](https://cloud.tencent.com/document/api/283/30640)

	* 新增出参：CosToken


### 第 13 次发布

发布时间：2023-05-08 01:41:34

本次发布包含了以下内容：

改善已有的文档。

<font color="#dd0000">**删除接口**：</font>

* CreateScanInstances
* DeleteScanInstances
* DescribeScanInstances
* DescribeScanResults

<font color="#dd0000">**删除数据结构**：</font>

* AdInfo
* AppScanSet
* PluginInfo
* ScanInfo
* ScanPermissionInfo
* ScanPermissionList
* ScanSensitiveInfo
* ScanSensitiveList
* ScanSetInfo
* VirusInfo
* VulInfo
* VulList

### 第 12 次发布

发布时间：2023-04-17 01:29:42

本次发布包含了以下内容：

改善已有的文档。

<font color="#dd0000">**预下线接口**：</font>

* DeleteScanInstances

### 第 11 次发布

发布时间：2023-03-15 01:56:41

本次发布包含了以下内容：

改善已有的文档。

<font color="#dd0000">**预下线接口**：</font>

* CreateScanInstances
* DescribeScanInstances
* DescribeScanResults

### 第 10 次发布

发布时间：2022-09-09 06:35:15

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeApkDetectionResult](https://cloud.tencent.com/document/api/283/80325)

新增数据结构：

* [OptPluginListItem](https://cloud.tencent.com/document/api/283/17759#OptPluginListItem)
* [PluginListItem](https://cloud.tencent.com/document/api/283/17759#PluginListItem)
* [ResultListItem](https://cloud.tencent.com/document/api/283/17759#ResultListItem)

### 第 9 次发布

发布时间：2022-07-07 06:13:41

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeResourceInstances](https://cloud.tencent.com/document/api/283/18578)

	* <font color="#dd0000">**修改入参**：</font>Pids


### 第 8 次发布

发布时间：2022-07-01 11:58:05

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeUrlDetectionResult](https://cloud.tencent.com/document/api/283/76351)

### 第 7 次发布

发布时间：2019-06-21 16:08:39

本次发布包含了以下内容：

改善已有的文档。

新增数据结构：

* [ScanPermissionInfo](https://cloud.tencent.com/document/api/283/17759#ScanPermissionInfo)
* [ScanPermissionList](https://cloud.tencent.com/document/api/283/17759#ScanPermissionList)
* [ScanSensitiveInfo](https://cloud.tencent.com/document/api/283/17759#ScanSensitiveInfo)
* [ScanSensitiveList](https://cloud.tencent.com/document/api/283/17759#ScanSensitiveList)

修改数据结构：

* [ScanSetInfo](https://cloud.tencent.com/document/api/283/17759#ScanSetInfo)

	* 新增成员：PermissionInfo, SensitiveInfo


### 第 6 次发布

发布时间：2018-12-20 19:36:19

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeUserBaseInfoInstance](https://cloud.tencent.com/document/api/283/31795)

### 第 5 次发布

发布时间：2018-11-22 20:56:36

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateCosSecKeyInstance](https://cloud.tencent.com/document/api/283/30640)

修改接口：

* [DescribeShieldResult](https://cloud.tencent.com/document/api/283/17750)

	* 新增出参：StatusDesc, StatusRef


修改数据结构：

* [ScanSetInfo](https://cloud.tencent.com/document/api/283/17759#ScanSetInfo)

	* 新增成员：StatusCode, StatusDesc, StatusRef


### 第 4 次发布

发布时间：2018-09-13 19:58:05

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateResourceInstances](https://cloud.tencent.com/document/api/283/19823)

### 第 3 次发布

发布时间：2018-09-07 11:09:23

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [PlanInfo](https://cloud.tencent.com/document/api/283/17759#PlanInfo)

	* <font color="#dd0000">**修改成员**：</font>SoType


### 第 2 次发布

发布时间：2018-07-26 15:10:56

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateBindInstance](https://cloud.tencent.com/document/api/283/18579)
* [CreateShieldPlanInstance](https://cloud.tencent.com/document/api/283/18576)
* [DescribeResourceInstances](https://cloud.tencent.com/document/api/283/18578)
* [DescribeShieldPlanInstance](https://cloud.tencent.com/document/api/283/18575)

修改接口：

* [DescribeScanInstances](https://cloud.tencent.com/document/api/283/17756)

	* <font color="#dd0000">**修改入参**：</font>Filters

* [DescribeShieldInstances](https://cloud.tencent.com/document/api/283/17751)

	* <font color="#dd0000">**修改入参**：</font>Filters


新增数据结构：

* [BindInfo](https://cloud.tencent.com/document/api/283/17759#BindInfo)
* [Filter](https://cloud.tencent.com/document/api/283/17759#Filter)
* [PlanDetailInfo](https://cloud.tencent.com/document/api/283/17759#PlanDetailInfo)
* [PlanInfo](https://cloud.tencent.com/document/api/283/17759#PlanInfo)
* [ResourceInfo](https://cloud.tencent.com/document/api/283/17759#ResourceInfo)
* [ResourceServiceInfo](https://cloud.tencent.com/document/api/283/17759#ResourceServiceInfo)
* [ShieldPlanInfo](https://cloud.tencent.com/document/api/283/17759#ShieldPlanInfo)
* [SoInfo](https://cloud.tencent.com/document/api/283/17759#SoInfo)

<font color="#dd0000">**删除数据结构**：</font>

* Filters

修改数据结构：

* [ServiceInfo](https://cloud.tencent.com/document/api/283/17759#ServiceInfo)

	* 新增成员：PlanId

* [ShieldInfo](https://cloud.tencent.com/document/api/283/17759#ShieldInfo)

	* 新增成员：ServiceEdition


### 第 1 次发布

发布时间：2018-06-07 15:01:42

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateScanInstances](https://cloud.tencent.com/document/api/283/17758)
* [CreateShieldInstance](https://cloud.tencent.com/document/api/283/17753)
* [DeleteScanInstances](https://cloud.tencent.com/document/api/283/17757)
* [DeleteShieldInstances](https://cloud.tencent.com/document/api/283/17752)
* [DescribeScanInstances](https://cloud.tencent.com/document/api/283/17756)
* [DescribeScanResults](https://cloud.tencent.com/document/api/283/17755)
* [DescribeShieldInstances](https://cloud.tencent.com/document/api/283/17751)
* [DescribeShieldResult](https://cloud.tencent.com/document/api/283/17750)

新增数据结构：

* [AdInfo](https://cloud.tencent.com/document/api/283/17759#AdInfo)
* [AppDetailInfo](https://cloud.tencent.com/document/api/283/17759#AppDetailInfo)
* [AppInfo](https://cloud.tencent.com/document/api/283/17759#AppInfo)
* [AppScanSet](https://cloud.tencent.com/document/api/283/17759#AppScanSet)
* [AppSetInfo](https://cloud.tencent.com/document/api/283/17759#AppSetInfo)
* [Filters](https://cloud.tencent.com/document/api/283/17759#Filters)
* [PluginInfo](https://cloud.tencent.com/document/api/283/17759#PluginInfo)
* [ScanInfo](https://cloud.tencent.com/document/api/283/17759#ScanInfo)
* [ScanSetInfo](https://cloud.tencent.com/document/api/283/17759#ScanSetInfo)
* [ServiceInfo](https://cloud.tencent.com/document/api/283/17759#ServiceInfo)
* [ShieldInfo](https://cloud.tencent.com/document/api/283/17759#ShieldInfo)
* [VirusInfo](https://cloud.tencent.com/document/api/283/17759#VirusInfo)
* [VulInfo](https://cloud.tencent.com/document/api/283/17759#VulInfo)
* [VulList](https://cloud.tencent.com/document/api/283/17759#VulList)




## 迁移服务平台(msp) 版本：2018-03-19

### 第 2 次发布

发布时间：2020-05-15 08:13:29

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [RegisterMigrationTask](https://cloud.tencent.com/document/api/659/18599)

	* <font color="#dd0000">**修改入参**：</font>SrcInfo, DstInfo


### 第 1 次发布

发布时间：2018-07-26 16:34:23

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DeregisterMigrationTask](https://cloud.tencent.com/document/api/659/18605)
* [DescribeMigrationTask](https://cloud.tencent.com/document/api/659/18604)
* [ListMigrationProject](https://cloud.tencent.com/document/api/659/18603)
* [ListMigrationTask](https://cloud.tencent.com/document/api/659/18602)
* [ModifyMigrationTaskBelongToProject](https://cloud.tencent.com/document/api/659/18601)
* [ModifyMigrationTaskStatus](https://cloud.tencent.com/document/api/659/18600)
* [RegisterMigrationTask](https://cloud.tencent.com/document/api/659/18599)

新增数据结构：

* [DstInfo](https://cloud.tencent.com/document/api/659/18606#DstInfo)
* [Project](https://cloud.tencent.com/document/api/659/18606#Project)
* [SrcInfo](https://cloud.tencent.com/document/api/659/18606#SrcInfo)
* [Task](https://cloud.tencent.com/document/api/659/18606#Task)
* [TaskStatus](https://cloud.tencent.com/document/api/659/18606#TaskStatus)
* [TimeObj](https://cloud.tencent.com/document/api/659/18606#TimeObj)




## 营销价值判断(mvj) 版本：2019-09-26

### 第 1 次发布

发布时间：2020-03-19 08:11:44

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [MarketingValueJudgement](https://cloud.tencent.com/document/api/#/#)

新增数据结构：

* [Data](https://cloud.tencent.com/document/api/#/##Data)




## NLP 服务(nlp) 版本：2019-04-08

### 第 23 次发布

发布时间：2023-09-15 02:14:19

本次发布包含了以下内容：

改善已有的文档。

<font color="#dd0000">**删除接口**：</font>

* TestingTextGeneration

<font color="#dd0000">**删除数据结构**：</font>

* TextGenerationChoices
* TextGenerationMessage
* TextGenerationUsage

### 第 22 次发布

发布时间：2023-09-14 02:08:26

本次发布包含了以下内容：

改善已有的文档。

<font color="#dd0000">**预下线接口**：</font>

* TestingTextGeneration

### 第 21 次发布

发布时间：2023-08-18 01:15:19

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [TestingTextGeneration](https://cloud.tencent.com/document/api/271/96708)

新增数据结构：

* [TextGenerationChoices](https://cloud.tencent.com/document/api/271/35511#TextGenerationChoices)
* [TextGenerationMessage](https://cloud.tencent.com/document/api/271/35511#TextGenerationMessage)
* [TextGenerationUsage](https://cloud.tencent.com/document/api/271/35511#TextGenerationUsage)

### 第 20 次发布

发布时间：2023-08-02 01:19:12

本次发布包含了以下内容：

改善已有的文档。

<font color="#dd0000">**删除接口**：</font>

* AutoSummarization
* ChatBot
* CreateDict
* CreateWordItems
* DeleteDict
* DeleteWordItems
* DependencyParsing
* DescribeDict
* DescribeDicts
* DescribeWordItems
* GenerateCouplet
* GeneratePoetry
* KeywordsExtraction
* LexicalAnalysis
* SearchWordItems
* SentenceEmbedding
* SentimentAnalysis
* SimilarWords
* TextClassification
* TextCorrection
* TextCorrectionPro
* TextSimilarity
* TextSimilarityPro
* UpdateDict
* WordEmbedding
* WordSimilarity

<font color="#dd0000">**删除数据结构**：</font>

* CCIToken
* ClassificationResult
* DictInfo
* DpToken
* Keyword
* NerToken
* PosToken
* SearchResult
* Similarity
* WordItem

### 第 19 次发布

发布时间：2023-06-26 15:51:14

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [AnalyzeSentiment](https://cloud.tencent.com/document/api/271/94294)
* [ClassifyContent](https://cloud.tencent.com/document/api/271/94293)
* [ComposeCouplet](https://cloud.tencent.com/document/api/271/94292)
* [ComposePoetry](https://cloud.tencent.com/document/api/271/94291)

新增数据结构：

* [Category](https://cloud.tencent.com/document/api/271/35511#Category)

### 第 18 次发布

发布时间：2023-05-08 01:41:54

本次发布包含了以下内容：

改善已有的文档。

<font color="#dd0000">**预下线接口**：</font>

* AutoSummarization
* ChatBot
* CreateDict
* CreateWordItems
* DeleteDict
* DeleteWordItems
* DependencyParsing
* DescribeDict
* DescribeDicts
* DescribeWordItems
* GenerateCouplet
* GeneratePoetry
* KeywordsExtraction
* LexicalAnalysis
* SearchWordItems
* SentenceEmbedding
* SentimentAnalysis
* SimilarWords
* TextClassification
* TextCorrection
* TextCorrectionPro
* TextSimilarity
* TextSimilarityPro
* UpdateDict
* WordEmbedding
* WordSimilarity

### 第 17 次发布

发布时间：2023-04-25 13:40:49

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [EvaluateSentenceSimilarity](https://cloud.tencent.com/document/api/271/90613)
* [EvaluateWordSimilarity](https://cloud.tencent.com/document/api/271/90612)
* [GenerateKeywordSentence](https://cloud.tencent.com/document/api/271/90608)
* [ParseWords](https://cloud.tencent.com/document/api/271/90611)
* [RetrieveSimilarWords](https://cloud.tencent.com/document/api/271/90610)
* [SentenceCorrection](https://cloud.tencent.com/document/api/271/90607)
* [TextEmbellish](https://cloud.tencent.com/document/api/271/90606)
* [TextWriting](https://cloud.tencent.com/document/api/271/90605)

新增数据结构：

* [BasicParticiple](https://cloud.tencent.com/document/api/271/35511#BasicParticiple)
* [CompoundParticiple](https://cloud.tencent.com/document/api/271/35511#CompoundParticiple)
* [CorrectionItem](https://cloud.tencent.com/document/api/271/35511#CorrectionItem)
* [Embellish](https://cloud.tencent.com/document/api/271/35511#Embellish)
* [Entity](https://cloud.tencent.com/document/api/271/35511#Entity)
* [KeywordSentence](https://cloud.tencent.com/document/api/271/35511#KeywordSentence)
* [SentencePair](https://cloud.tencent.com/document/api/271/35511#SentencePair)
* [Writing](https://cloud.tencent.com/document/api/271/35511#Writing)

### 第 16 次发布

发布时间：2022-12-15 10:27:58

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [GenerateCouplet](https://cloud.tencent.com/document/api/271/84075)
* [GeneratePoetry](https://cloud.tencent.com/document/api/271/84074)

### 第 15 次发布

发布时间：2022-03-31 06:11:26

本次发布包含了以下内容：

改善已有的文档。

<font color="#dd0000">**删除接口**：</font>

* DescribeEntity
* DescribeRelation
* DescribeTriple

<font color="#dd0000">**删除数据结构**：</font>

* EntityRelationContent
* EntityRelationObject
* EntityRelationSubject
* TripleContent

### 第 14 次发布

发布时间：2022-03-18 08:15:22

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [TextCorrectionPro](https://cloud.tencent.com/document/api/271/71355)

### 第 13 次发布

发布时间：2022-03-15 08:13:08

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [TextSimilarityPro](https://cloud.tencent.com/document/api/271/71168)

### 第 12 次发布

发布时间：2021-05-10 16:12:19

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [ClassificationResult](https://cloud.tencent.com/document/api/271/35511#ClassificationResult)

	* 新增成员：ThirdClassName, ThirdClassProbability, FourthClassName, FourthClassProbability, FifthClassName, FifthClassProbability

* [NerToken](https://cloud.tencent.com/document/api/271/35511#NerToken)

	* <font color="#dd0000">**修改成员**：</font>Word, Length, BeginOffset, Type

* [PosToken](https://cloud.tencent.com/document/api/271/35511#PosToken)

	* <font color="#dd0000">**修改成员**：</font>Word, Length, BeginOffset, Pos


### 第 11 次发布

发布时间：2020-08-05 08:15:46

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [WordItem](https://cloud.tencent.com/document/api/271/35511#WordItem)

	* <font color="#dd0000">**修改成员**：</font>CreateTime


### 第 10 次发布

发布时间：2020-07-09 08:14:16

本次发布包含了以下内容：

改善已有的文档。

<font color="#dd0000">**删除接口**：</font>

* SentenceSimilarity

### 第 9 次发布

发布时间：2020-06-22 08:15:14

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateDict](https://cloud.tencent.com/document/api/271/45678)
* [CreateWordItems](https://cloud.tencent.com/document/api/271/45677)
* [DeleteDict](https://cloud.tencent.com/document/api/271/45676)
* [DeleteWordItems](https://cloud.tencent.com/document/api/271/45675)
* [DescribeDict](https://cloud.tencent.com/document/api/271/45674)
* [DescribeDicts](https://cloud.tencent.com/document/api/271/45673)
* [DescribeWordItems](https://cloud.tencent.com/document/api/271/45672)
* [SearchWordItems](https://cloud.tencent.com/document/api/271/45671)
* [UpdateDict](https://cloud.tencent.com/document/api/271/45670)

新增数据结构：

* [DictInfo](https://cloud.tencent.com/document/api/271/35511#DictInfo)
* [SearchResult](https://cloud.tencent.com/document/api/271/35511#SearchResult)
* [WordItem](https://cloud.tencent.com/document/api/271/35511#WordItem)

### 第 8 次发布

发布时间：2020-06-11 08:14:21

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [LexicalAnalysis](https://cloud.tencent.com/document/api/271/35494)

	* 新增入参：DictId


### 第 7 次发布

发布时间：2020-05-19 08:13:38

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [TextSimilarity](https://cloud.tencent.com/document/api/271/44681)

新增数据结构：

* [Similarity](https://cloud.tencent.com/document/api/271/35511#Similarity)

### 第 6 次发布

发布时间：2020-05-08 08:14:08

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [SentimentAnalysis](https://cloud.tencent.com/document/api/271/35497)

	* 新增入参：Mode

	* 新增出参：Neutral


### 第 5 次发布

发布时间：2020-02-11 17:03:41

本次发布包含了以下内容：

改善已有的文档。

<font color="#dd0000">**删除接口**：</font>

* SensitiveWordsRecognition
* TextApproval

<font color="#dd0000">**删除数据结构**：</font>

* EvilToken

### 第 4 次发布

发布时间：2020-01-02 21:20:16

本次发布包含了以下内容：

改善已有的文档。

<font color="#dd0000">**删除接口**：</font>

* ContentApproval

### 第 3 次发布

发布时间：2019-11-21 19:33:08

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [ChatBot](https://cloud.tencent.com/document/api/271/39416)
* [DescribeEntity](https://cloud.tencent.com/document/api/271/39420)
* [DescribeRelation](https://cloud.tencent.com/document/api/271/39419)
* [DescribeTriple](https://cloud.tencent.com/document/api/271/39418)

新增数据结构：

* [EntityRelationContent](https://cloud.tencent.com/document/api/271/35511#EntityRelationContent)
* [EntityRelationObject](https://cloud.tencent.com/document/api/271/35511#EntityRelationObject)
* [EntityRelationSubject](https://cloud.tencent.com/document/api/271/35511#EntityRelationSubject)
* [TripleContent](https://cloud.tencent.com/document/api/271/35511#TripleContent)

### 第 2 次发布

发布时间：2019-09-19 20:21:32

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [TextApproval](https://cloud.tencent.com/document/api/271/38076)

修改接口：

* [KeywordsExtraction](https://cloud.tencent.com/document/api/271/35498)

	* 新增入参：Num


新增数据结构：

* [EvilToken](https://cloud.tencent.com/document/api/271/35511#EvilToken)

### 第 1 次发布

发布时间：2019-06-13 19:35:53

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [AutoSummarization](https://cloud.tencent.com/document/api/271/35499)
* [ContentApproval](https://cloud.tencent.com/document/api/271/35502)
* [DependencyParsing](https://cloud.tencent.com/document/api/271/35510)
* [KeywordsExtraction](https://cloud.tencent.com/document/api/271/35498)
* [LexicalAnalysis](https://cloud.tencent.com/document/api/271/35494)
* [SensitiveWordsRecognition](https://cloud.tencent.com/document/api/271/35501)
* [SentenceEmbedding](https://cloud.tencent.com/document/api/271/35507)
* [SentenceSimilarity](https://cloud.tencent.com/document/api/271/35506)
* [SentimentAnalysis](https://cloud.tencent.com/document/api/271/35497)
* [SimilarWords](https://cloud.tencent.com/document/api/271/35493)
* [TextClassification](https://cloud.tencent.com/document/api/271/35496)
* [TextCorrection](https://cloud.tencent.com/document/api/271/35509)
* [WordEmbedding](https://cloud.tencent.com/document/api/271/35505)
* [WordSimilarity](https://cloud.tencent.com/document/api/271/35504)

新增数据结构：

* [CCIToken](https://cloud.tencent.com/document/api/271/35511#CCIToken)
* [ClassificationResult](https://cloud.tencent.com/document/api/271/35511#ClassificationResult)
* [DpToken](https://cloud.tencent.com/document/api/271/35511#DpToken)
* [Keyword](https://cloud.tencent.com/document/api/271/35511#Keyword)
* [NerToken](https://cloud.tencent.com/document/api/271/35511#NerToken)
* [PosToken](https://cloud.tencent.com/document/api/271/35511#PosToken)




## 号码保护(npp) 版本：2019-08-23

### 第 1 次发布

发布时间：2020-01-10 09:58:54

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateCallBack](https://cloud.tencent.com/document/api/610/40980)
* [DelVirtualNum](https://cloud.tencent.com/document/api/610/40984)
* [DeleteCallBack](https://cloud.tencent.com/document/api/610/40979)
* [DescribeCallBackCdr](https://cloud.tencent.com/document/api/610/40978)
* [DescribeCallBackStatus](https://cloud.tencent.com/document/api/610/40977)
* [DescribeCallerDisplayList](https://cloud.tencent.com/document/api/610/40976)
* [Get400Cdr](https://cloud.tencent.com/document/api/610/40983)
* [GetVirtualNum](https://cloud.tencent.com/document/api/610/40982)

新增数据结构：

* [CallBackCdr](https://cloud.tencent.com/document/api/610/40985#CallBackCdr)
* [CallBackPhoneCode](https://cloud.tencent.com/document/api/610/40985#CallBackPhoneCode)
* [KeyList](https://cloud.tencent.com/document/api/610/40985#KeyList)
* [RreCallerHandle](https://cloud.tencent.com/document/api/610/40985#RreCallerHandle)
* [VirturalNumCdr](https://cloud.tencent.com/document/api/610/40985#VirturalNumCdr)




## 流计算 Oceanus(oceanus) 版本：2019-04-22

### 第 60 次发布

发布时间：2024-07-23 01:53:12

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [RunJobDescription](https://cloud.tencent.com/document/api/849/52010#RunJobDescription)

	* 新增成员：KafkaScanMode


### 第 59 次发布

发布时间：2024-07-19 02:08:08

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [Cluster](https://cloud.tencent.com/document/api/849/52010#Cluster)

	* 新增成员：BillingResourceMode

* [ClusterGroupSetItem](https://cloud.tencent.com/document/api/849/52010#ClusterGroupSetItem)

	* 新增成员：BillingResourceMode


### 第 58 次发布

发布时间：2024-07-15 01:16:56

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateJobConfig](https://cloud.tencent.com/document/api/849/52004)

	* 新增入参：FlinkVersion


### 第 57 次发布

发布时间：2024-07-12 01:21:39

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [JobConfig](https://cloud.tencent.com/document/api/849/52010#JobConfig)

	* 新增成员：FlinkVersion

* [SlotSharingGroup](https://cloud.tencent.com/document/api/849/52010#SlotSharingGroup)

	* 新增成员：Configuration


### 第 56 次发布

发布时间：2024-06-05 02:02:33

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [Cluster](https://cloud.tencent.com/document/api/849/52010#Cluster)

	* 新增成员：ResourceType


### 第 55 次发布

发布时间：2024-05-31 01:58:53

本次发布包含了以下内容：

改善已有的文档。

新增数据结构：

* [SubEks](https://cloud.tencent.com/document/api/849/52010#SubEks)

修改数据结构：

* [Cluster](https://cloud.tencent.com/document/api/849/52010#Cluster)

	* 新增成员：Type, SubEks, AgentSerialId

* [ClusterGroupSetItem](https://cloud.tencent.com/document/api/849/52010#ClusterGroupSetItem)

	* 新增成员：SubEks

	* <font color="#dd0000">**修改成员**：</font>RunningCu, PayMode


### 第 54 次发布

发布时间：2024-03-08 01:20:43

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateJob](https://cloud.tencent.com/document/api/849/52009)

	* 新增入参：Description

* [ModifyJob](https://cloud.tencent.com/document/api/849/75553)

	* 新增入参：Description


修改数据结构：

* [JobV1](https://cloud.tencent.com/document/api/849/52010#JobV1)

	* 新增成员：Description


### 第 53 次发布

发布时间：2024-01-19 01:18:01

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CopyJobs](https://cloud.tencent.com/document/api/849/77740)

	* 新增入参：TargetWorkspaceId


修改数据结构：

* [JobConfig](https://cloud.tencent.com/document/api/849/52010#JobConfig)

	* 新增成员：IndexName, WorkspaceName


### 第 52 次发布

发布时间：2024-01-01 00:15:04

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeJobs](https://cloud.tencent.com/document/api/849/52008)

	* 新增入参：ExtraResult


新增数据结构：

* [JobEventInfo](https://cloud.tencent.com/document/api/849/52010#JobEventInfo)

修改数据结构：

* [JobV1](https://cloud.tencent.com/document/api/849/52010#JobV1)

	* 新增成员：EventInfo


### 第 51 次发布

发布时间：2023-12-29 01:21:17

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [GetMetaTable](https://cloud.tencent.com/document/api/849/102773)

### 第 50 次发布

发布时间：2023-12-20 01:57:04

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeJobEvents](https://cloud.tencent.com/document/api/849/102554)

新增数据结构：

* [JobEvent](https://cloud.tencent.com/document/api/849/52010#JobEvent)

### 第 49 次发布

发布时间：2023-12-04 15:28:57

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeFolder](https://cloud.tencent.com/document/api/849/102187)

新增数据结构：

* [SubFolderInfo](https://cloud.tencent.com/document/api/849/52010#SubFolderInfo)

### 第 48 次发布

发布时间：2023-12-04 00:15:25

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [JobV1](https://cloud.tencent.com/document/api/849/52010#JobV1)

	* <font color="#dd0000">**修改成员**：</font>Tags


### 第 47 次发布

发布时间：2023-11-28 01:20:57

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateJobConfig](https://cloud.tencent.com/document/api/849/52004)

	* 新增入参：EsServerlessIndex, EsServerlessSpace


### 第 46 次发布

发布时间：2023-11-27 00:14:59

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [JobConfig](https://cloud.tencent.com/document/api/849/52010#JobConfig)

	* 新增成员：EsServerlessIndex, EsServerlessSpace


### 第 45 次发布

发布时间：2023-11-16 01:25:38

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeTreeResources](https://cloud.tencent.com/document/api/849/79568)

	* 新增入参：Filters, Offset, Limit


### 第 44 次发布

发布时间：2023-10-24 01:20:07

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateJobConfig](https://cloud.tencent.com/document/api/849/52004)

	* 新增入参：TraceModeOn, TraceModeConfiguration, CheckpointRetainedNum, JobGraph

* [DescribeJobSavepoint](https://cloud.tencent.com/document/api/849/74226)

	* 新增入参：RecordTypes

* [DescribeTreeJobs](https://cloud.tencent.com/document/api/849/76833)

	* 新增入参：Filters

	* 新增出参：ParentId, Id, Name, JobSet, Children


新增数据结构：

* [DescribeTreeJobsRsp](https://cloud.tencent.com/document/api/849/52010#DescribeTreeJobsRsp)
* [TraceModeConfiguration](https://cloud.tencent.com/document/api/849/52010#TraceModeConfiguration)
* [TreeJobSets](https://cloud.tencent.com/document/api/849/52010#TreeJobSets)

修改数据结构：

* [Cluster](https://cloud.tencent.com/document/api/849/52010#Cluster)

	* 新增成员：WebUIType

* [JobConfig](https://cloud.tencent.com/document/api/849/52010#JobConfig)

	* 新增成员：TraceModeOn, TraceModeConfiguration, CheckpointRetainedNum, JobGraph

	* <font color="#dd0000">**修改成员**：</font>ClazzLevels, ExpertModeOn, ExpertModeConfiguration


### 第 43 次发布

发布时间：2023-10-23 00:16:17

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DeleteWorkSpace](https://cloud.tencent.com/document/api/849/100579)

修改数据结构：

* [ClusterSession](https://cloud.tencent.com/document/api/849/52010#ClusterSession)

	* 新增成员：ClusterGroupSerialId, AppId, OwnerUin, CreatorUin, Region, Zone, Status, CuNum, FlinkVersion, WebUIUrl, Properties, JobManagerCuSpec, TaskManagerCuSpec, TaskManagerNum, CreateTime, UpdateTime


### 第 42 次发布

发布时间：2023-10-19 16:11:52

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateWorkSpace](https://cloud.tencent.com/document/api/849/100451)
* [DeleteFolders](https://cloud.tencent.com/document/api/849/100453)
* [DeleteJobConfigs](https://cloud.tencent.com/document/api/849/100454)
* [ModifyFolder](https://cloud.tencent.com/document/api/849/100452)
* [ModifyWorkSpace](https://cloud.tencent.com/document/api/849/100450)

### 第 41 次发布

发布时间：2023-10-18 02:29:23

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [FetchSqlGatewayStatementResult](https://cloud.tencent.com/document/api/849/100321)

	* 新增入参：ClusterId, SessionId, OperationHandleId, ResultUri

	* 新增出参：ErrorMessage, ResultType, IsQueryResult, ResultKind, Results, NextResultUri

* [RunSqlGatewayStatement](https://cloud.tencent.com/document/api/849/100320)

	* 新增入参：ClusterId, Sql, SessionId

	* 新增出参：ErrorMessage, SessionId, OperationHandleId


新增数据结构：

* [LogicalType](https://cloud.tencent.com/document/api/849/52010#LogicalType)
* [ResultColumn](https://cloud.tencent.com/document/api/849/52010#ResultColumn)
* [ResultData](https://cloud.tencent.com/document/api/849/52010#ResultData)
* [StatementResult](https://cloud.tencent.com/document/api/849/52010#StatementResult)

### 第 40 次发布

发布时间：2023-10-17 01:22:49

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [FetchSqlGatewayStatementResult](https://cloud.tencent.com/document/api/849/100321)
* [RunSqlGatewayStatement](https://cloud.tencent.com/document/api/849/100320)

### 第 39 次发布

发布时间：2023-10-12 02:20:57

本次发布包含了以下内容：

改善已有的文档。

新增数据结构：

* [GatewayRefItem](https://cloud.tencent.com/document/api/849/52010#GatewayRefItem)
* [SqlGatewayItem](https://cloud.tencent.com/document/api/849/52010#SqlGatewayItem)

修改数据结构：

* [Cluster](https://cloud.tencent.com/document/api/849/52010#Cluster)

	* 新增成员：SqlGateways


### 第 38 次发布

发布时间：2023-09-06 02:10:27

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [RunJobDescription](https://cloud.tencent.com/document/api/849/52010#RunJobDescription)

	* 新增成员：CustomTimestamp


### 第 37 次发布

发布时间：2023-08-31 01:20:56

本次发布包含了以下内容：

改善已有的文档。

新增数据结构：

* [Order](https://cloud.tencent.com/document/api/849/52010#Order)

修改数据结构：

* [Cluster](https://cloud.tencent.com/document/api/849/52010#Cluster)

	* 新增成员：ArchGeneration, ClusterType, Orders

	* <font color="#dd0000">**修改成员**：</font>ClusterSessions


### 第 36 次发布

发布时间：2023-08-01 01:34:42

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateJobConfig](https://cloud.tencent.com/document/api/849/52004)

	* 新增入参：ClazzLevels, ExpertModeOn, ExpertModeConfiguration


新增数据结构：

* [ClazzLevel](https://cloud.tencent.com/document/api/849/52010#ClazzLevel)
* [ExpertModeConfiguration](https://cloud.tencent.com/document/api/849/52010#ExpertModeConfiguration)
* [JobGraph](https://cloud.tencent.com/document/api/849/52010#JobGraph)
* [JobGraphEdge](https://cloud.tencent.com/document/api/849/52010#JobGraphEdge)
* [JobGraphNode](https://cloud.tencent.com/document/api/849/52010#JobGraphNode)
* [NodeConfig](https://cloud.tencent.com/document/api/849/52010#NodeConfig)
* [SlotSharingGroup](https://cloud.tencent.com/document/api/849/52010#SlotSharingGroup)
* [SlotSharingGroupSpec](https://cloud.tencent.com/document/api/849/52010#SlotSharingGroupSpec)

修改数据结构：

* [JobConfig](https://cloud.tencent.com/document/api/849/52010#JobConfig)

	* 新增成员：ClazzLevels, ExpertModeOn, ExpertModeConfiguration


### 第 35 次发布

发布时间：2023-07-17 01:29:44

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeJobSubmissionLog](https://cloud.tencent.com/document/api/849/95069)

新增数据结构：

* [JobInstanceForSubmissionLog](https://cloud.tencent.com/document/api/849/52010#JobInstanceForSubmissionLog)
* [LogContent](https://cloud.tencent.com/document/api/849/52010#LogContent)

### 第 34 次发布

发布时间：2023-06-19 01:30:56

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeWorkSpaces](https://cloud.tencent.com/document/api/849/94138)

新增数据结构：

* [ClusterGroupSetItem](https://cloud.tencent.com/document/api/849/52010#ClusterGroupSetItem)
* [RoleAuth](https://cloud.tencent.com/document/api/849/52010#RoleAuth)
* [WorkSpaceSetItem](https://cloud.tencent.com/document/api/849/52010#WorkSpaceSetItem)

### 第 33 次发布

发布时间：2023-05-29 01:34:54

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateJob](https://cloud.tencent.com/document/api/849/52009)

	* 新增入参：Tags


修改数据结构：

* [JobV1](https://cloud.tencent.com/document/api/849/52010#JobV1)

	* 新增成员：Tags

* [TreeResourceItem](https://cloud.tencent.com/document/api/849/52010#TreeResourceItem)

	* 新增成员：RefJobStatusCountSet


### 第 32 次发布

发布时间：2023-05-12 01:39:08

本次发布包含了以下内容：

改善已有的文档。

新增数据结构：

* [ClusterSession](https://cloud.tencent.com/document/api/849/52010#ClusterSession)

修改数据结构：

* [Cluster](https://cloud.tencent.com/document/api/849/52010#Cluster)

	* 新增成员：ClusterSessions


### 第 31 次发布

发布时间：2023-05-10 01:38:48

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [CopyJobItem](https://cloud.tencent.com/document/api/849/52010#CopyJobItem)

	* 新增成员：SourceId, TargetClusterId, SourceName, TargetName, TargetFolderId, JobType

* [CopyJobResult](https://cloud.tencent.com/document/api/849/52010#CopyJobResult)

	* 新增成员：JobId, JobName, TargetJobName, TargetJobId, Message, Result, ClusterName, ClusterId, JobType


### 第 30 次发布

发布时间：2023-03-09 01:40:49

本次发布包含了以下内容：

改善已有的文档。

新增数据结构：

* [RefJobStatusCountItem](https://cloud.tencent.com/document/api/849/52010#RefJobStatusCountItem)

修改数据结构：

* [ResourceConfigItem](https://cloud.tencent.com/document/api/849/52010#ResourceConfigItem)

	* 新增成员：RefJobStatusCountSet

* [ResourceItem](https://cloud.tencent.com/document/api/849/52010#ResourceItem)

	* 新增成员：IsJobRun, FileName, WorkSpaceId, RefJobStatusCountSet

	* <font color="#dd0000">**修改成员**：</font>ResourceId, Name, ResourceType, ResourceLoc, Region, AppId, OwnerUin, CreatorUin, CreateTime, UpdateTime, LatestResourceConfigVersion, Remark, VersionCount, RefJobCount

* [RunJobDescription](https://cloud.tencent.com/document/api/849/52010#RunJobDescription)

	* 新增成员：UseOldSystemConnector


### 第 29 次发布

发布时间：2023-02-21 01:54:49

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeTreeResources](https://cloud.tencent.com/document/api/849/79568)

	* 新增出参：ParentId, Id, Name, Items, Children, TotalCount


新增数据结构：

* [DescribeTreeResourcesRsp](https://cloud.tencent.com/document/api/849/52010#DescribeTreeResourcesRsp)
* [TreeResourceItem](https://cloud.tencent.com/document/api/849/52010#TreeResourceItem)

### 第 28 次发布

发布时间：2023-01-13 01:40:40

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [Savepoint](https://cloud.tencent.com/document/api/849/52010#Savepoint)

	* 新增成员：TimeConsuming, PathStatus

	* <font color="#dd0000">**修改成员**：</font>Id, VersionId, Status, CreateTime, UpdateTime, Path, Size, RecordType, JobRuntimeId, Description, Timeout, SerialId


### 第 27 次发布

发布时间：2022-10-27 06:45:50

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [WorkSpaceClusterItem](https://cloud.tencent.com/document/api/849/52010#WorkSpaceClusterItem)

	* 新增成员：ProjectId, ProjectIdStr


### 第 26 次发布

发布时间：2022-09-27 06:36:12

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [Cluster](https://cloud.tencent.com/document/api/849/52010#Cluster)

	* 新增成员：IsNeedManageNode


### 第 25 次发布

发布时间：2022-08-30 06:43:16

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateJobConfig](https://cloud.tencent.com/document/api/849/52004)

	* 新增入参：AutoRecover


修改数据结构：

* [JobConfig](https://cloud.tencent.com/document/api/849/52010#JobConfig)

	* 新增成员：AutoRecover, LogLevel


### 第 24 次发布

发布时间：2022-08-25 06:41:36

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeTreeResources](https://cloud.tencent.com/document/api/849/79568)

### 第 23 次发布

发布时间：2022-07-26 06:19:20

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CopyJobs](https://cloud.tencent.com/document/api/849/77740)

	* 新增入参：JobItems, WorkSpaceId

	* 新增出参：SuccessCount, FailCount, CopyJobsResults

* [CreateFolder](https://cloud.tencent.com/document/api/849/77739)

	* 新增入参：FolderName, ParentId

	* 新增出参：FolderId


新增数据结构：

* [CopyJobItem](https://cloud.tencent.com/document/api/849/52010#CopyJobItem)
* [CopyJobResult](https://cloud.tencent.com/document/api/849/52010#CopyJobResult)

### 第 22 次发布

发布时间：2022-07-25 06:12:04

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CopyJobs](https://cloud.tencent.com/document/api/849/77740)
* [CreateFolder](https://cloud.tencent.com/document/api/849/77739)

### 第 21 次发布

发布时间：2022-07-13 06:14:33

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DeleteJobs](https://cloud.tencent.com/document/api/849/76834)
* [DescribeClusters](https://cloud.tencent.com/document/api/849/76832)
* [DescribeTreeJobs](https://cloud.tencent.com/document/api/849/76833)

新增数据结构：

* [CCN](https://cloud.tencent.com/document/api/849/52010#CCN)
* [Cluster](https://cloud.tencent.com/document/api/849/52010#Cluster)
* [ClusterVersion](https://cloud.tencent.com/document/api/849/52010#ClusterVersion)
* [Tag](https://cloud.tencent.com/document/api/849/52010#Tag)
* [WorkSpaceClusterItem](https://cloud.tencent.com/document/api/849/52010#WorkSpaceClusterItem)

### 第 20 次发布

发布时间：2022-07-04 06:14:12

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateJobConfig](https://cloud.tencent.com/document/api/849/52004)

	* 新增入参：LogLevel


### 第 19 次发布

发布时间：2022-06-15 06:12:20

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [ModifyJob](https://cloud.tencent.com/document/api/849/75553)

### 第 18 次发布

发布时间：2022-06-08 06:13:07

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [TriggerJobSavepoint](https://cloud.tencent.com/document/api/849/75095)

### 第 17 次发布

发布时间：2022-05-23 06:11:33

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CheckSavepoint](https://cloud.tencent.com/document/api/849/74227)
* [DescribeJobSavepoint](https://cloud.tencent.com/document/api/849/74226)

新增数据结构：

* [Savepoint](https://cloud.tencent.com/document/api/849/52010#Savepoint)

### 第 16 次发布

发布时间：2022-03-03 08:09:36

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateJob](https://cloud.tencent.com/document/api/849/52009)

	* 新增入参：WorkSpaceId

* [CreateJobConfig](https://cloud.tencent.com/document/api/849/52004)

	* 新增入参：WorkSpaceId

* [CreateResource](https://cloud.tencent.com/document/api/849/52000)

	* 新增入参：WorkSpaceId

* [CreateResourceConfig](https://cloud.tencent.com/document/api/849/51997)

	* 新增入参：WorkSpaceId

* [DeleteResourceConfigs](https://cloud.tencent.com/document/api/849/54667)

	* 新增入参：WorkSpaceId

* [DeleteResources](https://cloud.tencent.com/document/api/849/54670)

	* 新增入参：WorkSpaceId

* [DeleteTableConfig](https://cloud.tencent.com/document/api/849/52002)

	* 新增入参：WorkSpaceId

* [DescribeJobConfigs](https://cloud.tencent.com/document/api/849/52875)

	* 新增入参：WorkSpaceId

* [DescribeJobs](https://cloud.tencent.com/document/api/849/52008)

	* 新增入参：WorkSpaceId

* [DescribeResourceConfigs](https://cloud.tencent.com/document/api/849/54666)

	* 新增入参：WorkSpaceId

* [DescribeResourceRelatedJobs](https://cloud.tencent.com/document/api/849/54669)

	* 新增入参：WorkSpaceId

* [DescribeResources](https://cloud.tencent.com/document/api/849/54668)

	* 新增入参：WorkSpaceId

* [RunJobs](https://cloud.tencent.com/document/api/849/52007)

	* 新增入参：WorkSpaceId

* [StopJobs](https://cloud.tencent.com/document/api/849/52006)

	* 新增入参：WorkSpaceId


修改数据结构：

* [JobV1](https://cloud.tencent.com/document/api/849/52010#JobV1)

	* 新增成员：WorkSpaceId, WorkSpaceName


### 第 15 次发布

发布时间：2022-02-24 08:11:34

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateJobConfig](https://cloud.tencent.com/document/api/849/52004)

	* 新增入参：PythonVersion


修改数据结构：

* [JobConfig](https://cloud.tencent.com/document/api/849/52010#JobConfig)

	* 新增成员：PythonVersion


### 第 14 次发布

发布时间：2022-01-25 08:15:03

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateJobConfig](https://cloud.tencent.com/document/api/849/52004)

	* 新增入参：LogCollectType


### 第 13 次发布

发布时间：2021-12-21 08:08:44

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [RunJobDescription](https://cloud.tencent.com/document/api/849/52010#RunJobDescription)

	* 新增成员：SavepointPath, SavepointId


### 第 12 次发布

发布时间：2021-12-07 08:09:58

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateJobConfig](https://cloud.tencent.com/document/api/849/52004)

	* 新增入参：ClsLogsetId, ClsTopicId


修改数据结构：

* [JobConfig](https://cloud.tencent.com/document/api/849/52010#JobConfig)

	* 新增成员：ClsLogsetId, ClsTopicId


### 第 11 次发布

发布时间：2021-11-15 08:11:30

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateResource](https://cloud.tencent.com/document/api/849/52000)

	* 新增入参：FolderId

	* <font color="#dd0000">**修改入参**：</font>Name

* [DescribeResourceRelatedJobs](https://cloud.tencent.com/document/api/849/54669)

	* 新增入参：ResourceConfigVersion


### 第 10 次发布

发布时间：2021-09-24 10:00:20

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateJob](https://cloud.tencent.com/document/api/849/52009)

	* 新增入参：FlinkVersion

* [DescribeSystemResources](https://cloud.tencent.com/document/api/849/51999)

	* 新增入参：FlinkVersion


### 第 9 次发布

发布时间：2021-09-06 08:01:03

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [JobV1](https://cloud.tencent.com/document/api/849/52010#JobV1)

	* 新增成员：FlinkVersion


### 第 8 次发布

发布时间：2021-08-12 08:01:27

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateJob](https://cloud.tencent.com/document/api/849/52009)

	* 新增入参：FolderId


### 第 7 次发布

发布时间：2021-06-24 08:01:29

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateJobConfig](https://cloud.tencent.com/document/api/849/52004)

	* 新增入参：JobManagerSpec, TaskManagerSpec


修改数据结构：

* [JobConfig](https://cloud.tencent.com/document/api/849/52010#JobConfig)

	* 新增成员：JobManagerSpec, TaskManagerSpec

* [JobV1](https://cloud.tencent.com/document/api/849/52010#JobV1)

	* 新增成员：RunningCu


### 第 6 次发布

发布时间：2021-04-15 08:00:16

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [JobConfig](https://cloud.tencent.com/document/api/849/52010#JobConfig)

	* 新增成员：MaxParallelism


### 第 5 次发布

发布时间：2021-04-14 08:00:14

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DeleteResourceConfigs](https://cloud.tencent.com/document/api/849/54667)
* [DeleteResources](https://cloud.tencent.com/document/api/849/54670)
* [DescribeResourceConfigs](https://cloud.tencent.com/document/api/849/54666)
* [DescribeResourceRelatedJobs](https://cloud.tencent.com/document/api/849/54669)
* [DescribeResources](https://cloud.tencent.com/document/api/849/54668)

新增数据结构：

* [ResourceConfigItem](https://cloud.tencent.com/document/api/849/52010#ResourceConfigItem)
* [ResourceItem](https://cloud.tencent.com/document/api/849/52010#ResourceItem)
* [ResourceRefJobInfo](https://cloud.tencent.com/document/api/849/52010#ResourceRefJobInfo)

### 第 4 次发布

发布时间：2021-02-05 14:54:40

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeJobConfigs](https://cloud.tencent.com/document/api/849/52875)

新增数据结构：

* [JobConfig](https://cloud.tencent.com/document/api/849/52010#JobConfig)
* [ResourceRefDetail](https://cloud.tencent.com/document/api/849/52010#ResourceRefDetail)

### 第 3 次发布

发布时间：2021-02-03 08:00:06

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateJobConfig](https://cloud.tencent.com/document/api/849/52004)

	* 新增入参：LogCollect


### 第 2 次发布

发布时间：2021-01-25 08:00:06

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [JobV1](https://cloud.tencent.com/document/api/849/52010#JobV1)

	* 新增成员：ClusterStatus


### 第 1 次发布

发布时间：2021-01-14 14:22:54

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateJob](https://cloud.tencent.com/document/api/849/52009)
* [CreateJobConfig](https://cloud.tencent.com/document/api/849/52004)
* [CreateResource](https://cloud.tencent.com/document/api/849/52000)
* [CreateResourceConfig](https://cloud.tencent.com/document/api/849/51997)
* [DeleteTableConfig](https://cloud.tencent.com/document/api/849/52002)
* [DescribeJobs](https://cloud.tencent.com/document/api/849/52008)
* [DescribeSystemResources](https://cloud.tencent.com/document/api/849/51999)
* [RunJobs](https://cloud.tencent.com/document/api/849/52007)
* [StopJobs](https://cloud.tencent.com/document/api/849/52006)

新增数据结构：

* [Filter](https://cloud.tencent.com/document/api/849/52010#Filter)
* [JobV1](https://cloud.tencent.com/document/api/849/52010#JobV1)
* [Property](https://cloud.tencent.com/document/api/849/52010#Property)
* [ResourceLoc](https://cloud.tencent.com/document/api/849/52010#ResourceLoc)
* [ResourceLocParam](https://cloud.tencent.com/document/api/849/52010#ResourceLocParam)
* [ResourceRef](https://cloud.tencent.com/document/api/849/52010#ResourceRef)
* [RunJobDescription](https://cloud.tencent.com/document/api/849/52010#RunJobDescription)
* [StopJobDescription](https://cloud.tencent.com/document/api/849/52010#StopJobDescription)
* [SystemResourceItem](https://cloud.tencent.com/document/api/849/52010#SystemResourceItem)




## 文字识别(ocr) 版本：2018-11-19

### 第 144 次发布

发布时间：2024-07-29 02:00:34

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [VerifyOfdVatInvoiceOCR](https://cloud.tencent.com/document/api/866/52296)

	* 新增出参：InvoiceTitle


### 第 143 次发布

发布时间：2024-07-25 02:00:21

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [PermitOCR](https://cloud.tencent.com/document/api/866/37074)

	* 新增入参：CropPortrait

	* 新增出参：PortraitImage


### 第 142 次发布

发布时间：2024-07-09 01:19:41

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [VerifyOfdVatInvoiceOCR](https://cloud.tencent.com/document/api/866/52296)

	* 新增入参：OfdPageNumber


### 第 141 次发布

发布时间：2024-07-03 01:21:25

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [AdvertiseOCR](https://cloud.tencent.com/document/api/866/49524)

	* 新增出参：ImageSize


新增数据结构：

* [ImageSize](https://cloud.tencent.com/document/api/866/33527#ImageSize)

### 第 140 次发布

发布时间：2024-06-28 01:16:42

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [BizLicenseOCR](https://cloud.tencent.com/document/api/866/36215)

	* 新增入参：EnablePeriodComplete


修改数据结构：

* [TrainTicket](https://cloud.tencent.com/document/api/866/33527#TrainTicket)

	* 新增成员：TicketChangeMark


### 第 139 次发布

发布时间：2024-06-26 01:21:05

本次发布包含了以下内容：

改善已有的文档。

<font color="#dd0000">**预下线接口**：</font>

* VatInvoiceVerify

### 第 138 次发布

发布时间：2024-06-21 02:02:31

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [VatInvoiceVerifyNew](https://cloud.tencent.com/document/api/866/73674)

	* 新增出参：FinancialBill


新增数据结构：

* [FinancialBill](https://cloud.tencent.com/document/api/866/33527#FinancialBill)
* [FinancialBillItem](https://cloud.tencent.com/document/api/866/33527#FinancialBillItem)
* [FinancialBillItemDetails](https://cloud.tencent.com/document/api/866/33527#FinancialBillItemDetails)

### 第 137 次发布

发布时间：2024-05-28 01:59:27

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [BizLicenseOCR](https://cloud.tencent.com/document/api/866/36215)

	* 新增出参：NationalEmblem, QRCode, Seal, Title, SerialNumber, RegistrationAuthority


### 第 136 次发布

发布时间：2024-05-21 01:58:59

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [RecognizeThaiIDCardOCR](https://cloud.tencent.com/document/api/866/48475)

	* 新增出参：EnIssueDate, EnExpirationDate, EnBirthday, Religion, SerialNumber


### 第 135 次发布

发布时间：2024-05-14 02:17:52

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [HKIDCardOCR](https://cloud.tencent.com/document/api/866/46919)

	* <font color="#dd0000">**修改入参**：</font>DetectFake

	* 新增出参：WarnCardInfos

* [MLIDCardOCR](https://cloud.tencent.com/document/api/866/37656)

	* 新增出参：WarnCardInfos

* [RecognizeIndonesiaIDCardOCR](https://cloud.tencent.com/document/api/866/75195)

	* 新增出参：WarnCardInfos

* [RecognizeThaiIDCardOCR](https://cloud.tencent.com/document/api/866/48475)

	* 新增出参：WarnCardInfos


### 第 134 次发布

发布时间：2024-04-29 01:21:11

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [RecognizeGeneralTextImageWarn](https://cloud.tencent.com/document/api/866/105752)

新增数据结构：

* [GeneralWarnInfo](https://cloud.tencent.com/document/api/866/33527#GeneralWarnInfo)

### 第 133 次发布

发布时间：2024-04-03 11:24:26

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [DocumentElement](https://cloud.tencent.com/document/api/866/33527#DocumentElement)

	* 新增成员：InsetImageName


### 第 132 次发布

发布时间：2024-03-27 16:33:01

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [ReconstructDocument](https://cloud.tencent.com/document/api/866/104610)

新增数据结构：

* [DocumentElement](https://cloud.tencent.com/document/api/866/33527#DocumentElement)
* [DocumentRecognizeInfo](https://cloud.tencent.com/document/api/866/33527#DocumentRecognizeInfo)
* [ReconstructDocumentConfig](https://cloud.tencent.com/document/api/866/33527#ReconstructDocumentConfig)

### 第 131 次发布

发布时间：2024-03-13 01:20:34

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [VatInvoiceVerifyNew](https://cloud.tencent.com/document/api/866/73674)

	* 新增入参：EnableTodayInvoice


### 第 130 次发布

发布时间：2024-02-21 01:20:39

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [RecognizeForeignPermanentResidentIdCard](https://cloud.tencent.com/document/api/866/103033)

	* 新增出参：PreviousNumber, IssuedAuthority


### 第 129 次发布

发布时间：2024-01-26 01:18:14

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [RecognizeEncryptedIDCardOCR](https://cloud.tencent.com/document/api/866/103433)

修改接口：

* [MLIDPassportOCR](https://cloud.tencent.com/document/api/866/37657)

	* 新增入参：ImageUrl

	* <font color="#dd0000">**修改入参**：</font>ImageBase64


新增数据结构：

* [Encryption](https://cloud.tencent.com/document/api/866/33527#Encryption)

修改数据结构：

* [PassportRecognizeInfos](https://cloud.tencent.com/document/api/866/33527#PassportRecognizeInfos)

	* 新增成员：Signature, IssuePlace, IssuingAuthority


### 第 128 次发布

发布时间：2024-01-16 01:19:57

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [RecognizeForeignPermanentResidentIdCard](https://cloud.tencent.com/document/api/866/103033)

### 第 127 次发布

发布时间：2024-01-12 01:20:10

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [SealOCR](https://cloud.tencent.com/document/api/866/45807)

	* 新增入参：EnablePdf, PdfPageNumber


### 第 126 次发布

发布时间：2024-01-05 01:21:40

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [SmartStructuralOCRV2](https://cloud.tencent.com/document/api/866/90013)

	* 新增入参：EnableSealRecognize


### 第 125 次发布

发布时间：2023-12-21 01:56:34

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [VatInvoiceVerifyNew](https://cloud.tencent.com/document/api/866/73674)

	* 新增出参：ElectronicTrainTicket, ElectronicAirTransport


新增数据结构：

* [ElectronicAirTransport](https://cloud.tencent.com/document/api/866/33527#ElectronicAirTransport)
* [ElectronicAirTransportDetail](https://cloud.tencent.com/document/api/866/33527#ElectronicAirTransportDetail)
* [ElectronicTrainTicket](https://cloud.tencent.com/document/api/866/33527#ElectronicTrainTicket)

修改数据结构：

* [VatInvoice](https://cloud.tencent.com/document/api/866/33527#VatInvoice)

	* 新增成员：ElectronicType


### 第 124 次发布

发布时间：2023-12-08 02:12:05

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [TextVehicleBack](https://cloud.tencent.com/document/api/866/33527#TextVehicleBack)

	* 新增成员：FuelType

	* <font color="#dd0000">**修改成员**：</font>SubPageCode


### 第 123 次发布

发布时间：2023-12-05 02:08:42

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [BizLicenseOCR](https://cloud.tencent.com/document/api/866/36215)

	* 新增出参：Angle


### 第 122 次发布

发布时间：2023-11-30 05:24:08

本次发布包含了以下内容：

改善已有的文档。

新增数据结构：

* [ElectronicFlightTicketFull](https://cloud.tencent.com/document/api/866/33527#ElectronicFlightTicketFull)
* [ElectronicTrainTicketFull](https://cloud.tencent.com/document/api/866/33527#ElectronicTrainTicketFull)
* [FlightItemInfo](https://cloud.tencent.com/document/api/866/33527#FlightItemInfo)

修改数据结构：

* [SingleInvoiceItem](https://cloud.tencent.com/document/api/866/33527#SingleInvoiceItem)

	* 新增成员：ElectronicTrainTicketFull, ElectronicFlightTicketFull


### 第 121 次发布

发布时间：2023-11-20 00:15:46

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [MLIDPassportOCR](https://cloud.tencent.com/document/api/866/37657)

	* 新增出参：Type, PassportRecognizeInfos


新增数据结构：

* [PassportRecognizeInfos](https://cloud.tencent.com/document/api/866/33527#PassportRecognizeInfos)

### 第 120 次发布

发布时间：2023-11-16 01:25:49

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [MotorVehicleSaleInvoice](https://cloud.tencent.com/document/api/866/33527#MotorVehicleSaleInvoice)

	* 新增成员：TaxPayNum, TaxCode

	* <font color="#dd0000">**修改成员**：</font>Title, Code, Number, Date, PretaxAmount, Total, TotalCn, Seller, SellerTaxID, SellerTel, SellerAddress, SellerBank, SellerBankAccount, Buyer, BuyerTaxID, BuyerID, TaxAuthorities, TaxAuthoritiesCode, VIN, VehicleModel, VehicleEngineCode, CertificateNumber, InspectionNumber, MachineID, VehicleType, Kind, Province, City, Tax, TaxRate, CompanySealMark, Tonnage, Remark, FormType, FormName, Issuer, TaxNum, MaxPeopleNum, Origin, MachineCode, MachineNumber, QRCodeMark

* [UsedCarPurchaseInvoice](https://cloud.tencent.com/document/api/866/33527#UsedCarPurchaseInvoice)

	* 新增成员：AuctionOrgName, AuctionOrgAddress, AuctionOrgTaxID, AuctionOrgBankAccount, AuctionOrgPhone, Issuer, TaxCode, MachineSerialNumber, MachineCode, MachineNumber

	* <font color="#dd0000">**修改成员**：</font>Title, QRCodeMark, Code, Number, Date, Total, TotalCn, Seller, SellerTel, SellerTaxID, SellerAddress, Buyer, BuyerID, BuyerAddress, BuyerTel, CompanyName, CompanyTaxID, CompanyBankAccount, CompanyTel, CompanyAddress, TransferAdministrationName, LicensePlate, RegistrationNumber, VIN, VehicleModel, Kind, Province, City, VehicleType, Remark, FormType, FormName, CompanySealMark


### 第 119 次发布

发布时间：2023-11-15 02:11:27

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [IDCardOCR](https://cloud.tencent.com/document/api/866/33524)

	* 新增入参：EnableReflectDetail

	* 新增出参：ReflectDetailInfos


新增数据结构：

* [ReflectDetailInfo](https://cloud.tencent.com/document/api/866/33527#ReflectDetailInfo)

### 第 118 次发布

发布时间：2023-11-14 01:22:01

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [MainlandPermitOCR](https://cloud.tencent.com/document/api/866/43105)

	* 新增入参：CardSide

	* 新增出参：MainlandTravelPermitBackInfos


新增数据结构：

* [MainlandTravelPermitBackInfos](https://cloud.tencent.com/document/api/866/33527#MainlandTravelPermitBackInfos)

### 第 117 次发布

发布时间：2023-11-10 01:21:12

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [VerifyOfdVatInvoiceOCR](https://cloud.tencent.com/document/api/866/52296)

	* 新增出参：AirTicketInfo, RailwayTicketInfo


新增数据结构：

* [AirTicketInfo](https://cloud.tencent.com/document/api/866/33527#AirTicketInfo)
* [DetailInformationOfAirTicketTupleList](https://cloud.tencent.com/document/api/866/33527#DetailInformationOfAirTicketTupleList)
* [RailwayTicketInfo](https://cloud.tencent.com/document/api/866/33527#RailwayTicketInfo)

### 第 116 次发布

发布时间：2023-11-08 01:58:53

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [VatInvoice](https://cloud.tencent.com/document/api/866/33527#VatInvoice)

	* 新增成员：RedLetterInvoiceMark, IssuingTypeMark, SellerAgentName, SellerAgentTaxID


### 第 115 次发布

发布时间：2023-10-31 02:11:36

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [RecognizeGeneralInvoice](https://cloud.tencent.com/document/api/866/90802)

	* 新增入参：EnableItemPolygon


新增数据结构：

* [ItemPolygonInfo](https://cloud.tencent.com/document/api/866/33527#ItemPolygonInfo)

修改数据结构：

* [InvoiceItem](https://cloud.tencent.com/document/api/866/33527#InvoiceItem)

	* 新增成员：ItemPolygon


### 第 114 次发布

发布时间：2023-10-30 01:04:20

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DriverLicenseOCR](https://cloud.tencent.com/document/api/866/36213)

	* 新增出参：BackPageName, BackPageCardCode


### 第 113 次发布

发布时间：2023-10-10 01:43:15

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [TrainTicket](https://cloud.tencent.com/document/api/866/33527#TrainTicket)

	* 新增成员：RefundMark

	* <font color="#dd0000">**修改成员**：</font>Title, Number, DateGetOn, TimeGetOn, Name, StationGetOn, StationGetOff, Seat, Total, Kind, SerialNumber, UserID, GateNumber, TrainNumber, HandlingFee, OriginalFare, TotalCn, SeatNumber, PickUpAddress, TicketChange, AdditionalFare, ReceiptNumber, QRCodeMark, ReimburseOnlyMark


### 第 112 次发布

发布时间：2023-09-21 04:56:57

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [GeneralAccurateOCR](https://cloud.tencent.com/document/api/866/34937)

	* 新增入参：EnableDetectText

	* 新增出参：Angle


### 第 111 次发布

发布时间：2023-09-12 02:18:31

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DriverLicenseOCR](https://cloud.tencent.com/document/api/866/36213)

	* 新增出参：CurrentTime, GenerateTime


### 第 110 次发布

发布时间：2023-08-09 01:39:38

本次发布包含了以下内容：

改善已有的文档。

<font color="#dd0000">**删除接口**：</font>

* VerifyBasicBizLicense
* VerifyBizLicense

<font color="#dd0000">**删除数据结构**：</font>

* BizLicenseVerifyResult

### 第 109 次发布

发布时间：2023-07-31 01:34:27

本次发布包含了以下内容：

改善已有的文档。

<font color="#dd0000">**删除接口**：</font>

* QueryBarCode
* VerifyEnterpriseFourFactors

<font color="#dd0000">**删除数据结构**：</font>

* Detail
* ProductDataRecord

### 第 108 次发布

发布时间：2023-07-27 01:16:57

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [IDCardOCR](https://cloud.tencent.com/document/api/866/33524)

	* 新增入参：EnableRecognitionRectify


### 第 107 次发布

发布时间：2023-07-26 01:30:16

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [OtherInvoice](https://cloud.tencent.com/document/api/866/33527#OtherInvoice)

	* 新增成员：Date

	* <font color="#dd0000">**修改成员**：</font>Title, Total, OtherInvoiceListItems, OtherInvoiceTableItems

* [SingleInvoiceItem](https://cloud.tencent.com/document/api/866/33527#SingleInvoiceItem)

	* 新增成员：VatSalesList

	* <font color="#dd0000">**修改成员**：</font>VatElectronicSpecialInvoice, VatElectronicInvoiceBlockchain, VatElectronicInvoiceToll, VatElectronicSpecialInvoiceFull, VatElectronicInvoiceFull, MachinePrintedInvoice, BusInvoice, ShippingInvoice, TollInvoice, OtherInvoice, MotorVehicleSaleInvoice, UsedCarPurchaseInvoice, VatInvoiceRoll, TaxiTicket, QuotaInvoice, AirTransport, NonTaxIncomeGeneralBill, NonTaxIncomeElectronicBill, TrainTicket, MedicalOutpatientInvoice, MedicalHospitalizedInvoice

* [VatInvoiceInfo](https://cloud.tencent.com/document/api/866/33527#VatInvoiceInfo)

	* 新增成员：BlockChainMark, AcquisitionMark, SubTotal, SubTax

	* <font color="#dd0000">**修改成员**：</font>CheckCode, FormType, TravelTax, BuyerAddrTel, BuyerBankAccount, CompanySealContent, TaxSealContent, ServiceName, City, QRCodeMark, AgentMark, TransitMark, OilMark, Title, Kind, Code, Number, NumberConfirm, Date, Total, TotalCn, PretaxAmount, Tax, MachineCode, Ciphertext, Remark, Seller, SellerTaxID, SellerAddrTel, SellerBankAccount, Buyer, BuyerTaxID, CompanySealMark, Issuer, Reviewer, Province, VatInvoiceItemInfos, CodeConfirm, Receiptor, ElectronicFullMark, ElectronicFullNumber, FormName

* [VatInvoiceItemInfo](https://cloud.tencent.com/document/api/866/33527#VatInvoiceItemInfo)

	* 新增成员：SerialNumber

	* <font color="#dd0000">**修改成员**：</font>Name, Specification, Unit, Quantity, Price, Total, TaxRate, Tax, DateStart, DateEnd, LicensePlate, VehicleType

* [VatInvoiceRoll](https://cloud.tencent.com/document/api/866/33527#VatInvoiceRoll)

	* <font color="#dd0000">**修改成员**：</font>Title, Code, Number, NumberConfirm, Date, CheckCode, Seller, SellerTaxID, Buyer, BuyerTaxID, Category, Total, TotalCn, Kind, Province, City, CompanySealMark, QRCodeMark, ServiceName, CompanySealContent, TaxSealContent, VatRollItems


### 第 106 次发布

发布时间：2023-07-19 01:34:27

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [GeneralBasicOCR](https://cloud.tencent.com/document/api/866/33526)

	* 新增出参：Angle

* [SmartStructuralOCRV2](https://cloud.tencent.com/document/api/866/90013)

	* 新增入参：ConfigId


### 第 105 次发布

发布时间：2023-07-17 01:30:01

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [InvoiceItem](https://cloud.tencent.com/document/api/866/33527#InvoiceItem)

	* <font color="#dd0000">**修改成员**：</font>Page, SubType, TypeDescription, CutImage, SubTypeDescription


### 第 104 次发布

发布时间：2023-06-13 01:30:41

本次发布包含了以下内容：

改善已有的文档。

新增数据结构：

* [MedicalInvoice](https://cloud.tencent.com/document/api/866/33527#MedicalInvoice)

修改数据结构：

* [SingleInvoiceItem](https://cloud.tencent.com/document/api/866/33527#SingleInvoiceItem)

	* 新增成员：MedicalOutpatientInvoice, MedicalHospitalizedInvoice

* [VatInvoiceInfo](https://cloud.tencent.com/document/api/866/33527#VatInvoiceInfo)

	* 新增成员：ElectronicFullMark, ElectronicFullNumber, FormName


### 第 103 次发布

发布时间：2023-06-09 01:31:39

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [BizLicenseOCR](https://cloud.tencent.com/document/api/866/36215)

	* 新增入参：EnableCopyWarn


### 第 102 次发布

发布时间：2023-06-01 09:54:24

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [RecognizePhilippinesUMIDOCR](https://cloud.tencent.com/document/api/866/93042)

### 第 101 次发布

发布时间：2023-05-26 01:45:09

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [BizLicenseOCR](https://cloud.tencent.com/document/api/866/36215)

	* 新增出参：IsDuplication, RegistrationDate


### 第 100 次发布

发布时间：2023-05-25 01:49:38

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [VatInvoiceItem](https://cloud.tencent.com/document/api/866/33527#VatInvoiceItem)

	* 新增成员：VehicleType, VehicleBrand, DeparturePlace, ArrivalPlace, TransportItemsName, ConstructionPlace, ConstructionName


### 第 99 次发布

发布时间：2023-05-24 01:38:44

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateAIFormTask](https://cloud.tencent.com/document/api/866/86724)

	* 新增入参：FileType


### 第 98 次发布

发布时间：2023-05-23 01:33:15

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [Key](https://cloud.tencent.com/document/api/866/33527#Key)

	* 新增成员：ConfigName


### 第 97 次发布

发布时间：2023-05-19 01:50:18

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [TextVehicleBack](https://cloud.tencent.com/document/api/866/33527#TextVehicleBack)

	* 新增成员：SubPageCode


### 第 96 次发布

发布时间：2023-05-06 14:35:19

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [RecognizeGeneralInvoice](https://cloud.tencent.com/document/api/866/90802)

新增数据结构：

* [AirTransport](https://cloud.tencent.com/document/api/866/33527#AirTransport)
* [BusInvoice](https://cloud.tencent.com/document/api/866/33527#BusInvoice)
* [FlightItem](https://cloud.tencent.com/document/api/866/33527#FlightItem)
* [GeneralMachineItem](https://cloud.tencent.com/document/api/866/33527#GeneralMachineItem)
* [InvoiceItem](https://cloud.tencent.com/document/api/866/33527#InvoiceItem)
* [MachinePrintedInvoice](https://cloud.tencent.com/document/api/866/33527#MachinePrintedInvoice)
* [MotorVehicleSaleInvoice](https://cloud.tencent.com/document/api/866/33527#MotorVehicleSaleInvoice)
* [NonTaxIncomeBill](https://cloud.tencent.com/document/api/866/33527#NonTaxIncomeBill)
* [NonTaxItem](https://cloud.tencent.com/document/api/866/33527#NonTaxItem)
* [OtherInvoice](https://cloud.tencent.com/document/api/866/33527#OtherInvoice)
* [OtherInvoiceItem](https://cloud.tencent.com/document/api/866/33527#OtherInvoiceItem)
* [OtherInvoiceList](https://cloud.tencent.com/document/api/866/33527#OtherInvoiceList)
* [QuotaInvoice](https://cloud.tencent.com/document/api/866/33527#QuotaInvoice)
* [ShippingInvoice](https://cloud.tencent.com/document/api/866/33527#ShippingInvoice)
* [SingleInvoiceItem](https://cloud.tencent.com/document/api/866/33527#SingleInvoiceItem)
* [TaxiTicket](https://cloud.tencent.com/document/api/866/33527#TaxiTicket)
* [TollInvoice](https://cloud.tencent.com/document/api/866/33527#TollInvoice)
* [TrainTicket](https://cloud.tencent.com/document/api/866/33527#TrainTicket)
* [UsedCarPurchaseInvoice](https://cloud.tencent.com/document/api/866/33527#UsedCarPurchaseInvoice)
* [VatElectronicInfo](https://cloud.tencent.com/document/api/866/33527#VatElectronicInfo)
* [VatElectronicItemInfo](https://cloud.tencent.com/document/api/866/33527#VatElectronicItemInfo)
* [VatInvoiceInfo](https://cloud.tencent.com/document/api/866/33527#VatInvoiceInfo)
* [VatInvoiceItemInfo](https://cloud.tencent.com/document/api/866/33527#VatInvoiceItemInfo)
* [VatInvoiceRoll](https://cloud.tencent.com/document/api/866/33527#VatInvoiceRoll)
* [VatRollItem](https://cloud.tencent.com/document/api/866/33527#VatRollItem)

### 第 95 次发布

发布时间：2023-04-24 01:33:06

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [SmartStructuralOCRV2](https://cloud.tencent.com/document/api/866/90013)

	* 新增入参：ReturnFullText

	* 新增出参：WordList


新增数据结构：

* [WordItem](https://cloud.tencent.com/document/api/866/33527#WordItem)

### 第 94 次发布

发布时间：2023-04-20 01:31:28

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [RecognizePhilippinesSssIDOCR](https://cloud.tencent.com/document/api/866/90322)
* [RecognizePhilippinesTinIDOCR](https://cloud.tencent.com/document/api/866/90321)

### 第 93 次发布

发布时间：2023-04-10 01:46:41

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [SmartStructuralOCRV2](https://cloud.tencent.com/document/api/866/90013)

新增数据结构：

* [GroupInfo](https://cloud.tencent.com/document/api/866/33527#GroupInfo)
* [ItemInfo](https://cloud.tencent.com/document/api/866/33527#ItemInfo)
* [Key](https://cloud.tencent.com/document/api/866/33527#Key)
* [LineInfo](https://cloud.tencent.com/document/api/866/33527#LineInfo)
* [Value](https://cloud.tencent.com/document/api/866/33527#Value)

### 第 92 次发布

发布时间：2023-03-31 01:39:23

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [RecognizeIndonesiaIDCardOCR](https://cloud.tencent.com/document/api/866/75195)

	* 新增出参：Provinsi, Kota


### 第 91 次发布

发布时间：2023-03-30 01:49:43

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [SmartFormFileUrl](https://cloud.tencent.com/document/api/866/33527#SmartFormFileUrl)

	* 新增成员：FileUrl, FileOrderNumber


### 第 90 次发布

发布时间：2023-03-23 01:57:00

本次发布包含了以下内容：

改善已有的文档。

<font color="#dd0000">**预下线接口**：</font>

* QueryBarCode
* VerifyBasicBizLicense
* VerifyBizLicense
* VerifyEnterpriseFourFactors

### 第 89 次发布

发布时间：2023-03-15 01:57:48

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [MLIDPassportOCR](https://cloud.tencent.com/document/api/866/37657)

	* 新增出参：Surname, GivenName


### 第 88 次发布

发布时间：2023-03-02 01:30:53

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [MixedInvoiceOCR](https://cloud.tencent.com/document/api/866/37835)

	* 新增入参：ReturnMultiplePage


修改数据结构：

* [MixedInvoiceItem](https://cloud.tencent.com/document/api/866/33527#MixedInvoiceItem)

	* 新增成员：Page


### 第 87 次发布

发布时间：2023-02-21 01:55:12

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateAIFormTask](https://cloud.tencent.com/document/api/866/86724)
* [GetTaskState](https://cloud.tencent.com/document/api/866/86723)
* [RecognizeTableAccurateOCR](https://cloud.tencent.com/document/api/866/86721)

修改接口：

* [RecognizeThaiIDCardOCR](https://cloud.tencent.com/document/api/866/48475)

	* 新增入参：CropPortrait

	* 新增出参：PortraitImage


新增数据结构：

* [SmartFormFileUrl](https://cloud.tencent.com/document/api/866/33527#SmartFormFileUrl)
* [TableCellInfo](https://cloud.tencent.com/document/api/866/33527#TableCellInfo)
* [TableInfo](https://cloud.tencent.com/document/api/866/33527#TableInfo)

### 第 86 次发布

发布时间：2022-12-22 01:53:11

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [RecognizeHealthCodeOCR](https://cloud.tencent.com/document/api/866/68580)

	* 新增出参：VaccinationTime


### 第 85 次发布

发布时间：2022-12-12 01:39:40

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [SealOCR](https://cloud.tencent.com/document/api/866/45807)

	* 新增出参：SealShape


### 第 84 次发布

发布时间：2022-12-09 01:50:13

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [SealInfo](https://cloud.tencent.com/document/api/866/33527#SealInfo)

	* 新增成员：SealShape


### 第 83 次发布

发布时间：2022-11-23 06:43:01

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [OnlineTaxiItineraryInfo](https://cloud.tencent.com/document/api/866/33527#OnlineTaxiItineraryInfo)

	* 新增成员：Row


### 第 82 次发布

发布时间：2022-11-15 06:33:44

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [StructuralItem](https://cloud.tencent.com/document/api/866/33527#StructuralItem)

	* 新增成员：Row


### 第 81 次发布

发布时间：2022-11-02 06:33:46

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [VatInvoiceVerifyNew](https://cloud.tencent.com/document/api/866/73674)

	* 新增入参：RegionCode, SellerTaxCode, EnableCommonElectronic


### 第 80 次发布

发布时间：2022-10-28 06:39:14

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [BankSlipOCR](https://cloud.tencent.com/document/api/866/57674)

	* 新增入参：IsPdf, PdfPageNumber

* [BusInvoiceOCR](https://cloud.tencent.com/document/api/866/37838)

	* 新增入参：IsPdf, PdfPageNumber

* [CarInvoiceOCR](https://cloud.tencent.com/document/api/866/37076)

	* 新增入参：IsPdf, PdfPageNumber

* [DutyPaidProofOCR](https://cloud.tencent.com/document/api/866/37839)

	* 新增入参：IsPdf, PdfPageNumber

* [FlightInvoiceOCR](https://cloud.tencent.com/document/api/866/37075)

	* 新增入参：IsPdf, PdfPageNumber

* [InvoiceGeneralOCR](https://cloud.tencent.com/document/api/866/37837)

	* 新增入参：IsPdf, PdfPageNumber

* [MixedInvoiceDetect](https://cloud.tencent.com/document/api/866/37836)

	* 新增入参：IsPdf, PdfPageNumber

* [MixedInvoiceOCR](https://cloud.tencent.com/document/api/866/37835)

	* 新增入参：IsPdf, PdfPageNumber

* [QuotaInvoiceOCR](https://cloud.tencent.com/document/api/866/37073)

	* 新增入参：IsPdf, PdfPageNumber

* [RecognizeMedicalInvoiceOCR](https://cloud.tencent.com/document/api/866/80326)

	* 新增入参：IsPdf, PdfPageNumber

* [ShipInvoiceOCR](https://cloud.tencent.com/document/api/866/37834)

	* 新增入参：IsPdf, PdfPageNumber

* [TaxiInvoiceOCR](https://cloud.tencent.com/document/api/866/37072)

	* 新增入参：IsPdf, PdfPageNumber

* [TollInvoiceOCR](https://cloud.tencent.com/document/api/866/37833)

	* 新增入参：IsPdf, PdfPageNumber

* [TrainTicketOCR](https://cloud.tencent.com/document/api/866/37071)

	* 新增入参：IsPdf, PdfPageNumber

* [VatRollInvoiceOCR](https://cloud.tencent.com/document/api/866/37832)

	* 新增入参：IsPdf, PdfPageNumber

* [WaybillOCR](https://cloud.tencent.com/document/api/866/34934)

	* 新增入参：IsPdf, PdfPageNumber


### 第 79 次发布

发布时间：2022-09-21 06:39:36

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [ImageEnhancement](https://cloud.tencent.com/document/api/866/80801)

### 第 78 次发布

发布时间：2022-09-14 06:29:31

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [RecognizeHealthCodeOCR](https://cloud.tencent.com/document/api/866/68580)

	* 新增出参：SpotName


### 第 77 次发布

发布时间：2022-09-09 06:35:53

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [RecognizeMedicalInvoiceOCR](https://cloud.tencent.com/document/api/866/80326)

新增数据结构：

* [MedicalInvoiceInfo](https://cloud.tencent.com/document/api/866/33527#MedicalInvoiceInfo)
* [MedicalInvoiceItem](https://cloud.tencent.com/document/api/866/33527#MedicalInvoiceItem)

### 第 76 次发布

发布时间：2022-08-29 06:40:32

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [VatInvoice](https://cloud.tencent.com/document/api/866/33527#VatInvoice)

	* 新增成员：TaxBureau, TrafficFreeFlag

* [VatInvoiceItem](https://cloud.tencent.com/document/api/866/33527#VatInvoiceItem)

	* 新增成员：TaxClassifyCode

* [VehicleInvoiceInfo](https://cloud.tencent.com/document/api/866/33527#VehicleInvoiceInfo)

	* 新增成员：BuyerNo


### 第 75 次发布

发布时间：2022-08-16 06:34:58

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [SmartStructuralOCR](https://cloud.tencent.com/document/api/866/60877)

	* 新增入参：ReturnFullText


### 第 74 次发布

发布时间：2022-08-12 11:13:38

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [SingleInvoiceInfo](https://cloud.tencent.com/document/api/866/33527#SingleInvoiceInfo)

	* 新增成员：Row


### 第 73 次发布

发布时间：2022-07-19 06:15:45

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [VehicleInvoiceInfo](https://cloud.tencent.com/document/api/866/33527#VehicleInvoiceInfo)

	* 新增成员：SellerAddress, SellerTel


### 第 72 次发布

发布时间：2022-07-18 06:14:15

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [LicensePlateOCR](https://cloud.tencent.com/document/api/866/36211)

	* 新增出参：LicensePlateInfos


新增数据结构：

* [LicensePlateInfo](https://cloud.tencent.com/document/api/866/33527#LicensePlateInfo)

### 第 71 次发布

发布时间：2022-07-08 06:12:23

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [RecognizePhilippinesDrivingLicenseOCR](https://cloud.tencent.com/document/api/866/75194)

	* <font color="#dd0000">**修改入参**：</font>ReturnHeadImage

* [SmartStructuralOCR](https://cloud.tencent.com/document/api/866/60877)

	* 新增入参：IsPdf, PdfPageNumber


### 第 70 次发布

发布时间：2022-06-17 06:11:40

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [RecognizeHealthCodeOCR](https://cloud.tencent.com/document/api/866/68580)

	* 新增出参：Vaccination


### 第 69 次发布

发布时间：2022-06-14 06:15:05

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [SealOCR](https://cloud.tencent.com/document/api/866/45807)

	* 新增出参：SealInfos


新增数据结构：

* [SealInfo](https://cloud.tencent.com/document/api/866/33527#SealInfo)

### 第 68 次发布

发布时间：2022-06-09 06:15:14

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [RecognizeIndonesiaIDCardOCR](https://cloud.tencent.com/document/api/866/75195)
* [RecognizePhilippinesDrivingLicenseOCR](https://cloud.tencent.com/document/api/866/75194)
* [RecognizePhilippinesVoteIDOCR](https://cloud.tencent.com/document/api/866/75193)

新增数据结构：

* [TextDetectionResult](https://cloud.tencent.com/document/api/866/33527#TextDetectionResult)

### 第 67 次发布

发布时间：2022-06-08 06:13:12

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [MixedInvoiceOCR](https://cloud.tencent.com/document/api/866/37835)

	* 新增入参：ReturnOther


### 第 66 次发布

发布时间：2022-05-12 06:14:35

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [VatInvoiceVerifyNew](https://cloud.tencent.com/document/api/866/73674)

新增数据结构：

* [PassInvoiceInfo](https://cloud.tencent.com/document/api/866/33527#PassInvoiceInfo)

### 第 65 次发布

发布时间：2022-04-19 19:47:18

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [RecognizeHealthCodeOCR](https://cloud.tencent.com/document/api/866/68580)

	* 新增入参：Type

	* 新增出参：IDNumber, TestingInterval, TestingResult, TestingTime


### 第 64 次发布

发布时间：2022-03-24 17:13:23

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [RecognizeTravelCardOCR](https://cloud.tencent.com/document/api/866/71657)

### 第 63 次发布

发布时间：2022-03-18 08:15:31

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [MLIDPassportOCR](https://cloud.tencent.com/document/api/866/37657)

	* 新增出参：CodeSet, CodeCrc


### 第 62 次发布

发布时间：2022-01-21 10:52:12

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [RecognizeHealthCodeOCR](https://cloud.tencent.com/document/api/866/68580)

### 第 61 次发布

发布时间：2022-01-21 08:15:03

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [LicensePlateOCR](https://cloud.tencent.com/document/api/866/36211)

	* 新增出参：Color


### 第 60 次发布

发布时间：2022-01-14 08:13:51

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DriverLicenseOCR](https://cloud.tencent.com/document/api/866/36213)

	* 新增出参：State, CumulativeScore


### 第 59 次发布

发布时间：2021-12-27 08:08:41

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [GeneralHandwritingOCR](https://cloud.tencent.com/document/api/866/36212)

	* 新增入参：EnableDetectText


### 第 58 次发布

发布时间：2021-11-10 08:09:29

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [RecognizeContainerOCR](https://cloud.tencent.com/document/api/866/63810)

修改接口：

* [ResidenceBookletOCR](https://cloud.tencent.com/document/api/866/40036)

	* 新增出参：Signature, IssueDate, HomePageNumber, HouseholderName, Relationship, OtherAddresses, ReligiousBelief, Height, BloodType, MaritalStatus, VeteranStatus, Profession, MoveToCityInformation, MoveToSiteInformation, RegistrationDate, FormerName


### 第 57 次发布

发布时间：2021-11-09 08:13:57

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [GeneralAccurateOCR](https://cloud.tencent.com/document/api/866/34937)

	* 新增入参：IsPdf, PdfPageNumber


### 第 56 次发布

发布时间：2021-10-13 08:10:08

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [RecognizeOnlineTaxiItineraryOCR](https://cloud.tencent.com/document/api/866/62614)

新增数据结构：

* [OnlineTaxiItineraryInfo](https://cloud.tencent.com/document/api/866/33527#OnlineTaxiItineraryInfo)

### 第 55 次发布

发布时间：2021-09-28 08:08:22

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [GeneralAccurateOCR](https://cloud.tencent.com/document/api/866/34937)

	* 新增入参：EnableDetectSplit


### 第 54 次发布

发布时间：2021-08-31 08:07:52

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [SmartStructuralOCR](https://cloud.tencent.com/document/api/866/60877)

新增数据结构：

* [StructuralItem](https://cloud.tencent.com/document/api/866/33527#StructuralItem)

### 第 53 次发布

发布时间：2021-08-06 08:07:23

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [VatInvoiceVerify](https://cloud.tencent.com/document/api/866/47324)

	* 新增出参：VehicleInvoiceInfo, UsedVehicleInvoiceInfo


新增数据结构：

* [UsedVehicleInvoiceInfo](https://cloud.tencent.com/document/api/866/33527#UsedVehicleInvoiceInfo)
* [VehicleInvoiceInfo](https://cloud.tencent.com/document/api/866/33527#VehicleInvoiceInfo)

### 第 52 次发布

发布时间：2021-07-30 08:07:52

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [TrainTicketOCR](https://cloud.tencent.com/document/api/866/37071)

	* 新增出参：AdditionalCost, HandlingFee, LegalAmount, TicketStation, OriginalPrice, InvoiceStyle, ReceiptNumber, IsReceipt


### 第 51 次发布

发布时间：2021-06-25 08:07:17

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [BankCardOCR](https://cloud.tencent.com/document/api/866/36216)

	* 新增入参：EnableQualityValue

	* 新增出参：QualityValue

* [EnglishOCR](https://cloud.tencent.com/document/api/866/34938)

	* 新增入参：Preprocess


### 第 50 次发布

发布时间：2021-06-22 08:08:03

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [BankSlipOCR](https://cloud.tencent.com/document/api/866/57674)

修改接口：

* [GeneralAccurateOCR](https://cloud.tencent.com/document/api/866/34937)

	* 新增入参：IsWords

* [GeneralBasicOCR](https://cloud.tencent.com/document/api/866/33526)

	* 新增入参：IsWords


新增数据结构：

* [BankSlipInfo](https://cloud.tencent.com/document/api/866/33527#BankSlipInfo)
* [DetectedWordCoordPoint](https://cloud.tencent.com/document/api/866/33527#DetectedWordCoordPoint)
* [DetectedWords](https://cloud.tencent.com/document/api/866/33527#DetectedWords)

修改数据结构：

* [TextDetection](https://cloud.tencent.com/document/api/866/33527#TextDetection)

	* 新增成员：Words, WordCoordPoint


### 第 49 次发布

发布时间：2021-05-27 08:06:56

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [VerifyBasicBizLicense](https://cloud.tencent.com/document/api/866/47279)

	* 新增入参：EstablishTime

	* 新增出参：EstablishTime


### 第 48 次发布

发布时间：2021-05-17 08:07:03

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [VerifyEnterpriseFourFactors](https://cloud.tencent.com/document/api/866/55857)

新增数据结构：

* [Detail](https://cloud.tencent.com/document/api/866/33527#Detail)

### 第 47 次发布

发布时间：2021-04-01 08:06:40

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [HmtResidentPermitOCR](https://cloud.tencent.com/document/api/866/43106)

	* 新增出参：VisaNum, PassNo


### 第 46 次发布

发布时间：2021-03-23 08:07:17

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [GeneralFastOCR](https://cloud.tencent.com/document/api/866/33525)

	* 新增入参：IsPdf, PdfPageNumber

	* 新增出参：PdfPageSize


修改数据结构：

* [FlightInvoiceInfo](https://cloud.tencent.com/document/api/866/33527#FlightInvoiceInfo)

	* 新增成员：Row


### 第 45 次发布

发布时间：2021-01-29 08:06:08

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [ArithmeticOCR](https://cloud.tencent.com/document/api/866/34939)

	* 新增入参：SupportHorizontalImage, RejectNonArithmeticPic, EnableDispRelatedVertical, EnableDispMidResult, EnablePdfRecognize, PdfPageIndex

	* 新增出参：Angle


修改数据结构：

* [TextArithmetic](https://cloud.tencent.com/document/api/866/33527#TextArithmetic)

	* 新增成员：Answer


### 第 44 次发布

发布时间：2021-01-22 11:47:16

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [QuestionBlockObj](https://cloud.tencent.com/document/api/866/33527#QuestionBlockObj)

	* 新增成员：QuestionBboxCoord

* [QuestionObj](https://cloud.tencent.com/document/api/866/33527#QuestionObj)

	* 新增成员：QuestionImageCoords


### 第 43 次发布

发布时间：2021-01-21 08:05:58

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [VerifyOfdVatInvoiceOCR](https://cloud.tencent.com/document/api/866/52296)

新增数据结构：

* [VatInvoiceGoodsInfo](https://cloud.tencent.com/document/api/866/33527#VatInvoiceGoodsInfo)
* [VatInvoiceUserInfo](https://cloud.tencent.com/document/api/866/33527#VatInvoiceUserInfo)

### 第 42 次发布

发布时间：2021-01-15 08:06:09

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [EnglishOCR](https://cloud.tencent.com/document/api/866/34938)

	* 新增出参：Angel

* [GeneralHandwritingOCR](https://cloud.tencent.com/document/api/866/36212)

	* 新增出参：Angel

* [RecognizeTableOCR](https://cloud.tencent.com/document/api/866/49525)

	* 新增入参：TableLanguage

	* 新增出参：Angle

* [VatInvoiceOCR](https://cloud.tencent.com/document/api/866/36210)

	* 新增出参：Angle


修改数据结构：

* [TableDetectInfo](https://cloud.tencent.com/document/api/866/33527#TableDetectInfo)

	* 新增成员：Type, TableCoordPoint


### 第 41 次发布

发布时间：2021-01-14 08:06:13

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DriverLicenseOCR](https://cloud.tencent.com/document/api/866/36213)

	* 新增出参：IssuingAuthority


### 第 40 次发布

发布时间：2021-01-07 08:06:59

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [BankCardOCR](https://cloud.tencent.com/document/api/866/36216)

	* 新增入参：RetBorderCutImage, RetCardNoImage, EnableCopyCheck, EnableReshootCheck, EnableBorderCheck

	* 新增出参：CardType, CardName, BorderCutImage, CardNoImage, WarningCode


### 第 39 次发布

发布时间：2020-11-05 08:05:27

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [PassportOCR](https://cloud.tencent.com/document/api/866/37840)

	* 新增出参：Country, PassportNo, Sex, Nationality, BirthDate, BirthPlace, IssueDate, IssuePlace, ExpiryDate, Signature, CodeSet, CodeCrc, Name, FamilyName, FirstName

* [QueryBarCode](https://cloud.tencent.com/document/api/866/45513)

	* 新增出参：BarCode, ProductDataRecords


新增数据结构：

* [ProductDataRecord](https://cloud.tencent.com/document/api/866/33527#ProductDataRecord)

### 第 38 次发布

发布时间：2020-10-30 08:05:20

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [PassportOCR](https://cloud.tencent.com/document/api/866/37840)

	* <font color="#dd0000">**删除出参**：</font>Country, PassportNo, Sex, Nationality, BirthDate, BirthPlace, IssueDate, IssuePlace, ExpiryDate, Signature, CodeSet, CodeCrc, Name, FamilyName, FirstName

* [WaybillOCR](https://cloud.tencent.com/document/api/866/34934)

	* 新增入参：EnablePreDetect


### 第 37 次发布

发布时间：2020-10-29 08:05:33

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [AdvertiseOCR](https://cloud.tencent.com/document/api/866/49524)
* [RecognizeTableOCR](https://cloud.tencent.com/document/api/866/49525)

新增数据结构：

* [AdvertiseTextDetection](https://cloud.tencent.com/document/api/866/33527#AdvertiseTextDetection)
* [CellContent](https://cloud.tencent.com/document/api/866/33527#CellContent)
* [TableCell](https://cloud.tencent.com/document/api/866/33527#TableCell)
* [TableDetectInfo](https://cloud.tencent.com/document/api/866/33527#TableDetectInfo)
* [TableTitle](https://cloud.tencent.com/document/api/866/33527#TableTitle)

### 第 36 次发布

发布时间：2020-10-28 08:05:09

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [QueryBarCode](https://cloud.tencent.com/document/api/866/45513)

	* <font color="#dd0000">**删除出参**：</font>BarCode, ProductDataRecords


<font color="#dd0000">**删除数据结构**：</font>

* ProductDataRecord

### 第 35 次发布

发布时间：2020-09-17 08:05:27

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [RecognizeThaiIDCardOCR](https://cloud.tencent.com/document/api/866/48475)

### 第 34 次发布

发布时间：2020-09-16 08:04:52

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [GeneralHandwritingOCR](https://cloud.tencent.com/document/api/866/36212)

	* 新增入参：EnableWordPolygon

* [VatInvoiceOCR](https://cloud.tencent.com/document/api/866/36210)

	* 新增入参：IsPdf, PdfPageNumber

	* 新增出参：PdfPageSize


新增数据结构：

* [Polygon](https://cloud.tencent.com/document/api/866/33527#Polygon)

修改数据结构：

* [CarInvoiceInfo](https://cloud.tencent.com/document/api/866/33527#CarInvoiceInfo)

	* 新增成员：Polygon

* [TextGeneralHandwriting](https://cloud.tencent.com/document/api/866/33527#TextGeneralHandwriting)

	* 新增成员：WordPolygon

* [TextVatInvoice](https://cloud.tencent.com/document/api/866/33527#TextVatInvoice)

	* 新增成员：Polygon


### 第 33 次发布

发布时间：2020-09-04 08:05:33

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [BizLicenseOCR](https://cloud.tencent.com/document/api/866/36215)

	* 新增出参：RecognizeWarnCode, RecognizeWarnMsg

* [LicensePlateOCR](https://cloud.tencent.com/document/api/866/36211)

	* 新增出参：Rect


### 第 32 次发布

发布时间：2020-08-20 08:17:32

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [BusinessCardOCR](https://cloud.tencent.com/document/api/866/36214)

	* 新增出参：Angle

* [GeneralBasicOCR](https://cloud.tencent.com/document/api/866/33526)

	* 新增入参：IsPdf, PdfPageNumber

	* 新增出参：PdfPageSize

* [MLIDCardOCR](https://cloud.tencent.com/document/api/866/37656)

	* 新增出参：Birthday


修改数据结构：

* [BusinessCardInfo](https://cloud.tencent.com/document/api/866/33527#BusinessCardInfo)

	* 新增成员：ItemCoord


### 第 31 次发布

发布时间：2020-08-11 08:18:56

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [RideHailingTransportLicenseOCR](https://cloud.tencent.com/document/api/866/47325)
* [VatInvoiceVerify](https://cloud.tencent.com/document/api/866/47324)

新增数据结构：

* [VatInvoice](https://cloud.tencent.com/document/api/866/33527#VatInvoice)

修改数据结构：

* [CarInvoiceInfo](https://cloud.tencent.com/document/api/866/33527#CarInvoiceInfo)

	* 新增成员：Rect


### 第 30 次发布

发布时间：2020-08-10 08:15:56

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [VerifyBasicBizLicense](https://cloud.tencent.com/document/api/866/47279)
* [VerifyBizLicense](https://cloud.tencent.com/document/api/866/47278)

新增数据结构：

* [BizLicenseVerifyResult](https://cloud.tencent.com/document/api/866/33527#BizLicenseVerifyResult)

### 第 29 次发布

发布时间：2020-08-06 08:15:23

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [RideHailingDriverLicenseOCR](https://cloud.tencent.com/document/api/866/47165)

### 第 28 次发布

发布时间：2020-07-28 08:14:59

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [HKIDCardOCR](https://cloud.tencent.com/document/api/866/46919)

### 第 27 次发布

发布时间：2020-07-23 08:14:48

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [ClassifyDetectOCR](https://cloud.tencent.com/document/api/866/46770)

新增数据结构：

* [ClassifyDetectInfo](https://cloud.tencent.com/document/api/866/33527#ClassifyDetectInfo)

### 第 26 次发布

发布时间：2020-06-29 08:14:24

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [SealOCR](https://cloud.tencent.com/document/api/866/45807)

### 第 25 次发布

发布时间：2020-06-17 11:52:47

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [EnglishOCR](https://cloud.tencent.com/document/api/866/34938)

	* 新增入参：EnableCoordPoint, EnableCandWord


新增数据结构：

* [CandWord](https://cloud.tencent.com/document/api/866/33527#CandWord)
* [WordCoordPoint](https://cloud.tencent.com/document/api/866/33527#WordCoordPoint)
* [Words](https://cloud.tencent.com/document/api/866/33527#Words)

修改数据结构：

* [TextDetectionEn](https://cloud.tencent.com/document/api/866/33527#TextDetectionEn)

	* 新增成员：WordCoordPoint, CandWord, Words


### 第 24 次发布

发布时间：2020-06-12 08:16:23

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [QueryBarCode](https://cloud.tencent.com/document/api/866/45513)

新增数据结构：

* [ProductDataRecord](https://cloud.tencent.com/document/api/866/33527#ProductDataRecord)

### 第 23 次发布

发布时间：2020-05-15 08:13:44

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [MLIDCardOCR](https://cloud.tencent.com/document/api/866/37656)

	* 新增出参：Type


### 第 22 次发布

发布时间：2020-05-11 10:12:35

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [VatInvoiceOCR](https://cloud.tencent.com/document/api/866/36210)

	* 新增出参：Items


新增数据结构：

* [VatInvoiceItem](https://cloud.tencent.com/document/api/866/33527#VatInvoiceItem)

### 第 21 次发布

发布时间：2020-04-17 08:12:36

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [GeneralAccurateOCR](https://cloud.tencent.com/document/api/866/34937)

	* 新增出参：Angel

* [GeneralBasicOCR](https://cloud.tencent.com/document/api/866/33526)

	* 新增出参：Angel

* [GeneralEfficientOCR](https://cloud.tencent.com/document/api/866/37831)

	* 新增出参：Angel

* [GeneralFastOCR](https://cloud.tencent.com/document/api/866/33525)

	* 新增出参：Angel


### 第 20 次发布

发布时间：2020-04-10 08:12:27

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [TextDetection](https://cloud.tencent.com/document/api/866/33527#TextDetection)

	* 新增成员：ItemPolygon


### 第 19 次发布

发布时间：2020-04-03 08:12:13

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [HmtResidentPermitOCR](https://cloud.tencent.com/document/api/866/43106)
* [MainlandPermitOCR](https://cloud.tencent.com/document/api/866/43105)

修改接口：

* [DriverLicenseOCR](https://cloud.tencent.com/document/api/866/36213)

	* 新增入参：CardSide

	* 新增出参：ArchivesCode, Record


### 第 18 次发布

发布时间：2020-03-27 08:11:10

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [BizLicenseOCR](https://cloud.tencent.com/document/api/866/36215)

	* 新增出参：SetDate


### 第 17 次发布

发布时间：2020-02-20 15:29:50

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [EduPaperOCR](https://cloud.tencent.com/document/api/866/38294)

	* 新增入参：Config


### 第 16 次发布

发布时间：2020-02-13 16:38:56

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [TextEduPaper](https://cloud.tencent.com/document/api/866/33527#TextEduPaper)

	* 新增成员：Item, Itemcoord


### 第 15 次发布

发布时间：2020-02-10 10:24:31

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [GeneralHandwritingOCR](https://cloud.tencent.com/document/api/866/36212)

	* 新增入参：Scene


### 第 14 次发布

发布时间：2020-01-02 19:55:20

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DriverLicenseOCR](https://cloud.tencent.com/document/api/866/36213)

	* 新增出参：RecognizeWarnCode, RecognizeWarnMsg

* [MLIDCardOCR](https://cloud.tencent.com/document/api/866/37656)

	* 新增出参：AdvancedInfo

* [MLIDPassportOCR](https://cloud.tencent.com/document/api/866/37657)

	* 新增出参：AdvancedInfo

* [QuotaInvoiceOCR](https://cloud.tencent.com/document/api/866/37073)

	* 新增出参：RateNum, InvoiceType, Province, City, HasStamp

* [TaxiInvoiceOCR](https://cloud.tencent.com/document/api/866/37072)

	* 新增出参：Location, PlateNumber, InvoiceType, Province, City

* [TrainTicketOCR](https://cloud.tencent.com/document/api/866/37071)

	* 新增出参：InvoiceType, SerialNumber

* [VehicleLicenseOCR](https://cloud.tencent.com/document/api/866/36209)

	* 新增出参：RecognizeWarnCode, RecognizeWarnMsg


### 第 13 次发布

发布时间：2019-12-05 16:09:03

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [PropOwnerCertOCR](https://cloud.tencent.com/document/api/866/40037)
* [ResidenceBookletOCR](https://cloud.tencent.com/document/api/866/40036)

### 第 12 次发布

发布时间：2019-11-28 20:37:06

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [MixedInvoiceOCR](https://cloud.tencent.com/document/api/866/37835)

	* 新增入参：Types


### 第 11 次发布

发布时间：2019-11-14 19:32:20

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [EstateCertOCR](https://cloud.tencent.com/document/api/866/38300)

	* 新增出参：Number


新增数据结构：

* [ItemCoord](https://cloud.tencent.com/document/api/866/33527#ItemCoord)

修改数据结构：

* [TextArithmetic](https://cloud.tencent.com/document/api/866/33527#TextArithmetic)

	* 新增成员：ItemCoord, ExpressionType


### 第 10 次发布

发布时间：2019-11-01 09:50:03

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [TrainTicketOCR](https://cloud.tencent.com/document/api/866/37071)

	* 新增出参：ID


### 第 9 次发布

发布时间：2019-10-31 11:32:09

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [EnterpriseLicenseOCR](https://cloud.tencent.com/document/api/866/38849)
* [InsuranceBillOCR](https://cloud.tencent.com/document/api/866/38848)

修改接口：

* [EduPaperOCR](https://cloud.tencent.com/document/api/866/38294)

	* 新增出参：QuestionBlockInfos


新增数据结构：

* [EnterpriseLicenseInfo](https://cloud.tencent.com/document/api/866/33527#EnterpriseLicenseInfo)
* [InsuranceBillInfo](https://cloud.tencent.com/document/api/866/33527#InsuranceBillInfo)
* [QuestionBlockObj](https://cloud.tencent.com/document/api/866/33527#QuestionBlockObj)
* [QuestionObj](https://cloud.tencent.com/document/api/866/33527#QuestionObj)

### 第 8 次发布

发布时间：2019-10-11 14:31:16

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [EduPaperOCR](https://cloud.tencent.com/document/api/866/38294)
* [EstateCertOCR](https://cloud.tencent.com/document/api/866/38300)
* [FinanBillOCR](https://cloud.tencent.com/document/api/866/38296)
* [FinanBillSliceOCR](https://cloud.tencent.com/document/api/866/38295)
* [FormulaOCR](https://cloud.tencent.com/document/api/866/38293)
* [InstitutionOCR](https://cloud.tencent.com/document/api/866/38299)
* [OrgCodeCertOCR](https://cloud.tencent.com/document/api/866/38298)
* [QrcodeOCR](https://cloud.tencent.com/document/api/866/38292)
* [VehicleRegCertOCR](https://cloud.tencent.com/document/api/866/38297)

新增数据结构：

* [FinanBillInfo](https://cloud.tencent.com/document/api/866/33527#FinanBillInfo)
* [FinanBillSliceInfo](https://cloud.tencent.com/document/api/866/33527#FinanBillSliceInfo)
* [QrcodeImgSize](https://cloud.tencent.com/document/api/866/33527#QrcodeImgSize)
* [QrcodePositionObj](https://cloud.tencent.com/document/api/866/33527#QrcodePositionObj)
* [QrcodeResultsInfo](https://cloud.tencent.com/document/api/866/33527#QrcodeResultsInfo)
* [TextEduPaper](https://cloud.tencent.com/document/api/866/33527#TextEduPaper)
* [TextFormula](https://cloud.tencent.com/document/api/866/33527#TextFormula)
* [VehicleRegCertInfo](https://cloud.tencent.com/document/api/866/33527#VehicleRegCertInfo)

### 第 7 次发布

发布时间：2019-09-06 12:09:27

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [BusInvoiceOCR](https://cloud.tencent.com/document/api/866/37838)
* [DutyPaidProofOCR](https://cloud.tencent.com/document/api/866/37839)
* [GeneralEfficientOCR](https://cloud.tencent.com/document/api/866/37831)
* [InvoiceGeneralOCR](https://cloud.tencent.com/document/api/866/37837)
* [MixedInvoiceDetect](https://cloud.tencent.com/document/api/866/37836)
* [MixedInvoiceOCR](https://cloud.tencent.com/document/api/866/37835)
* [PassportOCR](https://cloud.tencent.com/document/api/866/37840)
* [ShipInvoiceOCR](https://cloud.tencent.com/document/api/866/37834)
* [TextDetect](https://cloud.tencent.com/document/api/866/37830)
* [TollInvoiceOCR](https://cloud.tencent.com/document/api/866/37833)
* [VatRollInvoiceOCR](https://cloud.tencent.com/document/api/866/37832)

新增数据结构：

* [BusInvoiceInfo](https://cloud.tencent.com/document/api/866/33527#BusInvoiceInfo)
* [DutyPaidProofInfo](https://cloud.tencent.com/document/api/866/33527#DutyPaidProofInfo)
* [InvoiceDetectInfo](https://cloud.tencent.com/document/api/866/33527#InvoiceDetectInfo)
* [InvoiceGeneralInfo](https://cloud.tencent.com/document/api/866/33527#InvoiceGeneralInfo)
* [MixedInvoiceItem](https://cloud.tencent.com/document/api/866/33527#MixedInvoiceItem)
* [Rect](https://cloud.tencent.com/document/api/866/33527#Rect)
* [ShipInvoiceInfo](https://cloud.tencent.com/document/api/866/33527#ShipInvoiceInfo)
* [SingleInvoiceInfo](https://cloud.tencent.com/document/api/866/33527#SingleInvoiceInfo)
* [TollInvoiceInfo](https://cloud.tencent.com/document/api/866/33527#TollInvoiceInfo)
* [VatRollInvoiceInfo](https://cloud.tencent.com/document/api/866/33527#VatRollInvoiceInfo)

### 第 6 次发布

发布时间：2019-08-29 21:06:13

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [MLIDCardOCR](https://cloud.tencent.com/document/api/866/37656)
* [MLIDPassportOCR](https://cloud.tencent.com/document/api/866/37657)

### 第 5 次发布

发布时间：2019-08-12 22:17:44

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CarInvoiceOCR](https://cloud.tencent.com/document/api/866/37076)
* [FlightInvoiceOCR](https://cloud.tencent.com/document/api/866/37075)
* [PermitOCR](https://cloud.tencent.com/document/api/866/37074)
* [QuotaInvoiceOCR](https://cloud.tencent.com/document/api/866/37073)
* [TaxiInvoiceOCR](https://cloud.tencent.com/document/api/866/37072)
* [TrainTicketOCR](https://cloud.tencent.com/document/api/866/37071)

新增数据结构：

* [CarInvoiceInfo](https://cloud.tencent.com/document/api/866/33527#CarInvoiceInfo)
* [FlightInvoiceInfo](https://cloud.tencent.com/document/api/866/33527#FlightInvoiceInfo)

### 第 4 次发布

发布时间：2019-07-16 19:10:41

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [BankCardOCR](https://cloud.tencent.com/document/api/866/36216)
* [BizLicenseOCR](https://cloud.tencent.com/document/api/866/36215)
* [BusinessCardOCR](https://cloud.tencent.com/document/api/866/36214)
* [DriverLicenseOCR](https://cloud.tencent.com/document/api/866/36213)
* [GeneralHandwritingOCR](https://cloud.tencent.com/document/api/866/36212)
* [LicensePlateOCR](https://cloud.tencent.com/document/api/866/36211)
* [VatInvoiceOCR](https://cloud.tencent.com/document/api/866/36210)
* [VehicleLicenseOCR](https://cloud.tencent.com/document/api/866/36209)

修改接口：

* [GeneralBasicOCR](https://cloud.tencent.com/document/api/866/33526)

	* 新增入参：LanguageType


新增数据结构：

* [BusinessCardInfo](https://cloud.tencent.com/document/api/866/33527#BusinessCardInfo)
* [TextGeneralHandwriting](https://cloud.tencent.com/document/api/866/33527#TextGeneralHandwriting)
* [TextVatInvoice](https://cloud.tencent.com/document/api/866/33527#TextVatInvoice)
* [TextVehicleBack](https://cloud.tencent.com/document/api/866/33527#TextVehicleBack)
* [TextVehicleFront](https://cloud.tencent.com/document/api/866/33527#TextVehicleFront)

### 第 3 次发布

发布时间：2019-05-15 19:15:52

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [ArithmeticOCR](https://cloud.tencent.com/document/api/866/34939)
* [EnglishOCR](https://cloud.tencent.com/document/api/866/34938)
* [GeneralAccurateOCR](https://cloud.tencent.com/document/api/866/34937)
* [TableOCR](https://cloud.tencent.com/document/api/866/34936)
* [VinOCR](https://cloud.tencent.com/document/api/866/34935)
* [WaybillOCR](https://cloud.tencent.com/document/api/866/34934)

新增数据结构：

* [TextArithmetic](https://cloud.tencent.com/document/api/866/33527#TextArithmetic)
* [TextDetectionEn](https://cloud.tencent.com/document/api/866/33527#TextDetectionEn)
* [TextTable](https://cloud.tencent.com/document/api/866/33527#TextTable)
* [TextWaybill](https://cloud.tencent.com/document/api/866/33527#TextWaybill)
* [WaybillObj](https://cloud.tencent.com/document/api/866/33527#WaybillObj)

### 第 2 次发布

发布时间：2019-04-26 17:03:31

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [GeneralBasicOCR](https://cloud.tencent.com/document/api/866/33526)

	* 新增入参：Scene


### 第 1 次发布

发布时间：2019-03-07 20:59:23

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [GeneralBasicOCR](https://cloud.tencent.com/document/api/866/33526)
* [GeneralFastOCR](https://cloud.tencent.com/document/api/866/33525)
* [IDCardOCR](https://cloud.tencent.com/document/api/866/33524)

新增数据结构：

* [Coord](https://cloud.tencent.com/document/api/866/33527#Coord)
* [TextDetection](https://cloud.tencent.com/document/api/866/33527#TextDetection)




## 腾讯健康组学平台(omics) 版本：2022-11-28

### 第 15 次发布

发布时间：2024-04-22 01:22:30

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [RunApplication](https://cloud.tencent.com/document/api/1643/89094)

	* 新增入参：VolumeIds

* [RunWorkflow](https://cloud.tencent.com/document/api/1643/100857)

	* 新增入参：VolumeIds


### 第 14 次发布

发布时间：2024-04-03 11:24:43

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [RunApplication](https://cloud.tencent.com/document/api/1643/89094)

	* 新增入参：InputCosUri, AccessMode

	* <font color="#dd0000">**修改入参**：</font>InputBase64


### 第 13 次发布

发布时间：2024-03-04 01:21:08

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateVolume](https://cloud.tencent.com/document/api/1643/104065)
* [DeleteVolume](https://cloud.tencent.com/document/api/1643/104064)
* [DeleteVolumeData](https://cloud.tencent.com/document/api/1643/104063)
* [DescribeVolumes](https://cloud.tencent.com/document/api/1643/104062)
* [ModifyVolume](https://cloud.tencent.com/document/api/1643/104061)

新增数据结构：

* [Volume](https://cloud.tencent.com/document/api/1643/89100#Volume)

### 第 12 次发布

发布时间：2024-02-29 01:21:24

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [RunApplication](https://cloud.tencent.com/document/api/1643/89094)

	* 新增入参：WorkDir

	* <font color="#dd0000">**修改入参**：</font>CacheClearDelay

* [RunWorkflow](https://cloud.tencent.com/document/api/1643/100857)

	* 新增入参：WorkDir


修改数据结构：

* [ClusterOption](https://cloud.tencent.com/document/api/1643/89100#ClusterOption)

	* 新增成员：ServiceCidr

* [Environment](https://cloud.tencent.com/document/api/1643/89100#Environment)

	* 新增成员：IsDefault, IsManaged

	* <font color="#dd0000">**修改成员**：</font>EnvironmentId, Name, Description, Region, Type, Status, Available, Message, ResourceIds, LastWorkflowUuid, CreationTime

* [NFOption](https://cloud.tencent.com/document/api/1643/89100#NFOption)

	* 新增成员：NFVersion


### 第 11 次发布

发布时间：2024-01-05 01:21:57

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [RunApplication](https://cloud.tencent.com/document/api/1643/89094)

	* 新增入参：NFOption

	* <font color="#dd0000">**修改入参**：</font>ProjectId, Option


### 第 10 次发布

发布时间：2023-12-28 01:21:09

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [RetryRuns](https://cloud.tencent.com/document/api/1643/90978)

	* 新增入参：RunGroupId, WDLOption, NFOption

	* <font color="#dd0000">**修改入参**：</font>ProjectId, RunUuids

	* 新增出参：RunGroupId


### 第 9 次发布

发布时间：2023-12-13 02:14:02

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [GetRunMetadataFile](https://cloud.tencent.com/document/api/1643/100858)

	* 新增入参：Keys

	* <font color="#dd0000">**修改入参**：</font>Key

	* 新增出参：CosSignedUrls


### 第 8 次发布

发布时间：2023-11-14 01:22:26

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateEnvironment](https://cloud.tencent.com/document/api/1643/90909)

	* 新增入参：IsDefault


新增数据结构：

* [LimitRange](https://cloud.tencent.com/document/api/1643/89100#LimitRange)
* [ResourceQuota](https://cloud.tencent.com/document/api/1643/89100#ResourceQuota)
* [SecurityGroupOption](https://cloud.tencent.com/document/api/1643/89100#SecurityGroupOption)

修改数据结构：

* [ClusterOption](https://cloud.tencent.com/document/api/1643/89100#ClusterOption)

	* 新增成员：ResourceQuota, LimitRange

* [EnvironmentConfig](https://cloud.tencent.com/document/api/1643/89100#EnvironmentConfig)

	* 新增成员：SecurityGroupOption

* [VPCOption](https://cloud.tencent.com/document/api/1643/89100#VPCOption)

	* 新增成员：VPCId, SubnetId

	* <font color="#dd0000">**修改成员**：</font>SubnetZone, VPCCIDRBlock, SubnetCIDRBlock


### 第 7 次发布

发布时间：2023-10-27 16:07:10

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [GetRunMetadataFile](https://cloud.tencent.com/document/api/1643/100858)
* [RunWorkflow](https://cloud.tencent.com/document/api/1643/100857)
* [TerminateRunGroup](https://cloud.tencent.com/document/api/1643/100856)

新增数据结构：

* [GitInfo](https://cloud.tencent.com/document/api/1643/89100#GitInfo)

修改数据结构：

* [Run](https://cloud.tencent.com/document/api/1643/89100#Run)


### 第 6 次发布

发布时间：2023-10-27 02:03:46

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeRunGroups](https://cloud.tencent.com/document/api/1643/89099)

	* <font color="#dd0000">**修改入参**：</font>ProjectId

* [DescribeRuns](https://cloud.tencent.com/document/api/1643/89098)

	* <font color="#dd0000">**修改入参**：</font>ProjectId

* [GetRunCalls](https://cloud.tencent.com/document/api/1643/89097)

	* <font color="#dd0000">**修改入参**：</font>ProjectId

* [GetRunStatus](https://cloud.tencent.com/document/api/1643/89096)

	* <font color="#dd0000">**修改入参**：</font>ProjectId


新增数据结构：

* [ApplicationVersion](https://cloud.tencent.com/document/api/1643/89100#ApplicationVersion)
* [CacheInfo](https://cloud.tencent.com/document/api/1643/89100#CacheInfo)
* [NFOption](https://cloud.tencent.com/document/api/1643/89100#NFOption)

修改数据结构：

* [Run](https://cloud.tencent.com/document/api/1643/89100#Run)

	* 新增成员：Cache

	* <font color="#dd0000">**修改成员**：</font>RunUuid, ProjectId, ApplicationId, RunGroupId, EnvironmentId, UserDefinedId, TableId, TableRowUuid, Status, Input, Option, ExecutionTime, ErrorMessage, CreateTime, UpdateTime

* [RunGroup](https://cloud.tencent.com/document/api/1643/89100#RunGroup)

	* 新增成员：NFOption, Creator, CreatorId, ResultNotify, ApplicationVersion

	* <font color="#dd0000">**修改成员**：</font>RunGroupId, ProjectId, ProjectName, ApplicationId, ApplicationName, ApplicationType, EnvironmentId, EnvironmentName, TableId, Name, Description, Status, Input, Option, TotalRun, RunStatusCounts, ExecutionTime, ErrorMessage, CreateTime, UpdateTime

* [RunMetadata](https://cloud.tencent.com/document/api/1643/89100#RunMetadata)

	* 新增成员：Meta

	* <font color="#dd0000">**修改成员**：</font>RunType, RunId, ParentId, JobId, CallName, ScatterIndex, Input, Output, Status, ErrorMessage, StartTime, SubmitTime, EndTime, Command, Runtime, Preprocess, PostProcess, CallCached, Stdout, Stderr


### 第 5 次发布

发布时间：2023-07-20 01:37:20

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [RunApplication](https://cloud.tencent.com/document/api/1643/89094)

	* 新增入参：ApplicationVersionId


### 第 4 次发布

发布时间：2023-05-12 01:40:23

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeTables](https://cloud.tencent.com/document/api/1643/90980)
* [DescribeTablesRows](https://cloud.tencent.com/document/api/1643/90979)
* [RetryRuns](https://cloud.tencent.com/document/api/1643/90978)

新增数据结构：

* [Table](https://cloud.tencent.com/document/api/1643/89100#Table)
* [TableColumn](https://cloud.tencent.com/document/api/1643/89100#TableColumn)
* [TableRow](https://cloud.tencent.com/document/api/1643/89100#TableRow)

### 第 3 次发布

发布时间：2023-05-11 01:38:54

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [RunOption](https://cloud.tencent.com/document/api/1643/89100#RunOption)

	* 新增成员：FinalWorkflowOutputsDir, UseRelativeOutputPaths


### 第 2 次发布

发布时间：2023-05-10 01:39:47

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateEnvironment](https://cloud.tencent.com/document/api/1643/90909)
* [DeleteEnvironment](https://cloud.tencent.com/document/api/1643/90908)
* [DescribeEnvironments](https://cloud.tencent.com/document/api/1643/90907)

新增数据结构：

* [CVMOption](https://cloud.tencent.com/document/api/1643/89100#CVMOption)
* [ClusterOption](https://cloud.tencent.com/document/api/1643/89100#ClusterOption)
* [DatabaseOption](https://cloud.tencent.com/document/api/1643/89100#DatabaseOption)
* [Environment](https://cloud.tencent.com/document/api/1643/89100#Environment)
* [EnvironmentConfig](https://cloud.tencent.com/document/api/1643/89100#EnvironmentConfig)
* [ResourceIds](https://cloud.tencent.com/document/api/1643/89100#ResourceIds)
* [StorageOption](https://cloud.tencent.com/document/api/1643/89100#StorageOption)
* [VPCOption](https://cloud.tencent.com/document/api/1643/89100#VPCOption)

### 第 1 次发布

发布时间：2023-03-21 20:10:58

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeRunGroups](https://cloud.tencent.com/document/api/1643/89099)
* [DescribeRuns](https://cloud.tencent.com/document/api/1643/89098)
* [GetRunCalls](https://cloud.tencent.com/document/api/1643/89097)
* [GetRunStatus](https://cloud.tencent.com/document/api/1643/89096)
* [ImportTableFile](https://cloud.tencent.com/document/api/1643/89095)
* [RunApplication](https://cloud.tencent.com/document/api/1643/89094)

新增数据结构：

* [ExecutionTime](https://cloud.tencent.com/document/api/1643/89100#ExecutionTime)
* [Filter](https://cloud.tencent.com/document/api/1643/89100#Filter)
* [Run](https://cloud.tencent.com/document/api/1643/89100#Run)
* [RunGroup](https://cloud.tencent.com/document/api/1643/89100#RunGroup)
* [RunMetadata](https://cloud.tencent.com/document/api/1643/89100#RunMetadata)
* [RunOption](https://cloud.tencent.com/document/api/1643/89100#RunOption)
* [RunStatusCount](https://cloud.tencent.com/document/api/1643/89100#RunStatusCount)




## 集团账号管理(organization) 版本：2018-12-25

### 第 1 次发布

发布时间：2019-10-24 21:28:31

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [AcceptOrganizationInvitation](https://cloud.tencent.com/document/api/850/38748)
* [AddOrganizationNode](https://cloud.tencent.com/document/api/850/38747)
* [CancelOrganizationInvitation](https://cloud.tencent.com/document/api/850/38746)
* [CreateOrganization](https://cloud.tencent.com/document/api/850/38745)
* [DeleteOrganization](https://cloud.tencent.com/document/api/850/38744)
* [DeleteOrganizationMemberFromNode](https://cloud.tencent.com/document/api/850/38743)
* [DeleteOrganizationMembers](https://cloud.tencent.com/document/api/850/38742)
* [DeleteOrganizationNodes](https://cloud.tencent.com/document/api/850/38741)
* [DenyOrganizationInvitation](https://cloud.tencent.com/document/api/850/38740)
* [GetOrganization](https://cloud.tencent.com/document/api/850/38733)
* [GetOrganizationMember](https://cloud.tencent.com/document/api/850/38732)
* [ListOrganizationInvitations](https://cloud.tencent.com/document/api/850/38731)
* [ListOrganizationMembers](https://cloud.tencent.com/document/api/850/38730)
* [ListOrganizationNodeMembers](https://cloud.tencent.com/document/api/850/38729)
* [ListOrganizationNodes](https://cloud.tencent.com/document/api/850/38728)
* [MoveOrganizationMembersToNode](https://cloud.tencent.com/document/api/850/38739)
* [QuitOrganization](https://cloud.tencent.com/document/api/850/38738)
* [SendOrganizationInvitation](https://cloud.tencent.com/document/api/850/38737)
* [UpdateOrganizationMember](https://cloud.tencent.com/document/api/850/38736)
* [UpdateOrganizationNode](https://cloud.tencent.com/document/api/850/38735)

新增数据结构：

* [OrgInvitation](https://cloud.tencent.com/document/api/850/38749#OrgInvitation)
* [OrgMember](https://cloud.tencent.com/document/api/850/38749#OrgMember)
* [OrgNode](https://cloud.tencent.com/document/api/850/38749#OrgNode)



## 集团账号管理(organization) 版本：2021-03-31

### 第 34 次发布

发布时间：2024-08-01 02:03:22

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [ListOrganizationService](https://cloud.tencent.com/document/api/850/109561)

新增数据结构：

* [OrganizationServiceAssign](https://cloud.tencent.com/document/api/850/67060#OrganizationServiceAssign)

### 第 33 次发布

发布时间：2024-06-21 02:03:56

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [AcceptJoinShareUnitInvitation](https://cloud.tencent.com/document/api/850/107559)
* [RejectJoinShareUnitInvitation](https://cloud.tencent.com/document/api/850/107558)

### 第 32 次发布

发布时间：2024-06-14 02:20:06

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [AddShareUnit](https://cloud.tencent.com/document/api/850/103056)

	* 新增入参：ShareScope

* [UpdateShareUnit](https://cloud.tencent.com/document/api/850/103046)

	* 新增入参：ShareScope


修改数据结构：

* [ManagerShareUnit](https://cloud.tencent.com/document/api/850/67060#ManagerShareUnit)

	* 新增成员：ShareScope


### 第 31 次发布

发布时间：2024-04-22 01:22:36

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeEffectivePolicy](https://cloud.tencent.com/document/api/850/105463)
* [ListNonCompliantResource](https://cloud.tencent.com/document/api/850/105462)

新增数据结构：

* [EffectivePolicy](https://cloud.tencent.com/document/api/850/67060#EffectivePolicy)
* [ResourceTagMapping](https://cloud.tencent.com/document/api/850/67060#ResourceTagMapping)
* [TagComplianceDetails](https://cloud.tencent.com/document/api/850/67060#TagComplianceDetails)
* [Tags](https://cloud.tencent.com/document/api/850/67060#Tags)

### 第 30 次发布

发布时间：2024-04-17 14:48:36

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [AttachPolicy](https://cloud.tencent.com/document/api/850/105319)
* [CreatePolicy](https://cloud.tencent.com/document/api/850/105318)
* [DeletePolicy](https://cloud.tencent.com/document/api/850/105317)
* [DescribePolicy](https://cloud.tencent.com/document/api/850/105316)
* [DescribePolicyConfig](https://cloud.tencent.com/document/api/850/105315)
* [DetachPolicy](https://cloud.tencent.com/document/api/850/105314)
* [DisablePolicyType](https://cloud.tencent.com/document/api/850/105313)
* [EnablePolicyType](https://cloud.tencent.com/document/api/850/105312)
* [ListPolicies](https://cloud.tencent.com/document/api/850/105311)
* [ListPoliciesForTarget](https://cloud.tencent.com/document/api/850/105310)
* [ListTargetsForPolicy](https://cloud.tencent.com/document/api/850/105309)
* [UpdatePolicy](https://cloud.tencent.com/document/api/850/105305)

新增数据结构：

* [ListPoliciesForTarget](https://cloud.tencent.com/document/api/850/67060#ListPoliciesForTarget)
* [ListPolicyNode](https://cloud.tencent.com/document/api/850/67060#ListPolicyNode)
* [ListTargetsForPolicyNode](https://cloud.tencent.com/document/api/850/67060#ListTargetsForPolicyNode)

### 第 29 次发布

发布时间：2024-02-29 01:21:30

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CheckAccountDelete](https://cloud.tencent.com/document/api/850/104012)

新增数据结构：

* [NotAllowReason](https://cloud.tencent.com/document/api/850/67060#NotAllowReason)

### 第 28 次发布

发布时间：2024-01-17 01:19:45

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [AddShareUnit](https://cloud.tencent.com/document/api/850/103056)
* [AddShareUnitMembers](https://cloud.tencent.com/document/api/850/103055)
* [AddShareUnitResources](https://cloud.tencent.com/document/api/850/103054)
* [DeleteShareUnit](https://cloud.tencent.com/document/api/850/103053)
* [DeleteShareUnitMembers](https://cloud.tencent.com/document/api/850/103052)
* [DeleteShareUnitResources](https://cloud.tencent.com/document/api/850/103051)
* [DescribeShareAreas](https://cloud.tencent.com/document/api/850/103050)
* [DescribeShareUnitMembers](https://cloud.tencent.com/document/api/850/103049)
* [DescribeShareUnitResources](https://cloud.tencent.com/document/api/850/103048)
* [DescribeShareUnits](https://cloud.tencent.com/document/api/850/103047)
* [UpdateShareUnit](https://cloud.tencent.com/document/api/850/103046)

新增数据结构：

* [ManagerShareUnit](https://cloud.tencent.com/document/api/850/67060#ManagerShareUnit)
* [ProductResource](https://cloud.tencent.com/document/api/850/67060#ProductResource)
* [ShareArea](https://cloud.tencent.com/document/api/850/67060#ShareArea)
* [ShareMember](https://cloud.tencent.com/document/api/850/67060#ShareMember)
* [ShareResource](https://cloud.tencent.com/document/api/850/67060#ShareResource)
* [ShareUnitMember](https://cloud.tencent.com/document/api/850/67060#ShareUnitMember)
* [ShareUnitResource](https://cloud.tencent.com/document/api/850/67060#ShareUnitResource)

### 第 27 次发布

发布时间：2023-10-27 02:04:21

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DeleteAccount](https://cloud.tencent.com/document/api/850/100808)

### 第 26 次发布

发布时间：2023-10-19 16:12:27

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateOrganizationIdentity](https://cloud.tencent.com/document/api/850/100458)
* [CreateOrganizationMembersPolicy](https://cloud.tencent.com/document/api/850/100457)
* [DeleteOrganizationIdentity](https://cloud.tencent.com/document/api/850/100456)
* [UpdateOrganizationIdentity](https://cloud.tencent.com/document/api/850/100455)

### 第 25 次发布

发布时间：2023-09-22 02:15:37

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [AddOrganizationMemberEmail](https://cloud.tencent.com/document/api/850/93333)

	* 新增出参：BindId

* [DescribeOrganizationMemberAuthIdentities](https://cloud.tencent.com/document/api/850/82936)

	* 新增入参：IdentityId

	* <font color="#dd0000">**修改入参**：</font>MemberUin


修改数据结构：

* [IdentityPolicy](https://cloud.tencent.com/document/api/850/67060#IdentityPolicy)

	* 新增成员：PolicyType, PolicyDocument

	* <font color="#dd0000">**修改成员**：</font>PolicyId, PolicyName

* [OrgMemberAuthIdentity](https://cloud.tencent.com/document/api/850/67060#OrgMemberAuthIdentity)

	* 新增成员：Status, MemberUin, MemberName

	* <font color="#dd0000">**修改成员**：</font>IdentityType


### 第 24 次发布

发布时间：2023-09-19 14:35:45

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [QuitOrganization](https://cloud.tencent.com/document/api/850/98683)

### 第 23 次发布

发布时间：2023-09-19 01:22:23

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateOrganization](https://cloud.tencent.com/document/api/850/98673)
* [DeleteOrganization](https://cloud.tencent.com/document/api/850/98672)

### 第 22 次发布

发布时间：2023-08-10 01:32:28

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DeleteOrganizationMemberAuthIdentity](https://cloud.tencent.com/document/api/850/96120)

### 第 21 次发布

发布时间：2023-08-09 01:40:29

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateOrganizationMemberAuthIdentity](https://cloud.tencent.com/document/api/850/96106)
* [DeleteOrganizationMembersPolicy](https://cloud.tencent.com/document/api/850/96105)

### 第 20 次发布

发布时间：2023-06-30 01:38:16

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [UpdateOrganizationMember](https://cloud.tencent.com/document/api/850/94392)

### 第 19 次发布

发布时间：2023-06-14 01:34:43

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeOrganizationFinancialByMember](https://cloud.tencent.com/document/api/850/93482)
* [DescribeOrganizationFinancialByMonth](https://cloud.tencent.com/document/api/850/93481)
* [DescribeOrganizationFinancialByProduct](https://cloud.tencent.com/document/api/850/93480)

新增数据结构：

* [OrgFinancialByMonth](https://cloud.tencent.com/document/api/850/67060#OrgFinancialByMonth)
* [OrgMemberFinancial](https://cloud.tencent.com/document/api/850/67060#OrgMemberFinancial)
* [OrgProductFinancial](https://cloud.tencent.com/document/api/850/67060#OrgProductFinancial)

### 第 18 次发布

发布时间：2023-06-09 01:35:01

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [AddOrganizationMemberEmail](https://cloud.tencent.com/document/api/850/93333)
* [DescribeOrganizationMemberEmailBind](https://cloud.tencent.com/document/api/850/93332)
* [UpdateOrganizationMemberEmailBind](https://cloud.tencent.com/document/api/850/93331)

### 第 17 次发布

发布时间：2023-05-19 01:51:15

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [ListOrganizationIdentity](https://cloud.tencent.com/document/api/850/82934)

	* 新增入参：IdentityType


### 第 16 次发布

发布时间：2023-03-20 01:46:48

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [OrgMemberAuthIdentity](https://cloud.tencent.com/document/api/850/67060#OrgMemberAuthIdentity)

	* 新增成员：IdentityType


### 第 15 次发布

发布时间：2023-02-17 04:46:25

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeOrganizationAuthNode](https://cloud.tencent.com/document/api/850/82927)

	* 新增入参：AuthName


新增数据结构：

* [MemberMainInfo](https://cloud.tencent.com/document/api/850/67060#MemberMainInfo)

修改数据结构：

* [AuthNode](https://cloud.tencent.com/document/api/850/67060#AuthNode)

	* 新增成员：Manager


### 第 14 次发布

发布时间：2022-11-17 06:38:09

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CancelOrganizationMemberAuthAccount](https://cloud.tencent.com/document/api/850/83000)
* [DescribeOrganizationMemberAuthAccounts](https://cloud.tencent.com/document/api/850/82999)

新增数据结构：

* [OrgMemberAuthAccount](https://cloud.tencent.com/document/api/850/67060#OrgMemberAuthAccount)

### 第 13 次发布

发布时间：2022-11-16 06:33:07

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [AddOrganizationNode](https://cloud.tencent.com/document/api/850/82930)
* [DeleteOrganizationMembers](https://cloud.tencent.com/document/api/850/82929)
* [DeleteOrganizationNodes](https://cloud.tencent.com/document/api/850/82928)
* [DescribeOrganizationAuthNode](https://cloud.tencent.com/document/api/850/82927)
* [DescribeOrganizationMemberAuthIdentities](https://cloud.tencent.com/document/api/850/82936)
* [DescribeOrganizationMemberPolicies](https://cloud.tencent.com/document/api/850/82935)
* [DescribeOrganizationNodes](https://cloud.tencent.com/document/api/850/82926)
* [ListOrganizationIdentity](https://cloud.tencent.com/document/api/850/82934)
* [MoveOrganizationNodeMembers](https://cloud.tencent.com/document/api/850/82925)
* [UpdateOrganizationNode](https://cloud.tencent.com/document/api/850/82924)

新增数据结构：

* [AuthNode](https://cloud.tencent.com/document/api/850/67060#AuthNode)
* [IdentityPolicy](https://cloud.tencent.com/document/api/850/67060#IdentityPolicy)
* [OrgIdentity](https://cloud.tencent.com/document/api/850/67060#OrgIdentity)
* [OrgMemberAuthIdentity](https://cloud.tencent.com/document/api/850/67060#OrgMemberAuthIdentity)
* [OrgMemberPolicy](https://cloud.tencent.com/document/api/850/67060#OrgMemberPolicy)
* [OrgNode](https://cloud.tencent.com/document/api/850/67060#OrgNode)

### 第 12 次发布

发布时间：2022-11-02 06:34:29

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateOrganizationMember](https://cloud.tencent.com/document/api/850/63310)

	* 新增入参：AuthRelationId


### 第 11 次发布

发布时间：2022-09-23 06:41:45

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeOrganization](https://cloud.tencent.com/document/api/850/67059)

	* 新增出参：IsAuthManager


### 第 10 次发布

发布时间：2022-07-21 06:14:50

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [OrgMember](https://cloud.tencent.com/document/api/850/67060#OrgMember)

	* 新增成员：PermissionStatus


### 第 9 次发布

发布时间：2022-06-10 06:11:43

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeOrganization](https://cloud.tencent.com/document/api/850/67059)

	* 新增入参：Product

	* 新增出参：IsAssignManager

* [DescribeOrganizationMembers](https://cloud.tencent.com/document/api/850/67220)

	* 新增入参：AuthName, Product


### 第 8 次发布

发布时间：2022-05-30 06:11:27

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateOrganizationMemberPolicy](https://cloud.tencent.com/document/api/850/74595)

### 第 7 次发布

发布时间：2022-03-08 08:16:27

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [OrgMember](https://cloud.tencent.com/document/api/850/67060#OrgMember)

	* 新增成员：BindStatus


### 第 6 次发布

发布时间：2022-01-26 08:11:15

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeOrganization](https://cloud.tencent.com/document/api/850/67059)

	* 新增出参：PayUin, PayName


### 第 5 次发布

发布时间：2022-01-18 08:13:20

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateOrganizationMember](https://cloud.tencent.com/document/api/850/63310)

	* 新增入参：PayUin, IdentityRoleID

	* 新增出参：Uin


新增数据结构：

* [MemberIdentity](https://cloud.tencent.com/document/api/850/67060#MemberIdentity)

修改数据结构：

* [OrgMember](https://cloud.tencent.com/document/api/850/67060#OrgMember)

	* 新增成员：PayUin, PayName, OrgIdentity


### 第 4 次发布

发布时间：2021-12-30 08:12:38

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeOrganizationMembers](https://cloud.tencent.com/document/api/850/67220)

新增数据结构：

* [OrgMember](https://cloud.tencent.com/document/api/850/67060#OrgMember)

### 第 3 次发布

发布时间：2021-12-28 08:09:51

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeOrganization](https://cloud.tencent.com/document/api/850/67059)

新增数据结构：

* [OrgPermission](https://cloud.tencent.com/document/api/850/67060#OrgPermission)

### 第 2 次发布

发布时间：2021-10-25 11:36:50

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateOrganizationMember](https://cloud.tencent.com/document/api/850/63310)

### 第 1 次发布

发布时间：2021-08-26 08:07:43

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [BindOrganizationMemberAuthAccount](https://cloud.tencent.com/document/api/850/63308)




## 渠道合作伙伴(partners) 版本：2018-03-21

### 第 33 次发布

发布时间：2024-06-26 01:21:35

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [AgentAuditedClient](https://cloud.tencent.com/document/api/563/16047#AgentAuditedClient)

	* 新增成员：TransactionType


### 第 32 次发布

发布时间：2024-01-23 01:25:29

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [AgentDealNewElem](https://cloud.tencent.com/document/api/563/16047#AgentDealNewElem)

	* 新增成员：SubGoodsName


### 第 31 次发布

发布时间：2023-07-20 18:40:49

本次发布包含了以下内容：

改善已有的文档。

新增数据结构：

* [RefundMap](https://cloud.tencent.com/document/api/563/16047#RefundMap)

修改数据结构：

* [AgentDealNewElem](https://cloud.tencent.com/document/api/563/16047#AgentDealNewElem)

	* 新增成员：RefundMap

	* <font color="#dd0000">**修改成员**：</font>ResourceIds


### 第 30 次发布

发布时间：2023-06-21 01:29:51

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [AgentDealNewElem](https://cloud.tencent.com/document/api/563/16047#AgentDealNewElem)

	* 新增成员：ResourceIds


### 第 29 次发布

发布时间：2023-06-14 01:35:00

本次发布包含了以下内容：

改善已有的文档。

<font color="#dd0000">**删除接口**：</font>

* DescribeAgentDealsCache
* DescribeAgentPayDeals
* DescribeAgentSelfPayDeals
* DescribeClientBalance

<font color="#dd0000">**删除数据结构**：</font>

* AgentDealElem
* DealGoodsPriceElem

### 第 28 次发布

发布时间：2023-06-07 01:39:31

本次发布包含了以下内容：

改善已有的文档。

<font color="#dd0000">**预下线接口**：</font>

* DescribeAgentDealsCache
* DescribeAgentPayDeals
* DescribeAgentSelfPayDeals

### 第 27 次发布

发布时间：2023-06-02 01:39:39

本次发布包含了以下内容：

改善已有的文档。

<font color="#dd0000">**预下线接口**：</font>

* DescribeClientBalance

### 第 26 次发布

发布时间：2023-02-17 04:47:03

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [AssignClientsToSales](https://cloud.tencent.com/document/api/563/86667)

### 第 25 次发布

发布时间：2022-10-28 06:40:32

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeRebateInfosNew](https://cloud.tencent.com/document/api/563/82023)

新增数据结构：

* [RebateInfoElemNew](https://cloud.tencent.com/document/api/563/16047#RebateInfoElemNew)

### 第 24 次发布

发布时间：2022-03-31 06:11:44

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeAgentDealsByCache](https://cloud.tencent.com/document/api/563/54256)

	* 新增入参：BigDealIds

* [DescribeAgentPayDealsV2](https://cloud.tencent.com/document/api/563/55198)

	* 新增入参：BigDealIds

* [DescribeAgentSelfPayDealsV2](https://cloud.tencent.com/document/api/563/55197)

	* 新增入参：BigDealIds


### 第 23 次发布

发布时间：2021-09-16 08:09:23

本次发布包含了以下内容：

改善已有的文档。

<font color="#dd0000">**删除接口**：</font>

* DescribeClientBaseInfo

<font color="#dd0000">**删除数据结构**：</font>

* ClientBaseElem

### 第 22 次发布

发布时间：2021-06-25 08:07:32

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeClientBalanceNew](https://cloud.tencent.com/document/api/563/57850)

修改数据结构：

* [AgentClientElem](https://cloud.tencent.com/document/api/563/16047#AgentClientElem)

	* 新增成员：ClientName

* [AgentDealElem](https://cloud.tencent.com/document/api/563/16047#AgentDealElem)

	* 新增成员：PaymentMethod, UpdateTime

* [AgentDealNewElem](https://cloud.tencent.com/document/api/563/16047#AgentDealNewElem)

	* 新增成员：PaymentMethod, UpdateTime

* [DealGoodsPriceElem](https://cloud.tencent.com/document/api/563/16047#DealGoodsPriceElem)

	* 新增成员：OriginalTotalCost

* [DealGoodsPriceNewElem](https://cloud.tencent.com/document/api/563/16047#DealGoodsPriceNewElem)

	* 新增成员：OriginalTotalCost


### 第 21 次发布

发布时间：2021-05-18 08:08:01

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeClientBaseInfo](https://cloud.tencent.com/document/api/563/55899)

修改接口：

* [DescribeClientBalance](https://cloud.tencent.com/document/api/563/19924)

	* 新增出参：Cash


新增数据结构：

* [ClientBaseElem](https://cloud.tencent.com/document/api/563/16047#ClientBaseElem)

### 第 20 次发布

发布时间：2021-04-27 08:07:30

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeAgentPayDealsV2](https://cloud.tencent.com/document/api/563/55198)
* [DescribeAgentSelfPayDealsV2](https://cloud.tencent.com/document/api/563/55197)

### 第 19 次发布

发布时间：2021-04-01 08:06:54

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeAgentDealsByCache](https://cloud.tencent.com/document/api/563/54256)

新增数据结构：

* [AgentDealNewElem](https://cloud.tencent.com/document/api/563/16047#AgentDealNewElem)
* [DealGoodsPriceNewElem](https://cloud.tencent.com/document/api/563/16047#DealGoodsPriceNewElem)

### 第 18 次发布

发布时间：2021-01-18 08:06:08

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeUnbindClientList](https://cloud.tencent.com/document/api/563/52132)

新增数据结构：

* [UnbindClientElem](https://cloud.tencent.com/document/api/563/16047#UnbindClientElem)

### 第 17 次发布

发布时间：2020-12-24 08:06:19

本次发布包含了以下内容：

改善已有的文档。

新增数据结构：

* [ProductInfoElem](https://cloud.tencent.com/document/api/563/16047#ProductInfoElem)

修改数据结构：

* [AgentDealElem](https://cloud.tencent.com/document/api/563/16047#AgentDealElem)

	* 新增成员：ProductInfo


### 第 16 次发布

发布时间：2020-10-14 08:05:26

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeAgentSelfPayDeals](https://cloud.tencent.com/document/api/563/49103)

### 第 15 次发布

发布时间：2020-07-20 08:14:54

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [AgentDealElem](https://cloud.tencent.com/document/api/563/16047#AgentDealElem)

	* 新增成员：OverdueTime


### 第 14 次发布

发布时间：2020-07-02 08:15:06

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeAgentClientGrade](https://cloud.tencent.com/document/api/563/45286)

	* 新增出参：ClientType


### 第 13 次发布

发布时间：2020-06-04 08:14:37

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeAgentClientGrade](https://cloud.tencent.com/document/api/563/45286)

### 第 12 次发布

发布时间：2020-02-28 15:12:56

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeAgentClients](https://cloud.tencent.com/document/api/563/16046)

	* 新增入参：SalesUin, SalesName


修改数据结构：

* [AgentClientElem](https://cloud.tencent.com/document/api/563/16047#AgentClientElem)

	* 新增成员：SalesUin, SalesName


### 第 11 次发布

发布时间：2019-10-18 11:19:19

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreatePayRelationForClient](https://cloud.tencent.com/document/api/563/38535)
* [RemovePayRelationForClient](https://cloud.tencent.com/document/api/563/38534)

修改数据结构：

* [AgentAuditedClient](https://cloud.tencent.com/document/api/563/16047#AgentAuditedClient)

	* 新增成员：Mail

* [AgentBillElem](https://cloud.tencent.com/document/api/563/16047#AgentBillElem)

	* 新增成员：ActivityId

* [AgentDealElem](https://cloud.tencent.com/document/api/563/16047#AgentDealElem)

	* 新增成员：ActivityId


### 第 10 次发布

发布时间：2019-05-30 19:33:07

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeAgentDealsCache](https://cloud.tencent.com/document/api/563/35195)
* [DescribeAgentPayDeals](https://cloud.tencent.com/document/api/563/35194)
* [DescribeSalesmans](https://cloud.tencent.com/document/api/563/35196)

修改接口：

* [DescribeAgentAuditedClients](https://cloud.tencent.com/document/api/563/19184)

	* 新增入参：SalesUin, SalesName


新增数据结构：

* [AgentDealElem](https://cloud.tencent.com/document/api/563/16047#AgentDealElem)
* [AgentSalesmanElem](https://cloud.tencent.com/document/api/563/16047#AgentSalesmanElem)
* [DealGoodsPriceElem](https://cloud.tencent.com/document/api/563/16047#DealGoodsPriceElem)

修改数据结构：

* [AgentAuditedClient](https://cloud.tencent.com/document/api/563/16047#AgentAuditedClient)

	* 新增成员：SalesUin, SalesName


### 第 9 次发布

发布时间：2019-03-25 11:17:17

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [AgentAuditedClient](https://cloud.tencent.com/document/api/563/16047#AgentAuditedClient)

	* <font color="#dd0000">**修改成员**：</font>LastMonthAmt, ThisMonthAmt


### 第 8 次发布

发布时间：2019-03-21 19:47:45

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [AgentBillElem](https://cloud.tencent.com/document/api/563/16047#AgentBillElem)

	* 新增成员：ClientType, ProjectType


### 第 7 次发布

发布时间：2019-03-12 11:52:13

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeAgentAuditedClients](https://cloud.tencent.com/document/api/563/19184)

	* 新增入参：ClientType, ProjectType


修改数据结构：

* [AgentAuditedClient](https://cloud.tencent.com/document/api/563/16047#AgentAuditedClient)

	* 新增成员：ClientType, ProjectType


### 第 6 次发布

发布时间：2019-02-28 20:04:20

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [AgentBillElem](https://cloud.tencent.com/document/api/563/16047#AgentBillElem)

	* <font color="#dd0000">**修改成员**：</font>Amt


### 第 5 次发布

发布时间：2019-01-17 20:18:03

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [AgentClientElem](https://cloud.tencent.com/document/api/563/16047#AgentClientElem)

	* 新增成员：Status


### 第 4 次发布

发布时间：2018-09-20 11:03:04

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [AgentTransferMoney](https://cloud.tencent.com/document/api/563/19925)
* [DescribeClientBalance](https://cloud.tencent.com/document/api/563/19924)

### 第 3 次发布

发布时间：2018-08-23 22:20:08

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [AgentPayDeals](https://cloud.tencent.com/document/api/563/19186)
* [DescribeAgentAuditedClients](https://cloud.tencent.com/document/api/563/19184)

修改接口：

* [DescribeAgentBills](https://cloud.tencent.com/document/api/563/16042)

	* <font color="#dd0000">**修改入参**：</font>SettleMonth


新增数据结构：

* [AgentAuditedClient](https://cloud.tencent.com/document/api/563/16047#AgentAuditedClient)

### 第 2 次发布

发布时间：2018-05-24 17:08:50

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [AgentBillElem](https://cloud.tencent.com/document/api/563/16047#AgentBillElem)

	* 新增成员：PayerMode


### 第 1 次发布

发布时间：2018-04-24

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [AuditApplyClient](https://cloud.tencent.com/document/api/563/16044)
* [DescribeAgentBills](https://cloud.tencent.com/document/api/563/16042)
* [DescribeAgentClients](https://cloud.tencent.com/document/api/563/16046)
* [DescribeRebateInfos](https://cloud.tencent.com/document/api/563/16041)
* [ModifyClientRemark](https://cloud.tencent.com/document/api/563/16045)

新增数据结构：

* [AgentBillElem](https://cloud.tencent.com/document/api/563/16047#AgentBillElem)
* [AgentClientElem](https://cloud.tencent.com/document/api/563/16047#AgentClientElem)
* [RebateInfoElem](https://cloud.tencent.com/document/api/563/16047#RebateInfoElem)




## 私域安全(pds) 版本：2021-07-01

### 第 1 次发布

发布时间：2021-08-18 08:00:05

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeNewUserAcquisition](https://cloud.tencent.com/document/api/1473/60427)
* [DescribeStockEstimation](https://cloud.tencent.com/document/api/1473/60426)

新增数据结构：

* [Score](https://cloud.tencent.com/document/api/1473/60428#Score)
* [UserInfos](https://cloud.tencent.com/document/api/1473/60428#UserInfos)




## 云数据库 PostgreSQL(postgres) 版本：2017-03-12

### 第 44 次发布

发布时间：2024-07-23 01:55:36

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateAccount](https://cloud.tencent.com/document/api/409/109071)
* [DeleteAccount](https://cloud.tencent.com/document/api/409/109070)
* [DescribeAccountPrivileges](https://cloud.tencent.com/document/api/409/109069)
* [DescribeDatabaseObjects](https://cloud.tencent.com/document/api/409/109072)
* [LockAccount](https://cloud.tencent.com/document/api/409/109068)
* [ModifyAccountPrivileges](https://cloud.tencent.com/document/api/409/109067)
* [UnlockAccount](https://cloud.tencent.com/document/api/409/109066)

新增数据结构：

* [DatabaseObject](https://cloud.tencent.com/document/api/409/16778#DatabaseObject)
* [DatabasePrivilege](https://cloud.tencent.com/document/api/409/16778#DatabasePrivilege)
* [ModifyPrivilege](https://cloud.tencent.com/document/api/409/16778#ModifyPrivilege)

### 第 43 次发布

发布时间：2024-07-05 01:15:16

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [AccountInfo](https://cloud.tencent.com/document/api/409/16778#AccountInfo)

	* 新增成员：UserType


### 第 42 次发布

发布时间：2024-06-07 02:17:01

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [RestoreDBInstanceObjects](https://cloud.tencent.com/document/api/409/107100)

修改接口：

* [DescribeDatabases](https://cloud.tencent.com/document/api/409/43353)

	* 新增入参：Filters, Offset, Limit

	* 新增出参：TotalCount


### 第 41 次发布

发布时间：2024-03-01 01:22:03

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [InquiryPriceUpgradeDBInstance](https://cloud.tencent.com/document/api/409/18102)

	* 新增入参：Cpu

* [ModifyBackupPlan](https://cloud.tencent.com/document/api/409/68067)

	* 新增入参：LogBackupRetentionPeriod

* [ModifyDBInstanceSpec](https://cloud.tencent.com/document/api/409/63689)

	* 新增入参：Cpu


### 第 40 次发布

发布时间：2023-10-09 01:20:54

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [UpgradeDBInstanceMajorVersion](https://cloud.tencent.com/document/api/409/99280)

### 第 39 次发布

发布时间：2023-08-04 01:15:26

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeDBInstanceHAConfig](https://cloud.tencent.com/document/api/409/95970)
* [ModifyDBInstanceHAConfig](https://cloud.tencent.com/document/api/409/95969)
* [SwitchDBInstancePrimary](https://cloud.tencent.com/document/api/409/95968)

### 第 38 次发布

发布时间：2023-07-21 01:35:07

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CloneDBInstance](https://cloud.tencent.com/document/api/409/68071)

	* 新增入参：SyncMode


### 第 37 次发布

发布时间：2023-06-14 01:35:12

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateInstances](https://cloud.tencent.com/document/api/409/56107)

	* 新增入参：SyncMode


### 第 36 次发布

发布时间：2023-06-09 01:35:46

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateBaseBackup](https://cloud.tencent.com/document/api/409/89028)

	* 新增出参：BaseBackupId


### 第 35 次发布

发布时间：2023-04-24 01:34:02

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeBackupDownloadRestriction](https://cloud.tencent.com/document/api/409/90460)
* [ModifyBackupDownloadRestriction](https://cloud.tencent.com/document/api/409/90459)
* [ModifyDBInstanceChargeType](https://cloud.tencent.com/document/api/409/90458)

### 第 34 次发布

发布时间：2023-04-19 01:42:53

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeBackupDownloadURL](https://cloud.tencent.com/document/api/409/89025)

	* 新增入参：BackupDownloadRestriction


新增数据结构：

* [BackupDownloadRestriction](https://cloud.tencent.com/document/api/409/16778#BackupDownloadRestriction)

### 第 33 次发布

发布时间：2023-03-21 01:56:25

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateBaseBackup](https://cloud.tencent.com/document/api/409/89028)
* [DeleteBaseBackup](https://cloud.tencent.com/document/api/409/89027)
* [DeleteLogBackup](https://cloud.tencent.com/document/api/409/89026)
* [DescribeBackupDownloadURL](https://cloud.tencent.com/document/api/409/89025)
* [DescribeBackupOverview](https://cloud.tencent.com/document/api/409/89024)
* [DescribeBackupSummaries](https://cloud.tencent.com/document/api/409/89023)
* [DescribeBaseBackups](https://cloud.tencent.com/document/api/409/89022)
* [DescribeClasses](https://cloud.tencent.com/document/api/409/89019)
* [DescribeDBVersions](https://cloud.tencent.com/document/api/409/89018)
* [DescribeLogBackups](https://cloud.tencent.com/document/api/409/89021)
* [ModifyBaseBackupExpireTime](https://cloud.tencent.com/document/api/409/89020)
* [UpgradeDBInstanceKernelVersion](https://cloud.tencent.com/document/api/409/89029)

新增数据结构：

* [BackupSummary](https://cloud.tencent.com/document/api/409/16778#BackupSummary)
* [BaseBackup](https://cloud.tencent.com/document/api/409/16778#BaseBackup)
* [ClassInfo](https://cloud.tencent.com/document/api/409/16778#ClassInfo)
* [LogBackup](https://cloud.tencent.com/document/api/409/16778#LogBackup)
* [Version](https://cloud.tencent.com/document/api/409/16778#Version)

### 第 32 次发布

发布时间：2022-12-15 01:38:47

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateParameterTemplate](https://cloud.tencent.com/document/api/409/84071)
* [DeleteParameterTemplate](https://cloud.tencent.com/document/api/409/84070)
* [DescribeDBInstanceSecurityGroups](https://cloud.tencent.com/document/api/409/84064)
* [DescribeDefaultParameters](https://cloud.tencent.com/document/api/409/84069)
* [DescribeParameterTemplateAttributes](https://cloud.tencent.com/document/api/409/84068)
* [DescribeParameterTemplates](https://cloud.tencent.com/document/api/409/84067)
* [ModifyDBInstanceSecurityGroups](https://cloud.tencent.com/document/api/409/84063)
* [ModifyParameterTemplate](https://cloud.tencent.com/document/api/409/84066)

新增数据结构：

* [ParameterTemplate](https://cloud.tencent.com/document/api/409/16778#ParameterTemplate)
* [PolicyRule](https://cloud.tencent.com/document/api/409/16778#PolicyRule)
* [SecurityGroup](https://cloud.tencent.com/document/api/409/16778#SecurityGroup)

### 第 31 次发布

发布时间：2022-11-29 07:09:18

本次发布包含了以下内容：

改善已有的文档。

新增数据结构：

* [ParamSpecRelation](https://cloud.tencent.com/document/api/409/16778#ParamSpecRelation)
* [ParamVersionRelation](https://cloud.tencent.com/document/api/409/16778#ParamVersionRelation)

修改数据结构：

* [ParamInfo](https://cloud.tencent.com/document/api/409/16778#ParamInfo)

	* 新增成员：StandbyRelated, VersionRelationSet, SpecRelationSet


### 第 30 次发布

发布时间：2022-11-24 06:46:55

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [DBInstanceNetInfo](https://cloud.tencent.com/document/api/409/16778#DBInstanceNetInfo)

	* 新增成员：ProtocolType


### 第 29 次发布

发布时间：2022-09-23 06:42:05

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CloneDBInstance](https://cloud.tencent.com/document/api/409/68071)

	* 新增出参：DBInstanceId

* [CreateInstances](https://cloud.tencent.com/document/api/409/56107)

	* 新增入参：DBEngine, DBEngineConfig

* [CreateReadOnlyDBInstance](https://cloud.tencent.com/document/api/409/52602)

	* <font color="#dd0000">**修改入参**：</font>DBVersion

* [DescribeProductConfig](https://cloud.tencent.com/document/api/409/16776)

	* 新增入参：DBEngine

* [InquiryPriceCreateDBInstances](https://cloud.tencent.com/document/api/409/16777)

	* 新增入参：InstanceType, DBEngine

	* <font color="#dd0000">**修改入参**：</font>Pid


修改数据结构：

* [DBInstance](https://cloud.tencent.com/document/api/409/16778#DBInstance)

	* 新增成员：DBEngine, DBEngineConfig


### 第 28 次发布

发布时间：2022-06-15 06:12:41

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [InquiryPriceCreateDBInstances](https://cloud.tencent.com/document/api/409/16777)

	* 新增出参：Currency

* [InquiryPriceRenewDBInstance](https://cloud.tencent.com/document/api/409/18103)

	* 新增出参：Currency

* [InquiryPriceUpgradeDBInstance](https://cloud.tencent.com/document/api/409/18102)

	* 新增出参：Currency


### 第 27 次发布

发布时间：2022-04-25 06:10:40

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeEncryptionKeys](https://cloud.tencent.com/document/api/409/73069)

新增数据结构：

* [EncryptionKey](https://cloud.tencent.com/document/api/409/16778#EncryptionKey)

### 第 26 次发布

发布时间：2022-04-13 07:01:59

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateInstances](https://cloud.tencent.com/document/api/409/56107)

	* 新增入参：NeedSupportTDE, KMSKeyId, KMSRegion


修改数据结构：

* [DBInstance](https://cloud.tencent.com/document/api/409/16778#DBInstance)

	* 新增成员：IsSupportTDE

* [SpecInfo](https://cloud.tencent.com/document/api/409/16778#SpecInfo)

	* 新增成员：SupportKMSRegions

* [SpecItemInfo](https://cloud.tencent.com/document/api/409/16778#SpecItemInfo)

	* 新增成员：IsSupportTDE


### 第 25 次发布

发布时间：2022-03-03 08:10:01

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateDBInstanceNetworkAccess](https://cloud.tencent.com/document/api/409/70581)
* [CreateReadOnlyGroupNetworkAccess](https://cloud.tencent.com/document/api/409/70580)
* [DeleteDBInstanceNetworkAccess](https://cloud.tencent.com/document/api/409/70579)
* [DeleteReadOnlyGroupNetworkAccess](https://cloud.tencent.com/document/api/409/70578)

### 第 24 次发布

发布时间：2022-01-12 08:13:23

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CloneDBInstance](https://cloud.tencent.com/document/api/409/68071)
* [DescribeAvailableRecoveryTime](https://cloud.tencent.com/document/api/409/68070)
* [DescribeBackupPlans](https://cloud.tencent.com/document/api/409/68069)
* [DescribeCloneDBInstanceSpec](https://cloud.tencent.com/document/api/409/68068)
* [ModifyBackupPlan](https://cloud.tencent.com/document/api/409/68067)
* [ModifyDBInstanceDeployment](https://cloud.tencent.com/document/api/409/68066)

新增数据结构：

* [BackupPlan](https://cloud.tencent.com/document/api/409/16778#BackupPlan)

### 第 23 次发布

发布时间：2022-01-10 08:14:24

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateInstances](https://cloud.tencent.com/document/api/409/56107)

	* 新增入参：DBNodeSet


新增数据结构：

* [DBNode](https://cloud.tencent.com/document/api/409/16778#DBNode)

修改数据结构：

* [DBBackup](https://cloud.tencent.com/document/api/409/16778#DBBackup)

	* 新增成员：SetId

* [DBInstance](https://cloud.tencent.com/document/api/409/16778#DBInstance)

	* 新增成员：DBNodeSet

* [ZoneInfo](https://cloud.tencent.com/document/api/409/16778#ZoneInfo)

	* 新增成员：StandbyZoneSet


### 第 22 次发布

发布时间：2021-12-24 08:13:26

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateDBInstances](https://cloud.tencent.com/document/api/409/16771)

	* 新增入参：DBMajorVersion, DBKernelVersion

	* <font color="#dd0000">**修改入参**：</font>DBVersion

* [CreateInstances](https://cloud.tencent.com/document/api/409/56107)

	* 新增入参：DBMajorVersion, DBKernelVersion

	* <font color="#dd0000">**修改入参**：</font>DBVersion


修改数据结构：

* [DBInstance](https://cloud.tencent.com/document/api/409/16778#DBInstance)

	* 新增成员：DBMajorVersion

* [ServerlessDBInstance](https://cloud.tencent.com/document/api/409/16778#ServerlessDBInstance)

	* 新增成员：DBMajorVersion

* [SpecItemInfo](https://cloud.tencent.com/document/api/409/16778#SpecItemInfo)

	* 新增成员：MajorVersion, KernelVersion


### 第 21 次发布

发布时间：2021-12-02 08:10:29

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [DBInstanceNetInfo](https://cloud.tencent.com/document/api/409/16778#DBInstanceNetInfo)

	* 新增成员：VpcId, SubnetId


### 第 20 次发布

发布时间：2021-11-24 08:12:02

本次发布包含了以下内容：

改善已有的文档。

新增数据结构：

* [NetworkAccess](https://cloud.tencent.com/document/api/409/16778#NetworkAccess)

修改数据结构：

* [DBInstance](https://cloud.tencent.com/document/api/409/16778#DBInstance)

	* 新增成员：DBKernelVersion, NetworkAccessList

* [ReadOnlyGroup](https://cloud.tencent.com/document/api/409/16778#ReadOnlyGroup)

	* 新增成员：NetworkAccessList

* [ServerlessDBInstance](https://cloud.tencent.com/document/api/409/16778#ServerlessDBInstance)

	* 新增成员：DBKernelVersion


### 第 19 次发布

发布时间：2021-11-04 08:11:48

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [ModifyDBInstanceSpec](https://cloud.tencent.com/document/api/409/63689)

### 第 18 次发布

发布时间：2021-10-26 08:11:42

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeDBInstanceParameters](https://cloud.tencent.com/document/api/409/63344)
* [DescribeParamsEvent](https://cloud.tencent.com/document/api/409/63343)
* [ModifyDBInstanceParameters](https://cloud.tencent.com/document/api/409/63342)

新增数据结构：

* [EventInfo](https://cloud.tencent.com/document/api/409/16778#EventInfo)
* [EventItem](https://cloud.tencent.com/document/api/409/16778#EventItem)
* [ParamEntry](https://cloud.tencent.com/document/api/409/16778#ParamEntry)
* [ParamInfo](https://cloud.tencent.com/document/api/409/16778#ParamInfo)

### 第 17 次发布

发布时间：2021-08-23 08:07:32

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeSlowQueryAnalysis](https://cloud.tencent.com/document/api/409/60541)
* [DescribeSlowQueryList](https://cloud.tencent.com/document/api/409/60540)

新增数据结构：

* [AnalysisItems](https://cloud.tencent.com/document/api/409/16778#AnalysisItems)
* [Detail](https://cloud.tencent.com/document/api/409/16778#Detail)
* [DurationAnalysis](https://cloud.tencent.com/document/api/409/16778#DurationAnalysis)
* [RawSlowQuery](https://cloud.tencent.com/document/api/409/16778#RawSlowQuery)

### 第 16 次发布

发布时间：2021-07-22 08:07:32

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [ModifySwitchTimePeriod](https://cloud.tencent.com/document/api/409/59030)

修改接口：

* [UpgradeDBInstance](https://cloud.tencent.com/document/api/409/18095)

	* 新增入参：SwitchTag, SwitchStartTime, SwitchEndTime


### 第 15 次发布

发布时间：2021-05-20 08:07:05

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateInstances](https://cloud.tencent.com/document/api/409/56107)

### 第 14 次发布

发布时间：2021-04-19 08:06:30

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DisIsolateDBInstances](https://cloud.tencent.com/document/api/409/54791)
* [IsolateDBInstances](https://cloud.tencent.com/document/api/409/54790)

### 第 13 次发布

发布时间：2021-03-31 08:06:39

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateDBInstances](https://cloud.tencent.com/document/api/409/16771)

	* 新增入参：SecurityGroupIds

* [CreateReadOnlyDBInstance](https://cloud.tencent.com/document/api/409/52602)

	* 新增入参：SecurityGroupIds

* [CreateReadOnlyGroup](https://cloud.tencent.com/document/api/409/52601)

	* 新增入参：SecurityGroupIds


修改数据结构：

* [DBInstance](https://cloud.tencent.com/document/api/409/16778#DBInstance)

	* 新增成员：OfflineTime


### 第 12 次发布

发布时间：2021-01-29 08:06:25

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [AddDBInstanceToReadOnlyGroup](https://cloud.tencent.com/document/api/409/52603)
* [CreateReadOnlyDBInstance](https://cloud.tencent.com/document/api/409/52602)
* [CreateReadOnlyGroup](https://cloud.tencent.com/document/api/409/52601)
* [DeleteReadOnlyGroup](https://cloud.tencent.com/document/api/409/52600)
* [DescribeReadOnlyGroups](https://cloud.tencent.com/document/api/409/52599)
* [ModifyDBInstanceReadOnlyGroup](https://cloud.tencent.com/document/api/409/52598)
* [ModifyReadOnlyGroupConfig](https://cloud.tencent.com/document/api/409/52597)
* [RebalanceReadOnlyGroup](https://cloud.tencent.com/document/api/409/52596)
* [RemoveDBInstanceFromReadOnlyGroup](https://cloud.tencent.com/document/api/409/52595)

新增数据结构：

* [ReadOnlyGroup](https://cloud.tencent.com/document/api/409/16778#ReadOnlyGroup)

修改数据结构：

* [RegionInfo](https://cloud.tencent.com/document/api/409/16778#RegionInfo)

	* 新增成员：SupportInternational


### 第 11 次发布

发布时间：2020-11-23 08:06:23

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [DBInstance](https://cloud.tencent.com/document/api/409/16778#DBInstance)

	* 新增成员：MasterDBInstanceId, ReadOnlyInstanceNum, StatusInReadonlyGroup


### 第 10 次发布

发布时间：2020-08-20 08:18:19

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateDBInstances](https://cloud.tencent.com/document/api/409/16771)

	* 新增入参：TagList

* [CreateServerlessDBInstance](https://cloud.tencent.com/document/api/409/42762)

	* 新增入参：TagList

* [DescribeServerlessDBInstances](https://cloud.tencent.com/document/api/409/42760)

	* 新增入参：OrderBy, OrderByType


新增数据结构：

* [Tag](https://cloud.tencent.com/document/api/409/16778#Tag)

修改数据结构：

* [DBInstance](https://cloud.tencent.com/document/api/409/16778#DBInstance)

	* 新增成员：TagList

* [ServerlessDBInstance](https://cloud.tencent.com/document/api/409/16778#ServerlessDBInstance)

	* 新增成员：TagList


### 第 9 次发布

发布时间：2020-07-02 08:15:16

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [ZoneInfo](https://cloud.tencent.com/document/api/409/16778#ZoneInfo)

	* 新增成员：ZoneSupportIpv6


### 第 8 次发布

发布时间：2020-07-01 08:15:12

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CloseDBExtranetAccess](https://cloud.tencent.com/document/api/409/18105)

	* 新增入参：IsIpv6

* [CreateDBInstances](https://cloud.tencent.com/document/api/409/16771)

	* 新增入参：NeedSupportIpv6

* [OpenDBExtranetAccess](https://cloud.tencent.com/document/api/409/18099)

	* 新增入参：IsIpv6


修改数据结构：

* [DBInstance](https://cloud.tencent.com/document/api/409/16778#DBInstance)

	* 新增成员：SupportIpv6


### 第 7 次发布

发布时间：2020-04-10 08:13:04

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateDBInstances](https://cloud.tencent.com/document/api/409/16771)
* [DescribeDBInstances](https://cloud.tencent.com/document/api/409/16773)
* [DescribeDatabases](https://cloud.tencent.com/document/api/409/43353)
* [DestroyDBInstance](https://cloud.tencent.com/document/api/409/43352)
* [UpgradeDBInstance](https://cloud.tencent.com/document/api/409/18095)

### 第 6 次发布

发布时间：2020-03-30 08:43:08

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [DBInstance](https://cloud.tencent.com/document/api/409/16778#DBInstance)

	* 新增成员：AppId, Uid

* [Xlog](https://cloud.tencent.com/document/api/409/16778#Xlog)

	* 新增成员：Size


### 第 5 次发布

发布时间：2020-03-23 08:11:25

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CloseServerlessDBExtranetAccess](https://cloud.tencent.com/document/api/409/42763)
* [CreateServerlessDBInstance](https://cloud.tencent.com/document/api/409/42762)
* [DeleteServerlessDBInstance](https://cloud.tencent.com/document/api/409/42761)
* [DescribeServerlessDBInstances](https://cloud.tencent.com/document/api/409/42760)
* [OpenServerlessDBExtranetAccess](https://cloud.tencent.com/document/api/409/42759)

新增数据结构：

* [Filter](https://cloud.tencent.com/document/api/409/16778#Filter)
* [ServerlessDBAccount](https://cloud.tencent.com/document/api/409/16778#ServerlessDBAccount)
* [ServerlessDBInstance](https://cloud.tencent.com/document/api/409/16778#ServerlessDBInstance)
* [ServerlessDBInstanceNetInfo](https://cloud.tencent.com/document/api/409/16778#ServerlessDBInstanceNetInfo)

### 第 4 次发布

发布时间：2020-03-16 08:15:49

本次发布包含了以下内容：

改善已有的文档。

<font color="#dd0000">**删除接口**：</font>

* CreateDBInstances
* DescribeDBInstances
* UpgradeDBInstance

<font color="#dd0000">**删除数据结构**：</font>

* Filter

### 第 3 次发布

发布时间：2020-01-02 17:15:43

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateDBInstances](https://cloud.tencent.com/document/api/409/16771)

	* 新增入参：AutoRenewFlag


修改数据结构：

* [DBInstance](https://cloud.tencent.com/document/api/409/16778#DBInstance)

	* 新增成员：Type

* [SpecItemInfo](https://cloud.tencent.com/document/api/409/16778#SpecItemInfo)

	* 新增成员：Type


### 第 2 次发布

发布时间：2018-06-28 15:15:08

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CloseDBExtranetAccess](https://cloud.tencent.com/document/api/409/18105)
* [DescribeAccounts](https://cloud.tencent.com/document/api/409/18109)
* [DescribeDBBackups](https://cloud.tencent.com/document/api/409/18094)
* [DescribeDBErrlogs](https://cloud.tencent.com/document/api/409/18093)
* [DescribeDBSlowlogs](https://cloud.tencent.com/document/api/409/18092)
* [DescribeDBXlogs](https://cloud.tencent.com/document/api/409/18091)
* [DescribeOrders](https://cloud.tencent.com/document/api/409/18104)
* [InquiryPriceRenewDBInstance](https://cloud.tencent.com/document/api/409/18103)
* [InquiryPriceUpgradeDBInstance](https://cloud.tencent.com/document/api/409/18102)
* [ModifyAccountRemark](https://cloud.tencent.com/document/api/409/18108)
* [ModifyDBInstanceName](https://cloud.tencent.com/document/api/409/18101)
* [ModifyDBInstancesProject](https://cloud.tencent.com/document/api/409/18100)
* [OpenDBExtranetAccess](https://cloud.tencent.com/document/api/409/18099)
* [RenewInstance](https://cloud.tencent.com/document/api/409/18098)
* [ResetAccountPassword](https://cloud.tencent.com/document/api/409/18107)
* [RestartDBInstance](https://cloud.tencent.com/document/api/409/18097)
* [SetAutoRenewFlag](https://cloud.tencent.com/document/api/409/18096)
* [UpgradeDBInstance](https://cloud.tencent.com/document/api/409/18095)

修改接口：

* [DescribeDBInstances](https://cloud.tencent.com/document/api/409/16773)

	* 新增入参：Limit, Offset

	* <font color="#dd0000">**删除入参**：</font>PageSize, PageNumber


新增数据结构：

* [AccountInfo](https://cloud.tencent.com/document/api/409/16778#AccountInfo)
* [DBBackup](https://cloud.tencent.com/document/api/409/16778#DBBackup)
* [ErrLogDetail](https://cloud.tencent.com/document/api/409/16778#ErrLogDetail)
* [NormalQueryItem](https://cloud.tencent.com/document/api/409/16778#NormalQueryItem)
* [PgDeal](https://cloud.tencent.com/document/api/409/16778#PgDeal)
* [SlowlogDetail](https://cloud.tencent.com/document/api/409/16778#SlowlogDetail)
* [Xlog](https://cloud.tencent.com/document/api/409/16778#Xlog)

修改数据结构：

* [SpecItemInfo](https://cloud.tencent.com/document/api/409/16778#SpecItemInfo)

	* <font color="#dd0000">**修改成员**：</font>Cpu, Memory


### 第 1 次发布

发布时间：2018-04-24

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateDBInstances](https://cloud.tencent.com/document/api/409/16771)
* [DescribeDBInstanceAttribute](https://cloud.tencent.com/document/api/409/16772)
* [DescribeDBInstances](https://cloud.tencent.com/document/api/409/16773)
* [DescribeProductConfig](https://cloud.tencent.com/document/api/409/16776)
* [DescribeRegions](https://cloud.tencent.com/document/api/409/16768)
* [DescribeZones](https://cloud.tencent.com/document/api/409/16769)
* [InitDBInstances](https://cloud.tencent.com/document/api/409/16774)
* [InquiryPriceCreateDBInstances](https://cloud.tencent.com/document/api/409/16777)

新增数据结构：

* [DBInstance](https://cloud.tencent.com/document/api/409/16778#DBInstance)
* [DBInstanceNetInfo](https://cloud.tencent.com/document/api/409/16778#DBInstanceNetInfo)
* [Filter](https://cloud.tencent.com/document/api/409/16778#Filter)
* [RegionInfo](https://cloud.tencent.com/document/api/409/16778#RegionInfo)
* [SpecInfo](https://cloud.tencent.com/document/api/409/16778#SpecInfo)
* [SpecItemInfo](https://cloud.tencent.com/document/api/409/16778#SpecItemInfo)
* [ZoneInfo](https://cloud.tencent.com/document/api/409/16778#ZoneInfo)




## 私有域解析 Private DNS(privatedns) 版本：2020-10-28

### 第 17 次发布

发布时间：2024-01-19 01:18:43

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [PrivateZone](https://cloud.tencent.com/document/api/1338/55947#PrivateZone)

	* 新增成员：DeletedVpcSet


### 第 16 次发布

发布时间：2023-12-11 01:10:39

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [QueryAsyncBindVpcStatus](https://cloud.tencent.com/document/api/1338/102361)

### 第 15 次发布

发布时间：2023-12-07 02:16:03

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [AddSpecifyPrivateZoneVpc](https://cloud.tencent.com/document/api/1338/98675)

	* 新增入参：Sync

	* 新增出参：UniqId

* [DeleteSpecifyPrivateZoneVpc](https://cloud.tencent.com/document/api/1338/98674)

	* 新增入参：Sync

	* 新增出参：UniqId


### 第 14 次发布

发布时间：2023-09-19 01:22:56

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [AddSpecifyPrivateZoneVpc](https://cloud.tencent.com/document/api/1338/98675)
* [DeleteSpecifyPrivateZoneVpc](https://cloud.tencent.com/document/api/1338/98674)

### 第 13 次发布

发布时间：2023-06-14 01:36:28

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DeleteEndPoint](https://cloud.tencent.com/document/api/1338/93483)

### 第 12 次发布

发布时间：2022-12-09 01:52:05

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [PrivateZone](https://cloud.tencent.com/document/api/1338/55947#PrivateZone)

	* 新增成员：ForwardRuleName, ForwardRuleType, ForwardAddress, EndPointName


### 第 11 次发布

发布时间：2022-10-26 06:52:45

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [ModifyRecordsStatus](https://cloud.tencent.com/document/api/1338/81950)

### 第 10 次发布

发布时间：2022-09-19 06:43:11

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [MetricData](https://cloud.tencent.com/document/api/1338/55947#MetricData)

	* 新增成员：MetricCount


### 第 9 次发布

发布时间：2022-08-15 06:34:53

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreatePrivateZone](https://cloud.tencent.com/document/api/1338/55946)

	* 新增入参：CnameSpeedupStatus

* [ModifyPrivateZone](https://cloud.tencent.com/document/api/1338/55935)

	* 新增入参：CnameSpeedupStatus


修改数据结构：

* [PrivateZone](https://cloud.tencent.com/document/api/1338/55947#PrivateZone)

	* 新增成员：CnameSpeedupStatus


### 第 8 次发布

发布时间：2022-08-01 11:48:13

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [PrivateZoneRecord](https://cloud.tencent.com/document/api/1338/55947#PrivateZoneRecord)

	* 新增成员：Enabled


### 第 7 次发布

发布时间：2022-03-30 06:10:30

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [PrivateZone](https://cloud.tencent.com/document/api/1338/55947#PrivateZone)

	* 新增成员：IsCustomTld


### 第 6 次发布

发布时间：2022-03-22 08:13:14

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeQuotaUsage](https://cloud.tencent.com/document/api/1338/71482)

新增数据结构：

* [TldQuota](https://cloud.tencent.com/document/api/1338/55947#TldQuota)

### 第 5 次发布

发布时间：2021-12-02 08:10:37

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [AccountVpcInfo](https://cloud.tencent.com/document/api/1338/55947#AccountVpcInfo)

	* <font color="#dd0000">**修改成员**：</font>VpcName


### 第 4 次发布

发布时间：2021-11-30 08:10:39

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreatePrivateDNSAccount](https://cloud.tencent.com/document/api/1338/64976)
* [DeletePrivateDNSAccount](https://cloud.tencent.com/document/api/1338/64975)
* [DescribeAccountVpcList](https://cloud.tencent.com/document/api/1338/64974)

新增数据结构：

* [AccountVpcInfoOut](https://cloud.tencent.com/document/api/1338/55947#AccountVpcInfoOut)

### 第 3 次发布

发布时间：2021-09-13 08:00:37

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribePrivateDNSAccountList](https://cloud.tencent.com/document/api/1338/61417)

新增数据结构：

* [PrivateDNSAccount](https://cloud.tencent.com/document/api/1338/55947#PrivateDNSAccount)

### 第 2 次发布

发布时间：2021-09-06 08:00:36

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreatePrivateZone](https://cloud.tencent.com/document/api/1338/55946)

	* 新增入参：AccountVpcSet

* [ModifyPrivateZoneVpc](https://cloud.tencent.com/document/api/1338/55933)

	* 新增入参：AccountVpcSet

	* 新增出参：AccountVpcSet


新增数据结构：

* [AccountVpcInfo](https://cloud.tencent.com/document/api/1338/55947#AccountVpcInfo)
* [AccountVpcInfoOutput](https://cloud.tencent.com/document/api/1338/55947#AccountVpcInfoOutput)

修改数据结构：

* [PrivateZone](https://cloud.tencent.com/document/api/1338/55947#PrivateZone)

	* 新增成员：AccountVpcSet


### 第 1 次发布

发布时间：2021-05-18 11:34:31

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreatePrivateZone](https://cloud.tencent.com/document/api/1338/55946)
* [CreatePrivateZoneRecord](https://cloud.tencent.com/document/api/1338/55945)
* [DeletePrivateZone](https://cloud.tencent.com/document/api/1338/55944)
* [DeletePrivateZoneRecord](https://cloud.tencent.com/document/api/1338/55943)
* [DescribeAuditLog](https://cloud.tencent.com/document/api/1338/55942)
* [DescribeDashboard](https://cloud.tencent.com/document/api/1338/55941)
* [DescribePrivateZone](https://cloud.tencent.com/document/api/1338/55940)
* [DescribePrivateZoneList](https://cloud.tencent.com/document/api/1338/55939)
* [DescribePrivateZoneRecordList](https://cloud.tencent.com/document/api/1338/55938)
* [DescribePrivateZoneService](https://cloud.tencent.com/document/api/1338/55937)
* [DescribeRequestData](https://cloud.tencent.com/document/api/1338/55936)
* [ModifyPrivateZone](https://cloud.tencent.com/document/api/1338/55935)
* [ModifyPrivateZoneRecord](https://cloud.tencent.com/document/api/1338/55934)
* [ModifyPrivateZoneVpc](https://cloud.tencent.com/document/api/1338/55933)
* [SubscribePrivateZoneService](https://cloud.tencent.com/document/api/1338/55932)

新增数据结构：

* [AuditLog](https://cloud.tencent.com/document/api/1338/55947#AuditLog)
* [AuditLogInfo](https://cloud.tencent.com/document/api/1338/55947#AuditLogInfo)
* [DatePoint](https://cloud.tencent.com/document/api/1338/55947#DatePoint)
* [Filter](https://cloud.tencent.com/document/api/1338/55947#Filter)
* [FlowUsage](https://cloud.tencent.com/document/api/1338/55947#FlowUsage)
* [MetricData](https://cloud.tencent.com/document/api/1338/55947#MetricData)
* [PrivateZone](https://cloud.tencent.com/document/api/1338/55947#PrivateZone)
* [PrivateZoneRecord](https://cloud.tencent.com/document/api/1338/55947#PrivateZoneRecord)
* [TagInfo](https://cloud.tencent.com/document/api/1338/55947#TagInfo)
* [VpcInfo](https://cloud.tencent.com/document/api/1338/55947#VpcInfo)




## 云压测(pts) 版本：2021-07-28

### 第 15 次发布

发布时间：2024-04-19 01:24:07

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeRegions](https://cloud.tencent.com/document/api/1484/78073)

	* 新增入参：LoadType


### 第 14 次发布

发布时间：2024-03-27 01:23:10

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateEnvironment](https://cloud.tencent.com/document/api/1484/104600)
* [DeleteEnvironments](https://cloud.tencent.com/document/api/1484/104599)
* [DescribeEnvironments](https://cloud.tencent.com/document/api/1484/104598)
* [UpdateEnvironment](https://cloud.tencent.com/document/api/1484/104597)

### 第 13 次发布

发布时间：2023-08-23 01:36:48

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [UpdateScenario](https://cloud.tencent.com/document/api/1484/78057)

	* 新增入参：EnvId


### 第 12 次发布

发布时间：2023-07-21 01:35:57

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [Scenario](https://cloud.tencent.com/document/api/1484/78100#Scenario)

	* <font color="#dd0000">**修改成员**：</font>ScenarioId, Name, Description, Type, Status, Load, EncodedScripts, Configs, Extensions, Datasets, SLAId, CronId, CreatedAt, UpdatedAt, ProjectId, AppId, Uin, SubAccountUin, TestScripts, Protocols, RequestFiles, SLAPolicy, Plugins, DomainNameConfig, NotificationHooks, Owner, ProjectName


### 第 11 次发布

发布时间：2023-04-05 01:50:08

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeErrorSummary](https://cloud.tencent.com/document/api/1484/89896)

新增数据结构：

* [ErrorSummary](https://cloud.tencent.com/document/api/1484/78100#ErrorSummary)

修改数据结构：

* [Concurrency](https://cloud.tencent.com/document/api/1484/78100#Concurrency)

	* 新增成员：Resources


### 第 10 次发布

发布时间：2023-03-02 01:32:50

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [Job](https://cloud.tencent.com/document/api/1484/78100#Job)

	* 新增成员：ProjectName, ScenarioName

* [Scenario](https://cloud.tencent.com/document/api/1484/78100#Scenario)

	* 新增成员：ProjectName


### 第 9 次发布

发布时间：2022-12-28 14:35:16

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateScenario](https://cloud.tencent.com/document/api/1484/78091)

	* 新增入参：Owner

* [DescribeScenarioWithJobs](https://cloud.tencent.com/document/api/1484/78066)

	* 新增入参：ScenarioType, Owner

* [UpdateScenario](https://cloud.tencent.com/document/api/1484/78057)

	* 新增入参：Owner


修改数据结构：

* [Scenario](https://cloud.tencent.com/document/api/1484/78100#Scenario)

	* 新增成员：Owner

	* <font color="#dd0000">**修改成员**：</font>Name, AppId, Uin, SubAccountUin, TestScripts, Protocols, RequestFiles, SLAPolicy, Plugins, DomainNameConfig, NotificationHooks


### 第 8 次发布

发布时间：2022-12-08 01:40:36

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [Job](https://cloud.tencent.com/document/api/1484/78100#Job)

	* 新增成员：Message


### 第 7 次发布

发布时间：2022-11-18 06:42:29

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [Job](https://cloud.tencent.com/document/api/1484/78100#Job)

	* 新增成员：NetworkReceiveRate, NetworkSendRate


### 第 6 次发布

发布时间：2022-11-04 06:33:49

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [File](https://cloud.tencent.com/document/api/1484/78100#File)

	* 新增成员：AppId

* [ScriptInfo](https://cloud.tencent.com/document/api/1484/78100#ScriptInfo)

	* 新增成员：FileId


### 第 5 次发布

发布时间：2022-10-20 06:35:28

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [Concurrency](https://cloud.tencent.com/document/api/1484/78100#Concurrency)

	* 新增成员：GracefulStopSeconds

* [CustomSample](https://cloud.tencent.com/document/api/1484/78100#CustomSample)

	* 新增成员：Name

* [File](https://cloud.tencent.com/document/api/1484/78100#File)

	* 新增成员：AppID, Uin, SubAccountUin

* [RequestsPerSecond](https://cloud.tencent.com/document/api/1484/78100#RequestsPerSecond)

	* 新增成员：GracefulStopSeconds


### 第 4 次发布

发布时间：2022-09-19 06:43:24

本次发布包含了以下内容：

改善已有的文档。

新增数据结构：

* [NotificationHook](https://cloud.tencent.com/document/api/1484/78100#NotificationHook)

修改数据结构：

* [AlertChannelRecord](https://cloud.tencent.com/document/api/1484/78100#AlertChannelRecord)

	* 新增成员：AppId, Uin, SubAccountUin

* [AlertRecord](https://cloud.tencent.com/document/api/1484/78100#AlertRecord)

	* 新增成员：AppId, Uin, SubAccountUin, ScenarioName, Target, JobSLAId, JobSLADescription

* [CronJob](https://cloud.tencent.com/document/api/1484/78100#CronJob)

	* 新增成员：AppId, Uin, SubAccountUin

* [File](https://cloud.tencent.com/document/api/1484/78100#File)

	* 新增成员：CreatedAt, ProjectId

* [Job](https://cloud.tencent.com/document/api/1484/78100#Job)

	* 新增成员：Type, DomainNameConfig, Debug, AbortReason, CreatedAt, ProjectId, NotificationHooks

* [RequestSummary](https://cloud.tencent.com/document/api/1484/78100#RequestSummary)

	* 新增成员：P99, Status, Result

* [Scenario](https://cloud.tencent.com/document/api/1484/78100#Scenario)

	* 新增成员：NotificationHooks


### 第 3 次发布

发布时间：2022-08-22 06:42:21

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [UpdateScenario](https://cloud.tencent.com/document/api/1484/78057)

	* 新增入参：NotificationHooks


新增数据结构：

* [Notification](https://cloud.tencent.com/document/api/1484/78100#Notification)

### 第 2 次发布

发布时间：2022-08-15 06:35:03

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeScenarioWithJobs](https://cloud.tencent.com/document/api/1484/78066)

	* 新增入参：IgnoreDataset


### 第 1 次发布

发布时间：2022-07-29 11:04:42

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [AbortCronJobs](https://cloud.tencent.com/document/api/1484/78099)
* [AbortJob](https://cloud.tencent.com/document/api/1484/78098)
* [AdjustJobSpeed](https://cloud.tencent.com/document/api/1484/78097)
* [CopyScenario](https://cloud.tencent.com/document/api/1484/78096)
* [CreateAlertChannel](https://cloud.tencent.com/document/api/1484/78095)
* [CreateCronJob](https://cloud.tencent.com/document/api/1484/78094)
* [CreateFile](https://cloud.tencent.com/document/api/1484/78093)
* [CreateProject](https://cloud.tencent.com/document/api/1484/78092)
* [CreateScenario](https://cloud.tencent.com/document/api/1484/78091)
* [DeleteAlertChannel](https://cloud.tencent.com/document/api/1484/78090)
* [DeleteCronJobs](https://cloud.tencent.com/document/api/1484/78089)
* [DeleteFiles](https://cloud.tencent.com/document/api/1484/78088)
* [DeleteJobs](https://cloud.tencent.com/document/api/1484/78087)
* [DeleteProjects](https://cloud.tencent.com/document/api/1484/78086)
* [DeleteScenarios](https://cloud.tencent.com/document/api/1484/78085)
* [DescribeAlertChannels](https://cloud.tencent.com/document/api/1484/78084)
* [DescribeAlertRecords](https://cloud.tencent.com/document/api/1484/78083)
* [DescribeAvailableMetrics](https://cloud.tencent.com/document/api/1484/78082)
* [DescribeCheckSummary](https://cloud.tencent.com/document/api/1484/78081)
* [DescribeCronJobs](https://cloud.tencent.com/document/api/1484/78080)
* [DescribeFiles](https://cloud.tencent.com/document/api/1484/78079)
* [DescribeJobs](https://cloud.tencent.com/document/api/1484/78078)
* [DescribeLabelValues](https://cloud.tencent.com/document/api/1484/78077)
* [DescribeMetricLabelWithValues](https://cloud.tencent.com/document/api/1484/78076)
* [DescribeNormalLogs](https://cloud.tencent.com/document/api/1484/78075)
* [DescribeProjects](https://cloud.tencent.com/document/api/1484/78074)
* [DescribeRegions](https://cloud.tencent.com/document/api/1484/78073)
* [DescribeRequestSummary](https://cloud.tencent.com/document/api/1484/78072)
* [DescribeSampleBatchQuery](https://cloud.tencent.com/document/api/1484/78071)
* [DescribeSampleLogs](https://cloud.tencent.com/document/api/1484/78070)
* [DescribeSampleMatrixBatchQuery](https://cloud.tencent.com/document/api/1484/78069)
* [DescribeSampleMatrixQuery](https://cloud.tencent.com/document/api/1484/78068)
* [DescribeSampleQuery](https://cloud.tencent.com/document/api/1484/78067)
* [DescribeScenarioWithJobs](https://cloud.tencent.com/document/api/1484/78066)
* [DescribeScenarios](https://cloud.tencent.com/document/api/1484/78065)
* [GenerateTmpKey](https://cloud.tencent.com/document/api/1484/78064)
* [RestartCronJobs](https://cloud.tencent.com/document/api/1484/78063)
* [StartJob](https://cloud.tencent.com/document/api/1484/78062)
* [UpdateCronJob](https://cloud.tencent.com/document/api/1484/78061)
* [UpdateFileScenarioRelation](https://cloud.tencent.com/document/api/1484/78060)
* [UpdateJob](https://cloud.tencent.com/document/api/1484/78059)
* [UpdateProject](https://cloud.tencent.com/document/api/1484/78058)
* [UpdateScenario](https://cloud.tencent.com/document/api/1484/78057)

新增数据结构：

* [AggregationLegend](https://cloud.tencent.com/document/api/1484/78100#AggregationLegend)
* [AlertChannel](https://cloud.tencent.com/document/api/1484/78100#AlertChannel)
* [AlertChannelRecord](https://cloud.tencent.com/document/api/1484/78100#AlertChannelRecord)
* [AlertRecord](https://cloud.tencent.com/document/api/1484/78100#AlertRecord)
* [AlertRecordStatus](https://cloud.tencent.com/document/api/1484/78100#AlertRecordStatus)
* [Attributes](https://cloud.tencent.com/document/api/1484/78100#Attributes)
* [CheckSummary](https://cloud.tencent.com/document/api/1484/78100#CheckSummary)
* [Concurrency](https://cloud.tencent.com/document/api/1484/78100#Concurrency)
* [Credentials](https://cloud.tencent.com/document/api/1484/78100#Credentials)
* [CronJob](https://cloud.tencent.com/document/api/1484/78100#CronJob)
* [CustomSample](https://cloud.tencent.com/document/api/1484/78100#CustomSample)
* [CustomSampleMatrix](https://cloud.tencent.com/document/api/1484/78100#CustomSampleMatrix)
* [DNSConfig](https://cloud.tencent.com/document/api/1484/78100#DNSConfig)
* [DomainNameConfig](https://cloud.tencent.com/document/api/1484/78100#DomainNameConfig)
* [File](https://cloud.tencent.com/document/api/1484/78100#File)
* [FileInfo](https://cloud.tencent.com/document/api/1484/78100#FileInfo)
* [Filter](https://cloud.tencent.com/document/api/1484/78100#Filter)
* [GeoRegionsLoadItem](https://cloud.tencent.com/document/api/1484/78100#GeoRegionsLoadItem)
* [HostAlias](https://cloud.tencent.com/document/api/1484/78100#HostAlias)
* [InternalMetricQuery](https://cloud.tencent.com/document/api/1484/78100#InternalMetricQuery)
* [Job](https://cloud.tencent.com/document/api/1484/78100#Job)
* [Label](https://cloud.tencent.com/document/api/1484/78100#Label)
* [LabelWithValues](https://cloud.tencent.com/document/api/1484/78100#LabelWithValues)
* [Load](https://cloud.tencent.com/document/api/1484/78100#Load)
* [LoadSource](https://cloud.tencent.com/document/api/1484/78100#LoadSource)
* [LoadSpec](https://cloud.tencent.com/document/api/1484/78100#LoadSpec)
* [MetricInfo](https://cloud.tencent.com/document/api/1484/78100#MetricInfo)
* [MetricLabelWithValues](https://cloud.tencent.com/document/api/1484/78100#MetricLabelWithValues)
* [NormalLog](https://cloud.tencent.com/document/api/1484/78100#NormalLog)
* [Project](https://cloud.tencent.com/document/api/1484/78100#Project)
* [ProtocolInfo](https://cloud.tencent.com/document/api/1484/78100#ProtocolInfo)
* [ReactionTimeRange](https://cloud.tencent.com/document/api/1484/78100#ReactionTimeRange)
* [RegionDetail](https://cloud.tencent.com/document/api/1484/78100#RegionDetail)
* [RequestSummary](https://cloud.tencent.com/document/api/1484/78100#RequestSummary)
* [RequestsPerSecond](https://cloud.tencent.com/document/api/1484/78100#RequestsPerSecond)
* [SLALabel](https://cloud.tencent.com/document/api/1484/78100#SLALabel)
* [SLAPolicy](https://cloud.tencent.com/document/api/1484/78100#SLAPolicy)
* [SLARule](https://cloud.tencent.com/document/api/1484/78100#SLARule)
* [SampleLog](https://cloud.tencent.com/document/api/1484/78100#SampleLog)
* [SamplePair](https://cloud.tencent.com/document/api/1484/78100#SamplePair)
* [SampleStream](https://cloud.tencent.com/document/api/1484/78100#SampleStream)
* [Scenario](https://cloud.tencent.com/document/api/1484/78100#Scenario)
* [ScenarioRelatedJobsParams](https://cloud.tencent.com/document/api/1484/78100#ScenarioRelatedJobsParams)
* [ScenarioWithJobs](https://cloud.tencent.com/document/api/1484/78100#ScenarioWithJobs)
* [ScriptInfo](https://cloud.tencent.com/document/api/1484/78100#ScriptInfo)
* [ScriptOrigin](https://cloud.tencent.com/document/api/1484/78100#ScriptOrigin)
* [Stage](https://cloud.tencent.com/document/api/1484/78100#Stage)
* [TagSpec](https://cloud.tencent.com/document/api/1484/78100#TagSpec)
* [TestData](https://cloud.tencent.com/document/api/1484/78100#TestData)
* [VpcLoadDistribution](https://cloud.tencent.com/document/api/1484/78100#VpcLoadDistribution)




## 全栈式风控引擎(rce) 版本：2020-11-03

### 第 13 次发布

发布时间：2024-08-01 02:05:51

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [InputImportNameListDataFront](https://cloud.tencent.com/document/api/1343/52566#InputImportNameListDataFront)

	* <font color="#dd0000">**删除成员**：</font>FileCode, DataContent


### 第 12 次发布

发布时间：2024-07-31 11:55:08

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateNameList](https://cloud.tencent.com/document/api/1343/109467)
* [DeleteNameList](https://cloud.tencent.com/document/api/1343/109466)
* [DeleteNameListData](https://cloud.tencent.com/document/api/1343/109465)
* [DescribeNameList](https://cloud.tencent.com/document/api/1343/109464)
* [DescribeNameListDataList](https://cloud.tencent.com/document/api/1343/109463)
* [DescribeNameListDetail](https://cloud.tencent.com/document/api/1343/109462)
* [ImportNameListData](https://cloud.tencent.com/document/api/1343/109461)
* [ModifyNameList](https://cloud.tencent.com/document/api/1343/109460)
* [ModifyNameListData](https://cloud.tencent.com/document/api/1343/109407)

新增数据结构：

* [DataContentInfo](https://cloud.tencent.com/document/api/1343/52566#DataContentInfo)
* [InputCreateNameListFront](https://cloud.tencent.com/document/api/1343/52566#InputCreateNameListFront)
* [InputDeleteNameListData](https://cloud.tencent.com/document/api/1343/52566#InputDeleteNameListData)
* [InputDeleteNameListFront](https://cloud.tencent.com/document/api/1343/52566#InputDeleteNameListFront)
* [InputDescribeDataListFront](https://cloud.tencent.com/document/api/1343/52566#InputDescribeDataListFront)
* [InputDescribeNameListDetail](https://cloud.tencent.com/document/api/1343/52566#InputDescribeNameListDetail)
* [InputDescribeNameListFront](https://cloud.tencent.com/document/api/1343/52566#InputDescribeNameListFront)
* [InputImportNameListDataFront](https://cloud.tencent.com/document/api/1343/52566#InputImportNameListDataFront)
* [InputModifyNameFront](https://cloud.tencent.com/document/api/1343/52566#InputModifyNameFront)
* [InputModifyNameListDataFront](https://cloud.tencent.com/document/api/1343/52566#InputModifyNameListDataFront)
* [InputModifyNameListDataFrontListData](https://cloud.tencent.com/document/api/1343/52566#InputModifyNameListDataFrontListData)
* [OuntputDescribeDataListInfo](https://cloud.tencent.com/document/api/1343/52566#OuntputDescribeDataListInfo)
* [OutputCreateNameListFront](https://cloud.tencent.com/document/api/1343/52566#OutputCreateNameListFront)
* [OutputDeleteNameListData](https://cloud.tencent.com/document/api/1343/52566#OutputDeleteNameListData)
* [OutputDeleteNameListFront](https://cloud.tencent.com/document/api/1343/52566#OutputDeleteNameListFront)
* [OutputDescribeDataListFront](https://cloud.tencent.com/document/api/1343/52566#OutputDescribeDataListFront)
* [OutputDescribeDataListFrontData](https://cloud.tencent.com/document/api/1343/52566#OutputDescribeDataListFrontData)
* [OutputDescribeNameListDetail](https://cloud.tencent.com/document/api/1343/52566#OutputDescribeNameListDetail)
* [OutputDescribeNameListDetailFront](https://cloud.tencent.com/document/api/1343/52566#OutputDescribeNameListDetailFront)
* [OutputDescribeNameListFrontFix](https://cloud.tencent.com/document/api/1343/52566#OutputDescribeNameListFrontFix)
* [OutputDescribeNameListFrontFixListData](https://cloud.tencent.com/document/api/1343/52566#OutputDescribeNameListFrontFixListData)
* [OutputDescribeNameListInfo](https://cloud.tencent.com/document/api/1343/52566#OutputDescribeNameListInfo)
* [OutputImportNameListDataFront](https://cloud.tencent.com/document/api/1343/52566#OutputImportNameListDataFront)
* [OutputModifyNameFront](https://cloud.tencent.com/document/api/1343/52566#OutputModifyNameFront)
* [OutputModifyNameListFront](https://cloud.tencent.com/document/api/1343/52566#OutputModifyNameListFront)

### 第 11 次发布

发布时间：2024-07-23 01:57:03

本次发布包含了以下内容：

改善已有的文档。

新增数据结构：

* [DataAuthorizationInfo](https://cloud.tencent.com/document/api/1343/52566#DataAuthorizationInfo)

修改数据结构：

* [InputManageMarketingRisk](https://cloud.tencent.com/document/api/1343/52566#InputManageMarketingRisk)

	* 新增成员：DataAuthorization


### 第 10 次发布

发布时间：2024-05-17 02:07:15

本次发布包含了以下内容：

改善已有的文档。

<font color="#dd0000">**删除接口**：</font>

* DescribeRiskAssessment

### 第 9 次发布

发布时间：2024-05-09 01:21:46

本次发布包含了以下内容：

改善已有的文档。

<font color="#dd0000">**删除接口**：</font>

* DescribeRiskTrends

<font color="#dd0000">**删除数据结构**：</font>

* InputFrontRisk
* OutputFrontRisk
* OutputFrontRiskData
* OutputFrontRiskValue

### 第 8 次发布

发布时间：2023-10-31 02:15:24

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [OutputManageMarketingRiskValue](https://cloud.tencent.com/document/api/1343/52566#OutputManageMarketingRiskValue)

	* 新增成员：RiskInformation


### 第 7 次发布

发布时间：2022-08-05 06:32:35

本次发布包含了以下内容：

改善已有的文档。

<font color="#dd0000">**删除接口**：</font>

* DescribeRiskModel

<font color="#dd0000">**删除数据结构**：</font>

* InputDescribeRiskModelData
* OutputDescribeRiskModel
* OutputDescribeRiskModelValue

### 第 6 次发布

发布时间：2022-04-21 06:16:10

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [InputManageMarketingRisk](https://cloud.tencent.com/document/api/1343/52566#InputManageMarketingRisk)

	* 新增成员：Platform

* [OutputManageMarketingRiskValue](https://cloud.tencent.com/document/api/1343/52566#OutputManageMarketingRiskValue)

	* 新增成员：ConstId


### 第 5 次发布

发布时间：2022-01-10 08:14:37

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [InputDescribeRiskModelData](https://cloud.tencent.com/document/api/1343/52566#InputDescribeRiskModelData)

	* 新增成员：IsTest


### 第 4 次发布

发布时间：2021-12-29 08:11:26

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeRiskAssessment](https://cloud.tencent.com/document/api/#/#)
* [DescribeRiskTrends](https://cloud.tencent.com/document/api/#/#)

新增数据结构：

* [InputFrontRisk](https://cloud.tencent.com/document/api/1343/52566#InputFrontRisk)
* [OutputFrontRisk](https://cloud.tencent.com/document/api/1343/52566#OutputFrontRisk)
* [OutputFrontRiskData](https://cloud.tencent.com/document/api/1343/52566#OutputFrontRiskData)
* [OutputFrontRiskValue](https://cloud.tencent.com/document/api/1343/52566#OutputFrontRiskValue)

### 第 3 次发布

发布时间：2021-10-27 08:10:34

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [ManageMarketingRisk](https://cloud.tencent.com/document/api/1343/52565)

	* 新增入参：BusinessCryptoData

	* <font color="#dd0000">**修改入参**：</font>BusinessSecurityData


新增数据结构：

* [InputCryptoManageMarketingRisk](https://cloud.tencent.com/document/api/1343/52566#InputCryptoManageMarketingRisk)

### 第 2 次发布

发布时间：2021-09-22 08:12:15

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeRiskModel](https://cloud.tencent.com/document/api/1343/61728)

新增数据结构：

* [InputDescribeRiskModelData](https://cloud.tencent.com/document/api/1343/52566#InputDescribeRiskModelData)
* [OutputDescribeRiskModel](https://cloud.tencent.com/document/api/1343/52566#OutputDescribeRiskModel)
* [OutputDescribeRiskModelValue](https://cloud.tencent.com/document/api/1343/52566#OutputDescribeRiskModelValue)

### 第 1 次发布

发布时间：2021-01-27 08:10:11

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [ManageMarketingRisk](https://cloud.tencent.com/document/api/1343/52565)

新增数据结构：

* [AccountInfo](https://cloud.tencent.com/document/api/1343/52566#AccountInfo)
* [InputDetails](https://cloud.tencent.com/document/api/1343/52566#InputDetails)
* [InputManageMarketingRisk](https://cloud.tencent.com/document/api/1343/52566#InputManageMarketingRisk)
* [OnlineScamInfo](https://cloud.tencent.com/document/api/1343/52566#OnlineScamInfo)
* [OtherAccountInfo](https://cloud.tencent.com/document/api/1343/52566#OtherAccountInfo)
* [OutputManageMarketingRisk](https://cloud.tencent.com/document/api/1343/52566#OutputManageMarketingRisk)
* [OutputManageMarketingRiskValue](https://cloud.tencent.com/document/api/1343/52566#OutputManageMarketingRiskValue)
* [QQAccountInfo](https://cloud.tencent.com/document/api/1343/52566#QQAccountInfo)
* [SponsorInfo](https://cloud.tencent.com/document/api/1343/52566#SponsorInfo)
* [WeChatAccountInfo](https://cloud.tencent.com/document/api/1343/52566#WeChatAccountInfo)




## 云数据库Redis(redis) 版本：2018-04-12

### 第 80 次发布

发布时间：2024-08-02 02:00:28

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeRedisClusterOverview](https://cloud.tencent.com/document/api/239/109629)
* [DescribeRedisClusters](https://cloud.tencent.com/document/api/239/109628)

新增数据结构：

* [CDCResource](https://cloud.tencent.com/document/api/239/20022#CDCResource)
* [ResourceBundle](https://cloud.tencent.com/document/api/239/20022#ResourceBundle)

修改数据结构：

* [InstanceSet](https://cloud.tencent.com/document/api/239/20022#InstanceSet)

	* 新增成员：RedisClusterId, DedicatedClusterId, ProductVersion


### 第 79 次发布

发布时间：2024-06-18 02:05:48

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [TendisNodes](https://cloud.tencent.com/document/api/239/20022#TendisNodes)

	* 新增成员：ZoneId


### 第 78 次发布

发布时间：2024-06-17 02:05:47

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeGlobalReplicationArea](https://cloud.tencent.com/document/api/239/107301)
* [DescribeInstanceSpecBandwidth](https://cloud.tencent.com/document/api/239/107302)
* [DescribeReplicationGroupInstance](https://cloud.tencent.com/document/api/239/107300)
* [ModifyReplicationGroup](https://cloud.tencent.com/document/api/239/107299)

新增数据结构：

* [AvailableRegion](https://cloud.tencent.com/document/api/239/20022#AvailableRegion)

### 第 77 次发布

发布时间：2024-06-14 02:23:01

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeProjectSecurityGroups](https://cloud.tencent.com/document/api/239/41258)

	* <font color="#dd0000">**修改入参**：</font>ProjectId


### 第 76 次发布

发布时间：2024-06-10 02:18:13

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeBackupDetail](https://cloud.tencent.com/document/api/239/107146)

### 第 75 次发布

发布时间：2024-05-30 02:02:41

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CloneInstances](https://cloud.tencent.com/document/api/239/89391)

	* 新增入参：CloneTime


修改数据结构：

* [InstanceSet](https://cloud.tencent.com/document/api/239/20022#InstanceSet)

	* 新增成员：BackupMode


### 第 74 次发布

发布时间：2024-04-19 01:24:17

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateInstances](https://cloud.tencent.com/document/api/239/20026)

	* 新增入参：AlarmPolicyList


### 第 73 次发布

发布时间：2024-04-02 01:20:49

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeInstanceEvents](https://cloud.tencent.com/document/api/239/104779)
* [ModifyInstanceEvent](https://cloud.tencent.com/document/api/239/104778)

新增数据结构：

* [RedisInstanceEvent](https://cloud.tencent.com/document/api/239/20022#RedisInstanceEvent)

### 第 72 次发布

发布时间：2024-03-12 01:45:03

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [Account](https://cloud.tencent.com/document/api/239/20022#Account)

	* 新增成员：CreateTime


### 第 71 次发布

发布时间：2024-02-22 01:21:35

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeSlowLog](https://cloud.tencent.com/document/api/239/37984)

	* 新增出参：InstanceSlowLogDetail


### 第 70 次发布

发布时间：2024-01-29 01:18:51

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [InstanceClusterShard](https://cloud.tencent.com/document/api/239/20022#InstanceClusterShard)

	* 新增成员：RunId

* [InstanceSet](https://cloud.tencent.com/document/api/239/20022#InstanceSet)

	* 新增成员：IPv6

* [Instances](https://cloud.tencent.com/document/api/239/20022#Instances)

	* 新增成员：IPv6


### 第 69 次发布

发布时间：2023-12-22 01:21:35

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [ProductConf](https://cloud.tencent.com/document/api/239/20022#ProductConf)

	* 新增成员：EnableReplicaReadOnly


### 第 68 次发布

发布时间：2023-12-11 01:11:39

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeInstanceSupportFeature](https://cloud.tencent.com/document/api/239/102364)
* [ModifyInstanceAvailabilityZones](https://cloud.tencent.com/document/api/239/102363)
* [SwitchAccessNewInstance](https://cloud.tencent.com/document/api/239/102362)

### 第 67 次发布

发布时间：2023-07-18 01:42:27

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [BackupDownloadInfo](https://cloud.tencent.com/document/api/239/20022#BackupDownloadInfo)

	* <font color="#dd0000">**修改成员**：</font>FileSize


### 第 66 次发布

发布时间：2023-06-28 01:36:04

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [ChangeMasterInstance](https://cloud.tencent.com/document/api/239/77862)

	* 新增入参：ForceSwitch


### 第 65 次发布

发布时间：2023-04-27 01:33:11

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [KillMasterGroup](https://cloud.tencent.com/document/api/239/58399)

	* <font color="#dd0000">**修改入参**：</font>Password


### 第 64 次发布

发布时间：2023-04-12 01:49:54

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeBandwidthRange](https://cloud.tencent.com/document/api/239/90100)
* [RemoveReplicationInstance](https://cloud.tencent.com/document/api/239/90099)

### 第 63 次发布

发布时间：2023-03-27 02:24:20

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CloneInstances](https://cloud.tencent.com/document/api/239/89391)

### 第 62 次发布

发布时间：2023-03-16 02:04:37

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeSSLStatus](https://cloud.tencent.com/document/api/239/88703)

### 第 61 次发布

发布时间：2023-03-03 01:39:15

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeBackupDownloadRestriction](https://cloud.tencent.com/document/api/239/87742)
* [ModifyBackupDownloadRestriction](https://cloud.tencent.com/document/api/239/87741)

### 第 60 次发布

发布时间：2023-02-23 01:48:21

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeBackupUrl](https://cloud.tencent.com/document/api/239/34443)

	* 新增入参：LimitType, VpcComparisonSymbol, IpComparisonSymbol, LimitVpc, LimitIp

* [DescribeInstanceBackups](https://cloud.tencent.com/document/api/239/20011)

	* 新增入参：InstanceName

	* <font color="#dd0000">**修改入参**：</font>InstanceId

* [ModifyNetworkConfig](https://cloud.tencent.com/document/api/239/34436)

	* 新增入参：VPort

	* 新增出参：TaskId


新增数据结构：

* [BackupLimitVpcItem](https://cloud.tencent.com/document/api/239/20022#BackupLimitVpcItem)

修改数据结构：

* [RedisBackupSet](https://cloud.tencent.com/document/api/239/20022#RedisBackupSet)

	* 新增成员：InstanceId, InstanceName, Region, EndTime, FileType, ExpireTime


### 第 59 次发布

发布时间：2022-11-08 06:37:00

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [RenewInstance](https://cloud.tencent.com/document/api/239/20015)

	* 新增入参：ModifyPayMode


### 第 58 次发布

发布时间：2022-11-07 06:32:04

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [ProxyNodes](https://cloud.tencent.com/document/api/239/20022#ProxyNodes)

	* 新增成员：ZoneId


### 第 57 次发布

发布时间：2022-10-18 06:44:04

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeInstances](https://cloud.tencent.com/document/api/239/20018)

	* 新增入参：AzMode


### 第 56 次发布

发布时间：2022-10-14 06:44:02

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [InstanceSet](https://cloud.tencent.com/document/api/239/20022#InstanceSet)

	* 新增成员：WanAddress, PolarisServer, CurrentProxyVersion, CurrentRedisVersion, UpgradeProxyVersion, UpgradeRedisVersion


### 第 55 次发布

发布时间：2022-10-10 06:35:50

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CloseSSL](https://cloud.tencent.com/document/api/239/81240)
* [OpenSSL](https://cloud.tencent.com/document/api/239/81239)

### 第 54 次发布

发布时间：2022-09-30 06:48:02

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeSlowLog](https://cloud.tencent.com/document/api/239/37984)

	* 新增入参：Role


### 第 53 次发布

发布时间：2022-08-11 06:44:49

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [SwitchProxy](https://cloud.tencent.com/document/api/239/78841)

### 第 52 次发布

发布时间：2022-07-27 06:14:34

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [ChangeInstanceRole](https://cloud.tencent.com/document/api/239/77863)
* [ChangeMasterInstance](https://cloud.tencent.com/document/api/239/77862)

### 第 51 次发布

发布时间：2022-07-25 06:12:50

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeInstances](https://cloud.tencent.com/document/api/239/20018)

	* 新增入参：InstanceIds


### 第 50 次发布

发布时间：2022-07-15 06:13:33

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateInstances](https://cloud.tencent.com/document/api/239/20026)

	* 新增入参：ProductVersion, RedisClusterId

* [InquiryPriceCreateInstance](https://cloud.tencent.com/document/api/239/41159)

	* 新增入参：ProductVersion


### 第 49 次发布

发布时间：2022-07-13 06:15:09

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeInstances](https://cloud.tencent.com/document/api/239/20018)

	* 新增入参：ProductVersions


### 第 48 次发布

发布时间：2022-07-06 06:16:58

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeTaskList](https://cloud.tencent.com/document/api/239/39374)

	* 新增入参：OperateUin


### 第 47 次发布

发布时间：2022-06-16 06:10:57

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeTaskList](https://cloud.tencent.com/document/api/239/39374)

	* 新增入参：Result, OperatorUin


### 第 46 次发布

发布时间：2022-05-30 06:11:47

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [UpgradeProxyVersion](https://cloud.tencent.com/document/api/239/74597)
* [UpgradeSmallVersion](https://cloud.tencent.com/document/api/239/74596)

### 第 45 次发布

发布时间：2022-05-18 06:15:32

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateInstances](https://cloud.tencent.com/document/api/239/20026)

	* 新增入参：DryRun


### 第 44 次发布

发布时间：2022-05-17 06:14:17

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [ModifyInstanceReadOnly](https://cloud.tencent.com/document/api/239/73781)

### 第 43 次发布

发布时间：2022-04-21 06:16:12

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [AllocateWanAddress](https://cloud.tencent.com/document/api/239/72839)
* [ReleaseWanAddress](https://cloud.tencent.com/document/api/239/72838)

### 第 42 次发布

发布时间：2022-03-24 08:15:42

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeAutoBackupConfig](https://cloud.tencent.com/document/api/239/20019)

	* 新增出参：BackupStorageDays, BinlogStorageDays

* [DescribeDBSecurityGroups](https://cloud.tencent.com/document/api/239/41259)

	* 新增出参：VIP, VPort

* [DescribeInstances](https://cloud.tencent.com/document/api/239/20018)

	* 新增入参：InstanceTags, TagKeys

* [ManualBackupInstance](https://cloud.tencent.com/document/api/239/20010)

	* 新增入参：StorageDays

* [UpgradeVersionToMultiAvailabilityZones](https://cloud.tencent.com/document/api/239/54759)

	* 新增入参：UpgradeProxyAndRedisServer


修改数据结构：

* [RedisBackupSet](https://cloud.tencent.com/document/api/239/20022#RedisBackupSet)

	* 新增成员：BackupSize, FullBackup, InstanceType


### 第 41 次发布

发布时间：2022-03-23 08:10:37

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeReplicationGroup](https://cloud.tencent.com/document/api/239/71554)

修改接口：

* [ModifyAutoBackupConfig](https://cloud.tencent.com/document/api/239/20016)

	* 新增出参：BackupStorageDays

* [ModifyNetworkConfig](https://cloud.tencent.com/document/api/239/34436)

	* 新增入参：Recycle


新增数据结构：

* [Groups](https://cloud.tencent.com/document/api/239/20022#Groups)
* [Instances](https://cloud.tencent.com/document/api/239/20022#Instances)

### 第 40 次发布

发布时间：2022-01-19 08:13:55

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [AddReplicationInstance](https://cloud.tencent.com/document/api/239/68401)
* [CreateReplicationGroup](https://cloud.tencent.com/document/api/239/68400)
* [DeleteReplicationInstance](https://cloud.tencent.com/document/api/239/68399)

### 第 39 次发布

发布时间：2022-01-18 08:13:46

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [ChangeReplicaToMaster](https://cloud.tencent.com/document/api/239/56698)

	* <font color="#dd0000">**修改入参**：</font>GroupId

* [KillMasterGroup](https://cloud.tencent.com/document/api/239/58399)

	* 新增入参：ShardIds


### 第 38 次发布

发布时间：2021-12-07 13:09:58

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DisableReplicaReadonly](https://cloud.tencent.com/document/api/239/34438)

	* 新增出参：TaskId

	* <font color="#dd0000">**删除出参**：</font>Status


### 第 37 次发布

发布时间：2021-11-04 08:12:00

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [EnableReplicaReadonly](https://cloud.tencent.com/document/api/239/34437)

	* 新增出参：TaskId


### 第 36 次发布

发布时间：2021-07-23 08:08:01

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeBackupUrl](https://cloud.tencent.com/document/api/239/34443)

	* 新增出参：Filenames, BackupInfos

* [InquiryPriceCreateInstance](https://cloud.tencent.com/document/api/239/41159)

	* 新增入参：ZoneName

	* <font color="#dd0000">**修改入参**：</font>ZoneId


新增数据结构：

* [BackupDownloadInfo](https://cloud.tencent.com/document/api/239/20022#BackupDownloadInfo)

### 第 35 次发布

发布时间：2021-07-16 08:08:10

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [ApplyParamsTemplate](https://cloud.tencent.com/document/api/239/58753)
* [CreateParamTemplate](https://cloud.tencent.com/document/api/239/58752)
* [DeleteParamTemplate](https://cloud.tencent.com/document/api/239/58751)
* [DescribeParamTemplateInfo](https://cloud.tencent.com/document/api/239/58748)
* [DescribeParamTemplates](https://cloud.tencent.com/document/api/239/58750)
* [ModifyParamTemplate](https://cloud.tencent.com/document/api/239/58749)

修改接口：

* [CreateInstances](https://cloud.tencent.com/document/api/239/20026)

	* 新增入参：ZoneName, TemplateId

	* <font color="#dd0000">**修改入参**：</font>ZoneId


新增数据结构：

* [ParamTemplateInfo](https://cloud.tencent.com/document/api/239/20022#ParamTemplateInfo)
* [ParameterDetail](https://cloud.tencent.com/document/api/239/20022#ParameterDetail)

修改数据结构：

* [RedisNodeInfo](https://cloud.tencent.com/document/api/239/20022#RedisNodeInfo)

	* 新增成员：ZoneName

	* <font color="#dd0000">**修改成员**：</font>ZoneId


### 第 34 次发布

发布时间：2021-07-12 08:07:50

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [KillMasterGroup](https://cloud.tencent.com/document/api/239/58399)

	* <font color="#dd0000">**修改入参**：</font>Password


### 第 33 次发布

发布时间：2021-07-09 08:07:43

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [KillMasterGroup](https://cloud.tencent.com/document/api/239/58399)

### 第 32 次发布

发布时间：2021-06-09 08:07:24

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [RedisNode](https://cloud.tencent.com/document/api/239/20022#RedisNode)

	* 新增成员：Role

* [RedisNodes](https://cloud.tencent.com/document/api/239/20022#RedisNodes)

	* 新增成员：ZoneId


### 第 31 次发布

发布时间：2021-06-04 08:07:27

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [ChangeReplicaToMaster](https://cloud.tencent.com/document/api/239/56698)

### 第 30 次发布

发布时间：2021-04-16 08:06:39

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [UpgradeVersionToMultiAvailabilityZones](https://cloud.tencent.com/document/api/239/54759)

### 第 29 次发布

发布时间：2021-02-24 08:06:21

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [InstanceIntegerParam](https://cloud.tencent.com/document/api/239/20022#InstanceIntegerParam)

	* 新增成员：Unit

* [InstanceSlowlogDetail](https://cloud.tencent.com/document/api/239/20022#InstanceSlowlogDetail)

	* 新增成员：Node


### 第 28 次发布

发布时间：2021-02-02 08:07:36

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [InstanceSet](https://cloud.tencent.com/document/api/239/20022#InstanceSet)

	* 新增成员：ClientLimitMin, ClientLimitMax, NodeSet, Region


### 第 27 次发布

发布时间：2020-12-18 08:06:39

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [UpgradeInstance](https://cloud.tencent.com/document/api/239/20013)

	* 新增入参：NodeSet


### 第 26 次发布

发布时间：2020-12-11 08:06:05

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateInstances](https://cloud.tencent.com/document/api/239/20026)

	* 新增入参：ResourceTags


新增数据结构：

* [ResourceTag](https://cloud.tencent.com/document/api/239/20022#ResourceTag)

### 第 25 次发布

发布时间：2020-11-26 08:05:36

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeInstanceZoneInfo](https://cloud.tencent.com/document/api/239/50312)

新增数据结构：

* [RedisNode](https://cloud.tencent.com/document/api/239/20022#RedisNode)
* [ReplicaGroup](https://cloud.tencent.com/document/api/239/20022#ReplicaGroup)

### 第 24 次发布

发布时间：2020-11-19 08:05:46

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeTendisSlowLog](https://cloud.tencent.com/document/api/239/50085)

新增数据结构：

* [TendisSlowLogDetail](https://cloud.tencent.com/document/api/239/20022#TendisSlowLogDetail)

### 第 23 次发布

发布时间：2020-11-04 08:05:40

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [ModifyConnectionConfig](https://cloud.tencent.com/document/api/239/49639)

修改接口：

* [CreateInstances](https://cloud.tencent.com/document/api/239/20026)

	* 新增入参：NodeSet


新增数据结构：

* [RedisNodeInfo](https://cloud.tencent.com/document/api/239/20022#RedisNodeInfo)

### 第 22 次发布

发布时间：2020-10-27 08:06:31

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeCommonDBInstances](https://cloud.tencent.com/document/api/239/49428)

新增数据结构：

* [RedisCommonInstanceList](https://cloud.tencent.com/document/api/239/20022#RedisCommonInstanceList)

### 第 21 次发布

发布时间：2020-09-23 08:05:27

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeInstanceNodeInfo](https://cloud.tencent.com/document/api/239/48603)

新增数据结构：

* [ProxyNodes](https://cloud.tencent.com/document/api/239/20022#ProxyNodes)
* [RedisNodes](https://cloud.tencent.com/document/api/239/20022#RedisNodes)
* [TendisNodes](https://cloud.tencent.com/document/api/239/20022#TendisNodes)

### 第 20 次发布

发布时间：2020-09-04 08:05:55

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeProxySlowLog](https://cloud.tencent.com/document/api/239/48121)

新增数据结构：

* [InstanceProxySlowlogDetail](https://cloud.tencent.com/document/api/239/20022#InstanceProxySlowlogDetail)

### 第 19 次发布

发布时间：2020-08-26 08:05:27

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeInstances](https://cloud.tencent.com/document/api/239/20018)

	* 新增入参：MonitorVersion


修改数据结构：

* [InstanceSet](https://cloud.tencent.com/document/api/239/20022#InstanceSet)

	* 新增成员：DiskSize, MonitorVersion


### 第 18 次发布

发布时间：2020-07-15 08:15:20

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeMaintenanceWindow](https://cloud.tencent.com/document/api/239/46336)
* [ModifyMaintenanceWindow](https://cloud.tencent.com/document/api/239/46335)
* [UpgradeInstanceVersion](https://cloud.tencent.com/document/api/239/46334)

### 第 17 次发布

发布时间：2020-04-29 08:15:02

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [DelayDistribution](https://cloud.tencent.com/document/api/239/20022#DelayDistribution)

	* 新增成员：Updatetime


### 第 16 次发布

发布时间：2020-03-19 08:12:31

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [InstanceSet](https://cloud.tencent.com/document/api/239/20022#InstanceSet)

	* 新增成员：RemainBandwidthDuration


### 第 15 次发布

发布时间：2020-03-16 08:16:13

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [InstanceSet](https://cloud.tencent.com/document/api/239/20022#InstanceSet)

	* 新增成员：ClientLimit, DtsStatus, NetLimit, PasswordFree, ReadOnly, Vip6


### 第 14 次发布

发布时间：2020-02-13 16:56:05

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [AssociateSecurityGroups](https://cloud.tencent.com/document/api/239/41260)
* [DescribeDBSecurityGroups](https://cloud.tencent.com/document/api/239/41259)
* [DescribeProjectSecurityGroups](https://cloud.tencent.com/document/api/239/41258)
* [DisassociateSecurityGroups](https://cloud.tencent.com/document/api/239/41257)
* [ModifyDBInstanceSecurityGroups](https://cloud.tencent.com/document/api/239/41256)

修改接口：

* [DescribeInstances](https://cloud.tencent.com/document/api/239/20018)

	* 新增入参：TypeList


新增数据结构：

* [Inbound](https://cloud.tencent.com/document/api/239/20022#Inbound)
* [Outbound](https://cloud.tencent.com/document/api/239/20022#Outbound)
* [SecurityGroup](https://cloud.tencent.com/document/api/239/20022#SecurityGroup)

### 第 13 次发布

发布时间：2020-01-17 17:52:43

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [InquiryPriceCreateInstance](https://cloud.tencent.com/document/api/239/41159)
* [InquiryPriceRenewInstance](https://cloud.tencent.com/document/api/239/41158)
* [InquiryPriceUpgradeInstance](https://cloud.tencent.com/document/api/239/41157)

### 第 12 次发布

发布时间：2019-12-31 14:24:11

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [ModifyInstance](https://cloud.tencent.com/document/api/239/31785)

	* 新增入参：InstanceIds, InstanceNames, AutoRenews


修改数据结构：

* [InstanceMultiParam](https://cloud.tencent.com/document/api/239/20022#InstanceMultiParam)

	* <font color="#dd0000">**修改成员**：</font>EnumValue


### 第 11 次发布

发布时间：2019-11-21 19:29:01

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [StartupInstance](https://cloud.tencent.com/document/api/239/39415)

### 第 10 次发布

发布时间：2019-11-19 17:48:02

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeInstanceDTSInfo](https://cloud.tencent.com/document/api/239/39375)
* [DescribeTaskList](https://cloud.tencent.com/document/api/239/39374)

新增数据结构：

* [DescribeInstanceDTSInstanceInfo](https://cloud.tencent.com/document/api/239/20022#DescribeInstanceDTSInstanceInfo)
* [TaskInfoDetail](https://cloud.tencent.com/document/api/239/20022#TaskInfoDetail)

### 第 9 次发布

发布时间：2019-11-01 17:10:33

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateInstanceAccount](https://cloud.tencent.com/document/api/239/38926)
* [DeleteInstanceAccount](https://cloud.tencent.com/document/api/239/38925)
* [DescribeInstanceAccount](https://cloud.tencent.com/document/api/239/38924)
* [DescribeInstanceMonitorBigKey](https://cloud.tencent.com/document/api/239/38922)
* [DescribeInstanceMonitorBigKeySizeDist](https://cloud.tencent.com/document/api/239/40601)
* [DescribeInstanceMonitorBigKeyTypeDist](https://cloud.tencent.com/document/api/239/38921)
* [DescribeInstanceMonitorHotKey](https://cloud.tencent.com/document/api/239/38920)
* [DescribeInstanceMonitorSIP](https://cloud.tencent.com/document/api/239/38919)
* [DescribeInstanceMonitorTookDist](https://cloud.tencent.com/document/api/239/38918)
* [DescribeInstanceMonitorTopNCmd](https://cloud.tencent.com/document/api/239/38917)
* [DescribeInstanceMonitorTopNCmdTook](https://cloud.tencent.com/document/api/239/38916)
* [ModifyInstanceAccount](https://cloud.tencent.com/document/api/239/38923)

修改接口：

* [EnableReplicaReadonly](https://cloud.tencent.com/document/api/239/34437)

	* 新增入参：ReadonlyPolicy


新增数据结构：

* [Account](https://cloud.tencent.com/document/api/239/20022#Account)
* [BigKeyInfo](https://cloud.tencent.com/document/api/239/20022#BigKeyInfo)
* [BigKeyTypeInfo](https://cloud.tencent.com/document/api/239/20022#BigKeyTypeInfo)
* [CommandTake](https://cloud.tencent.com/document/api/239/20022#CommandTake)
* [DelayDistribution](https://cloud.tencent.com/document/api/239/20022#DelayDistribution)
* [HotKeyInfo](https://cloud.tencent.com/document/api/239/20022#HotKeyInfo)
* [SourceCommand](https://cloud.tencent.com/document/api/239/20022#SourceCommand)
* [SourceInfo](https://cloud.tencent.com/document/api/239/20022#SourceInfo)

### 第 8 次发布

发布时间：2019-09-12 17:10:13

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeSlowLog](https://cloud.tencent.com/document/api/239/37984)

新增数据结构：

* [InstanceSlowlogDetail](https://cloud.tencent.com/document/api/239/20022#InstanceSlowlogDetail)

### 第 7 次发布

发布时间：2019-08-12 22:01:38

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [SwitchInstanceVip](https://cloud.tencent.com/document/api/239/37070)

### 第 6 次发布

发布时间：2019-08-01 20:26:39

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [ClearInstance](https://cloud.tencent.com/document/api/239/20021)

	* <font color="#dd0000">**修改入参**：</font>Password

* [CreateInstances](https://cloud.tencent.com/document/api/239/20026)

	* 新增入参：NoAuth

	* <font color="#dd0000">**修改入参**：</font>Password

	* 新增出参：InstanceIds

* [DescribeInstanceParams](https://cloud.tencent.com/document/api/239/34448)

	* 新增出参：InstanceMultiParam

* [ModifyInstanceParams](https://cloud.tencent.com/document/api/239/34445)

	* 新增出参：TaskId

* [ResetPassword](https://cloud.tencent.com/document/api/239/20014)

	* 新增入参：NoAuth

	* <font color="#dd0000">**修改入参**：</font>Password

* [RestoreInstance](https://cloud.tencent.com/document/api/239/34435)

	* <font color="#dd0000">**修改入参**：</font>Password


新增数据结构：

* [InstanceMultiParam](https://cloud.tencent.com/document/api/239/20022#InstanceMultiParam)

修改数据结构：

* [InstanceEnumParam](https://cloud.tencent.com/document/api/239/20022#InstanceEnumParam)

	* 新增成员：Status

* [InstanceIntegerParam](https://cloud.tencent.com/document/api/239/20022#InstanceIntegerParam)

	* 新增成员：Status

* [InstanceSet](https://cloud.tencent.com/document/api/239/20022#InstanceSet)

	* 新增成员：NoAuth

* [InstanceTextParam](https://cloud.tencent.com/document/api/239/20022#InstanceTextParam)

	* 新增成员：Status


### 第 5 次发布

发布时间：2019-04-25 19:15:25

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CleanUpInstance](https://cloud.tencent.com/document/api/239/34442)
* [DescribeBackupUrl](https://cloud.tencent.com/document/api/239/34443)
* [DescribeInstanceParamRecords](https://cloud.tencent.com/document/api/239/34449)
* [DescribeInstanceParams](https://cloud.tencent.com/document/api/239/34448)
* [DescribeInstanceSecurityGroup](https://cloud.tencent.com/document/api/239/34447)
* [DescribeInstanceShards](https://cloud.tencent.com/document/api/239/34441)
* [DescribeProjectSecurityGroup](https://cloud.tencent.com/document/api/239/34446)
* [DestroyPostpaidInstance](https://cloud.tencent.com/document/api/239/34440)
* [DestroyPrepaidInstance](https://cloud.tencent.com/document/api/239/34439)
* [DisableReplicaReadonly](https://cloud.tencent.com/document/api/239/34438)
* [EnableReplicaReadonly](https://cloud.tencent.com/document/api/239/34437)
* [ModifyInstanceParams](https://cloud.tencent.com/document/api/239/34445)
* [ModifyNetworkConfig](https://cloud.tencent.com/document/api/239/34436)
* [RestoreInstance](https://cloud.tencent.com/document/api/239/34435)

修改接口：

* [CreateInstances](https://cloud.tencent.com/document/api/239/20026)

	* 新增入参：InstanceName

* [DescribeInstanceBackups](https://cloud.tencent.com/document/api/239/20011)

	* <font color="#dd0000">**修改入参**：</font>Status

* [DescribeInstances](https://cloud.tencent.com/document/api/239/20018)

	* 新增入参：Status, TypeVersion, EngineName, AutoRenew, BillingMode, Type, SearchKeys

* [ModifyInstance](https://cloud.tencent.com/document/api/239/31785)

	* 新增入参：ProjectId, AutoRenew


新增数据结构：

* [InstanceClusterNode](https://cloud.tencent.com/document/api/239/20022#InstanceClusterNode)
* [InstanceClusterShard](https://cloud.tencent.com/document/api/239/20022#InstanceClusterShard)
* [InstanceEnumParam](https://cloud.tencent.com/document/api/239/20022#InstanceEnumParam)
* [InstanceIntegerParam](https://cloud.tencent.com/document/api/239/20022#InstanceIntegerParam)
* [InstanceNode](https://cloud.tencent.com/document/api/239/20022#InstanceNode)
* [InstanceParam](https://cloud.tencent.com/document/api/239/20022#InstanceParam)
* [InstanceParamHistory](https://cloud.tencent.com/document/api/239/20022#InstanceParamHistory)
* [InstanceSecurityGroupDetail](https://cloud.tencent.com/document/api/239/20022#InstanceSecurityGroupDetail)
* [InstanceTagInfo](https://cloud.tencent.com/document/api/239/20022#InstanceTagInfo)
* [InstanceTextParam](https://cloud.tencent.com/document/api/239/20022#InstanceTextParam)
* [SecurityGroupDetail](https://cloud.tencent.com/document/api/239/20022#SecurityGroupDetail)
* [SecurityGroupsInboundAndOutbound](https://cloud.tencent.com/document/api/239/20022#SecurityGroupsInboundAndOutbound)

修改数据结构：

* [InstanceSet](https://cloud.tencent.com/document/api/239/20022#InstanceSet)

	* 新增成员：InstanceTitle, OfflineTime, SubStatus, Tags, InstanceNode, RedisShardSize, RedisShardNum, RedisReplicasNum, PriceId, CloseTime, SlaveReadWeight, InstanceTags, ProjectName


### 第 4 次发布

发布时间：2018-12-20 19:18:40

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [ModifyInstance](https://cloud.tencent.com/document/api/239/31785)

### 第 3 次发布

发布时间：2018-11-29 15:50:12

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateInstances](https://cloud.tencent.com/document/api/239/20026)

	* 新增入参：RedisShardNum, RedisReplicasNum, ReplicasReadonly

* [DescribeInstances](https://cloud.tencent.com/document/api/239/20018)

	* 新增入参：UniqVpcIds, UniqSubnetIds

* [UpgradeInstance](https://cloud.tencent.com/document/api/239/20013)

	* 新增入参：RedisShardNum, RedisReplicasNum


### 第 2 次发布

发布时间：2018-11-22 19:23:49

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeInstanceDealDetail](https://cloud.tencent.com/document/api/239/30602)
* [DescribeProductInfo](https://cloud.tencent.com/document/api/239/30600)
* [DescribeTaskInfo](https://cloud.tencent.com/document/api/239/30601)

新增数据结构：

* [ProductConf](https://cloud.tencent.com/document/api/239/20022#ProductConf)
* [RegionConf](https://cloud.tencent.com/document/api/239/20022#RegionConf)
* [TradeDealDetail](https://cloud.tencent.com/document/api/239/20022#TradeDealDetail)
* [ZoneCapacityConf](https://cloud.tencent.com/document/api/239/20022#ZoneCapacityConf)

修改数据结构：

* [InstanceSet](https://cloud.tencent.com/document/api/239/20022#InstanceSet)

	* 新增成员：Engine, ProductType, UniqVpcId, UniqSubnetId, BillingMode


### 第 1 次发布

发布时间：2018-09-21 11:22:59

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [ClearInstance](https://cloud.tencent.com/document/api/239/20021)
* [CreateInstances](https://cloud.tencent.com/document/api/239/20026)
* [DescribeAutoBackupConfig](https://cloud.tencent.com/document/api/239/20019)
* [DescribeInstanceBackups](https://cloud.tencent.com/document/api/239/20011)
* [DescribeInstances](https://cloud.tencent.com/document/api/239/20018)
* [ManualBackupInstance](https://cloud.tencent.com/document/api/239/20010)
* [ModfiyInstancePassword](https://cloud.tencent.com/document/api/239/20025)
* [ModifyAutoBackupConfig](https://cloud.tencent.com/document/api/239/20016)
* [RenewInstance](https://cloud.tencent.com/document/api/239/20015)
* [ResetPassword](https://cloud.tencent.com/document/api/239/20014)
* [UpgradeInstance](https://cloud.tencent.com/document/api/239/20013)

新增数据结构：

* [InstanceSet](https://cloud.tencent.com/document/api/239/20022#InstanceSet)
* [RedisBackupSet](https://cloud.tencent.com/document/api/239/20022#RedisBackupSet)




## 地域管理系统(region) 版本：2022-06-27

### 第 3 次发布

发布时间：2023-03-29 11:14:36

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeRegions](https://cloud.tencent.com/document/api/1596/77930)

	* 新增入参：Scene

* [DescribeZones](https://cloud.tencent.com/document/api/1596/77929)

	* 新增入参：Scene


### 第 2 次发布

发布时间：2022-12-28 01:09:18

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [RegionInfo](https://cloud.tencent.com/document/api/1596/77932#RegionInfo)

	* 新增成员：RegionTypeMC, LocationMC, RegionNameMC, RegionIdMC

* [ZoneInfo](https://cloud.tencent.com/document/api/1596/77932#ZoneInfo)

	* 新增成员：ParentZone, ParentZoneId, ParentZoneName, ZoneType, MachineRoomTypeMC, ZoneIdMC


### 第 1 次发布

发布时间：2022-07-27 21:10:02

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeProducts](https://cloud.tencent.com/document/api/1596/77931)
* [DescribeRegions](https://cloud.tencent.com/document/api/1596/77930)
* [DescribeZones](https://cloud.tencent.com/document/api/1596/77929)

新增数据结构：

* [RegionInfo](https://cloud.tencent.com/document/api/1596/77932#RegionInfo)
* [RegionProduct](https://cloud.tencent.com/document/api/1596/77932#RegionProduct)
* [ZoneInfo](https://cloud.tencent.com/document/api/1596/77932#ZoneInfo)




## 风险探针(rkp) 版本：2019-12-09

### 第 2 次发布

发布时间：2023-12-25 00:16:39

本次发布包含了以下内容：

改善已有的文档。

<font color="#dd0000">**预下线接口**：</font>

* GetOpenId
* GetToken
* QueryDevAndRisk

### 第 1 次发布

发布时间：2020-08-06 17:36:26

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [GetOpenId](https://cloud.tencent.com/document/api/1169/47211)
* [GetToken](https://cloud.tencent.com/document/api/1169/47213)
* [QueryDevAndRisk](https://cloud.tencent.com/document/api/1169/47215)

新增数据结构：

* [DevInfoQ](https://cloud.tencent.com/document/api/1169/47216#DevInfoQ)
* [RiskDetail](https://cloud.tencent.com/document/api/1169/47216#RiskDetail)
* [RiskInfo](https://cloud.tencent.com/document/api/1169/47216#RiskInfo)




## 注册保护(rp) 版本：2020-02-24

### 第 1 次发布

发布时间：2020-04-28 15:06:12

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [QueryRegisterProtection](https://cloud.tencent.com/document/api/1191/43977)




## 前端性能监控(rum) 版本：2021-06-22

### 第 35 次发布

发布时间：2024-07-12 01:22:59

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeReleaseFiles](https://cloud.tencent.com/document/api/1464/69215)

	* 新增入参：FileName


### 第 34 次发布

发布时间：2024-07-10 01:22:53

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeReleaseFileSign](https://cloud.tencent.com/document/api/1464/69216)

	* 新增入参：Site


### 第 33 次发布

发布时间：2024-01-31 01:20:58

本次发布包含了以下内容：

改善已有的文档。

<font color="#dd0000">**删除接口**：</font>

* DescribeDataPerformanceProject

### 第 32 次发布

发布时间：2024-01-23 01:26:09

本次发布包含了以下内容：

改善已有的文档。

<font color="#dd0000">**删除接口**：</font>

* CreateLogExport
* DeleteLogExport
* DescribeLogExports
* DescribeLogList

<font color="#dd0000">**删除数据结构**：</font>

* LogExport

### 第 31 次发布

发布时间：2024-01-12 01:21:17

本次发布包含了以下内容：

改善已有的文档。

<font color="#dd0000">**删除接口**：</font>

* DeleteOfflineLogConfig
* DeleteOfflineLogRecord
* DescribeOfflineLogConfigs

### 第 30 次发布

发布时间：2024-01-10 01:21:10

本次发布包含了以下内容：

改善已有的文档。

<font color="#dd0000">**删除接口**：</font>

* CreateOfflineLogConfig
* DescribeOfflineLogRecords
* DescribeOfflineLogs

### 第 29 次发布

发布时间：2023-10-13 01:22:31

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeDataPvUrlStatistics](https://cloud.tencent.com/document/api/1464/65768)

	* 新增入参：IsNewData


### 第 28 次发布

发布时间：2023-08-09 01:43:06

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeDataPvUrlStatistics](https://cloud.tencent.com/document/api/1464/65768)

	* 新增入参：GroupByType


### 第 27 次发布

发布时间：2023-05-12 01:43:18

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [RumProject](https://cloud.tencent.com/document/api/1464/61476#RumProject)

	* 新增成员：AccessPoint


### 第 26 次发布

发布时间：2023-04-26 01:43:23

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateTawInstance](https://cloud.tencent.com/document/api/1464/69244)

	* 新增入参：InstanceType


修改数据结构：

* [RumInstanceInfo](https://cloud.tencent.com/document/api/1464/61476#RumInstanceInfo)

	* 新增成员：InstanceType


### 第 25 次发布

发布时间：2023-04-18 01:36:49

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeAppDimensionMetrics](https://cloud.tencent.com/document/api/1464/90244)
* [DescribeAppMetricsData](https://cloud.tencent.com/document/api/1464/90243)
* [DescribeAppSingleCaseDetailList](https://cloud.tencent.com/document/api/1464/90242)
* [DescribeAppSingleCaseList](https://cloud.tencent.com/document/api/1464/90241)

### 第 24 次发布

发布时间：2023-04-10 01:49:56

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeReleaseFileSign](https://cloud.tencent.com/document/api/1464/69216)

	* 新增入参：FileType


### 第 23 次发布

发布时间：2023-02-10 01:54:01

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeRumLogExport](https://cloud.tencent.com/document/api/1464/86366)
* [DescribeRumLogExports](https://cloud.tencent.com/document/api/1464/86365)
* [ResumeProject](https://cloud.tencent.com/document/api/1464/86367)

### 第 22 次发布

发布时间：2023-01-12 01:32:36

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [ScoreInfo](https://cloud.tencent.com/document/api/1464/61476#ScoreInfo)

	* 新增成员：CreateTime


### 第 21 次发布

发布时间：2023-01-05 01:37:14

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeRumGroupLog](https://cloud.tencent.com/document/api/1464/85145)

### 第 20 次发布

发布时间：2022-12-23 01:49:31

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeRumLogList](https://cloud.tencent.com/document/api/1464/84474)
* [DescribeRumStatsLogList](https://cloud.tencent.com/document/api/1464/84473)

### 第 19 次发布

发布时间：2022-12-22 01:56:30

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [StopProject](https://cloud.tencent.com/document/api/1464/84458)

### 第 18 次发布

发布时间：2022-12-09 01:53:36

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateTawInstance](https://cloud.tencent.com/document/api/1464/69244)

	* 新增入参：ResourcePackageType, ResourcePackageNum

	* 新增出参：DealName


### 第 17 次发布

发布时间：2022-11-22 06:49:05

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateWhitelist](https://cloud.tencent.com/document/api/1464/69243)

	* 新增出参：ID


### 第 16 次发布

发布时间：2022-10-10 06:36:43

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeDataFetchUrl](https://cloud.tencent.com/document/api/1464/68355)

	* 新增入参：NetStatus

* [DescribeDataPerformancePage](https://cloud.tencent.com/document/api/1464/59944)

	* 新增入参：NetStatus


### 第 15 次发布

发布时间：2022-09-09 06:38:13

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [RumAreaInfo](https://cloud.tencent.com/document/api/1464/61476#RumAreaInfo)

	* 新增成员：AreaRegionID, AreaRegionCode, AreaAbbr


### 第 14 次发布

发布时间：2022-07-13 06:15:23

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeDataFetchProject](https://cloud.tencent.com/document/api/1464/69232)

	* 新增入参：Status, Ret

* [DescribeDataFetchUrl](https://cloud.tencent.com/document/api/1464/68355)

	* 新增入参：Status, Ret

* [DescribeDataSetUrlStatistics](https://cloud.tencent.com/document/api/1464/69227)

	* 新增入参：PackageType


### 第 13 次发布

发布时间：2022-03-21 08:15:09

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeProjects](https://cloud.tencent.com/document/api/1464/61475)

	* 新增入参：IsDemo

* [DescribeScores](https://cloud.tencent.com/document/api/1464/61951)

	* 新增入参：IsDemo

* [DescribeTawInstances](https://cloud.tencent.com/document/api/1464/69213)

	* 新增入参：IsDemo


修改数据结构：

* [ProjectLimit](https://cloud.tencent.com/document/api/1464/61476#ProjectLimit)

	* <font color="#dd0000">**修改成员**：</font>ID, ProjectID

* [RumProject](https://cloud.tencent.com/document/api/1464/61476#RumProject)

	* 新增成员：ProjectStatus


### 第 12 次发布

发布时间：2022-03-15 08:13:58

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateTawInstance](https://cloud.tencent.com/document/api/1464/69244)

	* 新增入参：BuyingChannel


### 第 11 次发布

发布时间：2022-02-14 08:15:11

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateLogExport](https://cloud.tencent.com/document/api/1464/69248)
* [CreateOfflineLogConfig](https://cloud.tencent.com/document/api/1464/69247)
* [CreateReleaseFile](https://cloud.tencent.com/document/api/1464/69246)
* [CreateStarProject](https://cloud.tencent.com/document/api/1464/69245)
* [CreateTawInstance](https://cloud.tencent.com/document/api/1464/69244)
* [CreateWhitelist](https://cloud.tencent.com/document/api/1464/69243)
* [DeleteInstance](https://cloud.tencent.com/document/api/1464/69242)
* [DeleteLogExport](https://cloud.tencent.com/document/api/1464/69241)
* [DeleteOfflineLogConfig](https://cloud.tencent.com/document/api/1464/69240)
* [DeleteOfflineLogRecord](https://cloud.tencent.com/document/api/1464/69239)
* [DeleteProject](https://cloud.tencent.com/document/api/1464/69238)
* [DeleteReleaseFile](https://cloud.tencent.com/document/api/1464/69237)
* [DeleteStarProject](https://cloud.tencent.com/document/api/1464/69236)
* [DeleteWhitelist](https://cloud.tencent.com/document/api/1464/69235)
* [DescribeData](https://cloud.tencent.com/document/api/1464/69234)
* [DescribeDataCustomUrl](https://cloud.tencent.com/document/api/1464/69233)
* [DescribeDataFetchProject](https://cloud.tencent.com/document/api/1464/69232)
* [DescribeDataLogUrlInfo](https://cloud.tencent.com/document/api/1464/69231)
* [DescribeDataPerformanceProject](https://cloud.tencent.com/document/api/1464/69230)
* [DescribeDataPvUrlInfo](https://cloud.tencent.com/document/api/1464/69229)
* [DescribeDataReportCount](https://cloud.tencent.com/document/api/1464/69228)
* [DescribeDataSetUrlStatistics](https://cloud.tencent.com/document/api/1464/69227)
* [DescribeDataStaticProject](https://cloud.tencent.com/document/api/1464/69226)
* [DescribeDataStaticResource](https://cloud.tencent.com/document/api/1464/69225)
* [DescribeDataStaticUrl](https://cloud.tencent.com/document/api/1464/69224)
* [DescribeDataWebVitalsPage](https://cloud.tencent.com/document/api/1464/69223)
* [DescribeLogExports](https://cloud.tencent.com/document/api/1464/69222)
* [DescribeOfflineLogConfigs](https://cloud.tencent.com/document/api/1464/69221)
* [DescribeOfflineLogRecords](https://cloud.tencent.com/document/api/1464/69220)
* [DescribeOfflineLogs](https://cloud.tencent.com/document/api/1464/69219)
* [DescribeProjectLimits](https://cloud.tencent.com/document/api/1464/69218)
* [DescribePvList](https://cloud.tencent.com/document/api/1464/69217)
* [DescribeReleaseFileSign](https://cloud.tencent.com/document/api/1464/69216)
* [DescribeReleaseFiles](https://cloud.tencent.com/document/api/1464/69215)
* [DescribeTawAreas](https://cloud.tencent.com/document/api/1464/69214)
* [DescribeTawInstances](https://cloud.tencent.com/document/api/1464/69213)
* [DescribeUvList](https://cloud.tencent.com/document/api/1464/69212)
* [DescribeWhitelists](https://cloud.tencent.com/document/api/1464/69211)
* [ModifyInstance](https://cloud.tencent.com/document/api/1464/69210)
* [ModifyProject](https://cloud.tencent.com/document/api/1464/69209)
* [ModifyProjectLimit](https://cloud.tencent.com/document/api/1464/69208)
* [ResumeInstance](https://cloud.tencent.com/document/api/1464/69207)
* [StopInstance](https://cloud.tencent.com/document/api/1464/69206)

新增数据结构：

* [LogExport](https://cloud.tencent.com/document/api/1464/61476#LogExport)
* [ProjectLimit](https://cloud.tencent.com/document/api/1464/61476#ProjectLimit)
* [ReleaseFile](https://cloud.tencent.com/document/api/1464/61476#ReleaseFile)
* [RumAreaInfo](https://cloud.tencent.com/document/api/1464/61476#RumAreaInfo)
* [RumInstanceInfo](https://cloud.tencent.com/document/api/1464/61476#RumInstanceInfo)
* [RumPvInfo](https://cloud.tencent.com/document/api/1464/61476#RumPvInfo)
* [RumUvInfo](https://cloud.tencent.com/document/api/1464/61476#RumUvInfo)
* [Tag](https://cloud.tencent.com/document/api/1464/61476#Tag)
* [Whitelist](https://cloud.tencent.com/document/api/1464/61476#Whitelist)

### 第 10 次发布

发布时间：2022-01-18 08:14:02

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeDataFetchUrl](https://cloud.tencent.com/document/api/1464/68355)
* [DescribeDataFetchUrlInfo](https://cloud.tencent.com/document/api/1464/68354)

### 第 9 次发布

发布时间：2021-12-14 08:13:36

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeDataEventUrl](https://cloud.tencent.com/document/api/1464/65769)

	* 新增入参：Env

* [DescribeDataLogUrlStatistics](https://cloud.tencent.com/document/api/1464/60495)

	* 新增入参：Env

* [DescribeDataPerformancePage](https://cloud.tencent.com/document/api/1464/59944)

	* 新增入参：Env

* [DescribeDataPvUrlStatistics](https://cloud.tencent.com/document/api/1464/65768)

	* 新增入参：Env


### 第 8 次发布

发布时间：2021-12-09 08:09:35

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeDataEventUrl](https://cloud.tencent.com/document/api/1464/65769)
* [DescribeDataPvUrlStatistics](https://cloud.tencent.com/document/api/1464/65768)

### 第 7 次发布

发布时间：2021-09-27 08:15:19

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeScores](https://cloud.tencent.com/document/api/1464/61951)

新增数据结构：

* [ScoreInfo](https://cloud.tencent.com/document/api/1464/61476#ScoreInfo)

### 第 6 次发布

发布时间：2021-09-14 08:00:07

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeProjects](https://cloud.tencent.com/document/api/1464/61475)

新增数据结构：

* [Filter](https://cloud.tencent.com/document/api/1464/61476#Filter)
* [RumProject](https://cloud.tencent.com/document/api/1464/61476#RumProject)

### 第 5 次发布

发布时间：2021-09-13 08:00:06

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeLogList](https://cloud.tencent.com/document/api/1464/61416)

### 第 4 次发布

发布时间：2021-08-20 08:00:08

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeDataLogUrlStatistics](https://cloud.tencent.com/document/api/1464/60495)

### 第 3 次发布

发布时间：2021-08-19 08:00:11

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeError](https://cloud.tencent.com/document/api/1464/60439)

### 第 2 次发布

发布时间：2021-08-09 08:00:05

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeDataPerformancePage](https://cloud.tencent.com/document/api/1464/59944)

### 第 1 次发布

发布时间：2021-08-04 08:00:04

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateProject](https://cloud.tencent.com/document/api/1464/59459)




## 云函数(scf) 版本：2018-04-16

### 第 64 次发布

发布时间：2023-12-29 01:22:39

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [GetFunction](https://cloud.tencent.com/document/api/583/18584)

	* <font color="#dd0000">**修改入参**：</font>FunctionName

* [UpdateFunctionConfiguration](https://cloud.tencent.com/document/api/583/18580)

	* 新增入参：IgnoreSysLog


### 第 63 次发布

发布时间：2023-11-30 05:41:26

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [UpdateFunctionConfiguration](https://cloud.tencent.com/document/api/583/18580)

	* 新增入参：DnsCache, IntranetConfig


### 第 62 次发布

发布时间：2023-11-29 02:01:37

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateFunction](https://cloud.tencent.com/document/api/583/18586)

	* 新增入参：DnsCache, IntranetConfig


新增数据结构：

* [IntranetConfigIn](https://cloud.tencent.com/document/api/583/17244#IntranetConfigIn)

### 第 61 次发布

发布时间：2023-11-24 01:21:32

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [GetFunction](https://cloud.tencent.com/document/api/583/18584)

	* 新增出参：ImageConfig, DnsCache, IntranetConfig


新增数据结构：

* [IntranetConfigOut](https://cloud.tencent.com/document/api/583/17244#IntranetConfigOut)

### 第 60 次发布

发布时间：2023-08-22 01:18:21

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [UpdateTrigger](https://cloud.tencent.com/document/api/583/96828)

### 第 59 次发布

发布时间：2023-08-04 01:16:09

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [NamespaceResourceEnvTKE](https://cloud.tencent.com/document/api/583/17244#NamespaceResourceEnvTKE)

	* 新增成员：PodTemplatePatch


### 第 58 次发布

发布时间：2023-08-02 01:20:41

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [K8SToleration](https://cloud.tencent.com/document/api/583/17244#K8SToleration)

	* <font color="#dd0000">**修改成员**：</font>Key


### 第 57 次发布

发布时间：2023-07-20 01:39:23

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateNamespace](https://cloud.tencent.com/document/api/583/37160)

	* 新增入参：ResourceEnv


新增数据结构：

* [K8SLabel](https://cloud.tencent.com/document/api/583/17244#K8SLabel)
* [K8SToleration](https://cloud.tencent.com/document/api/583/17244#K8SToleration)
* [NamespaceResourceEnv](https://cloud.tencent.com/document/api/583/17244#NamespaceResourceEnv)
* [NamespaceResourceEnvTKE](https://cloud.tencent.com/document/api/583/17244#NamespaceResourceEnvTKE)

### 第 56 次发布

发布时间：2023-06-30 01:40:45

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateFunction](https://cloud.tencent.com/document/api/583/18586)

	* 新增入参：AutoDeployClsTopicIndex, AutoCreateClsTopic


### 第 55 次发布

发布时间：2023-06-08 01:51:22

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [FunctionLog](https://cloud.tencent.com/document/api/583/17244#FunctionLog)

	* <font color="#dd0000">**修改成员**：</font>StartTime


### 第 54 次发布

发布时间：2023-05-31 01:38:53

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [Trigger](https://cloud.tencent.com/document/api/583/17244#Trigger)

	* <font color="#dd0000">**修改成员**：</font>ResourceId, BindStatus, TriggerAttribute

* [TriggerInfo](https://cloud.tencent.com/document/api/583/17244#TriggerInfo)

	* <font color="#dd0000">**修改成员**：</font>ResourceId, BindStatus, TriggerAttribute


### 第 53 次发布

发布时间：2023-05-15 01:55:08

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateTrigger](https://cloud.tencent.com/document/api/583/18589)

	* 新增入参：Description


修改数据结构：

* [Trigger](https://cloud.tencent.com/document/api/583/17244#Trigger)

	* 新增成员：Description


### 第 52 次发布

发布时间：2023-04-24 01:35:50

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [TriggerInfo](https://cloud.tencent.com/document/api/583/17244#TriggerInfo)

	* 新增成员：Description


### 第 51 次发布

发布时间：2023-04-20 01:34:05

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [LayerVersionInfo](https://cloud.tencent.com/document/api/583/17244#LayerVersionInfo)

	* 新增成员：Stamp


### 第 50 次发布

发布时间：2023-04-04 01:39:21

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [UpdateTriggerStatus](https://cloud.tencent.com/document/api/583/89800)

### 第 49 次发布

发布时间：2023-03-24 02:04:32

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [ImageConfig](https://cloud.tencent.com/document/api/583/17244#ImageConfig)

	* 新增成员：ImagePort


### 第 48 次发布

发布时间：2023-02-21 01:58:57

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [TriggerCount](https://cloud.tencent.com/document/api/583/17244#TriggerCount)

	* 新增成员：Eb


### 第 47 次发布

发布时间：2022-11-17 06:40:32

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateFunction](https://cloud.tencent.com/document/api/583/18586)

	* 新增入参：InstanceConcurrencyConfig

* [UpdateFunctionConfiguration](https://cloud.tencent.com/document/api/583/18580)

	* 新增入参：InstanceConcurrencyConfig


新增数据结构：

* [InstanceConcurrencyConfig](https://cloud.tencent.com/document/api/583/17244#InstanceConcurrencyConfig)

修改数据结构：

* [ImageConfig](https://cloud.tencent.com/document/api/583/17244#ImageConfig)

	* 新增成员：ContainerImageAccelerate


### 第 46 次发布

发布时间：2022-05-09 06:12:32

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [NamespaceUsage](https://cloud.tencent.com/document/api/583/17244#NamespaceUsage)

	* 新增成员：TotalAllocatedProvisionedMem


### 第 45 次发布

发布时间：2022-03-21 08:15:19

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [PutProvisionedConcurrencyConfig](https://cloud.tencent.com/document/api/583/51246)

	* 新增入参：ProvisionedType, TrackingTarget, MinCapacity, MaxCapacity


### 第 44 次发布

发布时间：2022-03-16 08:13:22

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [NamespaceUsage](https://cloud.tencent.com/document/api/583/17244#NamespaceUsage)

	* 新增成员：TotalConcurrencyMem, TotalAllocatedConcurrencyMem


### 第 43 次发布

发布时间：2022-01-12 08:13:52

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [TriggerAction](https://cloud.tencent.com/document/api/583/17244#TriggerAction)

	* 新增成员：ProvisionedType


### 第 42 次发布

发布时间：2021-12-09 08:09:39

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [FunctionVersion](https://cloud.tencent.com/document/api/583/17244#FunctionVersion)

	* 新增成员：Status


### 第 41 次发布

发布时间：2021-12-08 08:14:03

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [GetAsyncEventStatus](https://cloud.tencent.com/document/api/583/65704)

新增数据结构：

* [AsyncEventStatus](https://cloud.tencent.com/document/api/583/17244#AsyncEventStatus)

### 第 40 次发布

发布时间：2021-12-03 08:10:14

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [UpdateFunctionCode](https://cloud.tencent.com/document/api/583/18581)

	* 新增入参：InstallDependency


### 第 39 次发布

发布时间：2021-12-02 08:10:45

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [GetRequestStatus](https://cloud.tencent.com/document/api/583/65348)

新增数据结构：

* [RequestStatus](https://cloud.tencent.com/document/api/583/17244#RequestStatus)

### 第 38 次发布

发布时间：2021-11-17 08:14:54

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateFunction](https://cloud.tencent.com/document/api/583/18586)

	* 新增入参：InstallDependency

* [UpdateFunctionConfiguration](https://cloud.tencent.com/document/api/583/18580)

	* 新增入参：InstallDependency


### 第 37 次发布

发布时间：2021-11-08 08:09:22

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateFunction](https://cloud.tencent.com/document/api/583/18586)

	* 新增入参：ProtocolType, ProtocolParams

* [GetFunction](https://cloud.tencent.com/document/api/583/18584)

	* 新增出参：ProtocolType, ProtocolParams

* [UpdateFunctionConfiguration](https://cloud.tencent.com/document/api/583/18580)

	* 新增入参：ProtocolParams


新增数据结构：

* [ProtocolParams](https://cloud.tencent.com/document/api/583/17244#ProtocolParams)
* [WSParams](https://cloud.tencent.com/document/api/583/17244#WSParams)

### 第 36 次发布

发布时间：2021-11-02 08:10:12

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [TerminateAsyncEvent](https://cloud.tencent.com/document/api/583/52500)

	* 新增入参：GraceShutdown


### 第 35 次发布

发布时间：2021-10-25 08:09:06

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [PutProvisionedConcurrencyConfig](https://cloud.tencent.com/document/api/583/51246)

	* 新增入参：TriggerActions


新增数据结构：

* [TriggerAction](https://cloud.tencent.com/document/api/583/17244#TriggerAction)

修改数据结构：

* [VersionProvisionedConcurrencyInfo](https://cloud.tencent.com/document/api/583/17244#VersionProvisionedConcurrencyInfo)

	* 新增成员：TriggerActions


### 第 34 次发布

发布时间：2021-09-17 08:11:57

本次发布包含了以下内容：

改善已有的文档。

新增数据结构：

* [ImageConfig](https://cloud.tencent.com/document/api/583/17244#ImageConfig)

修改数据结构：

* [Code](https://cloud.tencent.com/document/api/583/17244#Code)

	* 新增成员：ImageConfig


### 第 33 次发布

发布时间：2021-09-07 08:07:50

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [Function](https://cloud.tencent.com/document/api/583/17244#Function)

	* 新增成员：AsyncRunEnable, TraceEnable


### 第 32 次发布

发布时间：2021-08-20 08:07:56

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [ListNamespaces](https://cloud.tencent.com/document/api/583/37158)

	* 新增入参：SearchKey


新增数据结构：

* [SearchKey](https://cloud.tencent.com/document/api/583/17244#SearchKey)

### 第 31 次发布

发布时间：2021-08-03 08:08:15

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [GetFunction](https://cloud.tencent.com/document/api/583/18584)

	* 新增出参：AsyncRunEnable, TraceEnable


### 第 30 次发布

发布时间：2021-07-09 08:07:55

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [InvokeFunction](https://cloud.tencent.com/document/api/583/58400)

### 第 29 次发布

发布时间：2021-05-31 08:07:35

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [UpdateFunctionCode](https://cloud.tencent.com/document/api/583/18581)

	* <font color="#dd0000">**修改入参**：</font>Handler


### 第 28 次发布

发布时间：2021-04-26 08:07:03

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateFunction](https://cloud.tencent.com/document/api/583/18586)

	* 新增入参：AsyncRunEnable, TraceEnable


### 第 27 次发布

发布时间：2021-03-16 08:07:54

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [GetFunctionEventInvokeConfig](https://cloud.tencent.com/document/api/583/53640)
* [UpdateFunctionEventInvokeConfig](https://cloud.tencent.com/document/api/583/53639)

新增数据结构：

* [AsyncTriggerConfig](https://cloud.tencent.com/document/api/583/17244#AsyncTriggerConfig)
* [RetryConfig](https://cloud.tencent.com/document/api/583/17244#RetryConfig)

### 第 26 次发布

发布时间：2021-03-09 08:07:21

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [GetAccount](https://cloud.tencent.com/document/api/583/53437)

新增数据结构：

* [LimitsInfo](https://cloud.tencent.com/document/api/583/17244#LimitsInfo)
* [NamespaceLimit](https://cloud.tencent.com/document/api/583/17244#NamespaceLimit)
* [NamespaceUsage](https://cloud.tencent.com/document/api/583/17244#NamespaceUsage)
* [TriggerCount](https://cloud.tencent.com/document/api/583/17244#TriggerCount)
* [UsageInfo](https://cloud.tencent.com/document/api/583/17244#UsageInfo)

### 第 25 次发布

发布时间：2021-01-26 08:07:28

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [ListAsyncEvents](https://cloud.tencent.com/document/api/583/52501)
* [TerminateAsyncEvent](https://cloud.tencent.com/document/api/583/52500)

新增数据结构：

* [AsyncEvent](https://cloud.tencent.com/document/api/583/17244#AsyncEvent)
* [TimeInterval](https://cloud.tencent.com/document/api/583/17244#TimeInterval)

### 第 24 次发布

发布时间：2020-12-31 08:06:16

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [Trigger](https://cloud.tencent.com/document/api/583/17244#Trigger)

	* 新增成员：Qualifier


### 第 23 次发布

发布时间：2020-12-21 08:06:44

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DeleteProvisionedConcurrencyConfig](https://cloud.tencent.com/document/api/583/51250)
* [DeleteReservedConcurrencyConfig](https://cloud.tencent.com/document/api/583/51249)
* [GetProvisionedConcurrencyConfig](https://cloud.tencent.com/document/api/583/51248)
* [GetReservedConcurrencyConfig](https://cloud.tencent.com/document/api/583/51247)
* [PutProvisionedConcurrencyConfig](https://cloud.tencent.com/document/api/583/51246)
* [PutReservedConcurrencyConfig](https://cloud.tencent.com/document/api/583/51245)
* [PutTotalConcurrencyConfig](https://cloud.tencent.com/document/api/583/51244)

新增数据结构：

* [VersionProvisionedConcurrencyInfo](https://cloud.tencent.com/document/api/583/17244#VersionProvisionedConcurrencyInfo)

### 第 22 次发布

发布时间：2020-11-20 08:05:55

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [Function](https://cloud.tencent.com/document/api/583/17244#Function)

	* 新增成员：StatusReasons, TotalProvisionedConcurrencyMem, ReservedConcurrencyMem

* [Trigger](https://cloud.tencent.com/document/api/583/17244#Trigger)

	* 新增成员：ResourceId, BindStatus, TriggerAttribute

* [TriggerInfo](https://cloud.tencent.com/document/api/583/17244#TriggerInfo)

	* 新增成员：ResourceId, BindStatus, TriggerAttribute


### 第 21 次发布

发布时间：2020-10-13 08:05:52

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateTrigger](https://cloud.tencent.com/document/api/583/18589)

	* 新增入参：CustomArgument


### 第 20 次发布

发布时间：2020-09-24 08:05:31

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateFunction](https://cloud.tencent.com/document/api/583/18586)

	* 新增入参：Tags


### 第 19 次发布

发布时间：2020-09-16 08:05:21

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [GetFunction](https://cloud.tencent.com/document/api/583/18584)

	* 新增出参：StatusReasons


新增数据结构：

* [StatusReason](https://cloud.tencent.com/document/api/583/17244#StatusReason)

### 第 18 次发布

发布时间：2020-08-20 08:18:57

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DeleteFunction](https://cloud.tencent.com/document/api/583/18585)

	* 新增入参：Qualifier


### 第 17 次发布

发布时间：2020-08-10 08:17:16

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateFunction](https://cloud.tencent.com/document/api/583/18586)

	* 新增入参：InitTimeout

* [GetFunction](https://cloud.tencent.com/document/api/583/18584)

	* 新增出参：InitTimeout

* [UpdateFunctionConfiguration](https://cloud.tencent.com/document/api/583/18580)

	* 新增入参：InitTimeout


### 第 16 次发布

发布时间：2020-07-16 08:16:53

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateFunction](https://cloud.tencent.com/document/api/583/18586)

	* 新增入参：CfsConfig

* [GetFunction](https://cloud.tencent.com/document/api/583/18584)

	* 新增出参：CfsConfig, AvailableStatus, Qualifier

* [UpdateFunctionConfiguration](https://cloud.tencent.com/document/api/583/18580)

	* 新增入参：CfsConfig


新增数据结构：

* [CfsConfig](https://cloud.tencent.com/document/api/583/17244#CfsConfig)
* [CfsInsInfo](https://cloud.tencent.com/document/api/583/17244#CfsInsInfo)

### 第 15 次发布

发布时间：2020-06-10 08:15:37

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [FunctionLog](https://cloud.tencent.com/document/api/583/17244#FunctionLog)

	* 新增成员：RetryNum


### 第 14 次发布

发布时间：2020-05-11 10:13:56

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateFunction](https://cloud.tencent.com/document/api/583/18586)

	* 新增入参：PublicNetConfig

* [UpdateFunctionConfiguration](https://cloud.tencent.com/document/api/583/18580)

	* 新增入参：PublicNetConfig


新增数据结构：

* [EipConfigIn](https://cloud.tencent.com/document/api/583/17244#EipConfigIn)
* [PublicNetConfigIn](https://cloud.tencent.com/document/api/583/17244#PublicNetConfigIn)

### 第 13 次发布

发布时间：2020-05-08 08:15:22

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [ListTriggers](https://cloud.tencent.com/document/api/583/44268)

新增数据结构：

* [TriggerInfo](https://cloud.tencent.com/document/api/583/17244#TriggerInfo)

### 第 12 次发布

发布时间：2020-04-30 08:14:42

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateAlias](https://cloud.tencent.com/document/api/583/44164)
* [GetAlias](https://cloud.tencent.com/document/api/583/44163)
* [ListAliases](https://cloud.tencent.com/document/api/583/44162)
* [UpdateAlias](https://cloud.tencent.com/document/api/583/44161)

修改接口：

* [UpdateFunctionConfiguration](https://cloud.tencent.com/document/api/583/18580)

	* 新增入参：L5Enable


新增数据结构：

* [Alias](https://cloud.tencent.com/document/api/583/17244#Alias)
* [RoutingConfig](https://cloud.tencent.com/document/api/583/17244#RoutingConfig)
* [VersionMatch](https://cloud.tencent.com/document/api/583/17244#VersionMatch)
* [VersionWeight](https://cloud.tencent.com/document/api/583/17244#VersionWeight)

### 第 11 次发布

发布时间：2020-04-29 08:15:20

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DeleteAlias](https://cloud.tencent.com/document/api/583/44048)

修改接口：

* [UpdateFunctionConfiguration](https://cloud.tencent.com/document/api/583/18580)

	* <font color="#dd0000">**删除入参**：</font>L5Enable, OnsEnable


### 第 10 次发布

发布时间：2020-04-24 08:14:03

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [Trigger](https://cloud.tencent.com/document/api/583/17244#Trigger)

	* 新增成员：AvailableStatus


### 第 9 次发布

发布时间：2020-04-16 08:14:01

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [Invoke](https://cloud.tencent.com/document/api/583/17243)

	* 新增入参：RoutingKey


### 第 8 次发布

发布时间：2020-04-14 08:13:51

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [ListVersionByFunction](https://cloud.tencent.com/document/api/583/37162)

	* 新增入参：Offset, Limit, Order, OrderBy

	* 新增出参：TotalCount


### 第 7 次发布

发布时间：2020-04-02 08:14:22

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [FunctionVersion](https://cloud.tencent.com/document/api/583/17244#FunctionVersion)

	* 新增成员：AddTime, ModTime


### 第 6 次发布

发布时间：2020-02-19 16:00:09

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DeleteLayerVersion](https://cloud.tencent.com/document/api/583/41387)
* [GetLayerVersion](https://cloud.tencent.com/document/api/583/41386)
* [ListLayerVersions](https://cloud.tencent.com/document/api/583/41385)
* [ListLayers](https://cloud.tencent.com/document/api/583/41384)
* [PublishLayerVersion](https://cloud.tencent.com/document/api/583/41383)

修改接口：

* [CreateFunction](https://cloud.tencent.com/document/api/583/18586)

	* 新增入参：Layers, DeadLetterConfig

* [GetFunction](https://cloud.tencent.com/document/api/583/18584)

	* 新增出参：Layers, DeadLetterConfig, AddTime, PublicNetConfig, OnsEnable

* [GetFunctionLogs](https://cloud.tencent.com/document/api/583/18583)

	* <font color="#dd0000">**修改入参**：</font>FunctionName

* [UpdateFunctionConfiguration](https://cloud.tencent.com/document/api/583/18580)

	* 新增入参：Layers, DeadLetterConfig, OnsEnable


新增数据结构：

* [DeadLetterConfig](https://cloud.tencent.com/document/api/583/17244#DeadLetterConfig)
* [EipConfigOut](https://cloud.tencent.com/document/api/583/17244#EipConfigOut)
* [LayerVersionInfo](https://cloud.tencent.com/document/api/583/17244#LayerVersionInfo)
* [LayerVersionSimple](https://cloud.tencent.com/document/api/583/17244#LayerVersionSimple)
* [PublicNetConfigOut](https://cloud.tencent.com/document/api/583/17244#PublicNetConfigOut)

### 第 5 次发布

发布时间：2019-09-26 20:40:24

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [GetFunction](https://cloud.tencent.com/document/api/583/18584)

	* 新增出参：L5Enable

* [GetFunctionLogs](https://cloud.tencent.com/document/api/583/18583)

	* <font color="#dd0000">**修改入参**：</font>FunctionName

* [UpdateFunctionCode](https://cloud.tencent.com/document/api/583/18581)

	* 新增入参：Code, CodeSource

* [UpdateFunctionConfiguration](https://cloud.tencent.com/document/api/583/18580)

	* 新增入参：L5Enable


### 第 4 次发布

发布时间：2019-08-15 20:51:37

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateNamespace](https://cloud.tencent.com/document/api/583/37160)
* [DeleteNamespace](https://cloud.tencent.com/document/api/583/37159)
* [GetFunctionAddress](https://cloud.tencent.com/document/api/583/37164)
* [ListNamespaces](https://cloud.tencent.com/document/api/583/37158)
* [ListVersionByFunction](https://cloud.tencent.com/document/api/583/37162)
* [PublishVersion](https://cloud.tencent.com/document/api/583/37161)
* [UpdateNamespace](https://cloud.tencent.com/document/api/583/37157)

修改接口：

* [CopyFunction](https://cloud.tencent.com/document/api/583/33847)

	* 新增入参：Override, CopyConfiguration

* [CreateFunction](https://cloud.tencent.com/document/api/583/18586)

	* 新增入参：Namespace, Role, Type, CodeSource

* [CreateTrigger](https://cloud.tencent.com/document/api/583/18589)

	* 新增入参：Namespace

* [DeleteFunction](https://cloud.tencent.com/document/api/583/18585)

	* 新增入参：Namespace

* [DeleteTrigger](https://cloud.tencent.com/document/api/583/18588)

	* 新增入参：Namespace

* [GetFunction](https://cloud.tencent.com/document/api/583/18584)

	* 新增入参：Namespace

	* 新增出参：EipConfig, AccessInfo, Type

* [GetFunctionLogs](https://cloud.tencent.com/document/api/583/18583)

	* 新增入参：Namespace, SearchContext

	* 新增出参：SearchContext

* [ListFunctions](https://cloud.tencent.com/document/api/583/18582)

	* 新增入参：Namespace

* [UpdateFunctionCode](https://cloud.tencent.com/document/api/583/18581)

	* 新增入参：Namespace, EnvId, Publish

* [UpdateFunctionConfiguration](https://cloud.tencent.com/document/api/583/18580)

	* 新增入参：Namespace, Role, ClsLogsetId, ClsTopicId, Publish


新增数据结构：

* [AccessInfo](https://cloud.tencent.com/document/api/583/17244#AccessInfo)
* [EipOutConfig](https://cloud.tencent.com/document/api/583/17244#EipOutConfig)
* [FunctionVersion](https://cloud.tencent.com/document/api/583/17244#FunctionVersion)
* [LogSearchContext](https://cloud.tencent.com/document/api/583/17244#LogSearchContext)
* [Namespace](https://cloud.tencent.com/document/api/583/17244#Namespace)

修改数据结构：

* [Code](https://cloud.tencent.com/document/api/583/17244#Code)

	* 新增成员：GitUrl, GitUserName, GitPassword, GitPasswordSecret, GitBranch, GitDirectory, GitCommitId, GitUserNameSecret

* [Function](https://cloud.tencent.com/document/api/583/17244#Function)

	* 新增成员：Type

* [FunctionLog](https://cloud.tencent.com/document/api/583/17244#FunctionLog)

	* 新增成员：Level, Source


### 第 3 次发布

发布时间：2019-03-21 19:50:07

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CopyFunction](https://cloud.tencent.com/document/api/583/33847)

修改接口：

* [CreateFunction](https://cloud.tencent.com/document/api/583/18586)

	* 新增入参：ClsLogsetId, ClsTopicId

* [CreateTrigger](https://cloud.tencent.com/document/api/583/18589)

	* 新增入参：Enable

	* 新增出参：TriggerInfo

* [GetFunction](https://cloud.tencent.com/document/api/583/18584)

	* 新增出参：InstallDependency, Status, StatusDesc, ClsLogsetId, ClsTopicId, FunctionId, Tags

* [GetFunctionLogs](https://cloud.tencent.com/document/api/583/18583)

	* <font color="#dd0000">**修改入参**：</font>Filter

* [ListFunctions](https://cloud.tencent.com/document/api/583/18582)

	* 新增入参：Description, Filters


新增数据结构：

* [LogFilter](https://cloud.tencent.com/document/api/583/17244#LogFilter)
* [Tag](https://cloud.tencent.com/document/api/583/17244#Tag)

修改数据结构：

* [Code](https://cloud.tencent.com/document/api/583/17244#Code)

	* 新增成员：DemoId, TempCosObjectName

* [Filter](https://cloud.tencent.com/document/api/583/17244#Filter)

	* 新增成员：Name, Values

	* <font color="#dd0000">**删除成员**：</font>RetCode

* [Function](https://cloud.tencent.com/document/api/583/17244#Function)

	* 新增成员：Status, StatusDesc, Description, Tags

* [Trigger](https://cloud.tencent.com/document/api/583/17244#Trigger)

	* 新增成员：Enable, CustomArgument


### 第 2 次发布

发布时间：2018-07-26 19:15:23

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateFunction](https://cloud.tencent.com/document/api/583/18586)
* [CreateTrigger](https://cloud.tencent.com/document/api/583/18589)
* [DeleteFunction](https://cloud.tencent.com/document/api/583/18585)
* [DeleteTrigger](https://cloud.tencent.com/document/api/583/18588)
* [GetFunction](https://cloud.tencent.com/document/api/583/18584)
* [GetFunctionLogs](https://cloud.tencent.com/document/api/583/18583)
* [ListFunctions](https://cloud.tencent.com/document/api/583/18582)
* [UpdateFunctionCode](https://cloud.tencent.com/document/api/583/18581)
* [UpdateFunctionConfiguration](https://cloud.tencent.com/document/api/583/18580)

修改接口：

* [Invoke](https://cloud.tencent.com/document/api/583/17243)

	* 新增入参：Namespace


新增数据结构：

* [Code](https://cloud.tencent.com/document/api/583/17244#Code)
* [Environment](https://cloud.tencent.com/document/api/583/17244#Environment)
* [Filter](https://cloud.tencent.com/document/api/583/17244#Filter)
* [Function](https://cloud.tencent.com/document/api/583/17244#Function)
* [FunctionLog](https://cloud.tencent.com/document/api/583/17244#FunctionLog)
* [Trigger](https://cloud.tencent.com/document/api/583/17244#Trigger)
* [Variable](https://cloud.tencent.com/document/api/583/17244#Variable)
* [VpcConfig](https://cloud.tencent.com/document/api/583/17244#VpcConfig)

### 第 1 次发布

发布时间：2018-05-17 15:58:40

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [Invoke](https://cloud.tencent.com/document/api/583/17243)

新增数据结构：

* [Result](https://cloud.tencent.com/document/api/583/17244#Result)




## 邮件推送(ses) 版本：2020-10-02

### 第 22 次发布

发布时间：2024-07-01 01:22:01

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateCustomBlacklist](https://cloud.tencent.com/document/api/1288/107854)
* [DeleteCustomBlackList](https://cloud.tencent.com/document/api/1288/107853)
* [ListCustomBlacklist](https://cloud.tencent.com/document/api/1288/107852)
* [UpdateCustomBlackList](https://cloud.tencent.com/document/api/1288/107851)

新增数据结构：

* [BlackAddressDetail](https://cloud.tencent.com/document/api/1288/51053#BlackAddressDetail)

### 第 21 次发布

发布时间：2024-06-21 16:22:39

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [SendEmail](https://cloud.tencent.com/document/api/1288/51034)

	* 新增入参：SmtpMessageId, SmtpHeaders


### 第 20 次发布

发布时间：2023-09-14 02:15:22

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [BlackEmailAddress](https://cloud.tencent.com/document/api/1288/51053#BlackEmailAddress)

	* 新增成员：IspDesc


### 第 19 次发布

发布时间：2023-09-12 02:25:46

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [ListReceiverDetails](https://cloud.tencent.com/document/api/1288/97935)

新增数据结构：

* [ReceiverDetail](https://cloud.tencent.com/document/api/1288/51053#ReceiverDetail)

### 第 18 次发布

发布时间：2023-06-06 01:51:18

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [SendEmail](https://cloud.tencent.com/document/api/1288/51034)

	* 新增入参：Cc, Bcc


### 第 17 次发布

发布时间：2022-12-16 01:37:37

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [UpdateEmailSmtpPassWord](https://cloud.tencent.com/document/api/1288/84274)

### 第 16 次发布

发布时间：2022-11-03 06:36:44

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [GetEmailTemplate](https://cloud.tencent.com/document/api/1288/51040)

	* 新增出参：TemplateName


### 第 15 次发布

发布时间：2022-10-26 06:55:19

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [CycleEmailParam](https://cloud.tencent.com/document/api/1288/51053#CycleEmailParam)

	* 新增成员：TermCycle


### 第 14 次发布

发布时间：2022-07-22 06:12:49

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [ListEmailIdentities](https://cloud.tencent.com/document/api/1288/51045)

	* 新增出参：MaxReputationLevel, MaxDailyQuota


修改数据结构：

* [EmailIdentity](https://cloud.tencent.com/document/api/1288/51053#EmailIdentity)

	* 新增成员：CurrentReputationLevel, DailyQuota


### 第 13 次发布

发布时间：2022-07-21 06:15:51

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [GetEmailTemplate](https://cloud.tencent.com/document/api/1288/51040)

	* 新增出参：TemplateStatus


### 第 12 次发布

发布时间：2022-03-29 08:14:38

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateEmailTemplate](https://cloud.tencent.com/document/api/1288/51042)

	* 新增出参：TemplateID


### 第 11 次发布

发布时间：2022-03-23 08:11:08

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [BatchSendEmail](https://cloud.tencent.com/document/api/1288/63481)

	* 新增入参：ADLocation


### 第 10 次发布

发布时间：2022-03-16 08:13:30

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [SendEmail](https://cloud.tencent.com/document/api/1288/51034)

	* 新增入参：TriggerType


### 第 9 次发布

发布时间：2022-03-15 08:14:13

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DeleteReceiver](https://cloud.tencent.com/document/api/1288/71169)

### 第 8 次发布

发布时间：2022-03-07 16:52:17

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateReceiverDetailWithData](https://cloud.tencent.com/document/api/1288/70776)

新增数据结构：

* [ReceiverInputData](https://cloud.tencent.com/document/api/1288/51053#ReceiverInputData)

### 第 7 次发布

发布时间：2022-01-18 08:14:15

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateReceiver](https://cloud.tencent.com/document/api/1288/68360)
* [CreateReceiverDetail](https://cloud.tencent.com/document/api/1288/68359)
* [ListReceivers](https://cloud.tencent.com/document/api/1288/68358)
* [ListSendTasks](https://cloud.tencent.com/document/api/1288/68357)

修改接口：

* [BatchSendEmail](https://cloud.tencent.com/document/api/1288/63481)

	* 新增入参：Unsubscribe


新增数据结构：

* [ReceiverData](https://cloud.tencent.com/document/api/1288/51053#ReceiverData)
* [SendTaskData](https://cloud.tencent.com/document/api/1288/51053#SendTaskData)

### 第 6 次发布

发布时间：2022-01-13 08:58:20

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [SendEmail](https://cloud.tencent.com/document/api/1288/51034)

	* 新增入参：Unsubscribe


### 第 5 次发布

发布时间：2021-10-29 08:08:48

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [BatchSendEmail](https://cloud.tencent.com/document/api/1288/63481)

新增数据结构：

* [CycleEmailParam](https://cloud.tencent.com/document/api/1288/51053#CycleEmailParam)
* [TimedEmailParam](https://cloud.tencent.com/document/api/1288/51053#TimedEmailParam)

### 第 4 次发布

发布时间：2021-01-15 08:09:39

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [SendEmail](https://cloud.tencent.com/document/api/1288/51034)

	* 新增入参：Attachments


新增数据结构：

* [Attachment](https://cloud.tencent.com/document/api/1288/51053#Attachment)

### 第 3 次发布

发布时间：2021-01-08 08:09:07

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [GetSendEmailStatus](https://cloud.tencent.com/document/api/1288/51832)

新增数据结构：

* [SendEmailStatus](https://cloud.tencent.com/document/api/1288/51053#SendEmailStatus)

### 第 2 次发布

发布时间：2020-12-22 08:11:35

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [TemplatesMetadata](https://cloud.tencent.com/document/api/1288/51053#TemplatesMetadata)

	* 新增成员：ReviewReason


### 第 1 次发布

发布时间：2020-12-16 14:14:46

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateEmailAddress](https://cloud.tencent.com/document/api/1288/51052)
* [CreateEmailIdentity](https://cloud.tencent.com/document/api/1288/51048)
* [CreateEmailTemplate](https://cloud.tencent.com/document/api/1288/51042)
* [DeleteBlackList](https://cloud.tencent.com/document/api/1288/51032)
* [DeleteEmailAddress](https://cloud.tencent.com/document/api/1288/51051)
* [DeleteEmailIdentity](https://cloud.tencent.com/document/api/1288/51047)
* [DeleteEmailTemplate](https://cloud.tencent.com/document/api/1288/51041)
* [GetEmailIdentity](https://cloud.tencent.com/document/api/1288/51046)
* [GetEmailTemplate](https://cloud.tencent.com/document/api/1288/51040)
* [GetStatisticsReport](https://cloud.tencent.com/document/api/1288/51036)
* [ListBlackEmailAddress](https://cloud.tencent.com/document/api/1288/51031)
* [ListEmailAddress](https://cloud.tencent.com/document/api/1288/51050)
* [ListEmailIdentities](https://cloud.tencent.com/document/api/1288/51045)
* [ListEmailTemplates](https://cloud.tencent.com/document/api/1288/51039)
* [SendEmail](https://cloud.tencent.com/document/api/1288/51034)
* [UpdateEmailIdentity](https://cloud.tencent.com/document/api/1288/51044)
* [UpdateEmailTemplate](https://cloud.tencent.com/document/api/1288/51038)

新增数据结构：

* [BlackEmailAddress](https://cloud.tencent.com/document/api/1288/51053#BlackEmailAddress)
* [DNSAttributes](https://cloud.tencent.com/document/api/1288/51053#DNSAttributes)
* [EmailIdentity](https://cloud.tencent.com/document/api/1288/51053#EmailIdentity)
* [EmailSender](https://cloud.tencent.com/document/api/1288/51053#EmailSender)
* [Simple](https://cloud.tencent.com/document/api/1288/51053#Simple)
* [Template](https://cloud.tencent.com/document/api/1288/51053#Template)
* [TemplateContent](https://cloud.tencent.com/document/api/1288/51053#TemplateContent)
* [TemplatesMetadata](https://cloud.tencent.com/document/api/1288/51053#TemplatesMetadata)
* [Volume](https://cloud.tencent.com/document/api/1288/51053#Volume)




## 智能媒资托管(smh) 版本：2021-07-12

### 第 5 次发布

发布时间：2023-06-21 01:31:57

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateLibrary](https://cloud.tencent.com/document/api/1339/69089)

	* <font color="#dd0000">**修改入参**：</font>BucketName, BucketRegion, LibraryExtension


### 第 4 次发布

发布时间：2022-11-23 06:47:21

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [SendSmsCode](https://cloud.tencent.com/document/api/1339/69080)

	* <font color="#dd0000">**修改入参**：</font>InstanceId

* [VerifySmsCode](https://cloud.tencent.com/document/api/1339/69079)

	* <font color="#dd0000">**修改入参**：</font>InstanceId


### 第 3 次发布

发布时间：2022-04-25 06:11:28

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [SendSmsCode](https://cloud.tencent.com/document/api/1339/69080)

	* 新增入参：CountryCode

* [VerifySmsCode](https://cloud.tencent.com/document/api/1339/69079)

	* 新增入参：CountryCode


### 第 2 次发布

发布时间：2022-03-17 08:11:49

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeOfficialInstances](https://cloud.tencent.com/document/api/1339/69083)

	* 新增入参：OrderBy, OrderByType, AutoRenew, BindPhone

* [DescribeTrafficPackages](https://cloud.tencent.com/document/api/1339/69081)

	* 新增入参：OrderBy, OrderByType, Type


### 第 1 次发布

发布时间：2022-02-10 11:28:45

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateLibrary](https://cloud.tencent.com/document/api/1339/69089)
* [DeleteLibrary](https://cloud.tencent.com/document/api/1339/69088)
* [DescribeLibraries](https://cloud.tencent.com/document/api/1339/69087)
* [DescribeLibrarySecret](https://cloud.tencent.com/document/api/1339/69086)
* [DescribeOfficialInstances](https://cloud.tencent.com/document/api/1339/69083)
* [DescribeOfficialOverview](https://cloud.tencent.com/document/api/1339/69082)
* [DescribeTrafficPackages](https://cloud.tencent.com/document/api/1339/69081)
* [ModifyLibrary](https://cloud.tencent.com/document/api/1339/69085)
* [SendSmsCode](https://cloud.tencent.com/document/api/1339/69080)
* [VerifySmsCode](https://cloud.tencent.com/document/api/1339/69079)

新增数据结构：

* [Instance](https://cloud.tencent.com/document/api/1339/69090#Instance)
* [Library](https://cloud.tencent.com/document/api/1339/69090#Library)
* [LibraryExtension](https://cloud.tencent.com/document/api/1339/69090#LibraryExtension)
* [TrafficPackage](https://cloud.tencent.com/document/api/1339/69090#TrafficPackage)




## 腾讯安心用户运营平台(smop) 版本：2020-12-03

### 第 2 次发布

发布时间：2023-04-03 01:30:29

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [TaskEventData](https://cloud.tencent.com/document/api/1310/89033#TaskEventData)

	* 新增成员：GrowScore


### 第 1 次发布

发布时间：2023-03-21 09:25:44

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [SubmitTaskEvent](https://cloud.tencent.com/document/api/1310/89032)

新增数据结构：

* [TaskEventData](https://cloud.tencent.com/document/api/1310/89033#TaskEventData)




## 营销号码安全(smpn) 版本：2019-08-22

### 第 3 次发布

发布时间：2024-07-09 01:21:06

本次发布包含了以下内容：

改善已有的文档。

<font color="#dd0000">**删除接口**：</font>

* CreateSmpnEpa
* DescribeSmpnMhm
* DescribeSmpnMrl

<font color="#dd0000">**删除数据结构**：</font>

* EPARequest
* EPAResponse
* MHMRequest
* MHMResponse
* MRLRequest
* MRLResponse

### 第 2 次发布

发布时间：2024-07-08 01:20:52

本次发布包含了以下内容：

改善已有的文档。

<font color="#dd0000">**预下线接口**：</font>

* CreateSmpnEpa
* DescribeSmpnChp
* DescribeSmpnFnr
* DescribeSmpnMhm
* DescribeSmpnMrl

### 第 1 次发布

发布时间：2019-12-17 16:50:17

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateSmpnEpa](https://cloud.tencent.com/document/api/1127/40318)
* [DescribeSmpnChp](https://cloud.tencent.com/document/api/1127/40314)
* [DescribeSmpnFnr](https://cloud.tencent.com/document/api/1127/40310)
* [DescribeSmpnMhm](https://cloud.tencent.com/document/api/1127/40312)
* [DescribeSmpnMrl](https://cloud.tencent.com/document/api/1127/40316)

新增数据结构：

* [CHPRequest](https://cloud.tencent.com/document/api/1127/40319#CHPRequest)
* [CHPResponse](https://cloud.tencent.com/document/api/1127/40319#CHPResponse)
* [EPARequest](https://cloud.tencent.com/document/api/1127/40319#EPARequest)
* [EPAResponse](https://cloud.tencent.com/document/api/1127/40319#EPAResponse)
* [FNRRequest](https://cloud.tencent.com/document/api/1127/40319#FNRRequest)
* [FNRResponse](https://cloud.tencent.com/document/api/1127/40319#FNRResponse)
* [MHMRequest](https://cloud.tencent.com/document/api/1127/40319#MHMRequest)
* [MHMResponse](https://cloud.tencent.com/document/api/1127/40319#MHMResponse)
* [MRLRequest](https://cloud.tencent.com/document/api/1127/40319#MRLRequest)
* [MRLResponse](https://cloud.tencent.com/document/api/1127/40319#MRLResponse)




## 短信(sms) 版本：2019-07-11

### 第 9 次发布

发布时间：2020-07-02 08:15:59

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [SendStatus](https://cloud.tencent.com/document/api/382/38779#SendStatus)

	* 新增成员：IsoCode


### 第 8 次发布

发布时间：2020-06-03 08:15:51

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [PullSmsReplyStatusByPhoneNumber](https://cloud.tencent.com/document/api/382/38775)

	* 新增入参：EndDateTime

* [PullSmsSendStatusByPhoneNumber](https://cloud.tencent.com/document/api/382/38773)

	* 新增入参：EndDateTime


### 第 7 次发布

发布时间：2020-02-21 12:53:39

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeSmsSignList](https://cloud.tencent.com/document/api/382/41429)
* [DescribeSmsTemplateList](https://cloud.tencent.com/document/api/382/41430)

新增数据结构：

* [DescribeSignListStatus](https://cloud.tencent.com/document/api/382/38779#DescribeSignListStatus)
* [DescribeTemplateListStatus](https://cloud.tencent.com/document/api/382/38779#DescribeTemplateListStatus)

### 第 6 次发布

发布时间：2020-01-16 18:08:26

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [AddSmsSign](https://cloud.tencent.com/document/api/382/41146)
* [AddSmsTemplate](https://cloud.tencent.com/document/api/382/41150)
* [DeleteSmsSign](https://cloud.tencent.com/document/api/382/41145)
* [DeleteSmsTemplate](https://cloud.tencent.com/document/api/382/41149)
* [ModifySmsSign](https://cloud.tencent.com/document/api/382/41144)
* [ModifySmsTemplate](https://cloud.tencent.com/document/api/382/41148)

新增数据结构：

* [AddSignStatus](https://cloud.tencent.com/document/api/382/38779#AddSignStatus)
* [AddTemplateStatus](https://cloud.tencent.com/document/api/382/38779#AddTemplateStatus)
* [DeleteSignStatus](https://cloud.tencent.com/document/api/382/38779#DeleteSignStatus)
* [DeleteTemplateStatus](https://cloud.tencent.com/document/api/382/38779#DeleteTemplateStatus)
* [ModifySignStatus](https://cloud.tencent.com/document/api/382/38779#ModifySignStatus)
* [ModifyTemplateStatus](https://cloud.tencent.com/document/api/382/38779#ModifyTemplateStatus)

### 第 5 次发布

发布时间：2019-12-20 00:03:15

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [PullSmsReplyStatus](https://cloud.tencent.com/document/api/382/38779#PullSmsReplyStatus)

	* 新增成员：ReplyUnixTime

* [PullSmsSendStatus](https://cloud.tencent.com/document/api/382/38779#PullSmsSendStatus)

	* 新增成员：UserReceiveUnixTime

* [SmsPackagesStatistics](https://cloud.tencent.com/document/api/382/38779#SmsPackagesStatistics)

	* 新增成员：PackageCreateUnixTime, PackageEffectiveUnixTime, PackageExpiredUnixTime


### 第 4 次发布

发布时间：2019-12-05 16:41:21

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [PullSmsReplyStatusByPhoneNumber](https://cloud.tencent.com/document/api/382/38775)

	* <font color="#dd0000">**修改入参**：</font>SendDateTime

* [PullSmsSendStatusByPhoneNumber](https://cloud.tencent.com/document/api/382/38773)

	* <font color="#dd0000">**修改入参**：</font>SendDateTime

* [SendSms](https://cloud.tencent.com/document/api/382/38778)

	* <font color="#dd0000">**修改入参**：</font>ExtendCode

* [SmsPackagesStatistics](https://cloud.tencent.com/document/api/382/39533)

	* <font color="#dd0000">**删除入参**：</font>NumberOfPullPackages


修改数据结构：

* [PullSmsReplyStatus](https://cloud.tencent.com/document/api/382/38779#PullSmsReplyStatus)

	* <font color="#dd0000">**修改成员**：</font>ExtendCode

* [SendStatusStatistics](https://cloud.tencent.com/document/api/382/38779#SendStatusStatistics)

	* 新增成员：FeeCount, RequestCount, RequestSuccessCount

	* <font color="#dd0000">**删除成员**：</font>BillingStatistics, RequestStatistics, RequestSuccessStatistics


### 第 3 次发布

发布时间：2019-11-22 12:17:33

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CallbackStatusStatistics](https://cloud.tencent.com/document/api/382/39535)
* [SendStatusStatistics](https://cloud.tencent.com/document/api/382/39534)
* [SmsPackagesStatistics](https://cloud.tencent.com/document/api/382/39533)

新增数据结构：

* [CallbackStatusStatistics](https://cloud.tencent.com/document/api/382/38779#CallbackStatusStatistics)
* [SendStatusStatistics](https://cloud.tencent.com/document/api/382/38779#SendStatusStatistics)
* [SmsPackagesStatistics](https://cloud.tencent.com/document/api/382/38779#SmsPackagesStatistics)

### 第 2 次发布

发布时间：2019-11-14 17:39:37

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [PullSmsReplyStatus](https://cloud.tencent.com/document/api/382/38779#PullSmsReplyStatus)

	* <font color="#dd0000">**修改成员**：</font>ExtendCode, ReplyTime


### 第 1 次发布

发布时间：2019-10-28 16:23:12

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [PullSmsReplyStatus](https://cloud.tencent.com/document/api/382/38776)
* [PullSmsReplyStatusByPhoneNumber](https://cloud.tencent.com/document/api/382/38775)
* [PullSmsSendStatus](https://cloud.tencent.com/document/api/382/38774)
* [PullSmsSendStatusByPhoneNumber](https://cloud.tencent.com/document/api/382/38773)
* [SendSms](https://cloud.tencent.com/document/api/382/38778)

新增数据结构：

* [PullSmsReplyStatus](https://cloud.tencent.com/document/api/382/38779#PullSmsReplyStatus)
* [PullSmsSendStatus](https://cloud.tencent.com/document/api/382/38779#PullSmsSendStatus)
* [SendStatus](https://cloud.tencent.com/document/api/382/38779#SendStatus)



## 短信(sms) 版本：2021-01-11

### 第 5 次发布

发布时间：2022-08-17 06:36:01

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [ReportConversion](https://cloud.tencent.com/document/api/382/79152)

新增数据结构：

* [ReportConversionStatus](https://cloud.tencent.com/document/api/382/52068#ReportConversionStatus)

### 第 4 次发布

发布时间：2022-02-23 08:11:58

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [PullSmsSendStatus](https://cloud.tencent.com/document/api/382/52068#PullSmsSendStatus)

	* 新增成员：SessionContext


### 第 3 次发布

发布时间：2021-11-16 08:13:49

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeSmsTemplateList](https://cloud.tencent.com/document/api/382/52067)

	* 新增入参：Limit, Offset

	* <font color="#dd0000">**修改入参**：</font>TemplateIdSet


### 第 2 次发布

发布时间：2021-09-23 08:11:56

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribePhoneNumberInfo](https://cloud.tencent.com/document/api/382/61755)

新增数据结构：

* [PhoneNumberInfo](https://cloud.tencent.com/document/api/382/52068#PhoneNumberInfo)

### 第 1 次发布

发布时间：2021-05-18 14:31:03

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [AddSmsSign](https://cloud.tencent.com/document/api/382/55971)
* [AddSmsTemplate](https://cloud.tencent.com/document/api/382/55974)
* [CallbackStatusStatistics](https://cloud.tencent.com/document/api/382/55966)
* [DeleteSmsSign](https://cloud.tencent.com/document/api/382/55970)
* [DeleteSmsTemplate](https://cloud.tencent.com/document/api/382/55973)
* [DescribeSmsSignList](https://cloud.tencent.com/document/api/382/55969)
* [DescribeSmsTemplateList](https://cloud.tencent.com/document/api/382/52067)
* [ModifySmsSign](https://cloud.tencent.com/document/api/382/55968)
* [ModifySmsTemplate](https://cloud.tencent.com/document/api/382/55972)
* [PullSmsReplyStatus](https://cloud.tencent.com/document/api/382/55979)
* [PullSmsReplyStatusByPhoneNumber](https://cloud.tencent.com/document/api/382/55978)
* [PullSmsSendStatus](https://cloud.tencent.com/document/api/382/55977)
* [PullSmsSendStatusByPhoneNumber](https://cloud.tencent.com/document/api/382/55976)
* [SendSms](https://cloud.tencent.com/document/api/382/55981)
* [SendStatusStatistics](https://cloud.tencent.com/document/api/382/55965)
* [SmsPackagesStatistics](https://cloud.tencent.com/document/api/382/55964)

新增数据结构：

* [AddSignStatus](https://cloud.tencent.com/document/api/382/52068#AddSignStatus)
* [AddTemplateStatus](https://cloud.tencent.com/document/api/382/52068#AddTemplateStatus)
* [CallbackStatusStatistics](https://cloud.tencent.com/document/api/382/52068#CallbackStatusStatistics)
* [DeleteSignStatus](https://cloud.tencent.com/document/api/382/52068#DeleteSignStatus)
* [DeleteTemplateStatus](https://cloud.tencent.com/document/api/382/52068#DeleteTemplateStatus)
* [DescribeSignListStatus](https://cloud.tencent.com/document/api/382/52068#DescribeSignListStatus)
* [DescribeTemplateListStatus](https://cloud.tencent.com/document/api/382/52068#DescribeTemplateListStatus)
* [ModifySignStatus](https://cloud.tencent.com/document/api/382/52068#ModifySignStatus)
* [ModifyTemplateStatus](https://cloud.tencent.com/document/api/382/52068#ModifyTemplateStatus)
* [PullSmsReplyStatus](https://cloud.tencent.com/document/api/382/52068#PullSmsReplyStatus)
* [PullSmsSendStatus](https://cloud.tencent.com/document/api/382/52068#PullSmsSendStatus)
* [SendStatus](https://cloud.tencent.com/document/api/382/52068#SendStatus)
* [SendStatusStatistics](https://cloud.tencent.com/document/api/382/52068#SendStatusStatistics)
* [SmsPackagesStatistics](https://cloud.tencent.com/document/api/382/52068#SmsPackagesStatistics)




## 智聆口语评测(soe) 版本：2018-07-24

### 第 15 次发布

发布时间：2023-10-16 01:23:02

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [TransmitOralProcessWithInit](https://cloud.tencent.com/document/api/884/32605)

	* 新增入参：COSBucketURL


### 第 14 次发布

发布时间：2023-07-10 01:39:48

本次发布包含了以下内容：

改善已有的文档。

新增数据结构：

* [Tone](https://cloud.tencent.com/document/api/884/19320#Tone)

修改数据结构：

* [WordRsp](https://cloud.tencent.com/document/api/884/19320#WordRsp)

	* 新增成员：Tone


### 第 13 次发布

发布时间：2022-10-31 06:46:23

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [InitOralProcess](https://cloud.tencent.com/document/api/884/19319)

	* 新增入参：Keyword

* [TransmitOralProcess](https://cloud.tencent.com/document/api/884/19318)

	* 新增出参：RefTextId, KeyWordHits, UnKeyWordHits

* [TransmitOralProcessWithInit](https://cloud.tencent.com/document/api/884/32605)

	* 新增入参：Keyword

	* 新增出参：RefTextId, KeyWordHits, UnKeyWordHits


修改数据结构：

* [SentenceInfo](https://cloud.tencent.com/document/api/884/19320#SentenceInfo)

	* 新增成员：RefTextId, KeyWordHits, UnKeyWordHits

* [WordRsp](https://cloud.tencent.com/document/api/884/19320#WordRsp)

	* 新增成员：KeywordTag


### 第 12 次发布

发布时间：2021-06-18 08:07:31

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [PhoneInfo](https://cloud.tencent.com/document/api/884/19320#PhoneInfo)

	* 新增成员：ReferenceLetter


### 第 11 次发布

发布时间：2019-08-15 17:39:10

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [PhoneInfo](https://cloud.tencent.com/document/api/884/19320#PhoneInfo)

	* 新增成员：ReferencePhone, MatchTag

* [WordRsp](https://cloud.tencent.com/document/api/884/19320#WordRsp)

	* 新增成员：ReferenceWord


### 第 10 次发布

发布时间：2019-06-21 14:17:30

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [KeywordEvaluate](https://cloud.tencent.com/document/api/884/35587)

新增数据结构：

* [Keyword](https://cloud.tencent.com/document/api/884/19320#Keyword)
* [KeywordScore](https://cloud.tencent.com/document/api/884/19320#KeywordScore)

### 第 9 次发布

发布时间：2019-04-19 17:55:30

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [TransmitOralProcess](https://cloud.tencent.com/document/api/884/19318)

	* 新增出参：SuggestedScore

* [TransmitOralProcessWithInit](https://cloud.tencent.com/document/api/884/32605)

	* 新增出参：SuggestedScore


修改数据结构：

* [SentenceInfo](https://cloud.tencent.com/document/api/884/19320#SentenceInfo)

	* 新增成员：SuggestedScore


### 第 8 次发布

发布时间：2019-03-14 17:15:57

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [InitOralProcess](https://cloud.tencent.com/document/api/884/19319)

	* 新增入参：TextMode

* [TransmitOralProcessWithInit](https://cloud.tencent.com/document/api/884/32605)

	* 新增入参：TextMode


### 第 7 次发布

发布时间：2019-01-18 15:57:49

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [TransmitOralProcessWithInit](https://cloud.tencent.com/document/api/884/32605)

修改接口：

* [InitOralProcess](https://cloud.tencent.com/document/api/884/19319)

	* 新增入参：IsAsync

* [TransmitOralProcess](https://cloud.tencent.com/document/api/884/19318)

	* 新增入参：IsQuery

	* 新增出参：Status


### 第 6 次发布

发布时间：2018-12-13 16:02:00

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [InitOralProcess](https://cloud.tencent.com/document/api/884/19319)

	* 新增入参：SentenceInfoEnabled, ServerType

* [TransmitOralProcess](https://cloud.tencent.com/document/api/884/19318)

	* 新增出参：SentenceInfoSet


新增数据结构：

* [SentenceInfo](https://cloud.tencent.com/document/api/884/19320#SentenceInfo)

### 第 5 次发布

发布时间：2018-11-29 20:16:45

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [InitOralProcess](https://cloud.tencent.com/document/api/884/19319)

	* 新增入参：StorageMode

* [TransmitOralProcess](https://cloud.tencent.com/document/api/884/19318)

	* 新增出参：AudioUrl


### 第 4 次发布

发布时间：2018-10-29 11:21:16

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [InitOralProcess](https://cloud.tencent.com/document/api/884/19319)

	* 新增入参：SoeAppId, IsLongLifeSession

	* 新增出参：SessionId

* [TransmitOralProcess](https://cloud.tencent.com/document/api/884/19318)

	* 新增入参：IsLongLifeSession

	* 新增出参：SessionId


### 第 3 次发布

发布时间：2018-09-20 19:44:06

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [TransmitOralProcess](https://cloud.tencent.com/document/api/884/19318)

	* 新增入参：SoeAppId


### 第 2 次发布

发布时间：2018-09-07 11:09:02

本次发布包含了以下内容：

改善已有的文档。

### 第 1 次发布

发布时间：2018-08-28 20:08:16

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [InitOralProcess](https://cloud.tencent.com/document/api/884/19319)
* [TransmitOralProcess](https://cloud.tencent.com/document/api/884/19318)

新增数据结构：

* [PhoneInfo](https://cloud.tencent.com/document/api/884/19320#PhoneInfo)
* [WordRsp](https://cloud.tencent.com/document/api/884/19320#WordRsp)




## 金融资源聚合平台(solar) 版本：2018-10-11

### 第 1 次发布

发布时间：2020-03-19 08:01:59

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CheckStaffChUser](https://cloud.tencent.com/document/api/#/#)
* [CopyActivityChannel](https://cloud.tencent.com/document/api/#/#)
* [CreateProject](https://cloud.tencent.com/document/api/#/#)
* [CreateSubProject](https://cloud.tencent.com/document/api/#/#)
* [DeleteProject](https://cloud.tencent.com/document/api/#/#)
* [DescribeCustomer](https://cloud.tencent.com/document/api/#/#)
* [DescribeCustomers](https://cloud.tencent.com/document/api/#/#)
* [DescribeProject](https://cloud.tencent.com/document/api/#/#)
* [DescribeProjectStock](https://cloud.tencent.com/document/api/#/#)
* [DescribeProjects](https://cloud.tencent.com/document/api/#/#)
* [DescribeResourceTemplateHeaders](https://cloud.tencent.com/document/api/#/#)
* [DescribeSubProject](https://cloud.tencent.com/document/api/#/#)
* [ExpireFlow](https://cloud.tencent.com/document/api/#/#)
* [ModifyProject](https://cloud.tencent.com/document/api/#/#)
* [OffLineProject](https://cloud.tencent.com/document/api/#/#)
* [ReplenishProjectStock](https://cloud.tencent.com/document/api/#/#)
* [SendWxTouchTask](https://cloud.tencent.com/document/api/#/#)

新增数据结构：

* [ActivityInfo](https://cloud.tencent.com/document/api/#/##ActivityInfo)
* [CustomerInfo](https://cloud.tencent.com/document/api/#/##CustomerInfo)
* [Filters](https://cloud.tencent.com/document/api/#/##Filters)
* [ProductInfo](https://cloud.tencent.com/document/api/#/##ProductInfo)
* [ProjectInfo](https://cloud.tencent.com/document/api/#/##ProjectInfo)
* [ProjectStock](https://cloud.tencent.com/document/api/#/##ProjectStock)
* [ResourceTemplateHeader](https://cloud.tencent.com/document/api/#/##ResourceTemplateHeader)
* [SubProjectInfo](https://cloud.tencent.com/document/api/#/##SubProjectInfo)




## 云数据库 SQL Server(sqlserver) 版本：2018-03-28

### 第 63 次发布

发布时间：2024-08-05 02:02:14

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CutXEvents](https://cloud.tencent.com/document/api/238/109684)

### 第 62 次发布

发布时间：2024-06-06 02:22:45

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [AccountCreateInfo](https://cloud.tencent.com/document/api/238/19976#AccountCreateInfo)

	* 新增成员：IsCam

	* <font color="#dd0000">**修改成员**：</font>Password

* [AccountDetail](https://cloud.tencent.com/document/api/238/19976#AccountDetail)

	* 新增成员：IsCam


### 第 61 次发布

发布时间：2024-04-15 02:06:58

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeRestoreTimeRange](https://cloud.tencent.com/document/api/238/105136)

### 第 60 次发布

发布时间：2024-04-10 01:21:30

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeDBInstancesAttribute](https://cloud.tencent.com/document/api/238/90299)

	* 新增出参：OldVipList


新增数据结构：

* [OldVip](https://cloud.tencent.com/document/api/238/19976#OldVip)

### 第 59 次发布

发布时间：2024-03-15 01:20:49

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeCollationTimeZone](https://cloud.tencent.com/document/api/238/101735)

	* 新增入参：DBVersion


### 第 58 次发布

发布时间：2024-03-11 01:21:49

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [ModifyDReadable](https://cloud.tencent.com/document/api/238/104234)

### 第 57 次发布

发布时间：2024-03-08 01:22:30

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeDBInstancesAttribute](https://cloud.tencent.com/document/api/238/90299)

	* 新增出参：DrReadableInfo

* [ModifyCloseWanIp](https://cloud.tencent.com/document/api/238/101718)

	* 新增入参：RoGroupId

* [ModifyDBInstanceNetwork](https://cloud.tencent.com/document/api/238/52347)

	* 新增入参：DRNetwork

* [ModifyOpenWanIp](https://cloud.tencent.com/document/api/238/101717)

	* 新增入参：RoGroupId


新增数据结构：

* [DrReadableInfo](https://cloud.tencent.com/document/api/238/19976#DrReadableInfo)

修改数据结构：

* [ReadOnlyGroup](https://cloud.tencent.com/document/api/238/19976#ReadOnlyGroup)

	* 新增成员：DnsPodDomain, TgwWanVPort


### 第 56 次发布

发布时间：2023-12-01 01:22:35

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [ModifyDBInstanceSSL](https://cloud.tencent.com/document/api/238/102112)

修改接口：

* [DescribeDBInstancesAttribute](https://cloud.tencent.com/document/api/238/90299)

	* 新增出参：SSLConfig


新增数据结构：

* [SSLConfig](https://cloud.tencent.com/document/api/238/19976#SSLConfig)

### 第 55 次发布

发布时间：2023-11-21 01:25:12

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [BalanceReadOnlyGroup](https://cloud.tencent.com/document/api/238/101753)
* [DeleteRestoreTask](https://cloud.tencent.com/document/api/238/101743)
* [DescribeAccountPrivilegeByDB](https://cloud.tencent.com/document/api/238/101729)
* [DescribeCollationTimeZone](https://cloud.tencent.com/document/api/238/101735)
* [DescribeCrossRegions](https://cloud.tencent.com/document/api/238/101738)
* [DescribeDBPrivilegeByAccount](https://cloud.tencent.com/document/api/238/101715)
* [DescribeDBRestoreTime](https://cloud.tencent.com/document/api/238/101742)
* [DescribeDatabaseNames](https://cloud.tencent.com/document/api/238/101714)
* [DescribeInquiryPriceParameter](https://cloud.tencent.com/document/api/238/101749)
* [DescribeInstanceTasks](https://cloud.tencent.com/document/api/238/101734)
* [DescribeInstanceTradeParameter](https://cloud.tencent.com/document/api/238/101748)
* [DescribeProductSpec](https://cloud.tencent.com/document/api/238/101747)
* [DescribeReadOnlyGroupAutoWeight](https://cloud.tencent.com/document/api/238/101752)
* [DescribeRestoreTask](https://cloud.tencent.com/document/api/238/101741)
* [DescribeSpecSellStatus](https://cloud.tencent.com/document/api/238/101746)
* [DescribeUpgradeInstanceCheck](https://cloud.tencent.com/document/api/238/101733)
* [ModifyCloseWanIp](https://cloud.tencent.com/document/api/238/101718)
* [ModifyDBInstanceNote](https://cloud.tencent.com/document/api/238/101732)
* [ModifyOpenWanIp](https://cloud.tencent.com/document/api/238/101717)
* [ModifyPublishSubscribe](https://cloud.tencent.com/document/api/238/101756)

新增数据结构：

* [CheckItem](https://cloud.tencent.com/document/api/238/19976#CheckItem)
* [InstanceTask](https://cloud.tencent.com/document/api/238/19976#InstanceTask)
* [ModifyDataBaseTuple](https://cloud.tencent.com/document/api/238/19976#ModifyDataBaseTuple)
* [Price](https://cloud.tencent.com/document/api/238/19976#Price)
* [ProductSpec](https://cloud.tencent.com/document/api/238/19976#ProductSpec)
* [RestoreTask](https://cloud.tencent.com/document/api/238/19976#RestoreTask)
* [SpecSellStatus](https://cloud.tencent.com/document/api/238/19976#SpecSellStatus)
* [ZoneStatus](https://cloud.tencent.com/document/api/238/19976#ZoneStatus)

### 第 54 次发布

发布时间：2023-11-17 01:22:32

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeBackupMonitor](https://cloud.tencent.com/document/api/238/101650)
* [DescribeBackupStatistical](https://cloud.tencent.com/document/api/238/101649)
* [DescribeBackupSummary](https://cloud.tencent.com/document/api/238/101648)
* [DescribeCrossBackupStatistical](https://cloud.tencent.com/document/api/238/101647)
* [DescribeDatabases](https://cloud.tencent.com/document/api/238/101644)
* [DescribeDatabasesNormal](https://cloud.tencent.com/document/api/238/101643)
* [DescribeRegularBackupPlan](https://cloud.tencent.com/document/api/238/101646)
* [ModifyCrossBackupStrategy](https://cloud.tencent.com/document/api/238/101645)
* [ModifyDatabaseShrinkMDF](https://cloud.tencent.com/document/api/238/101642)

新增数据结构：

* [CrossSummaryDetailRes](https://cloud.tencent.com/document/api/238/19976#CrossSummaryDetailRes)
* [SummaryDetailRes](https://cloud.tencent.com/document/api/238/19976#SummaryDetailRes)

### 第 53 次发布

发布时间：2023-11-06 00:18:16

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeSlowlogs](https://cloud.tencent.com/document/api/238/19936)

	* 新增出参：SlowLogs

* [DescribeUploadBackupInfo](https://cloud.tencent.com/document/api/238/53185)

	* 新增出参：CosSecurityToken

* [DescribeUploadIncrementalInfo](https://cloud.tencent.com/document/api/238/53184)

	* 新增出参：CosSecurityToken

* [ModifyBackupStrategy](https://cloud.tencent.com/document/api/238/46288)

	* 新增出参：Code


新增数据结构：

* [SlowLog](https://cloud.tencent.com/document/api/238/19976#SlowLog)

修改数据结构：

* [DbNormalDetail](https://cloud.tencent.com/document/api/238/19976#DbNormalDetail)

	* 新增成员：IsFullTextEnabled

	* <font color="#dd0000">**修改成员**：</font>CreateTime


### 第 52 次发布

发布时间：2023-09-25 01:24:51

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeDBInstances](https://cloud.tencent.com/document/api/238/19969)

	* 新增入参：PaginationType


### 第 51 次发布

发布时间：2023-09-13 02:18:02

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateBackup](https://cloud.tencent.com/document/api/238/19946)

	* 新增入参：StorageStrategy

* [DescribeBackups](https://cloud.tencent.com/document/api/238/19943)

	* 新增入参：StorageStrategy


修改数据结构：

* [Backup](https://cloud.tencent.com/document/api/238/19976#Backup)

	* 新增成员：StorageStrategy


### 第 50 次发布

发布时间：2023-09-11 02:35:40

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeHASwitchLog](https://cloud.tencent.com/document/api/238/97923)
* [SwitchCloudInstanceHA](https://cloud.tencent.com/document/api/238/97922)

新增数据结构：

* [SwitchLog](https://cloud.tencent.com/document/api/238/19976#SwitchLog)

### 第 49 次发布

发布时间：2023-08-04 01:16:26

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [DBInstance](https://cloud.tencent.com/document/api/238/19976#DBInstance)

	* <font color="#dd0000">**修改成员**：</font>Architecture, Style


### 第 48 次发布

发布时间：2023-08-02 01:20:58

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeInstanceByOrders](https://cloud.tencent.com/document/api/238/95801)

新增数据结构：

* [DealInstance](https://cloud.tencent.com/document/api/238/19976#DealInstance)

### 第 47 次发布

发布时间：2023-06-28 01:38:12

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [ModifyDBEncryptAttributes](https://cloud.tencent.com/document/api/238/94327)
* [ModifyInstanceEncryptAttributes](https://cloud.tencent.com/document/api/238/94328)

新增数据结构：

* [DBTDEEncrypt](https://cloud.tencent.com/document/api/238/19976#DBTDEEncrypt)

### 第 46 次发布

发布时间：2023-06-26 01:49:10

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeDBInstancesAttribute](https://cloud.tencent.com/document/api/238/90299)

	* 新增出参：TDEConfig

* [DescribeDBs](https://cloud.tencent.com/document/api/238/19968)

	* 新增入参：Encryption


新增数据结构：

* [TDEConfigAttribute](https://cloud.tencent.com/document/api/238/19976#TDEConfigAttribute)

修改数据结构：

* [DBDetail](https://cloud.tencent.com/document/api/238/19976#DBDetail)

	* 新增成员：Encryption


### 第 45 次发布

发布时间：2023-05-26 01:49:53

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateBusinessDBInstances](https://cloud.tencent.com/document/api/238/80332)

	* 新增出参：FlowId, InstanceIdSet


### 第 44 次发布

发布时间：2023-05-22 01:53:58

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateCloudDBInstances](https://cloud.tencent.com/document/api/238/91710)
* [CreateCloudReadOnlyDBInstances](https://cloud.tencent.com/document/api/238/91709)

### 第 43 次发布

发布时间：2023-04-21 01:38:00

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [RestoreInstance](https://cloud.tencent.com/document/api/238/19950)

	* 新增入参：Type, DBList

* [RollbackInstance](https://cloud.tencent.com/document/api/238/19949)

	* <font color="#dd0000">**修改入参**：</font>DBs


修改数据结构：

* [DBInstance](https://cloud.tencent.com/document/api/238/19976#DBInstance)

	* 新增成员：Architecture, Style


### 第 42 次发布

发布时间：2023-04-19 01:48:11

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeDBInstancesAttribute](https://cloud.tencent.com/document/api/238/90299)
* [DescribeXEvents](https://cloud.tencent.com/document/api/238/90298)
* [StartInstanceXEvent](https://cloud.tencent.com/document/api/238/90297)

新增数据结构：

* [EventConfig](https://cloud.tencent.com/document/api/238/19976#EventConfig)
* [Events](https://cloud.tencent.com/document/api/238/19976#Events)

### 第 41 次发布

发布时间：2023-03-01 01:40:19

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [ResourceTag](https://cloud.tencent.com/document/api/238/19976#ResourceTag)

	* <font color="#dd0000">**修改成员**：</font>TagKey, TagValue


### 第 40 次发布

发布时间：2023-02-09 01:58:45

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [ModifyBackupMigration](https://cloud.tencent.com/document/api/238/53183)

	* 新增入参：DBRename


新增数据结构：

* [DBRenameRes](https://cloud.tencent.com/document/api/238/19976#DBRenameRes)

修改数据结构：

* [AccountCreateInfo](https://cloud.tencent.com/document/api/238/19976#AccountCreateInfo)

	* 新增成员：AccountType

* [AccountDetail](https://cloud.tencent.com/document/api/238/19976#AccountDetail)

	* 新增成员：AccountType

* [AccountPrivilege](https://cloud.tencent.com/document/api/238/19976#AccountPrivilege)

	* 新增成员：AccountType

* [AccountPrivilegeModifyInfo](https://cloud.tencent.com/document/api/238/19976#AccountPrivilegeModifyInfo)

	* 新增成员：AccountType

* [DbNormalDetail](https://cloud.tencent.com/document/api/238/19976#DbNormalDetail)

	* 新增成员：CreateTime

* [Migration](https://cloud.tencent.com/document/api/238/19976#Migration)

	* 新增成员：DBRename


### 第 39 次发布

发布时间：2022-12-07 06:58:03

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeAccounts](https://cloud.tencent.com/document/api/238/19970)

	* 新增入参：Name, OrderBy, OrderByType

* [DescribeDBs](https://cloud.tencent.com/document/api/238/19968)

	* 新增入参：Name, OrderByType


新增数据结构：

* [SlaveZones](https://cloud.tencent.com/document/api/238/19976#SlaveZones)

修改数据结构：

* [DBInstance](https://cloud.tencent.com/document/api/238/19976#DBInstance)

	* 新增成员：IsDrZone, SlaveZones


### 第 38 次发布

发布时间：2022-11-16 06:36:12

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [ModifyBackupStrategy](https://cloud.tencent.com/document/api/238/46288)

	* 新增入参：RegularBackupEnable, RegularBackupSaveDays, RegularBackupStrategy, RegularBackupCounts, RegularBackupStartTime


### 第 37 次发布

发布时间：2022-09-09 06:39:25

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CloseInterCommunication](https://cloud.tencent.com/document/api/238/80333)
* [CreateBusinessDBInstances](https://cloud.tencent.com/document/api/238/80332)
* [CreateBusinessIntelligenceFile](https://cloud.tencent.com/document/api/238/80331)
* [DeleteBusinessIntelligenceFile](https://cloud.tencent.com/document/api/238/80330)
* [DescribeBusinessIntelligenceFile](https://cloud.tencent.com/document/api/238/80329)
* [DescribeDBInstanceInter](https://cloud.tencent.com/document/api/238/80328)
* [OpenInterCommunication](https://cloud.tencent.com/document/api/238/80327)

新增数据结构：

* [BusinessIntelligenceFile](https://cloud.tencent.com/document/api/238/19976#BusinessIntelligenceFile)
* [FileAction](https://cloud.tencent.com/document/api/238/19976#FileAction)
* [InterInstance](https://cloud.tencent.com/document/api/238/19976#InterInstance)
* [InterInstanceFlow](https://cloud.tencent.com/document/api/238/19976#InterInstanceFlow)

### 第 36 次发布

发布时间：2022-08-11 06:47:08

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateBasicDBInstances](https://cloud.tencent.com/document/api/238/46808)

	* 新增入参：Collation, TimeZone

* [CreateDBInstances](https://cloud.tencent.com/document/api/238/19973)

	* 新增入参：Collation, TimeZone

* [CreateReadOnlyDBInstances](https://cloud.tencent.com/document/api/238/46807)

	* 新增入参：Collation, TimeZone


修改数据结构：

* [DBInstance](https://cloud.tencent.com/document/api/238/19976#DBInstance)

	* 新增成员：Collation, TimeZone


### 第 35 次发布

发布时间：2022-07-29 06:14:07

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [DBInstance](https://cloud.tencent.com/document/api/238/19976#DBInstance)

	* 新增成员：DnsPodDomain, TgwWanVPort


### 第 34 次发布

发布时间：2022-07-18 06:15:30

本次发布包含了以下内容：

改善已有的文档。

新增数据结构：

* [CrossBackupAddr](https://cloud.tencent.com/document/api/238/19976#CrossBackupAddr)
* [CrossRegionStatus](https://cloud.tencent.com/document/api/238/19976#CrossRegionStatus)

修改数据结构：

* [Backup](https://cloud.tencent.com/document/api/238/19976#Backup)

	* 新增成员：Region, CrossBackupAddr, CrossBackupStatus

* [BackupFile](https://cloud.tencent.com/document/api/238/19976#BackupFile)

	* 新增成员：Region, CrossBackupAddr

* [DBInstance](https://cloud.tencent.com/document/api/238/19976#DBInstance)

	* 新增成员：CrossRegions, CrossBackupEnabled, CrossBackupSaveDays


### 第 33 次发布

发布时间：2022-06-07 06:12:09

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [RemoveBackups](https://cloud.tencent.com/document/api/238/46287)

	* 新增入参：StartTime, EndTime

	* <font color="#dd0000">**修改入参**：</font>BackupNames


### 第 32 次发布

发布时间：2022-05-23 06:12:44

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeReadOnlyGroupByReadOnlyInstance](https://cloud.tencent.com/document/api/238/46773)

	* 新增出参：MasterRegionId


修改数据结构：

* [ReadOnlyInstance](https://cloud.tencent.com/document/api/238/19976#ReadOnlyInstance)

	* 新增成员：RegionId, ZoneId


### 第 31 次发布

发布时间：2022-05-20 06:16:38

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [UpgradeDBInstance](https://cloud.tencent.com/document/api/238/19948)

	* 新增入参：WaitSwitch


修改数据结构：

* [AccountCreateInfo](https://cloud.tencent.com/document/api/238/19976#AccountCreateInfo)

	* 新增成员：Authentication

* [AccountDetail](https://cloud.tencent.com/document/api/238/19976#AccountDetail)

	* 新增成员：Authentication, Host


### 第 30 次发布

发布时间：2022-05-19 06:17:03

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [AccountPrivilegeModifyInfo](https://cloud.tencent.com/document/api/238/19976#AccountPrivilegeModifyInfo)

	* 新增成员：IsAdmin


### 第 29 次发布

发布时间：2022-05-09 06:12:52

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeBackupFiles](https://cloud.tencent.com/document/api/238/61561)

	* 新增入参：OrderBy

* [DescribeBackups](https://cloud.tencent.com/document/api/238/19943)

	* 新增入参：Type, BackupFormat

* [DescribeDBInstances](https://cloud.tencent.com/document/api/238/19969)

	* 新增入参：InstanceType

* [ModifyBackupStrategy](https://cloud.tencent.com/document/api/238/46288)

	* 新增入参：BackupCycle, BackupSaveDays


修改数据结构：

* [Backup](https://cloud.tencent.com/document/api/238/19976#Backup)

	* 新增成员：BackupFormat

* [DBInstance](https://cloud.tencent.com/document/api/238/19976#DBInstance)

	* 新增成员：InstanceNote, BackupCycle, BackupCycleType, BackupSaveDays, InstanceType


### 第 28 次发布

发布时间：2022-01-10 08:15:07

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [ModifyDBInstanceNetwork](https://cloud.tencent.com/document/api/238/52347)

	* 新增入参：Vip


### 第 27 次发布

发布时间：2021-09-16 08:09:54

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeBackupFiles](https://cloud.tencent.com/document/api/238/61561)

修改接口：

* [DescribeBackupByFlowId](https://cloud.tencent.com/document/api/238/47203)

	* 新增出参：GroupId

* [DescribeBackups](https://cloud.tencent.com/document/api/238/19943)

	* 新增入参：Group

* [DescribeDBInstances](https://cloud.tencent.com/document/api/238/19969)

	* 新增入参：UidSet

* [ModifyBackupName](https://cloud.tencent.com/document/api/238/47202)

	* 新增入参：GroupId

	* <font color="#dd0000">**修改入参**：</font>BackupId

* [ModifyBackupStrategy](https://cloud.tencent.com/document/api/238/46288)

	* 新增入参：BackupModel

	* <font color="#dd0000">**修改入参**：</font>BackupType, BackupTime, BackupDay

* [RestoreInstance](https://cloud.tencent.com/document/api/238/19950)

	* 新增入参：GroupId


新增数据结构：

* [BackupFile](https://cloud.tencent.com/document/api/238/19976#BackupFile)

修改数据结构：

* [Backup](https://cloud.tencent.com/document/api/238/19976#Backup)

	* 新增成员：GroupId

* [DBInstance](https://cloud.tencent.com/document/api/238/19976#DBInstance)

	* 新增成员：BackupModel


### 第 26 次发布

发布时间：2021-09-02 08:07:01

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [RenewDBInstance](https://cloud.tencent.com/document/api/238/19953)

	* 新增入参：AutoRenewFlag


### 第 25 次发布

发布时间：2021-07-23 08:08:24

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeInstanceParamRecords](https://cloud.tencent.com/document/api/238/59109)
* [DescribeInstanceParams](https://cloud.tencent.com/document/api/238/59108)
* [ModifyInstanceParam](https://cloud.tencent.com/document/api/238/59107)

新增数据结构：

* [ParamRecord](https://cloud.tencent.com/document/api/238/19976#ParamRecord)
* [Parameter](https://cloud.tencent.com/document/api/238/19976#Parameter)
* [ParameterDetail](https://cloud.tencent.com/document/api/238/19976#ParameterDetail)

### 第 24 次发布

发布时间：2021-07-22 08:07:59

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeDBsNormal](https://cloud.tencent.com/document/api/238/59034)
* [ModifyDatabaseCDC](https://cloud.tencent.com/document/api/238/59033)
* [ModifyDatabaseCT](https://cloud.tencent.com/document/api/238/59032)
* [ModifyDatabaseMdf](https://cloud.tencent.com/document/api/238/59031)

新增数据结构：

* [DbNormalDetail](https://cloud.tencent.com/document/api/238/19976#DbNormalDetail)

### 第 23 次发布

发布时间：2021-03-10 08:08:58

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [DBCreateInfo](https://cloud.tencent.com/document/api/238/19976#DBCreateInfo)

	* <font color="#dd0000">**修改成员**：</font>Charset, Accounts, Remark


### 第 22 次发布

发布时间：2021-03-03 08:06:52

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeDBCharsets](https://cloud.tencent.com/document/api/238/53357)

### 第 21 次发布

发布时间：2021-02-26 08:06:55

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateBackupMigration](https://cloud.tencent.com/document/api/238/53193)
* [CreateIncrementalMigration](https://cloud.tencent.com/document/api/238/53192)
* [DeleteBackupMigration](https://cloud.tencent.com/document/api/238/53191)
* [DeleteIncrementalMigration](https://cloud.tencent.com/document/api/238/53190)
* [DescribeBackupCommand](https://cloud.tencent.com/document/api/238/53189)
* [DescribeBackupMigration](https://cloud.tencent.com/document/api/238/53188)
* [DescribeBackupUploadSize](https://cloud.tencent.com/document/api/238/53187)
* [DescribeIncrementalMigration](https://cloud.tencent.com/document/api/238/53186)
* [DescribeUploadBackupInfo](https://cloud.tencent.com/document/api/238/53185)
* [DescribeUploadIncrementalInfo](https://cloud.tencent.com/document/api/238/53184)
* [ModifyBackupMigration](https://cloud.tencent.com/document/api/238/53183)
* [ModifyIncrementalMigration](https://cloud.tencent.com/document/api/238/53182)
* [StartBackupMigration](https://cloud.tencent.com/document/api/238/53181)
* [StartIncrementalMigration](https://cloud.tencent.com/document/api/238/53180)

新增数据结构：

* [CosUploadBackupFile](https://cloud.tencent.com/document/api/238/19976#CosUploadBackupFile)
* [Migration](https://cloud.tencent.com/document/api/238/19976#Migration)
* [MigrationAction](https://cloud.tencent.com/document/api/238/19976#MigrationAction)
* [MigrationDetail](https://cloud.tencent.com/document/api/238/19976#MigrationDetail)
* [MigrationStep](https://cloud.tencent.com/document/api/238/19976#MigrationStep)

### 第 20 次发布

发布时间：2021-01-28 08:06:47

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CloneDB](https://cloud.tencent.com/document/api/238/52563)

### 第 19 次发布

发布时间：2021-01-22 08:06:18

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [ModifyDBInstanceNetwork](https://cloud.tencent.com/document/api/238/52347)

修改接口：

* [CreateBasicDBInstances](https://cloud.tencent.com/document/api/238/46808)

	* 新增入参：ResourceTags

* [CreateDBInstances](https://cloud.tencent.com/document/api/238/19973)

	* 新增入参：ResourceTags

* [CreateReadOnlyDBInstances](https://cloud.tencent.com/document/api/238/46807)

	* 新增入参：ResourceTags

* [DescribeDBInstances](https://cloud.tencent.com/document/api/238/19969)

	* 新增入参：VipSet, InstanceNameSet, VersionSet, Zone, TagKeys, SearchKey

* [UpgradeDBInstance](https://cloud.tencent.com/document/api/238/19948)

	* 新增入参：DBVersion, HAType, MultiZones

	* <font color="#dd0000">**修改入参**：</font>Memory, Storage


新增数据结构：

* [ResourceTag](https://cloud.tencent.com/document/api/238/19976#ResourceTag)

修改数据结构：

* [DBInstance](https://cloud.tencent.com/document/api/238/19976#DBInstance)

	* 新增成员：ResourceTags


### 第 18 次发布

发布时间：2021-01-18 08:06:32

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeBackups](https://cloud.tencent.com/document/api/238/19943)

	* 新增入参：DatabaseName


### 第 17 次发布

发布时间：2020-12-09 08:06:12

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [RecycleReadOnlyGroup](https://cloud.tencent.com/document/api/238/50274)

	* 新增入参：InstanceId, ReadOnlyGroupId


### 第 16 次发布

发布时间：2020-11-25 08:06:07

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [RecycleReadOnlyGroup](https://cloud.tencent.com/document/api/238/50274)

修改接口：

* [DescribeProductConfig](https://cloud.tencent.com/document/api/238/19966)

	* 新增入参：InstanceType


修改数据结构：

* [SpecInfo](https://cloud.tencent.com/document/api/238/19976#SpecInfo)

	* 新增成员：InstanceType, MultiZonesStatus


### 第 15 次发布

发布时间：2020-11-16 08:06:22

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [AccountDetail](https://cloud.tencent.com/document/api/238/19976#AccountDetail)

	* 新增成员：IsAdmin


### 第 14 次发布

发布时间：2020-10-20 08:06:26

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [RecycleDBInstance](https://cloud.tencent.com/document/api/238/49228)

### 第 13 次发布

发布时间：2020-09-08 08:07:23

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [RenameRestoreDatabase](https://cloud.tencent.com/document/api/238/19976#RenameRestoreDatabase)

	* <font color="#dd0000">**修改成员**：</font>OldName, NewName


### 第 12 次发布

发布时间：2020-09-04 08:06:15

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateMigration](https://cloud.tencent.com/document/api/238/19945)

	* 新增入参：RenameRestore

* [DescribeBackups](https://cloud.tencent.com/document/api/238/19943)

	* 新增入参：BackupId

* [RestoreInstance](https://cloud.tencent.com/document/api/238/19950)

	* 新增入参：TargetInstanceId, RenameRestore

* [RollbackInstance](https://cloud.tencent.com/document/api/238/19949)

	* 新增入参：TargetInstanceId, RenameRestore


新增数据结构：

* [RenameRestoreDatabase](https://cloud.tencent.com/document/api/238/19976#RenameRestoreDatabase)

### 第 11 次发布

发布时间：2020-08-11 08:21:16

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CompleteMigration](https://cloud.tencent.com/document/api/238/47330)
* [DescribeMigrationDatabases](https://cloud.tencent.com/document/api/238/47329)
* [QueryMigrationCheckProcess](https://cloud.tencent.com/document/api/238/47328)
* [StartMigrationCheck](https://cloud.tencent.com/document/api/238/47327)
* [StopMigration](https://cloud.tencent.com/document/api/238/47326)

新增数据结构：

* [StepDetail](https://cloud.tencent.com/document/api/238/19976#StepDetail)

### 第 10 次发布

发布时间：2020-08-07 08:17:08

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeBackupByFlowId](https://cloud.tencent.com/document/api/238/47203)
* [DescribeCrossRegionZone](https://cloud.tencent.com/document/api/238/47201)
* [ModifyBackupName](https://cloud.tencent.com/document/api/238/47202)

修改接口：

* [CreateBackup](https://cloud.tencent.com/document/api/238/19946)

	* 新增入参：BackupName

* [DescribeBackups](https://cloud.tencent.com/document/api/238/19943)

	* 新增入参：BackupName, Strategy, BackupWay


### 第 9 次发布

发布时间：2020-08-03 08:18:52

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [Backup](https://cloud.tencent.com/document/api/238/19976#Backup)

	* 新增成员：BackupName


### 第 8 次发布

发布时间：2020-07-24 08:16:28

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [AssociateSecurityGroups](https://cloud.tencent.com/document/api/238/46813)
* [CreateBasicDBInstances](https://cloud.tencent.com/document/api/238/46808)
* [CreateReadOnlyDBInstances](https://cloud.tencent.com/document/api/238/46807)
* [DeleteDBInstance](https://cloud.tencent.com/document/api/238/46806)
* [DescribeDBSecurityGroups](https://cloud.tencent.com/document/api/238/46812)
* [DescribeProjectSecurityGroups](https://cloud.tencent.com/document/api/238/46811)
* [DisassociateSecurityGroups](https://cloud.tencent.com/document/api/238/46810)
* [ModifyDBInstanceSecurityGroups](https://cloud.tencent.com/document/api/238/46809)
* [RenewPostpaidDBInstance](https://cloud.tencent.com/document/api/238/46805)

新增数据结构：

* [SecurityGroup](https://cloud.tencent.com/document/api/238/19976#SecurityGroup)
* [SecurityGroupPolicy](https://cloud.tencent.com/document/api/238/19976#SecurityGroupPolicy)

### 第 7 次发布

发布时间：2020-07-23 08:16:29

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeReadOnlyGroupByReadOnlyInstance](https://cloud.tencent.com/document/api/238/46773)
* [DescribeReadOnlyGroupDetails](https://cloud.tencent.com/document/api/238/46772)
* [DescribeReadOnlyGroupList](https://cloud.tencent.com/document/api/238/46771)
* [ModifyReadOnlyGroupDetails](https://cloud.tencent.com/document/api/238/46774)

新增数据结构：

* [ReadOnlyGroup](https://cloud.tencent.com/document/api/238/19976#ReadOnlyGroup)
* [ReadOnlyInstance](https://cloud.tencent.com/document/api/238/19976#ReadOnlyInstance)
* [ReadOnlyInstanceWeightPair](https://cloud.tencent.com/document/api/238/19976#ReadOnlyInstanceWeightPair)

### 第 6 次发布

发布时间：2020-07-14 08:16:33

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CompleteExpansion](https://cloud.tencent.com/document/api/238/46286)
* [CreatePublishSubscribe](https://cloud.tencent.com/document/api/238/46285)
* [DeletePublishSubscribe](https://cloud.tencent.com/document/api/238/46284)
* [DescribeMaintenanceSpan](https://cloud.tencent.com/document/api/238/46283)
* [DescribePublishSubscribe](https://cloud.tencent.com/document/api/238/46282)
* [ModifyBackupStrategy](https://cloud.tencent.com/document/api/238/46288)
* [ModifyMaintenanceSpan](https://cloud.tencent.com/document/api/238/46281)
* [ModifyPublishSubscribeName](https://cloud.tencent.com/document/api/238/46280)
* [RemoveBackups](https://cloud.tencent.com/document/api/238/46287)

修改接口：

* [CreateDBInstances](https://cloud.tencent.com/document/api/238/19973)

	* 新增入参：SecurityGroupList, Weekly, StartTime, Span, HAType, MultiZones

* [InquiryPriceCreateDBInstances](https://cloud.tencent.com/document/api/238/19962)

	* 新增入参：Cpu, InstanceType, MachineType

* [InquiryPriceUpgradeDBInstance](https://cloud.tencent.com/document/api/238/19960)

	* 新增入参：Cpu

* [UpgradeDBInstance](https://cloud.tencent.com/document/api/238/19948)

	* 新增入参：Cpu


新增数据结构：

* [DatabaseTuple](https://cloud.tencent.com/document/api/238/19976#DatabaseTuple)
* [DatabaseTupleStatus](https://cloud.tencent.com/document/api/238/19976#DatabaseTupleStatus)
* [PublishSubscribe](https://cloud.tencent.com/document/api/238/19976#PublishSubscribe)

修改数据结构：

* [DBInstance](https://cloud.tencent.com/document/api/238/19976#DBInstance)

	* 新增成员：IsolateOperator, SubFlag, ROFlag, HAFlag


### 第 5 次发布

发布时间：2020-03-20 08:12:59

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateDBInstances](https://cloud.tencent.com/document/api/238/19973)

	* 新增入参：AutoRenewFlag

	* 新增出参：DealNames

* [DescribeDBInstances](https://cloud.tencent.com/document/api/238/19969)

	* 新增入参：VpcId, SubnetId


### 第 4 次发布

发布时间：2020-03-19 08:13:10

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [DBInstance](https://cloud.tencent.com/document/api/238/19976#DBInstance)

	* 新增成员：UniqVpcId, UniqSubnetId


### 第 3 次发布

发布时间：2020-02-27 15:55:57

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [AccountCreateInfo](https://cloud.tencent.com/document/api/238/19976#AccountCreateInfo)

	* 新增成员：IsAdmin


### 第 2 次发布

发布时间：2019-09-26 22:17:31

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [TerminateDBInstance](https://cloud.tencent.com/document/api/238/38210)

修改接口：

* [DescribeAccounts](https://cloud.tencent.com/document/api/238/19970)

	* 新增出参：TotalCount

* [DescribeDBInstances](https://cloud.tencent.com/document/api/238/19969)

	* 新增入参：PayMode


修改数据结构：

* [DBInstance](https://cloud.tencent.com/document/api/238/19976#DBInstance)

	* 新增成员：PayMode, Uid, Cpu, Version, Type, Pid

* [DealInfo](https://cloud.tencent.com/document/api/238/19976#DealInfo)

	* 新增成员：InstanceChargeType

* [SlowlogInfo](https://cloud.tencent.com/document/api/238/19976#SlowlogInfo)

	* 新增成员：Status

* [SpecInfo](https://cloud.tencent.com/document/api/238/19976#SpecInfo)

	* 新增成员：PostPid, PayModeStatus


### 第 1 次发布

发布时间：2018-09-20 19:43:37

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateAccount](https://cloud.tencent.com/document/api/238/19975)
* [CreateBackup](https://cloud.tencent.com/document/api/238/19946)
* [CreateDB](https://cloud.tencent.com/document/api/238/19974)
* [CreateDBInstances](https://cloud.tencent.com/document/api/238/19973)
* [CreateMigration](https://cloud.tencent.com/document/api/238/19945)
* [DeleteAccount](https://cloud.tencent.com/document/api/238/19972)
* [DeleteDB](https://cloud.tencent.com/document/api/238/19971)
* [DeleteMigration](https://cloud.tencent.com/document/api/238/19944)
* [DescribeAccounts](https://cloud.tencent.com/document/api/238/19970)
* [DescribeBackups](https://cloud.tencent.com/document/api/238/19943)
* [DescribeDBInstances](https://cloud.tencent.com/document/api/238/19969)
* [DescribeDBs](https://cloud.tencent.com/document/api/238/19968)
* [DescribeFlowStatus](https://cloud.tencent.com/document/api/238/19967)
* [DescribeMigrationDetail](https://cloud.tencent.com/document/api/238/19942)
* [DescribeMigrations](https://cloud.tencent.com/document/api/238/19941)
* [DescribeOrders](https://cloud.tencent.com/document/api/238/19937)
* [DescribeProductConfig](https://cloud.tencent.com/document/api/238/19966)
* [DescribeRegions](https://cloud.tencent.com/document/api/238/19965)
* [DescribeRollbackTime](https://cloud.tencent.com/document/api/238/19964)
* [DescribeSlowlogs](https://cloud.tencent.com/document/api/238/19936)
* [DescribeZones](https://cloud.tencent.com/document/api/238/19963)
* [InquiryPriceCreateDBInstances](https://cloud.tencent.com/document/api/238/19962)
* [InquiryPriceRenewDBInstance](https://cloud.tencent.com/document/api/238/19961)
* [InquiryPriceUpgradeDBInstance](https://cloud.tencent.com/document/api/238/19960)
* [ModifyAccountPrivilege](https://cloud.tencent.com/document/api/238/19959)
* [ModifyAccountRemark](https://cloud.tencent.com/document/api/238/19935)
* [ModifyDBInstanceName](https://cloud.tencent.com/document/api/238/19958)
* [ModifyDBInstanceProject](https://cloud.tencent.com/document/api/238/19957)
* [ModifyDBInstanceRenewFlag](https://cloud.tencent.com/document/api/238/19956)
* [ModifyDBName](https://cloud.tencent.com/document/api/238/19955)
* [ModifyDBRemark](https://cloud.tencent.com/document/api/238/19954)
* [ModifyMigration](https://cloud.tencent.com/document/api/238/19940)
* [RenewDBInstance](https://cloud.tencent.com/document/api/238/19953)
* [ResetAccountPassword](https://cloud.tencent.com/document/api/238/19952)
* [RestartDBInstance](https://cloud.tencent.com/document/api/238/19951)
* [RestoreInstance](https://cloud.tencent.com/document/api/238/19950)
* [RollbackInstance](https://cloud.tencent.com/document/api/238/19949)
* [RunMigration](https://cloud.tencent.com/document/api/238/19939)
* [UpgradeDBInstance](https://cloud.tencent.com/document/api/238/19948)

新增数据结构：

* [AccountCreateInfo](https://cloud.tencent.com/document/api/238/19976#AccountCreateInfo)
* [AccountDetail](https://cloud.tencent.com/document/api/238/19976#AccountDetail)
* [AccountPassword](https://cloud.tencent.com/document/api/238/19976#AccountPassword)
* [AccountPrivilege](https://cloud.tencent.com/document/api/238/19976#AccountPrivilege)
* [AccountPrivilegeModifyInfo](https://cloud.tencent.com/document/api/238/19976#AccountPrivilegeModifyInfo)
* [AccountRemark](https://cloud.tencent.com/document/api/238/19976#AccountRemark)
* [Backup](https://cloud.tencent.com/document/api/238/19976#Backup)
* [DBCreateInfo](https://cloud.tencent.com/document/api/238/19976#DBCreateInfo)
* [DBDetail](https://cloud.tencent.com/document/api/238/19976#DBDetail)
* [DBInstance](https://cloud.tencent.com/document/api/238/19976#DBInstance)
* [DBPrivilege](https://cloud.tencent.com/document/api/238/19976#DBPrivilege)
* [DBPrivilegeModifyInfo](https://cloud.tencent.com/document/api/238/19976#DBPrivilegeModifyInfo)
* [DBRemark](https://cloud.tencent.com/document/api/238/19976#DBRemark)
* [DbRollbackTimeInfo](https://cloud.tencent.com/document/api/238/19976#DbRollbackTimeInfo)
* [DealInfo](https://cloud.tencent.com/document/api/238/19976#DealInfo)
* [InstanceDBDetail](https://cloud.tencent.com/document/api/238/19976#InstanceDBDetail)
* [InstanceRenewInfo](https://cloud.tencent.com/document/api/238/19976#InstanceRenewInfo)
* [MigrateDB](https://cloud.tencent.com/document/api/238/19976#MigrateDB)
* [MigrateDetail](https://cloud.tencent.com/document/api/238/19976#MigrateDetail)
* [MigrateSource](https://cloud.tencent.com/document/api/238/19976#MigrateSource)
* [MigrateTarget](https://cloud.tencent.com/document/api/238/19976#MigrateTarget)
* [MigrateTask](https://cloud.tencent.com/document/api/238/19976#MigrateTask)
* [RegionInfo](https://cloud.tencent.com/document/api/238/19976#RegionInfo)
* [SlowlogInfo](https://cloud.tencent.com/document/api/238/19976#SlowlogInfo)
* [SpecInfo](https://cloud.tencent.com/document/api/238/19976#SpecInfo)
* [ZoneInfo](https://cloud.tencent.com/document/api/238/19976#ZoneInfo)




## 安全运营中心(ssa) 版本：2018-06-08

### 第 21 次发布

发布时间：2023-11-15 02:18:28

本次发布包含了以下内容：

改善已有的文档。

<font color="#dd0000">**删除接口**：</font>

* DescribeAssetsMappingList
* DescribeSafetyEventList
* SaDivulgeDataQueryPub

<font color="#dd0000">**删除数据结构**：</font>

* DataAssetMapping
* DataEvent
* SaDivulgeDataQueryPub
* SaDivulgeDataQueryPubList

### 第 20 次发布

发布时间：2023-09-15 02:24:19

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [SaDivulgeScanRuleMutate](https://cloud.tencent.com/document/api/664/98526)

新增数据结构：

* [SaDivulgeScanRuleSetList](https://cloud.tencent.com/document/api/664/51406#SaDivulgeScanRuleSetList)

### 第 19 次发布

发布时间：2023-09-12 02:29:07

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeAlarmStat](https://cloud.tencent.com/document/api/664/97936)

新增数据结构：

* [AlarmInfoRsp](https://cloud.tencent.com/document/api/664/51406#AlarmInfoRsp)
* [AttackEvent](https://cloud.tencent.com/document/api/664/51406#AttackEvent)

### 第 18 次发布

发布时间：2023-07-26 01:34:12

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [ConcernInfo](https://cloud.tencent.com/document/api/664/51406#ConcernInfo)

	* <font color="#dd0000">**修改成员**：</font>IpCountry, IpProvince, Result, Confidence, IpIsp, IpInfrastructure, ThreatType, Groups, Status, Tags, VictimAssetType, VictimAssetName, DomainRegistrant, DomainRegisteredInstitution, DomainRegistrationTime, FileName, FileMd5, VirusName, FilePath, FileSize, ProcName, Pid, ProcPath, ProcUser, DefendedCount, DetectedCount


### 第 17 次发布

发布时间：2023-06-14 01:38:59

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [DomainInfo](https://cloud.tencent.com/document/api/664/51406#DomainInfo)

	* 新增成员：NetworkRisk, NetworkAttack, BotVisit, NetworkAccess, CreateTime, WafStatus, LastScanTime, AssetId, AssetName, SourceType, IsNotCore, IsCloud


### 第 16 次发布

发布时间：2023-06-13 01:37:42

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeDomainList](https://cloud.tencent.com/document/api/664/93451)

新增数据结构：

* [DomainInfo](https://cloud.tencent.com/document/api/664/51406#DomainInfo)
* [QueryFilterV3](https://cloud.tencent.com/document/api/664/51406#QueryFilterV3)

### 第 15 次发布

发布时间：2023-05-08 01:50:08

本次发布包含了以下内容：

改善已有的文档。

新增数据结构：

* [AlertListAggregations](https://cloud.tencent.com/document/api/664/51406#AlertListAggregations)

修改数据结构：

* [AlertListData](https://cloud.tencent.com/document/api/664/51406#AlertListData)

	* 新增成员：Aggregations

* [AlertType](https://cloud.tencent.com/document/api/664/51406#AlertType)

	* 新增成员：VictimAssetVpc, Timestamp, AssetGroupName, AssetProjectName, VictimAssetContent, WrongReportStatus, WrongReportConditionId

* [AssetDetail](https://cloud.tencent.com/document/api/664/51406#AssetDetail)

	* 新增成员：AssetEventNum, AssetCspmRiskNum, SsaAssetDeleteTime, ChargeType, AssetRegionName, AssetVpcid

* [ConcernInfo](https://cloud.tencent.com/document/api/664/51406#ConcernInfo)

	* 新增成员：IpCountry, IpProvince, Result, Confidence, IpIsp, IpInfrastructure, ThreatType, Groups, Status, Tags, VictimAssetType, VictimAssetName, DomainRegistrant, DomainRegisteredInstitution, DomainRegistrationTime, FileName, FileMd5, VirusName, FilePath, FileSize, ProcName, Pid, ProcPath, ProcUser, DefendedCount, DetectedCount

* [MappingResult](https://cloud.tencent.com/document/api/664/51406#MappingResult)

	* 新增成员：DisposalRecommendation, MappingType

* [Tag](https://cloud.tencent.com/document/api/664/51406#Tag)

	* <font color="#dd0000">**修改成员**：</font>Fid, Fname


### 第 14 次发布

发布时间：2023-02-17 05:08:17

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [SaEventPub](https://cloud.tencent.com/document/api/#/#)

新增数据结构：

* [ListDataSaEventPub](https://cloud.tencent.com/document/api/664/51406#ListDataSaEventPub)
* [ObjDataSaEventPub](https://cloud.tencent.com/document/api/664/51406#ObjDataSaEventPub)

### 第 13 次发布

发布时间：2023-01-05 01:39:20

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeAssetDetailList](https://cloud.tencent.com/document/api/664/85146)

### 第 12 次发布

发布时间：2022-07-25 06:13:43

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [QueryFilter](https://cloud.tencent.com/document/api/664/51406#QueryFilter)

	* <font color="#dd0000">**修改成员**：</font>FilterKey, FilterOperatorType, FilterValue


### 第 11 次发布

发布时间：2022-04-18 06:17:42

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeSocCheckResultList](https://cloud.tencent.com/document/api/664/72634)

新增数据结构：

* [DescribeSocCheckResultListRspRsp](https://cloud.tencent.com/document/api/664/51406#DescribeSocCheckResultListRspRsp)
* [SocCheckResult](https://cloud.tencent.com/document/api/664/51406#SocCheckResult)

### 第 10 次发布

发布时间：2022-04-14 06:16:47

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeSocCheckItemList](https://cloud.tencent.com/document/api/664/72477)

	* 新增入参：Filter, Sorter, PageSize, PageIndex

	* 新增出参：Data


新增数据结构：

* [DescribeSocCheckItemListRspRsp](https://cloud.tencent.com/document/api/664/51406#DescribeSocCheckItemListRspRsp)
* [SocCheckItemV1](https://cloud.tencent.com/document/api/664/51406#SocCheckItemV1)

### 第 9 次发布

发布时间：2022-04-13 07:07:25

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeSocCheckItemList](https://cloud.tencent.com/document/api/664/72477)

### 第 8 次发布

发布时间：2022-04-11 06:16:51

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeMappingResults](https://cloud.tencent.com/document/api/664/72341)

新增数据结构：

* [AssetQueryFilter](https://cloud.tencent.com/document/api/664/51406#AssetQueryFilter)
* [AssetTypeStatistic](https://cloud.tencent.com/document/api/664/51406#AssetTypeStatistic)
* [MappingResult](https://cloud.tencent.com/document/api/664/51406#MappingResult)
* [Results](https://cloud.tencent.com/document/api/664/51406#Results)
* [SecurityStatus](https://cloud.tencent.com/document/api/664/51406#SecurityStatus)

### 第 7 次发布

发布时间：2022-04-01 06:13:54

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeSocAlertList](https://cloud.tencent.com/document/api/664/64446)

	* 新增入参：ExportFlag

* [DescribeVulDetail](https://cloud.tencent.com/document/api/664/51980)

	* 新增出参：VulPath


修改数据结构：

* [ConcernInfo](https://cloud.tencent.com/document/api/664/51406#ConcernInfo)

	* 新增成员：SearchData, IpCountryIso, IpProvinceIso, IpCity, EventSubType

* [VulItem](https://cloud.tencent.com/document/api/664/51406#VulItem)

	* 新增成员：VulPath


### 第 6 次发布

发布时间：2021-11-22 08:10:13

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeSocAlertDetails](https://cloud.tencent.com/document/api/664/64537)

新增数据结构：

* [AlertDetail](https://cloud.tencent.com/document/api/664/51406#AlertDetail)

### 第 5 次发布

发布时间：2021-11-19 08:14:18

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeSocAlertList](https://cloud.tencent.com/document/api/664/64446)

新增数据结构：

* [AlertListData](https://cloud.tencent.com/document/api/664/51406#AlertListData)
* [AlertType](https://cloud.tencent.com/document/api/664/51406#AlertType)
* [ConcernInfo](https://cloud.tencent.com/document/api/664/51406#ConcernInfo)
* [QueryFilter](https://cloud.tencent.com/document/api/664/51406#QueryFilter)
* [QuerySort](https://cloud.tencent.com/document/api/664/51406#QuerySort)

### 第 4 次发布

发布时间：2021-08-16 08:01:05

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [DataEvent](https://cloud.tencent.com/document/api/664/51406#DataEvent)

	* 新增成员：IsNewCfwEvent, Direction


### 第 3 次发布

发布时间：2021-08-12 08:01:33

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeSocCspmCompliance](https://cloud.tencent.com/document/api/664/60183)

新增数据结构：

* [SocCheckItem](https://cloud.tencent.com/document/api/664/51406#SocCheckItem)
* [SocComplianceInfoResp](https://cloud.tencent.com/document/api/664/51406#SocComplianceInfoResp)
* [SocComplianceItem](https://cloud.tencent.com/document/api/664/51406#SocComplianceItem)
* [SocProductionItem](https://cloud.tencent.com/document/api/664/51406#SocProductionItem)

### 第 2 次发布

发布时间：2021-01-14 08:00:06

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeComplianceAssetList](https://cloud.tencent.com/document/api/664/51981)
* [DescribeVulDetail](https://cloud.tencent.com/document/api/664/51980)

修改数据结构：

* [CheckAssetItem](https://cloud.tencent.com/document/api/664/51406#CheckAssetItem)

	* 新增成员：Remarks

* [DataCheck](https://cloud.tencent.com/document/api/664/51406#DataCheck)

	* 新增成员：Remarks

* [DataCompliance](https://cloud.tencent.com/document/api/664/51406#DataCompliance)

	* 新增成员：Remarks


### 第 1 次发布

发布时间：2020-12-23 14:34:45

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeAssetDetail](https://cloud.tencent.com/document/api/664/51404)
* [DescribeAssetList](https://cloud.tencent.com/document/api/664/51403)
* [DescribeAssetsMappingList](https://cloud.tencent.com/document/api/664/51401)
* [DescribeCheckConfigAssetList](https://cloud.tencent.com/document/api/664/51400)
* [DescribeCheckConfigDetail](https://cloud.tencent.com/document/api/664/51399)
* [DescribeComplianceDetail](https://cloud.tencent.com/document/api/664/51398)
* [DescribeComplianceList](https://cloud.tencent.com/document/api/664/51397)
* [DescribeConfigList](https://cloud.tencent.com/document/api/664/51396)
* [DescribeEventDetail](https://cloud.tencent.com/document/api/664/51395)
* [DescribeLeakDetectionList](https://cloud.tencent.com/document/api/664/51387)
* [DescribeVulList](https://cloud.tencent.com/document/api/664/51392)
* [SaDivulgeDataQueryPub](https://cloud.tencent.com/document/api/664/51384)

新增数据结构：

* [AggregationObj](https://cloud.tencent.com/document/api/664/51406#AggregationObj)
* [Asset](https://cloud.tencent.com/document/api/664/51406#Asset)
* [AssetDetail](https://cloud.tencent.com/document/api/664/51406#AssetDetail)
* [AssetList](https://cloud.tencent.com/document/api/664/51406#AssetList)
* [Bucket](https://cloud.tencent.com/document/api/664/51406#Bucket)
* [CheckAssetItem](https://cloud.tencent.com/document/api/664/51406#CheckAssetItem)
* [CheckConfigDetail](https://cloud.tencent.com/document/api/664/51406#CheckConfigDetail)
* [ComplianceCheckDetail](https://cloud.tencent.com/document/api/664/51406#ComplianceCheckDetail)
* [DataAssetMapping](https://cloud.tencent.com/document/api/664/51406#DataAssetMapping)
* [DataCheck](https://cloud.tencent.com/document/api/664/51406#DataCheck)
* [DataCompliance](https://cloud.tencent.com/document/api/664/51406#DataCompliance)
* [DataEvent](https://cloud.tencent.com/document/api/664/51406#DataEvent)
* [Filter](https://cloud.tencent.com/document/api/664/51406#Filter)
* [SaDivulgeDataQueryPub](https://cloud.tencent.com/document/api/664/51406#SaDivulgeDataQueryPub)
* [SaDivulgeDataQueryPubList](https://cloud.tencent.com/document/api/664/51406#SaDivulgeDataQueryPubList)
* [Tag](https://cloud.tencent.com/document/api/664/51406#Tag)
* [VulItem](https://cloud.tencent.com/document/api/664/51406#VulItem)
* [VulList](https://cloud.tencent.com/document/api/664/51406#VulList)




## SSL 证书(ssl) 版本：2019-12-05

### 第 63 次发布

发布时间：2024-07-05 01:16:31

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [ClbListenerRule](https://cloud.tencent.com/document/api/400/41679#ClbListenerRule)

	* 新增成员：Url

* [DeployRecordDetail](https://cloud.tencent.com/document/api/400/41679#DeployRecordDetail)

	* 新增成员：Url

* [UpdateRecordDetail](https://cloud.tencent.com/document/api/400/41679#UpdateRecordDetail)

	* 新增成员：Url


### 第 62 次发布

发布时间：2024-07-02 01:22:32

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeManagerDetail](https://cloud.tencent.com/document/api/400/52673)


修改数据结构：

* [ManagerStatusInfo](https://cloud.tencent.com/document/api/400/41679#ManagerStatusInfo)

	* 新增成员：Type, Status, CreateTime, ExpireTime


### 第 61 次发布

发布时间：2024-07-01 01:22:30

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [BindResourceRegionResult](https://cloud.tencent.com/document/api/400/41679#BindResourceRegionResult)

	* 新增成员：Error


### 第 60 次发布

发布时间：2024-06-28 01:18:28

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DeleteCertificates](https://cloud.tencent.com/document/api/400/107800)

新增数据结构：

* [BatchDeleteFail](https://cloud.tencent.com/document/api/400/41679#BatchDeleteFail)

### 第 59 次发布

发布时间：2024-06-27 01:18:46

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeCertificateBindResourceTaskDetail](https://cloud.tencent.com/document/api/400/97758)

	* 新增出参：COS


新增数据结构：

* [COSInstanceList](https://cloud.tencent.com/document/api/400/41679#COSInstanceList)

修改数据结构：

* [ApiGatewayInstanceList](https://cloud.tencent.com/document/api/400/41679#ApiGatewayInstanceList)

	* 新增成员：Error

* [CdnInstanceList](https://cloud.tencent.com/document/api/400/41679#CdnInstanceList)

	* 新增成员：Error

* [ClbInstanceList](https://cloud.tencent.com/document/api/400/41679#ClbInstanceList)

	* 新增成员：Error

* [ClbListenerRule](https://cloud.tencent.com/document/api/400/41679#ClbListenerRule)

	* <font color="#dd0000">**修改成员**：</font>NoMatchDomains

* [DdosInstanceList](https://cloud.tencent.com/document/api/400/41679#DdosInstanceList)

	* 新增成员：Error

* [LiveInstanceList](https://cloud.tencent.com/document/api/400/41679#LiveInstanceList)

	* 新增成员：Error

* [TCBInstanceList](https://cloud.tencent.com/document/api/400/41679#TCBInstanceList)

	* 新增成员：Error

* [TSEInstanceList](https://cloud.tencent.com/document/api/400/41679#TSEInstanceList)

	* 新增成员：Error

* [TeoInstanceList](https://cloud.tencent.com/document/api/400/41679#TeoInstanceList)

	* 新增成员：Error

* [TkeInstanceList](https://cloud.tencent.com/document/api/400/41679#TkeInstanceList)

	* 新增成员：Error

* [VODInstanceList](https://cloud.tencent.com/document/api/400/41679#VODInstanceList)

	* 新增成员：Error

* [WafInstanceList](https://cloud.tencent.com/document/api/400/41679#WafInstanceList)

	* 新增成员：Error


### 第 58 次发布

发布时间：2024-05-13 01:26:12

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeDownloadCertificateUrl](https://cloud.tencent.com/document/api/400/106083)

### 第 57 次发布

发布时间：2024-04-23 01:23:47

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeHostCosInstanceList](https://cloud.tencent.com/document/api/400/91661)

	* 新增入参：OldCertificateId, Offset, Limit, AsyncCache

	* <font color="#dd0000">**修改入参**：</font>CertificateId, ResourceType


### 第 56 次发布

发布时间：2024-04-22 01:24:18

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeDeleteCertificatesTaskResult](https://cloud.tencent.com/document/api/400/105464)

新增数据结构：

* [DeleteTaskResult](https://cloud.tencent.com/document/api/400/41679#DeleteTaskResult)

### 第 55 次发布

发布时间：2024-04-09 01:21:02

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DeployCertificateInstance](https://cloud.tencent.com/document/api/400/91667)

	* 新增入参：IsCache


### 第 54 次发布

发布时间：2024-02-02 01:20:24

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [ApplyCertificate](https://cloud.tencent.com/document/api/400/41678)

	* 新增入参：DnsNames


### 第 53 次发布

发布时间：2024-01-29 01:19:48

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DeleteCertificate](https://cloud.tencent.com/document/api/400/41675)

	* 新增入参：IsCheckResource

	* 新增出参：TaskId


### 第 52 次发布

发布时间：2024-01-19 01:19:47

本次发布包含了以下内容：

改善已有的文档。

<font color="#dd0000">**删除接口**：</font>

* HostCertificate

<font color="#dd0000">**删除数据结构**：</font>

* CertHostingInfo

### 第 51 次发布

发布时间：2023-12-20 02:05:02

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [OperationLog](https://cloud.tencent.com/document/api/400/41679#OperationLog)

	* 新增成员：Uin, SubAccountUin, CertId, Type


### 第 50 次发布

发布时间：2023-12-15 20:14:50

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeCertificates](https://cloud.tencent.com/document/api/400/41671)

	* 新增入参：Tags, IsPendingIssue


### 第 49 次发布

发布时间：2023-11-30 05:53:04

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [UpdateCertificateInstance](https://cloud.tencent.com/document/api/400/91649)

	* 新增出参：UpdateSyncProgress


新增数据结构：

* [SupportDownloadType](https://cloud.tencent.com/document/api/400/41679#SupportDownloadType)
* [UpdateSyncProgress](https://cloud.tencent.com/document/api/400/41679#UpdateSyncProgress)
* [UpdateSyncProgressRegion](https://cloud.tencent.com/document/api/400/41679#UpdateSyncProgressRegion)

修改数据结构：

* [Certificates](https://cloud.tencent.com/document/api/400/41679#Certificates)

	* 新增成员：IsDNSPODResolve, IsPackage, KeyPasswordCustomFlag, SupportDownloadType


### 第 48 次发布

发布时间：2023-11-24 01:22:20

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [CertificateExtra](https://cloud.tencent.com/document/api/400/41679#CertificateExtra)

	* 新增成员：CompanyType

	* <font color="#dd0000">**修改成员**：</font>SMCert

* [Certificates](https://cloud.tencent.com/document/api/400/41679#Certificates)

	* 新增成员：HasRenewOrder, ReplaceOriCertIsDelete, IsExpiring, DVAuthDeadline, ValidationPassedTime, CertSANs, AwaitingValidationMsg, AllowDownload


### 第 47 次发布

发布时间：2023-10-23 00:18:24

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeCertificateBindResourceTaskDetail](https://cloud.tencent.com/document/api/400/97758)

	* 新增出参：TSE


新增数据结构：

* [GatewayCertificate](https://cloud.tencent.com/document/api/400/41679#GatewayCertificate)
* [TSEInstanceDetail](https://cloud.tencent.com/document/api/400/41679#TSEInstanceDetail)
* [TSEInstanceList](https://cloud.tencent.com/document/api/400/41679#TSEInstanceList)

### 第 46 次发布

发布时间：2023-10-10 01:50:30

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [UpdateCertificateInstance](https://cloud.tencent.com/document/api/400/91649)

	* 新增入参：CertificatePublicKey, CertificatePrivateKey, ExpiringNotificationSwitch, Repeatable, AllowDownload, Tags, ProjectId

	* <font color="#dd0000">**修改入参**：</font>CertificateId


### 第 45 次发布

发布时间：2023-10-09 01:22:23

本次发布包含了以下内容：

改善已有的文档。

<font color="#dd0000">**预下线接口**：</font>

* HostCertificate

### 第 44 次发布

发布时间：2023-09-15 02:24:49

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CancelAuditCertificate](https://cloud.tencent.com/document/api/400/98528)
* [ModifyCertificateResubmit](https://cloud.tencent.com/document/api/400/98527)

### 第 43 次发布

发布时间：2023-09-12 02:29:39

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeHostTeoInstanceList](https://cloud.tencent.com/document/api/400/91655)

	* 新增入参：Offset, Limit, AsyncCache


修改数据结构：

* [Certificates](https://cloud.tencent.com/document/api/400/41679#Certificates)

	* 新增成员：HostingStatus, HostingCompleteTime, HostingRenewCertId


### 第 42 次发布

发布时间：2023-09-05 06:45:12

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateCertificateBindResourceSyncTask](https://cloud.tencent.com/document/api/400/97759)
* [DescribeCertificateBindResourceTaskDetail](https://cloud.tencent.com/document/api/400/97758)
* [DescribeCertificateBindResourceTaskResult](https://cloud.tencent.com/document/api/400/97757)

新增数据结构：

* [ApiGatewayInstanceList](https://cloud.tencent.com/document/api/400/41679#ApiGatewayInstanceList)
* [BindResourceRegionResult](https://cloud.tencent.com/document/api/400/41679#BindResourceRegionResult)
* [BindResourceResult](https://cloud.tencent.com/document/api/400/41679#BindResourceResult)
* [CdnInstanceList](https://cloud.tencent.com/document/api/400/41679#CdnInstanceList)
* [CertTaskId](https://cloud.tencent.com/document/api/400/41679#CertTaskId)
* [ClbInstanceList](https://cloud.tencent.com/document/api/400/41679#ClbInstanceList)
* [DdosInstanceList](https://cloud.tencent.com/document/api/400/41679#DdosInstanceList)
* [Error](https://cloud.tencent.com/document/api/400/41679#Error)
* [LiveInstanceList](https://cloud.tencent.com/document/api/400/41679#LiveInstanceList)
* [SyncTaskBindResourceResult](https://cloud.tencent.com/document/api/400/41679#SyncTaskBindResourceResult)
* [TCBAccessInstance](https://cloud.tencent.com/document/api/400/41679#TCBAccessInstance)
* [TCBAccessService](https://cloud.tencent.com/document/api/400/41679#TCBAccessService)
* [TCBEnvironment](https://cloud.tencent.com/document/api/400/41679#TCBEnvironment)
* [TCBEnvironments](https://cloud.tencent.com/document/api/400/41679#TCBEnvironments)
* [TCBHostInstance](https://cloud.tencent.com/document/api/400/41679#TCBHostInstance)
* [TCBHostService](https://cloud.tencent.com/document/api/400/41679#TCBHostService)
* [TCBInstanceList](https://cloud.tencent.com/document/api/400/41679#TCBInstanceList)
* [TeoInstanceList](https://cloud.tencent.com/document/api/400/41679#TeoInstanceList)
* [TkeInstanceList](https://cloud.tencent.com/document/api/400/41679#TkeInstanceList)
* [VODInstanceList](https://cloud.tencent.com/document/api/400/41679#VODInstanceList)
* [WafInstanceDetail](https://cloud.tencent.com/document/api/400/41679#WafInstanceDetail)
* [WafInstanceList](https://cloud.tencent.com/document/api/400/41679#WafInstanceList)

### 第 41 次发布

发布时间：2023-08-30 01:21:56

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [CdnInstanceDetail](https://cloud.tencent.com/document/api/400/41679#CdnInstanceDetail)

	* 新增成员：HttpsBillingSwitch

* [Certificate](https://cloud.tencent.com/document/api/400/41679#Certificate)

	* 新增成员：CertCaId, SSLMode

* [TkeInstanceDetail](https://cloud.tencent.com/document/api/400/41679#TkeInstanceDetail)

	* 新增成员：ClusterType, ClusterVersion


### 第 40 次发布

发布时间：2023-08-16 01:40:52

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [ReplaceCertificate](https://cloud.tencent.com/document/api/400/41667)

	* 新增入参：CertCSREncryptAlgo, CertCSRKeyParameter


### 第 39 次发布

发布时间：2023-08-09 01:45:30

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeCertificates](https://cloud.tencent.com/document/api/400/41671)

	* 新增入参：Hostable

* [UpdateCertificateInstance](https://cloud.tencent.com/document/api/400/91649)

* [UploadCertificate](https://cloud.tencent.com/document/api/400/41665)

	* 新增入参：Tags


修改数据结构：

* [DeployRecordDetail](https://cloud.tencent.com/document/api/400/41679#DeployRecordDetail)

	* 新增成员：EnvId, TCBType, Region

	* <font color="#dd0000">**修改成员**：</font>Port

* [UpdateRecordDetail](https://cloud.tencent.com/document/api/400/41679#UpdateRecordDetail)

	* 新增成员：EnvId, TCBType

	* <font color="#dd0000">**修改成员**：</font>Port, Namespace, SecretName


### 第 38 次发布

发布时间：2023-07-17 01:34:11

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeCertificate](https://cloud.tencent.com/document/api/400/41674)

	* 新增出参：DvRevokeAuthDetail

* [DescribeCertificateDetail](https://cloud.tencent.com/document/api/400/41673)

	* 新增出参：DvRevokeAuthDetail


### 第 37 次发布

发布时间：2023-06-13 01:37:56

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeHostUpdateRecordDetail](https://cloud.tencent.com/document/api/400/91652)

	* 新增入参：Limit, Offset


修改数据结构：

* [UpdateRecordDetail](https://cloud.tencent.com/document/api/400/41679#UpdateRecordDetail)

	* 新增成员：Port, Namespace, SecretName

* [UpdateRecordDetails](https://cloud.tencent.com/document/api/400/41679#UpdateRecordDetails)

	* 新增成员：TotalCount


### 第 36 次发布

发布时间：2023-06-12 01:35:30

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeHostCdnInstanceList](https://cloud.tencent.com/document/api/400/91663)

	* 新增入参：AsyncCache

	* 新增出参：AsyncTotalNum, AsyncOffset, AsyncCacheTime

* [DescribeHostClbInstanceList](https://cloud.tencent.com/document/api/400/91662)

	* 新增出参：AsyncCacheTime

* [DescribeHostCosInstanceList](https://cloud.tencent.com/document/api/400/91661)

	* 新增出参：AsyncCacheTime

* [DescribeHostTkeInstanceList](https://cloud.tencent.com/document/api/400/91654)

	* 新增出参：AsyncCacheTime


### 第 35 次发布

发布时间：2023-06-02 01:43:30

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateCertificateByPackage](https://cloud.tencent.com/document/api/400/93094)

### 第 34 次发布

发布时间：2023-05-29 14:59:54

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CommitCertificateInformation](https://cloud.tencent.com/document/api/400/41676)

	* 新增入参：VerifyType


### 第 33 次发布

发布时间：2023-05-26 01:50:53

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [TeoInstanceDetail](https://cloud.tencent.com/document/api/400/41679#TeoInstanceDetail)

	* 新增成员：ZoneId, Status


### 第 32 次发布

发布时间：2023-05-19 01:55:56

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DeployCertificateInstance](https://cloud.tencent.com/document/api/400/91667)
* [DeployCertificateRecordRetry](https://cloud.tencent.com/document/api/400/91666)
* [DeployCertificateRecordRollback](https://cloud.tencent.com/document/api/400/91665)
* [DescribeHostApiGatewayInstanceList](https://cloud.tencent.com/document/api/400/91664)
* [DescribeHostCdnInstanceList](https://cloud.tencent.com/document/api/400/91663)
* [DescribeHostClbInstanceList](https://cloud.tencent.com/document/api/400/91662)
* [DescribeHostCosInstanceList](https://cloud.tencent.com/document/api/400/91661)
* [DescribeHostDdosInstanceList](https://cloud.tencent.com/document/api/400/91660)
* [DescribeHostDeployRecord](https://cloud.tencent.com/document/api/400/91659)
* [DescribeHostDeployRecordDetail](https://cloud.tencent.com/document/api/400/91658)
* [DescribeHostLighthouseInstanceList](https://cloud.tencent.com/document/api/400/91657)
* [DescribeHostLiveInstanceList](https://cloud.tencent.com/document/api/400/91656)
* [DescribeHostTeoInstanceList](https://cloud.tencent.com/document/api/400/91655)
* [DescribeHostTkeInstanceList](https://cloud.tencent.com/document/api/400/91654)
* [DescribeHostUpdateRecord](https://cloud.tencent.com/document/api/400/91653)
* [DescribeHostUpdateRecordDetail](https://cloud.tencent.com/document/api/400/91652)
* [DescribeHostVodInstanceList](https://cloud.tencent.com/document/api/400/91651)
* [DescribeHostWafInstanceList](https://cloud.tencent.com/document/api/400/91650)
* [UpdateCertificateInstance](https://cloud.tencent.com/document/api/400/91649)
* [UpdateCertificateRecordRetry](https://cloud.tencent.com/document/api/400/91648)
* [UpdateCertificateRecordRollback](https://cloud.tencent.com/document/api/400/91647)

新增数据结构：

* [ApiGatewayInstanceDetail](https://cloud.tencent.com/document/api/400/41679#ApiGatewayInstanceDetail)
* [CdnInstanceDetail](https://cloud.tencent.com/document/api/400/41679#CdnInstanceDetail)
* [Certificate](https://cloud.tencent.com/document/api/400/41679#Certificate)
* [ClbInstanceDetail](https://cloud.tencent.com/document/api/400/41679#ClbInstanceDetail)
* [ClbListener](https://cloud.tencent.com/document/api/400/41679#ClbListener)
* [ClbListenerRule](https://cloud.tencent.com/document/api/400/41679#ClbListenerRule)
* [CosInstanceDetail](https://cloud.tencent.com/document/api/400/41679#CosInstanceDetail)
* [DdosInstanceDetail](https://cloud.tencent.com/document/api/400/41679#DdosInstanceDetail)
* [DeployRecordDetail](https://cloud.tencent.com/document/api/400/41679#DeployRecordDetail)
* [DeployRecordInfo](https://cloud.tencent.com/document/api/400/41679#DeployRecordInfo)
* [Filter](https://cloud.tencent.com/document/api/400/41679#Filter)
* [LighthouseInstanceDetail](https://cloud.tencent.com/document/api/400/41679#LighthouseInstanceDetail)
* [LiveInstanceDetail](https://cloud.tencent.com/document/api/400/41679#LiveInstanceDetail)
* [ResourceTypeRegions](https://cloud.tencent.com/document/api/400/41679#ResourceTypeRegions)
* [TeoInstanceDetail](https://cloud.tencent.com/document/api/400/41679#TeoInstanceDetail)
* [TkeIngressDetail](https://cloud.tencent.com/document/api/400/41679#TkeIngressDetail)
* [TkeInstanceDetail](https://cloud.tencent.com/document/api/400/41679#TkeInstanceDetail)
* [TkeNameSpaceDetail](https://cloud.tencent.com/document/api/400/41679#TkeNameSpaceDetail)
* [TkeSecretDetail](https://cloud.tencent.com/document/api/400/41679#TkeSecretDetail)
* [UpdateRecordDetail](https://cloud.tencent.com/document/api/400/41679#UpdateRecordDetail)
* [UpdateRecordDetails](https://cloud.tencent.com/document/api/400/41679#UpdateRecordDetails)
* [UpdateRecordInfo](https://cloud.tencent.com/document/api/400/41679#UpdateRecordInfo)
* [VodInstanceDetail](https://cloud.tencent.com/document/api/400/41679#VodInstanceDetail)

### 第 31 次发布

发布时间：2023-05-12 01:45:40

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeCertificate](https://cloud.tencent.com/document/api/400/41674)

	* 新增出参：CAEncryptAlgorithms, CACommonNames, CAEndTimes


修改数据结构：

* [CompanyInfo](https://cloud.tencent.com/document/api/400/41679#CompanyInfo)

	* 新增成员：IdType, IdNumber


### 第 30 次发布

发布时间：2023-04-21 01:38:46

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeCompanies](https://cloud.tencent.com/document/api/400/90375)

### 第 29 次发布

发布时间：2023-03-29 11:14:40

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeManagerDetail](https://cloud.tencent.com/document/api/400/52673)

	* 新增出参：StatusInfo


### 第 28 次发布

发布时间：2023-03-22 02:22:56

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [CertificateExtra](https://cloud.tencent.com/document/api/400/41679#CertificateExtra)

	* 新增成员：SMCert


### 第 27 次发布

发布时间：2023-03-20 01:52:16

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [UploadCertificate](https://cloud.tencent.com/document/api/400/41665)

	* 新增入参：Repeatable

	* 新增出参：RepeatCertId


### 第 26 次发布

发布时间：2022-12-28 14:53:49

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [Certificates](https://cloud.tencent.com/document/api/400/41679#Certificates)

	* 新增成员：AutoRenewFlag


### 第 25 次发布

发布时间：2022-12-21 02:00:03

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [ApplyCertificate](https://cloud.tencent.com/document/api/400/41678)

	* 新增入参：DeleteDnsAutoRecord


### 第 24 次发布

发布时间：2022-12-19 01:58:27

本次发布包含了以下内容：

改善已有的文档。

新增数据结构：

* [PreAuditInfo](https://cloud.tencent.com/document/api/400/41679#PreAuditInfo)

修改数据结构：

* [Certificates](https://cloud.tencent.com/document/api/400/41679#Certificates)

	* 新增成员：CAEncryptAlgorithms, CAEndTimes, CACommonNames, PreAuditInfo


### 第 23 次发布

发布时间：2022-11-21 06:46:02

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [DeployedResources](https://cloud.tencent.com/document/api/400/41679#DeployedResources)

	* 新增成员：Resources


### 第 22 次发布

发布时间：2022-11-16 06:37:00

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeCertificates](https://cloud.tencent.com/document/api/400/41671)

	* 新增入参：FilterExpiring


### 第 21 次发布

发布时间：2022-11-02 06:38:26

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [ModifyCertificatesExpiringNotificationSwitch](https://cloud.tencent.com/document/api/400/82277)

### 第 20 次发布

发布时间：2022-10-18 06:47:25

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribePackages](https://cloud.tencent.com/document/api/400/81519)

新增数据结构：

* [PackageInfo](https://cloud.tencent.com/document/api/400/41679#PackageInfo)
* [PackageTransferOutInfo](https://cloud.tencent.com/document/api/400/41679#PackageTransferOutInfo)

### 第 19 次发布

发布时间：2022-10-14 06:47:12

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [ApplyCertificate](https://cloud.tencent.com/document/api/400/41678)

	* 新增入参：PackageId


### 第 18 次发布

发布时间：2022-09-08 06:38:47

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeCertificateDetail](https://cloud.tencent.com/document/api/400/41673)

	* 新增出参：EncryptAlgorithm


修改数据结构：

* [Certificates](https://cloud.tencent.com/document/api/400/41679#Certificates)

	* 新增成员：EncryptAlgorithm


### 第 17 次发布

发布时间：2022-07-20 06:12:05

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeCertificateDetail](https://cloud.tencent.com/document/api/400/41673)

	* 新增出参：CertFingerprint, EncryptCertFingerprint


### 第 16 次发布

发布时间：2022-07-14 06:15:09

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeCertificates](https://cloud.tencent.com/document/api/400/41671)

	* 新增入参：IsSM


修改数据结构：

* [Certificates](https://cloud.tencent.com/document/api/400/41679#Certificates)

	* 新增成员：IsSM


### 第 15 次发布

发布时间：2022-06-20 06:13:03

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [Certificates](https://cloud.tencent.com/document/api/400/41679#Certificates)

	* 新增成员：IsIgnore


### 第 14 次发布

发布时间：2022-06-13 06:16:49

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [RootCertificates](https://cloud.tencent.com/document/api/400/41679#RootCertificates)

	* 新增成员：Sign, Encrypt, Standard


### 第 13 次发布

发布时间：2022-06-01 06:15:43

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeCertificateDetail](https://cloud.tencent.com/document/api/400/41673)

	* 新增出参：RootCert, EncryptCert, EncryptPrivateKey


新增数据结构：

* [RootCertificates](https://cloud.tencent.com/document/api/400/41679#RootCertificates)

### 第 12 次发布

发布时间：2022-05-20 06:17:18

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [HostCertificate](https://cloud.tencent.com/document/api/400/74073)

新增数据结构：

* [CertHostingInfo](https://cloud.tencent.com/document/api/400/41679#CertHostingInfo)

### 第 11 次发布

发布时间：2022-02-11 08:11:30

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [DeployedResources](https://cloud.tencent.com/document/api/400/41679#DeployedResources)

	* 新增成员：ResourceIds


### 第 10 次发布

发布时间：2022-01-17 08:12:18

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeCertificates](https://cloud.tencent.com/document/api/400/41671)

	* 新增入参：FilterSource


### 第 9 次发布

发布时间：2021-10-14 08:12:50

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeDeployedResources](https://cloud.tencent.com/document/api/400/62674)

新增数据结构：

* [DeployedResources](https://cloud.tencent.com/document/api/400/41679#DeployedResources)

### 第 8 次发布

发布时间：2021-09-27 08:15:47

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeManagers](https://cloud.tencent.com/document/api/400/52672)

	* 新增入参：SearchKey


新增数据结构：

* [ManagerStatusInfo](https://cloud.tencent.com/document/api/400/41679#ManagerStatusInfo)

修改数据结构：

* [ManagerInfo](https://cloud.tencent.com/document/api/400/41679#ManagerInfo)

	* 新增成员：StatusInfo


### 第 7 次发布

发布时间：2021-07-20 08:04:21

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeCertificates](https://cloud.tencent.com/document/api/400/41671)

	* 新增入参：Upload, Renew


### 第 6 次发布

发布时间：2021-02-02 08:01:51

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DeleteManager](https://cloud.tencent.com/document/api/400/52674)
* [DescribeManagerDetail](https://cloud.tencent.com/document/api/400/52673)
* [DescribeManagers](https://cloud.tencent.com/document/api/400/52672)
* [SubmitAuditManager](https://cloud.tencent.com/document/api/400/52671)
* [VerifyManager](https://cloud.tencent.com/document/api/400/52670)

修改接口：

* [UploadCertificate](https://cloud.tencent.com/document/api/400/41665)

	* 新增入参：CertificateUse


新增数据结构：

* [CompanyInfo](https://cloud.tencent.com/document/api/400/41679#CompanyInfo)
* [ManagerInfo](https://cloud.tencent.com/document/api/400/41679#ManagerInfo)

### 第 5 次发布

发布时间：2021-01-25 08:01:44

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeCertificate](https://cloud.tencent.com/document/api/400/41674)

	* 新增出参：Tags

* [DescribeCertificateDetail](https://cloud.tencent.com/document/api/400/41673)

	* 新增出参：Tags


新增数据结构：

* [Tags](https://cloud.tencent.com/document/api/400/41679#Tags)

修改数据结构：

* [Certificates](https://cloud.tencent.com/document/api/400/41679#Certificates)

	* 新增成员：Tags


### 第 4 次发布

发布时间：2020-10-27 08:01:32

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateCertificate](https://cloud.tencent.com/document/api/400/49427)
* [RevokeCertificate](https://cloud.tencent.com/document/api/400/49426)
* [UploadConfirmLetter](https://cloud.tencent.com/document/api/400/49425)
* [UploadRevokeLetter](https://cloud.tencent.com/document/api/400/49424)

修改接口：

* [ReplaceCertificate](https://cloud.tencent.com/document/api/400/41667)

	* 新增入参：Reason


新增数据结构：

* [RevokeDomainValidateAuths](https://cloud.tencent.com/document/api/400/41679#RevokeDomainValidateAuths)

### 第 3 次发布

发布时间：2020-10-23 08:01:42

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CheckCertificateChain](https://cloud.tencent.com/document/api/400/49323)
* [CompleteCertificate](https://cloud.tencent.com/document/api/400/49322)

### 第 2 次发布

发布时间：2020-03-27 08:01:22

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeCertificateDetail](https://cloud.tencent.com/document/api/400/41673)

	* 新增出参：Deployable


### 第 1 次发布

发布时间：2020-02-28 14:51:47

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [ApplyCertificate](https://cloud.tencent.com/document/api/400/41678)
* [CancelCertificateOrder](https://cloud.tencent.com/document/api/400/41677)
* [CommitCertificateInformation](https://cloud.tencent.com/document/api/400/41676)
* [DeleteCertificate](https://cloud.tencent.com/document/api/400/41675)
* [DescribeCertificate](https://cloud.tencent.com/document/api/400/41674)
* [DescribeCertificateDetail](https://cloud.tencent.com/document/api/400/41673)
* [DescribeCertificateOperateLogs](https://cloud.tencent.com/document/api/400/41672)
* [DescribeCertificates](https://cloud.tencent.com/document/api/400/41671)
* [DownloadCertificate](https://cloud.tencent.com/document/api/400/41670)
* [ModifyCertificateAlias](https://cloud.tencent.com/document/api/400/41669)
* [ModifyCertificateProject](https://cloud.tencent.com/document/api/400/41668)
* [ReplaceCertificate](https://cloud.tencent.com/document/api/400/41667)
* [SubmitCertificateInformation](https://cloud.tencent.com/document/api/400/41666)
* [UploadCertificate](https://cloud.tencent.com/document/api/400/41665)

新增数据结构：

* [CertificateExtra](https://cloud.tencent.com/document/api/400/41679#CertificateExtra)
* [Certificates](https://cloud.tencent.com/document/api/400/41679#Certificates)
* [DvAuthDetail](https://cloud.tencent.com/document/api/400/41679#DvAuthDetail)
* [DvAuths](https://cloud.tencent.com/document/api/400/41679#DvAuths)
* [OperationLog](https://cloud.tencent.com/document/api/400/41679#OperationLog)
* [ProjectInfo](https://cloud.tencent.com/document/api/400/41679#ProjectInfo)
* [SubmittedData](https://cloud.tencent.com/document/api/400/41679#SubmittedData)




## 证书监控 SSLPod(sslpod) 版本：2019-06-05

### 第 2 次发布

发布时间：2022-03-03 08:11:12

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeDomains](https://cloud.tencent.com/document/api/1084/49339)

	* 新增入参：Domain


### 第 1 次发布

发布时间：2020-10-23 18:56:12

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateDomain](https://cloud.tencent.com/document/api/1084/49344)
* [DeleteDomain](https://cloud.tencent.com/document/api/1084/49343)
* [DescribeDashboard](https://cloud.tencent.com/document/api/1084/49342)
* [DescribeDomainCerts](https://cloud.tencent.com/document/api/1084/49341)
* [DescribeDomainTags](https://cloud.tencent.com/document/api/1084/49340)
* [DescribeDomains](https://cloud.tencent.com/document/api/1084/49339)
* [DescribeNoticeInfo](https://cloud.tencent.com/document/api/1084/49338)
* [ModifyDomainTags](https://cloud.tencent.com/document/api/1084/49337)
* [RefreshDomain](https://cloud.tencent.com/document/api/1084/49336)
* [ResolveDomain](https://cloud.tencent.com/document/api/1084/49335)

新增数据结构：

* [CertInfo](https://cloud.tencent.com/document/api/1084/49345#CertInfo)
* [ChartHistogram](https://cloud.tencent.com/document/api/1084/49345#ChartHistogram)
* [ChartNameValue](https://cloud.tencent.com/document/api/1084/49345#ChartNameValue)
* [DashboardResult](https://cloud.tencent.com/document/api/1084/49345#DashboardResult)
* [DescribeDomains](https://cloud.tencent.com/document/api/1084/49345#DescribeDomains)
* [DomainSiteInfo](https://cloud.tencent.com/document/api/1084/49345#DomainSiteInfo)
* [LimitInfo](https://cloud.tencent.com/document/api/1084/49345#LimitInfo)
* [NoticeInfoResult](https://cloud.tencent.com/document/api/1084/49345#NoticeInfoResult)




## 凭据管理系统(ssm) 版本：2019-09-23

### 第 10 次发布

发布时间：2024-02-21 01:22:44

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [SecretMetadata](https://cloud.tencent.com/document/api/1140/40530#SecretMetadata)

	* <font color="#dd0000">**修改成员**：</font>RotationFrequency, ResourceID, RotationBeginTime


### 第 9 次发布

发布时间：2023-05-12 01:46:03

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateSecret](https://cloud.tencent.com/document/api/1140/40529)

	* 新增入参：SecretType, AdditionalConfig

	* <font color="#dd0000">**修改入参**：</font>VersionId

* [DescribeSecret](https://cloud.tencent.com/document/api/1140/40526)

	* 新增出参：AdditionalConfig


### 第 8 次发布

发布时间：2023-04-27 01:35:41

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [SecretMetadata](https://cloud.tencent.com/document/api/1140/40530#SecretMetadata)

	* 新增成员：RotationFrequency, ResourceID, RotationBeginTime


### 第 7 次发布

发布时间：2022-07-18 06:15:58

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateSSHKeyPairSecret](https://cloud.tencent.com/document/api/1140/60331)

	* 新增入参：SSHKeyName


### 第 6 次发布

发布时间：2022-01-11 08:14:31

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeSecret](https://cloud.tencent.com/document/api/1140/40526)

	* 新增出参：TargetUin

* [GetServiceStatus](https://cloud.tencent.com/document/api/1140/40521)

	* 新增出参：AccessKeyEscrowEnabled


修改数据结构：

* [SecretMetadata](https://cloud.tencent.com/document/api/1140/40530#SecretMetadata)

	* 新增成员：TargetUin


### 第 5 次发布

发布时间：2021-09-08 08:02:54

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [GetSSHKeyPairValue](https://cloud.tencent.com/document/api/1140/60330)

	* 新增入参：SSHKeyId

	* <font color="#dd0000">**修改入参**：</font>SecretName

* [ListSecrets](https://cloud.tencent.com/document/api/1140/40519)

	* 新增入参：ProductName


### 第 4 次发布

发布时间：2021-08-17 08:03:01

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateSSHKeyPairSecret](https://cloud.tencent.com/document/api/1140/60331)
* [GetSSHKeyPairValue](https://cloud.tencent.com/document/api/1140/60330)

修改接口：

* [DeleteSecret](https://cloud.tencent.com/document/api/1140/40528)

	* 新增入参：CleanSSHKey

* [DescribeSecret](https://cloud.tencent.com/document/api/1140/40526)

	* 新增出参：ResourceName, ProjectID, AssociatedInstanceIDs


修改数据结构：

* [SecretMetadata](https://cloud.tencent.com/document/api/1140/40530#SecretMetadata)

	* 新增成员：ResourceName, ProjectID, AssociatedInstanceIDs


### 第 3 次发布

发布时间：2021-07-08 08:02:48

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateProductSecret](https://cloud.tencent.com/document/api/1140/58266)
* [DescribeAsyncRequestInfo](https://cloud.tencent.com/document/api/1140/58265)
* [DescribeRotationDetail](https://cloud.tencent.com/document/api/1140/58264)
* [DescribeRotationHistory](https://cloud.tencent.com/document/api/1140/58263)
* [DescribeSupportedProducts](https://cloud.tencent.com/document/api/1140/58268)
* [RotateProductSecret](https://cloud.tencent.com/document/api/1140/58262)
* [UpdateRotationStatus](https://cloud.tencent.com/document/api/1140/58261)

修改接口：

* [DescribeSecret](https://cloud.tencent.com/document/api/1140/40526)

	* 新增出参：SecretType, ProductName, ResourceID, RotationStatus, RotationFrequency

* [ListSecrets](https://cloud.tencent.com/document/api/1140/40519)

	* 新增入参：SecretType


新增数据结构：

* [ProductPrivilegeUnit](https://cloud.tencent.com/document/api/1140/40530#ProductPrivilegeUnit)

修改数据结构：

* [SecretMetadata](https://cloud.tencent.com/document/api/1140/40530#SecretMetadata)

	* 新增成员：RotationStatus, NextRotationTime, SecretType, ProductName


### 第 2 次发布

发布时间：2020-09-03 08:01:05

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateSecret](https://cloud.tencent.com/document/api/1140/40529)

	* 新增入参：Tags

	* 新增出参：TagCode, TagMsg

* [ListSecrets](https://cloud.tencent.com/document/api/1140/40519)

	* 新增入参：TagFilters


新增数据结构：

* [Tag](https://cloud.tencent.com/document/api/1140/40530#Tag)
* [TagFilter](https://cloud.tencent.com/document/api/1140/40530#TagFilter)

### 第 1 次发布

发布时间：2019-12-27 15:29:46

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateSecret](https://cloud.tencent.com/document/api/1140/40529)
* [DeleteSecret](https://cloud.tencent.com/document/api/1140/40528)
* [DeleteSecretVersion](https://cloud.tencent.com/document/api/1140/40527)
* [DescribeSecret](https://cloud.tencent.com/document/api/1140/40526)
* [DisableSecret](https://cloud.tencent.com/document/api/1140/40525)
* [EnableSecret](https://cloud.tencent.com/document/api/1140/40524)
* [GetRegions](https://cloud.tencent.com/document/api/1140/40523)
* [GetSecretValue](https://cloud.tencent.com/document/api/1140/40522)
* [GetServiceStatus](https://cloud.tencent.com/document/api/1140/40521)
* [ListSecretVersionIds](https://cloud.tencent.com/document/api/1140/40520)
* [ListSecrets](https://cloud.tencent.com/document/api/1140/40519)
* [PutSecretValue](https://cloud.tencent.com/document/api/1140/40518)
* [RestoreSecret](https://cloud.tencent.com/document/api/1140/40517)
* [UpdateDescription](https://cloud.tencent.com/document/api/1140/40516)
* [UpdateSecret](https://cloud.tencent.com/document/api/1140/40515)

新增数据结构：

* [SecretMetadata](https://cloud.tencent.com/document/api/1140/40530#SecretMetadata)
* [VersionInfo](https://cloud.tencent.com/document/api/1140/40530#VersionInfo)




## 安全凭证服务(sts) 版本：2018-08-13

### 第 10 次发布

发布时间：2022-07-07 06:15:25

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [AssumeRole](https://cloud.tencent.com/document/api/1312/48197)

	* 新增入参：SourceIdentity


### 第 9 次发布

发布时间：2022-05-18 06:16:35

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [AssumeRole](https://cloud.tencent.com/document/api/1312/48197)

	* 新增入参：Tags


新增数据结构：

* [Tag](https://cloud.tencent.com/document/api/1312/48198#Tag)

### 第 8 次发布

发布时间：2022-04-25 06:12:01

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [AssumeRoleWithWebIdentity](https://cloud.tencent.com/document/api/1312/73070)

### 第 7 次发布

发布时间：2021-12-16 08:13:48

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [GetCallerIdentity](https://cloud.tencent.com/document/api/1312/66098)

### 第 6 次发布

发布时间：2020-12-23 08:09:13

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [AssumeRole](https://cloud.tencent.com/document/api/1312/48197)

	* 新增入参：ExternalId


### 第 5 次发布

发布时间：2020-02-26 17:50:41

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [GetFederationToken](https://cloud.tencent.com/document/api/1312/48195)

	* 新增出参：Expiration


### 第 4 次发布

发布时间：2019-12-20 11:17:47

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [QueryApiKey](https://cloud.tencent.com/document/api/1312/48194)

新增数据结构：

* [ApiKey](https://cloud.tencent.com/document/api/1312/48198#ApiKey)

### 第 3 次发布

发布时间：2019-06-27 20:16:35

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [AssumeRoleWithSAML](https://cloud.tencent.com/document/api/1312/48196)

修改接口：

* [AssumeRole](https://cloud.tencent.com/document/api/1312/48197)

	* 新增入参：Policy


### 第 2 次发布

发布时间：2019-02-28 14:21:08

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [GetFederationToken](https://cloud.tencent.com/document/api/1312/48195)

	* <font color="#dd0000">**删除入参**：</font>OpenUin, OpenOwnerUin, Ua, Mfa, InterfaceName, ExtraInfo, ThUin, ThOwnerUin, CodeMode


### 第 1 次发布

发布时间：2019-01-25 12:11:30

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [AssumeRole](https://cloud.tencent.com/document/api/1312/48197)
* [GetFederationToken](https://cloud.tencent.com/document/api/1312/48195)

新增数据结构：

* [Credentials](https://cloud.tencent.com/document/api/1312/48198#Credentials)




## 节省计划(svp) 版本：2024-01-25

### 第 2 次发布

发布时间：2024-05-23 17:09:13

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeSavingPlanDeduct](https://cloud.tencent.com/document/api/1761/106542)
* [DescribeSavingPlanOverview](https://cloud.tencent.com/document/api/1761/106541)
* [DescribeSavingPlanUsage](https://cloud.tencent.com/document/api/1761/106540)

新增数据结构：

* [SavingPlanDeductDetail](https://cloud.tencent.com/document/api/1761/106543#SavingPlanDeductDetail)
* [SavingPlanOverviewDetail](https://cloud.tencent.com/document/api/1761/106543#SavingPlanOverviewDetail)
* [SavingPlanUsageDetail](https://cloud.tencent.com/document/api/1761/106543#SavingPlanUsageDetail)

### 第 1 次发布

发布时间：2024-01-26 16:30:56

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateSavingPlanOrder](https://cloud.tencent.com/document/api/1761/103541)




## 流量反欺诈(taf) 版本：2020-02-10

### 第 18 次发布

发布时间：2024-02-05 01:21:52

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [ManagePortraitRisk](https://cloud.tencent.com/document/api/1031/103776)

新增数据结构：

* [ManagePortraitRiskInput](https://cloud.tencent.com/document/api/1031/43310#ManagePortraitRiskInput)
* [ManagePortraitRiskOutput](https://cloud.tencent.com/document/api/1031/43310#ManagePortraitRiskOutput)
* [ManagePortraitRiskValueOutput](https://cloud.tencent.com/document/api/1031/43310#ManagePortraitRiskValueOutput)

### 第 17 次发布

发布时间：2023-05-24 01:44:57

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [OutputRecognizeTargetAudienceValue](https://cloud.tencent.com/document/api/1031/43310#OutputRecognizeTargetAudienceValue)

	* 新增成员：ModelType, Uid


### 第 16 次发布

发布时间：2022-09-12 06:39:19

本次发布包含了以下内容：

改善已有的文档。

<font color="#dd0000">**删除接口**：</font>

* SendTrafficSecuritySmsMessage

<font color="#dd0000">**删除数据结构**：</font>

* InputSendTrafficSecuritySmsMsg
* OutputSendTrafficSecuritySmsMsg

### 第 15 次发布

发布时间：2022-08-22 06:46:33

本次发布包含了以下内容：

改善已有的文档。

<font color="#dd0000">**删除接口**：</font>

* DetectFraudKOL

<font color="#dd0000">**删除数据结构**：</font>

* InputKolBspData
* InputKolDataList
* OutputKolData
* OutputKolValue

### 第 14 次发布

发布时间：2022-08-11 06:48:40

本次发布包含了以下内容：

改善已有的文档。

<font color="#dd0000">**删除接口**：</font>

* RecognizeEffectiveFlow

<font color="#dd0000">**删除数据结构**：</font>

* InputRecognizeEffectiveFlow
* OutputRecognizeEffectiveFlow
* OutputRecognizeEffectiveFlowValue

### 第 13 次发布

发布时间：2022-07-19 06:17:28

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [InputRecognizeTargetAudience](https://cloud.tencent.com/document/api/1031/43310#InputRecognizeTargetAudience)

	* <font color="#dd0000">**修改成员**：</font>Uid, AccountType


### 第 12 次发布

发布时间：2022-07-01 06:16:56

本次发布包含了以下内容：

改善已有的文档。

<font color="#dd0000">**删除接口**：</font>

* EnhanceTaDegree

<font color="#dd0000">**删除数据结构**：</font>

* InputTaBspData
* OutputTaData
* OutputTaValue

### 第 11 次发布

发布时间：2021-12-23 08:14:47

本次发布包含了以下内容：

改善已有的文档。

新增数据结构：

* [Device](https://cloud.tencent.com/document/api/1031/43310#Device)

修改数据结构：

* [InputRecognizeTargetAudience](https://cloud.tencent.com/document/api/1031/43310#InputRecognizeTargetAudience)

	* 新增成员：DeviceList


### 第 10 次发布

发布时间：2021-11-03 08:14:28

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DetectFraudKOL](https://cloud.tencent.com/document/api/1031/43309)

	* 新增入参：BusinessEncryptData


修改数据结构：

* [InputKolDataList](https://cloud.tencent.com/document/api/1031/43310#InputKolDataList)

	* 新增成员：IsAuthorized


### 第 9 次发布

发布时间：2021-11-02 08:10:53

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [RecognizeTargetAudience](https://cloud.tencent.com/document/api/1031/43305)

	* 新增入参：BusinessEncryptData


修改数据结构：

* [InputRecognizeTargetAudience](https://cloud.tencent.com/document/api/1031/43310#InputRecognizeTargetAudience)

	* 新增成员：IsAuthorized


### 第 8 次发布

发布时间：2021-11-01 08:13:31

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [EnhanceTaDegree](https://cloud.tencent.com/document/api/1031/43308)

	* 新增入参：BusinessEncryptData


新增数据结构：

* [InputBusinessEncryptData](https://cloud.tencent.com/document/api/1031/43310#InputBusinessEncryptData)

修改数据结构：

* [InputTaBspData](https://cloud.tencent.com/document/api/1031/43310#InputTaBspData)

	* 新增成员：IsAuthorized


### 第 7 次发布

发布时间：2021-10-29 08:09:22

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [InputSendTrafficSecuritySmsMsg](https://cloud.tencent.com/document/api/1031/43310#InputSendTrafficSecuritySmsMsg)

	* 新增成员：IsAuthorized, EncryptMethod, EncryptMode, PaddingType, EncryptData


### 第 6 次发布

发布时间：2020-11-24 08:00:36

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [RecognizeEffectiveFlow](https://cloud.tencent.com/document/api/1031/50223)

新增数据结构：

* [InputRecognizeEffectiveFlow](https://cloud.tencent.com/document/api/1031/43310#InputRecognizeEffectiveFlow)
* [OutputRecognizeEffectiveFlow](https://cloud.tencent.com/document/api/1031/43310#OutputRecognizeEffectiveFlow)
* [OutputRecognizeEffectiveFlowValue](https://cloud.tencent.com/document/api/1031/43310#OutputRecognizeEffectiveFlowValue)

### 第 5 次发布

发布时间：2020-05-26 08:00:44

本次发布包含了以下内容：

改善已有的文档。

<font color="#dd0000">**删除接口**：</font>

* DetectAccountActivity

<font color="#dd0000">**删除数据结构**：</font>

* InputDetectAccountActivity
* OutputDetectAccountActivity
* OutputDetectAccountActivityValue

### 第 4 次发布

发布时间：2020-04-29 08:00:55

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [OutputDetectAccountActivityValue](https://cloud.tencent.com/document/api/1031/43310#OutputDetectAccountActivityValue)

	* <font color="#dd0000">**修改成员**：</font>Type


### 第 3 次发布

发布时间：2020-04-28 08:00:11

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [OutputDetectAccountActivityValue](https://cloud.tencent.com/document/api/1031/43310#OutputDetectAccountActivityValue)

	* 新增成员：Type


### 第 2 次发布

发布时间：2020-04-22 08:00:09

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DetectAccountActivity](https://cloud.tencent.com/document/api/1031/43662)

新增数据结构：

* [InputDetectAccountActivity](https://cloud.tencent.com/document/api/1031/43310#InputDetectAccountActivity)
* [OutputDetectAccountActivity](https://cloud.tencent.com/document/api/1031/43310#OutputDetectAccountActivity)
* [OutputDetectAccountActivityValue](https://cloud.tencent.com/document/api/1031/43310#OutputDetectAccountActivityValue)

### 第 1 次发布

发布时间：2020-04-09 10:50:09

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DetectFraudKOL](https://cloud.tencent.com/document/api/1031/43309)
* [EnhanceTaDegree](https://cloud.tencent.com/document/api/1031/43308)
* [RecognizeCustomizedAudience](https://cloud.tencent.com/document/api/1031/43307)
* [RecognizePreciseTargetAudience](https://cloud.tencent.com/document/api/1031/43306)
* [RecognizeTargetAudience](https://cloud.tencent.com/document/api/1031/43305)
* [SendTrafficSecuritySmsMessage](https://cloud.tencent.com/document/api/1031/43304)

新增数据结构：

* [InputKolBspData](https://cloud.tencent.com/document/api/1031/43310#InputKolBspData)
* [InputKolDataList](https://cloud.tencent.com/document/api/1031/43310#InputKolDataList)
* [InputRecognizeTargetAudience](https://cloud.tencent.com/document/api/1031/43310#InputRecognizeTargetAudience)
* [InputSendTrafficSecuritySmsMsg](https://cloud.tencent.com/document/api/1031/43310#InputSendTrafficSecuritySmsMsg)
* [InputTaBspData](https://cloud.tencent.com/document/api/1031/43310#InputTaBspData)
* [OutputKolData](https://cloud.tencent.com/document/api/1031/43310#OutputKolData)
* [OutputKolValue](https://cloud.tencent.com/document/api/1031/43310#OutputKolValue)
* [OutputRecognizeTargetAudience](https://cloud.tencent.com/document/api/1031/43310#OutputRecognizeTargetAudience)
* [OutputRecognizeTargetAudienceValue](https://cloud.tencent.com/document/api/1031/43310#OutputRecognizeTargetAudienceValue)
* [OutputSendTrafficSecuritySmsMsg](https://cloud.tencent.com/document/api/1031/43310#OutputSendTrafficSecuritySmsMsg)
* [OutputTaData](https://cloud.tencent.com/document/api/1031/43310#OutputTaData)
* [OutputTaValue](https://cloud.tencent.com/document/api/1031/43310#OutputTaValue)




## 标签(tag) 版本：2018-08-13

### 第 14 次发布

发布时间：2024-01-26 01:20:11

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeProjects](https://cloud.tencent.com/document/api/651/78725)

	* 新增入参：ProjectId, ProjectName


### 第 13 次发布

发布时间：2023-09-21 05:27:30

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeResourceTagsByResourceIds](https://cloud.tencent.com/document/api/651/35319)

	* 新增入参：Category

* [DescribeTagKeys](https://cloud.tencent.com/document/api/651/35318)

	* 新增入参：Category

* [DescribeTagValues](https://cloud.tencent.com/document/api/651/35317)

	* 新增入参：Category

* [GetTagKeys](https://cloud.tencent.com/document/api/651/72277)

	* 新增入参：Category

* [GetTagValues](https://cloud.tencent.com/document/api/651/72276)

	* 新增入参：Category

* [GetTags](https://cloud.tencent.com/document/api/651/72275)

	* 新增入参：Category


修改数据结构：

* [Tag](https://cloud.tencent.com/document/api/651/35327#Tag)

	* 新增成员：Category

* [TagResource](https://cloud.tencent.com/document/api/651/35327#TagResource)

	* 新增成员：Category

* [TagWithDelete](https://cloud.tencent.com/document/api/651/35327#TagWithDelete)

	* 新增成员：Category


### 第 12 次发布

发布时间：2022-10-26 06:58:19

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [AddProject](https://cloud.tencent.com/document/api/651/81952)
* [UpdateProject](https://cloud.tencent.com/document/api/651/81951)

### 第 11 次发布

发布时间：2022-08-08 06:36:01

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeProjects](https://cloud.tencent.com/document/api/651/78725)

新增数据结构：

* [Project](https://cloud.tencent.com/document/api/651/35327#Project)

### 第 10 次发布

发布时间：2022-04-08 06:12:35

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateTags](https://cloud.tencent.com/document/api/651/72282)
* [DeleteTags](https://cloud.tencent.com/document/api/651/72281)
* [GetResources](https://cloud.tencent.com/document/api/651/72278)
* [GetTagKeys](https://cloud.tencent.com/document/api/651/72277)
* [GetTagValues](https://cloud.tencent.com/document/api/651/72276)
* [GetTags](https://cloud.tencent.com/document/api/651/72275)
* [TagResources](https://cloud.tencent.com/document/api/651/72280)
* [UnTagResources](https://cloud.tencent.com/document/api/651/72279)

新增数据结构：

* [FailedResource](https://cloud.tencent.com/document/api/651/35327#FailedResource)
* [ResourceTagMapping](https://cloud.tencent.com/document/api/651/35327#ResourceTagMapping)

### 第 9 次发布

发布时间：2020-07-30 08:15:41

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeResourcesByTagsUnion](https://cloud.tencent.com/document/api/651/47023)

### 第 8 次发布

发布时间：2020-07-14 08:17:00

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [AttachResourcesTag](https://cloud.tencent.com/document/api/651/46294)
* [DescribeResourceTagsByResourceIdsSeq](https://cloud.tencent.com/document/api/651/46291)
* [DescribeTagValuesSeq](https://cloud.tencent.com/document/api/651/46290)
* [DescribeTagsSeq](https://cloud.tencent.com/document/api/651/46289)
* [DetachResourcesTag](https://cloud.tencent.com/document/api/651/46293)
* [ModifyResourcesTagValue](https://cloud.tencent.com/document/api/651/46292)

### 第 7 次发布

发布时间：2020-04-07 08:13:55

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeTags](https://cloud.tencent.com/document/api/651/35316)

	* 新增入参：ShowProject


### 第 6 次发布

发布时间：2020-04-02 08:15:07

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeResourceTagsByTagKeys](https://cloud.tencent.com/document/api/651/43061)

修改接口：

* [DescribeTagKeys](https://cloud.tencent.com/document/api/651/35318)

	* 新增入参：ShowProject

* [DescribeTags](https://cloud.tencent.com/document/api/651/35316)

	* 新增入参：TagKeys


新增数据结构：

* [ResourceIdTag](https://cloud.tencent.com/document/api/651/35327#ResourceIdTag)

### 第 5 次发布

发布时间：2020-04-01 08:37:05

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeResourceTags](https://cloud.tencent.com/document/api/651/43044)

### 第 4 次发布

发布时间：2020-03-26 08:12:32

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [TagResource](https://cloud.tencent.com/document/api/651/35327#TagResource)

	* 新增成员：ServiceType


### 第 3 次发布

发布时间：2019-10-11 21:04:23

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeResourcesByTags](https://cloud.tencent.com/document/api/651/38320)

	* <font color="#dd0000">**修改入参**：</font>TagFilters

	* <font color="#dd0000">**修改出参**：</font>Rows


新增数据结构：

* [ResourceTag](https://cloud.tencent.com/document/api/651/35327#ResourceTag)
* [TagFilter](https://cloud.tencent.com/document/api/651/35327#TagFilter)

<font color="#dd0000">**删除数据结构**：</font>

* ResourcesTag
* TagFilters

### 第 2 次发布

发布时间：2019-08-22 20:11:03

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeResourcesByTags](https://cloud.tencent.com/document/api/651/38320)

新增数据结构：

* [ResourcesTag](https://cloud.tencent.com/document/api/651/35327#ResourcesTag)
* [TagFilters](https://cloud.tencent.com/document/api/651/35327#TagFilters)

### 第 1 次发布

发布时间：2019-06-06 20:32:16

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [AddResourceTag](https://cloud.tencent.com/document/api/651/35326)
* [CreateTag](https://cloud.tencent.com/document/api/651/35325)
* [DeleteResourceTag](https://cloud.tencent.com/document/api/651/35324)
* [DeleteTag](https://cloud.tencent.com/document/api/651/35323)
* [DescribeResourceTagsByResourceIds](https://cloud.tencent.com/document/api/651/35319)
* [DescribeTagKeys](https://cloud.tencent.com/document/api/651/35318)
* [DescribeTagValues](https://cloud.tencent.com/document/api/651/35317)
* [DescribeTags](https://cloud.tencent.com/document/api/651/35316)
* [ModifyResourceTags](https://cloud.tencent.com/document/api/651/35322)
* [UpdateResourceTagValue](https://cloud.tencent.com/document/api/651/35321)

新增数据结构：

* [Tag](https://cloud.tencent.com/document/api/651/35327#Tag)
* [TagKeyObject](https://cloud.tencent.com/document/api/651/35327#TagKeyObject)
* [TagResource](https://cloud.tencent.com/document/api/651/35327#TagResource)
* [TagWithDelete](https://cloud.tencent.com/document/api/651/35327#TagWithDelete)




## 碳引擎(tan) 版本：2022-04-20

### 第 1 次发布

发布时间：2022-06-06 16:47:40

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateBlockNodeRecords](https://cloud.tencent.com/document/api/1498/74949)




## 自动化助手(tat) 版本：2020-10-28

### 第 22 次发布

发布时间：2023-12-15 20:16:37

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [AutomationAgentInfo](https://cloud.tencent.com/document/api/1340/52687#AutomationAgentInfo)

	* <font color="#dd0000">**修改成员**：</font>SupportFeatures

* [CommandDocument](https://cloud.tencent.com/document/api/1340/52687#CommandDocument)

	* <font color="#dd0000">**修改成员**：</font>OutputCOSBucketUrl, OutputCOSKeyPrefix

* [RegisterCodeInfo](https://cloud.tencent.com/document/api/1340/52687#RegisterCodeInfo)

	* <font color="#dd0000">**修改成员**：</font>RegisterCodeId, Description, InstanceNamePrefix, RegisterLimit, ExpiredTime, IpAddressRange, Enabled, RegisteredCount, CreatedTime, UpdatedTime


### 第 21 次发布

发布时间：2023-10-11 02:22:08

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DeleteCommands](https://cloud.tencent.com/document/api/1340/100133)
* [DescribeQuotas](https://cloud.tencent.com/document/api/1340/100132)

新增数据结构：

* [GeneralResourceQuotaSet](https://cloud.tencent.com/document/api/1340/52687#GeneralResourceQuotaSet)

### 第 20 次发布

发布时间：2023-09-18 02:20:44

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateCommand](https://cloud.tencent.com/document/api/1340/52684)

	* 新增入参：DefaultParameterConfs

* [ModifyCommand](https://cloud.tencent.com/document/api/1340/52677)

	* 新增入参：DefaultParameterConfs

* [RunCommand](https://cloud.tencent.com/document/api/1340/52676)

	* 新增入参：DefaultParameterConfs


### 第 19 次发布

发布时间：2023-08-24 01:26:36

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateRegisterCode](https://cloud.tencent.com/document/api/1340/96928)
* [DeleteRegisterCodes](https://cloud.tencent.com/document/api/1340/96927)
* [DeleteRegisterInstance](https://cloud.tencent.com/document/api/1340/96926)
* [DescribeRegisterCodes](https://cloud.tencent.com/document/api/1340/96925)
* [DescribeRegisterInstances](https://cloud.tencent.com/document/api/1340/96924)
* [DisableRegisterCodes](https://cloud.tencent.com/document/api/1340/96923)
* [ModifyRegisterInstance](https://cloud.tencent.com/document/api/1340/96922)

新增数据结构：

* [DefaultParameterConf](https://cloud.tencent.com/document/api/1340/52687#DefaultParameterConf)
* [RegisterCodeInfo](https://cloud.tencent.com/document/api/1340/52687#RegisterCodeInfo)
* [RegisterInstanceInfo](https://cloud.tencent.com/document/api/1340/52687#RegisterInstanceInfo)

修改数据结构：

* [Command](https://cloud.tencent.com/document/api/1340/52687#Command)

	* 新增成员：DefaultParameterConfs


### 第 18 次发布

发布时间：2023-02-20 01:49:40

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [AutomationAgentInfo](https://cloud.tencent.com/document/api/1340/52687#AutomationAgentInfo)

	* 新增成员：SupportFeatures

* [CommandDocument](https://cloud.tencent.com/document/api/1340/52687#CommandDocument)

	* 新增成员：OutputCOSBucketUrl, OutputCOSKeyPrefix


### 第 17 次发布

发布时间：2021-12-09 08:10:32

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CancelInvocation](https://cloud.tencent.com/document/api/1340/65770)

### 第 16 次发布

发布时间：2021-12-03 08:11:00

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [Command](https://cloud.tencent.com/document/api/1340/52687#Command)

	* 新增成员：OutputCOSBucketUrl, OutputCOSKeyPrefix

* [Invocation](https://cloud.tencent.com/document/api/1340/52687#Invocation)

	* 新增成员：OutputCOSBucketUrl, OutputCOSKeyPrefix

* [TaskResult](https://cloud.tencent.com/document/api/1340/52687#TaskResult)

	* 新增成员：OutputUrl, OutputUploadCOSErrorInfo


### 第 15 次发布

发布时间：2021-12-02 08:11:32

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [InvokeCommand](https://cloud.tencent.com/document/api/1340/52678)

	* 新增入参：OutputCOSBucketUrl, OutputCOSKeyPrefix

* [ModifyCommand](https://cloud.tencent.com/document/api/1340/52677)

	* 新增入参：OutputCOSBucketUrl, OutputCOSKeyPrefix

* [RunCommand](https://cloud.tencent.com/document/api/1340/52676)

	* 新增入参：OutputCOSBucketUrl, OutputCOSKeyPrefix


### 第 14 次发布

发布时间：2021-11-24 08:13:01

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateCommand](https://cloud.tencent.com/document/api/1340/52684)

	* 新增入参：OutputCOSBucketUrl, OutputCOSKeyPrefix


### 第 13 次发布

发布时间：2021-09-23 08:12:30

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateInvoker](https://cloud.tencent.com/document/api/1340/61762)
* [DeleteInvoker](https://cloud.tencent.com/document/api/1340/61761)
* [DescribeInvokerRecords](https://cloud.tencent.com/document/api/1340/61760)
* [DescribeInvokers](https://cloud.tencent.com/document/api/1340/61759)
* [DisableInvoker](https://cloud.tencent.com/document/api/1340/61758)
* [EnableInvoker](https://cloud.tencent.com/document/api/1340/61757)
* [ModifyInvoker](https://cloud.tencent.com/document/api/1340/61756)

新增数据结构：

* [Invoker](https://cloud.tencent.com/document/api/1340/52687#Invoker)
* [InvokerRecord](https://cloud.tencent.com/document/api/1340/52687#InvokerRecord)
* [ScheduleSettings](https://cloud.tencent.com/document/api/1340/52687#ScheduleSettings)

### 第 12 次发布

发布时间：2021-09-01 08:11:51

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [Invocation](https://cloud.tencent.com/document/api/1340/52687#Invocation)

	* 新增成员：CommandContent, CommandType, Timeout, WorkingDirectory


### 第 11 次发布

发布时间：2021-07-28 08:12:03

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [Invocation](https://cloud.tencent.com/document/api/1340/52687#Invocation)

	* 新增成员：InvocationSource

* [InvocationTask](https://cloud.tencent.com/document/api/1340/52687#InvocationTask)

	* 新增成员：InvocationSource


### 第 10 次发布

发布时间：2021-07-21 08:11:56

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [InvokeCommand](https://cloud.tencent.com/document/api/1340/52678)

	* 新增入参：WorkingDirectory, Timeout


### 第 9 次发布

发布时间：2021-07-19 08:11:15

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [InvocationTask](https://cloud.tencent.com/document/api/1340/52687#InvocationTask)

	* 新增成员：ErrorInfo


### 第 8 次发布

发布时间：2021-07-14 08:12:04

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateCommand](https://cloud.tencent.com/document/api/1340/52684)

	* 新增入参：Username

* [InvokeCommand](https://cloud.tencent.com/document/api/1340/52678)

	* 新增入参：Username

* [ModifyCommand](https://cloud.tencent.com/document/api/1340/52677)

	* 新增入参：Username

* [RunCommand](https://cloud.tencent.com/document/api/1340/52676)

	* 新增入参：Username


修改数据结构：

* [Command](https://cloud.tencent.com/document/api/1340/52687#Command)

	* 新增成员：Username

* [CommandDocument](https://cloud.tencent.com/document/api/1340/52687#CommandDocument)

	* 新增成员：Username

* [Invocation](https://cloud.tencent.com/document/api/1340/52687#Invocation)

	* 新增成员：Username


### 第 7 次发布

发布时间：2021-07-07 10:06:48

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [Invocation](https://cloud.tencent.com/document/api/1340/52687#Invocation)

	* 新增成员：InstanceKind


### 第 6 次发布

发布时间：2021-05-31 08:11:21

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateCommand](https://cloud.tencent.com/document/api/1340/52684)

	* 新增入参：Tags

* [RunCommand](https://cloud.tencent.com/document/api/1340/52676)

	* 新增入参：Tags


### 第 5 次发布

发布时间：2021-05-28 08:11:06

本次发布包含了以下内容：

改善已有的文档。

新增数据结构：

* [Tag](https://cloud.tencent.com/document/api/1340/52687#Tag)

修改数据结构：

* [Command](https://cloud.tencent.com/document/api/1340/52687#Command)

	* 新增成员：Tags


### 第 4 次发布

发布时间：2021-04-25 10:20:20

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [TaskResult](https://cloud.tencent.com/document/api/1340/52687#TaskResult)

	* 新增成员：Dropped


### 第 3 次发布

发布时间：2021-04-13 08:11:56

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [Command](https://cloud.tencent.com/document/api/1340/52687#Command)

	* 新增成员：FormattedDescription, CreatedBy


### 第 2 次发布

发布时间：2021-03-23 08:12:09

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [PreviewReplacedCommandContent](https://cloud.tencent.com/document/api/1340/53938)

修改接口：

* [CreateCommand](https://cloud.tencent.com/document/api/1340/52684)

	* 新增入参：EnableParameter, DefaultParameters

* [InvokeCommand](https://cloud.tencent.com/document/api/1340/52678)

	* 新增入参：Parameters

* [ModifyCommand](https://cloud.tencent.com/document/api/1340/52677)

	* 新增入参：DefaultParameters

* [RunCommand](https://cloud.tencent.com/document/api/1340/52676)

	* 新增入参：EnableParameter, DefaultParameters, Parameters


修改数据结构：

* [Command](https://cloud.tencent.com/document/api/1340/52687#Command)

	* 新增成员：EnableParameter, DefaultParameters

* [Invocation](https://cloud.tencent.com/document/api/1340/52687#Invocation)

	* 新增成员：Parameters, DefaultParameters


### 第 1 次发布

发布时间：2021-02-02 08:11:53

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateCommand](https://cloud.tencent.com/document/api/1340/52684)
* [DeleteCommand](https://cloud.tencent.com/document/api/1340/52683)
* [DescribeAutomationAgentStatus](https://cloud.tencent.com/document/api/1340/52682)
* [DescribeCommands](https://cloud.tencent.com/document/api/1340/52681)
* [DescribeInvocationTasks](https://cloud.tencent.com/document/api/1340/52680)
* [DescribeInvocations](https://cloud.tencent.com/document/api/1340/52679)
* [DescribeRegions](https://cloud.tencent.com/document/api/1340/52686)
* [InvokeCommand](https://cloud.tencent.com/document/api/1340/52678)
* [ModifyCommand](https://cloud.tencent.com/document/api/1340/52677)
* [RunCommand](https://cloud.tencent.com/document/api/1340/52676)

新增数据结构：

* [AutomationAgentInfo](https://cloud.tencent.com/document/api/1340/52687#AutomationAgentInfo)
* [Command](https://cloud.tencent.com/document/api/1340/52687#Command)
* [CommandDocument](https://cloud.tencent.com/document/api/1340/52687#CommandDocument)
* [Filter](https://cloud.tencent.com/document/api/1340/52687#Filter)
* [Invocation](https://cloud.tencent.com/document/api/1340/52687#Invocation)
* [InvocationTask](https://cloud.tencent.com/document/api/1340/52687#InvocationTask)
* [InvocationTaskBasicInfo](https://cloud.tencent.com/document/api/1340/52687#InvocationTaskBasicInfo)
* [RegionInfo](https://cloud.tencent.com/document/api/1340/52687#RegionInfo)
* [TaskResult](https://cloud.tencent.com/document/api/1340/52687#TaskResult)




## 反病毒TAV(tav) 版本：2019-01-18

### 第 1 次发布

发布时间：2019-02-22 15:45:31

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [GetLocalEngine](https://cloud.tencent.com/document/api/1035/33202)
* [GetScanResult](https://cloud.tencent.com/document/api/1035/33201)
* [ScanFile](https://cloud.tencent.com/document/api/1035/33200)
* [ScanFileHash](https://cloud.tencent.com/document/api/1035/33199)




## 腾讯云区块链服务平台 TBaaS(tbaas) 版本：2018-04-16

### 第 20 次发布

发布时间：2023-11-23 01:26:18

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DownloadUserCert](https://cloud.tencent.com/document/api/663/38516)

	* 新增出参：Cert

* [Invoke](https://cloud.tencent.com/document/api/663/19464)

	* 新增出参：TxId


### 第 19 次发布

发布时间：2023-11-21 01:32:15

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeFabricBlock](https://cloud.tencent.com/document/api/663/101763)
* [DescribeFabricTransaction](https://cloud.tencent.com/document/api/663/101762)
* [InvokeFabricChaincode](https://cloud.tencent.com/document/api/663/101761)
* [QueryFabricChaincode](https://cloud.tencent.com/document/api/663/101760)

新增数据结构：

* [Transaction](https://cloud.tencent.com/document/api/663/19466#Transaction)

### 第 18 次发布

发布时间：2023-07-20 01:41:44

本次发布包含了以下内容：

改善已有的文档。

<font color="#dd0000">**删除接口**：</font>

* CreateChaincodeAndInstallForUser
* GetChaincodeCompileLogForUser
* GetChaincodeInitializeResultForUser
* GetChaincodeLogForUser
* GetChannelListForUser
* GetClusterListForUser
* GetPeerLogForUser
* InitializeChaincodeForUser

<font color="#dd0000">**删除数据结构**：</font>

* ChannelDetailForUser
* ClusterDetailForUser
* GroupDetailForUser
* LogDetailForUser
* PeerDetailForUser

### 第 17 次发布

发布时间：2023-06-27 01:39:58

本次发布包含了以下内容：

改善已有的文档。

<font color="#dd0000">**预下线接口**：</font>

* CreateChaincodeAndInstallForUser
* GetChaincodeCompileLogForUser
* GetChaincodeInitializeResultForUser
* GetChaincodeLogForUser
* GetChannelListForUser
* GetClusterListForUser
* GetPeerLogForUser
* InitializeChaincodeForUser

### 第 16 次发布

发布时间：2023-06-26 01:51:21

本次发布包含了以下内容：

改善已有的文档。

<font color="#dd0000">**删除接口**：</font>

* DeployDynamicBcosContract
* GetBcosBlockByNumber
* GetBcosBlockList
* GetBcosTransByHash
* GetBcosTransList
* InvokeBcosTrans

<font color="#dd0000">**删除数据结构**：</font>

* BcosBlockObj
* BcosTransInfo

### 第 15 次发布

发布时间：2023-06-20 01:47:44

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [GetLatestTransactionList](https://cloud.tencent.com/document/api/663/94178)

<font color="#dd0000">**预下线接口**：</font>

* DeployDynamicBcosContract
* GetBcosBlockByNumber
* GetBcosBlockList
* GetBcosTransByHash
* GetBcosTransList
* InvokeBcosTrans

### 第 14 次发布

发布时间：2022-11-24 06:52:49

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [ApplyChainMakerBatchUserCert](https://cloud.tencent.com/document/api/663/83253)

新增数据结构：

* [SignCertCsr](https://cloud.tencent.com/document/api/663/19466#SignCertCsr)

### 第 13 次发布

发布时间：2022-08-11 06:49:15

本次发布包含了以下内容：

改善已有的文档。

<font color="#dd0000">**删除接口**：</font>

* BlockByNumberHandler
* DeployDynamicContractHandler
* GetBlockListHandler
* GetTransByHashHandler
* GetTransListHandler
* SendTransactionHandler
* TransByDynamicContractHandler

### 第 12 次发布

发布时间：2022-06-20 15:31:45

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [InvokeChainMakerDemoContract](https://cloud.tencent.com/document/api/663/75766)
* [QueryChainMakerDemoBlockTransaction](https://cloud.tencent.com/document/api/663/75765)
* [QueryChainMakerDemoContract](https://cloud.tencent.com/document/api/663/75764)
* [QueryChainMakerDemoTransaction](https://cloud.tencent.com/document/api/663/75763)

### 第 11 次发布

发布时间：2021-08-24 08:09:26

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [InvokeChainMakerContract](https://cloud.tencent.com/document/api/663/60624)
* [QueryChainMakerBlockTransaction](https://cloud.tencent.com/document/api/663/60623)
* [QueryChainMakerContract](https://cloud.tencent.com/document/api/663/60622)
* [QueryChainMakerTransaction](https://cloud.tencent.com/document/api/663/60621)

新增数据结构：

* [ChainMakerContractResult](https://cloud.tencent.com/document/api/663/19466#ChainMakerContractResult)
* [ChainMakerTransactionResult](https://cloud.tencent.com/document/api/663/19466#ChainMakerTransactionResult)

### 第 10 次发布

发布时间：2021-03-16 17:32:27

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DeployDynamicBcosContract](https://cloud.tencent.com/document/api/663/53680)
* [GetBcosBlockByNumber](https://cloud.tencent.com/document/api/663/53679)
* [GetBcosBlockList](https://cloud.tencent.com/document/api/663/53678)
* [GetBcosTransByHash](https://cloud.tencent.com/document/api/663/53677)
* [GetBcosTransList](https://cloud.tencent.com/document/api/663/53676)
* [InvokeBcosTrans](https://cloud.tencent.com/document/api/663/53675)

### 第 9 次发布

发布时间：2021-01-29 08:07:22

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateChaincodeAndInstallForUser](https://cloud.tencent.com/document/api/663/52614)
* [GetChaincodeCompileLogForUser](https://cloud.tencent.com/document/api/663/52610)
* [GetChaincodeInitializeResultForUser](https://cloud.tencent.com/document/api/663/52613)
* [GetChaincodeLogForUser](https://cloud.tencent.com/document/api/663/52609)
* [GetChannelListForUser](https://cloud.tencent.com/document/api/663/52606)
* [GetClusterListForUser](https://cloud.tencent.com/document/api/663/52605)
* [GetPeerLogForUser](https://cloud.tencent.com/document/api/663/52608)
* [InitializeChaincodeForUser](https://cloud.tencent.com/document/api/663/52612)

新增数据结构：

* [ChannelDetailForUser](https://cloud.tencent.com/document/api/663/19466#ChannelDetailForUser)
* [ClusterDetailForUser](https://cloud.tencent.com/document/api/663/19466#ClusterDetailForUser)
* [GroupDetailForUser](https://cloud.tencent.com/document/api/663/19466#GroupDetailForUser)
* [LogDetailForUser](https://cloud.tencent.com/document/api/663/19466#LogDetailForUser)
* [PeerDetailForUser](https://cloud.tencent.com/document/api/663/19466#PeerDetailForUser)

### 第 8 次发布

发布时间：2020-01-13 22:02:43

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DeployDynamicContractHandler](https://cloud.tencent.com/document/api/663/41048)
* [TransByDynamicContractHandler](https://cloud.tencent.com/document/api/663/41047)

### 第 7 次发布

发布时间：2020-01-09 15:50:30

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [GetBlockTransactionListForUser](https://cloud.tencent.com/document/api/663/40954)

修改接口：

* [ApplyUserCert](https://cloud.tencent.com/document/api/663/38517)

	* 新增出参：CertId, CertDn


### 第 6 次发布

发布时间：2020-01-08 11:44:16

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [SendTransactionHandler](https://cloud.tencent.com/document/api/663/38527)

	* <font color="#dd0000">**删除入参**：</font>KeyUser


### 第 5 次发布

发布时间：2019-11-21 21:54:40

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [GetTransactionDetailForUser](https://cloud.tencent.com/document/api/663/39448)

新增数据结构：

* [EndorserGroup](https://cloud.tencent.com/document/api/663/19466#EndorserGroup)

### 第 4 次发布

发布时间：2019-10-18 10:31:32

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [ApplyUserCert](https://cloud.tencent.com/document/api/663/38517)
* [BlockByNumberHandler](https://cloud.tencent.com/document/api/663/38531)
* [DownloadUserCert](https://cloud.tencent.com/document/api/663/38516)
* [GetBlockListHandler](https://cloud.tencent.com/document/api/663/38530)
* [GetTransByHashHandler](https://cloud.tencent.com/document/api/663/38529)
* [GetTransListHandler](https://cloud.tencent.com/document/api/663/38528)
* [SendTransactionHandler](https://cloud.tencent.com/document/api/663/38527)
* [SrvInvoke](https://cloud.tencent.com/document/api/663/38519)

修改接口：

* [GetClusterSummary](https://cloud.tencent.com/document/api/663/35192)

	* 新增出参：OrderCount

	* <font color="#dd0000">**删除出参**：</font>OtherChannelCount, NoneChannelCount, OtherPeerCount, OtherGroupCount, OtherChaincodeCount, OrderCertCount


新增数据结构：

* [BcosBlockObj](https://cloud.tencent.com/document/api/663/19466#BcosBlockObj)
* [BcosTransInfo](https://cloud.tencent.com/document/api/663/19466#BcosTransInfo)

### 第 3 次发布

发布时间：2019-05-30 19:29:39

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [GetBlockList](https://cloud.tencent.com/document/api/663/35193)
* [GetClusterSummary](https://cloud.tencent.com/document/api/663/35192)
* [GetLatesdTransactionList](https://cloud.tencent.com/document/api/663/35191)

修改接口：

* [GetInvokeTx](https://cloud.tencent.com/document/api/663/19465)

	* 新增出参：BlockId


新增数据结构：

* [Block](https://cloud.tencent.com/document/api/663/19466#Block)
* [TransactionItem](https://cloud.tencent.com/document/api/663/19466#TransactionItem)

### 第 2 次发布

发布时间：2019-04-25 20:19:09

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [GetInvokeTx](https://cloud.tencent.com/document/api/663/19465)

	* 新增入参：GroupName

* [Invoke](https://cloud.tencent.com/document/api/663/19464)

	* 新增入参：GroupName

* [Query](https://cloud.tencent.com/document/api/663/19463)

	* 新增入参：GroupName


### 第 1 次发布

发布时间：2018-08-30 15:59:14

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [GetInvokeTx](https://cloud.tencent.com/document/api/663/19465)
* [Invoke](https://cloud.tencent.com/document/api/663/19464)
* [Query](https://cloud.tencent.com/document/api/663/19463)

新增数据结构：

* [PeerSet](https://cloud.tencent.com/document/api/663/19466#PeerSet)




## 腾讯优评(tbm) 版本：2018-01-29

### 第 1 次发布

发布时间：2018-07-19 21:36:12

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeBrandCommentCount](https://cloud.tencent.com/document/api/853/18399)
* [DescribeBrandExposure](https://cloud.tencent.com/document/api/853/18398)
* [DescribeBrandMediaReport](https://cloud.tencent.com/document/api/853/18397)
* [DescribeBrandNegComments](https://cloud.tencent.com/document/api/853/18396)
* [DescribeBrandPosComments](https://cloud.tencent.com/document/api/853/18395)
* [DescribeBrandSocialOpinion](https://cloud.tencent.com/document/api/853/18394)
* [DescribeBrandSocialReport](https://cloud.tencent.com/document/api/853/18393)
* [DescribeIndustryNews](https://cloud.tencent.com/document/api/853/18401)
* [DescribeUserPortrait](https://cloud.tencent.com/document/api/853/18392)

新增数据结构：

* [AgePortrait](https://cloud.tencent.com/document/api/853/18402#AgePortrait)
* [AgePortraitInfo](https://cloud.tencent.com/document/api/853/18402#AgePortraitInfo)
* [BrandReportArticle](https://cloud.tencent.com/document/api/853/18402#BrandReportArticle)
* [Comment](https://cloud.tencent.com/document/api/853/18402#Comment)
* [CommentInfo](https://cloud.tencent.com/document/api/853/18402#CommentInfo)
* [DateCount](https://cloud.tencent.com/document/api/853/18402#DateCount)
* [GenderPortrait](https://cloud.tencent.com/document/api/853/18402#GenderPortrait)
* [GenderPortraitInfo](https://cloud.tencent.com/document/api/853/18402#GenderPortraitInfo)
* [IndustryNews](https://cloud.tencent.com/document/api/853/18402#IndustryNews)
* [MoviePortrait](https://cloud.tencent.com/document/api/853/18402#MoviePortrait)
* [MoviePortraitInfo](https://cloud.tencent.com/document/api/853/18402#MoviePortraitInfo)
* [ProvincePortrait](https://cloud.tencent.com/document/api/853/18402#ProvincePortrait)
* [ProvincePortraitInfo](https://cloud.tencent.com/document/api/853/18402#ProvincePortraitInfo)
* [StarPortrait](https://cloud.tencent.com/document/api/853/18402#StarPortrait)
* [StarPortraitInfo](https://cloud.tencent.com/document/api/853/18402#StarPortraitInfo)




## 腾讯智能对话平台(tbp) 版本：2019-03-11

### 第 6 次发布

发布时间：2023-06-22 01:50:05

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [ResponseMessage](https://cloud.tencent.com/document/api/1060/34559#ResponseMessage)

	* <font color="#dd0000">**修改成员**：</font>GroupList


### 第 5 次发布

发布时间：2023-06-06 01:54:55

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [TextProcess](https://cloud.tencent.com/document/api/1060/34557)

	* 新增出参：ResponseMessage, ResultType


新增数据结构：

* [Group](https://cloud.tencent.com/document/api/1060/34559#Group)
* [ResponseMessage](https://cloud.tencent.com/document/api/1060/34559#ResponseMessage)

### 第 4 次发布

发布时间：2020-03-16 08:17:53

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateBot](https://cloud.tencent.com/document/api/1060/42602)

### 第 3 次发布

发布时间：2019-06-17 19:43:09

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [TextProcess](https://cloud.tencent.com/document/api/1060/34557)
* [TextReset](https://cloud.tencent.com/document/api/1060/35522)

<font color="#dd0000">**删除接口**：</font>

* PostText

### 第 2 次发布

发布时间：2019-06-12 19:36:21

本次发布包含了以下内容：

改善已有的文档。

<font color="#dd0000">**删除接口**：</font>

* PostAudio

### 第 1 次发布

发布时间：2019-04-29 20:23:24

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [PostAudio](https://cloud.tencent.com/document/api/1060/34547)
* [PostText](https://cloud.tencent.com/document/api/1060/34557)
* [Reset](https://cloud.tencent.com/document/api/1060/34556)

新增数据结构：

* [SlotInfo](https://cloud.tencent.com/document/api/1060/34559#SlotInfo)



## 腾讯智能对话平台(tbp) 版本：2019-06-27

### 第 4 次发布

发布时间：2023-06-06 01:55:04

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [TextProcess](https://cloud.tencent.com/document/api/1060/37438)

	* 新增出参：ResponseText


### 第 3 次发布

发布时间：2023-06-05 01:49:22

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [TextReset](https://cloud.tencent.com/document/api/1060/37437)

	* 新增出参：ResponseText


### 第 2 次发布

发布时间：2019-11-14 17:49:19

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [TextProcess](https://cloud.tencent.com/document/api/1060/37438)

	* 新增入参：PlatformId

* [TextReset](https://cloud.tencent.com/document/api/1060/37437)

	* 新增入参：PlatformId


### 第 1 次发布

发布时间：2019-08-21 18:57:41

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [TextProcess](https://cloud.tencent.com/document/api/1060/37438)
* [TextReset](https://cloud.tencent.com/document/api/1060/37437)

新增数据结构：

* [Group](https://cloud.tencent.com/document/api/1060/37439#Group)
* [ResponseMessage](https://cloud.tencent.com/document/api/1060/37439#ResponseMessage)
* [SlotInfo](https://cloud.tencent.com/document/api/1060/37439#SlotInfo)




## 游戏数据库 TcaplusDB(tcaplusdb) 版本：2019-08-23

### 第 21 次发布

发布时间：2024-06-18 02:11:49

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [SnapshotResult](https://cloud.tencent.com/document/api/596/39686#SnapshotResult)

	* 新增成员：ApplicationId

* [TaskInfoNew](https://cloud.tencent.com/document/api/596/39686#TaskInfoNew)

	* 新增成员：TableGroupId, TableGroupName, TableName


### 第 20 次发布

发布时间：2023-06-20 01:48:17

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [ImportSnapshots](https://cloud.tencent.com/document/api/596/54347)

	* 新增出参：ApplicationId


### 第 19 次发布

发布时间：2023-04-13 01:37:44

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DeleteBackupRecords](https://cloud.tencent.com/document/api/596/90121)
* [DescribeBackupRecords](https://cloud.tencent.com/document/api/596/90119)
* [SetBackupExpireRule](https://cloud.tencent.com/document/api/596/90120)

新增数据结构：

* [BackupExpireRuleInfo](https://cloud.tencent.com/document/api/596/39686#BackupExpireRuleInfo)
* [BackupRecords](https://cloud.tencent.com/document/api/596/39686#BackupRecords)

### 第 18 次发布

发布时间：2023-03-10 01:48:39

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [ClusterInfo](https://cloud.tencent.com/document/api/596/39686#ClusterInfo)

	* 新增成员：RestProxyStatus

* [ProxyDetailInfo](https://cloud.tencent.com/document/api/596/39686#ProxyDetailInfo)

	* 新增成员：Version

* [ServerDetailInfo](https://cloud.tencent.com/document/api/596/39686#ServerDetailInfo)

	* 新增成员：Version

* [TableGroupInfo](https://cloud.tencent.com/document/api/596/39686#TableGroupInfo)

	* 新增成员：TxhBackupExpireDay, EnableMysql, MysqlConnIp, MysqlConnPort


### 第 17 次发布

发布时间：2023-01-11 01:39:23

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeSnapshots](https://cloud.tencent.com/document/api/596/54348)

	* 新增入参：SelectedTables


### 第 16 次发布

发布时间：2022-08-23 06:49:36

本次发布包含了以下内容：

改善已有的文档。

新增数据结构：

* [SyncTableField](https://cloud.tencent.com/document/api/596/39686#SyncTableField)
* [SyncTableInfo](https://cloud.tencent.com/document/api/596/39686#SyncTableInfo)

修改数据结构：

* [TableInfoNew](https://cloud.tencent.com/document/api/596/39686#TableInfoNew)

	* 新增成员：SyncTableInfo


### 第 15 次发布

发布时间：2022-03-29 08:15:32

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [ClusterInfo](https://cloud.tencent.com/document/api/596/39686#ClusterInfo)

	* 新增成员：TxhBackupExpireDay, UlogBackupExpireDay, IsReadOnlyUlogBackupExpireDay

* [TableInfoNew](https://cloud.tencent.com/document/api/596/39686#TableInfoNew)

	* 新增成员：TxhBackupExpireDay


### 第 14 次发布

发布时间：2021-09-28 08:09:50

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateCluster](https://cloud.tencent.com/document/api/596/41491)

	* 新增入参：AuthType


### 第 13 次发布

发布时间：2021-09-24 10:11:33

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DeleteTableDataFlow](https://cloud.tencent.com/document/api/596/61849)
* [SetTableDataFlow](https://cloud.tencent.com/document/api/596/61848)

新增数据结构：

* [KafkaInfo](https://cloud.tencent.com/document/api/596/39686#KafkaInfo)

修改数据结构：

* [ClusterInfo](https://cloud.tencent.com/document/api/596/39686#ClusterInfo)

	* 新增成员：DataFlowStatus, KafkaInfo

* [ProxyMachineInfo](https://cloud.tencent.com/document/api/596/39686#ProxyMachineInfo)

	* 新增成员：AvailableCount

* [SelectedTableWithField](https://cloud.tencent.com/document/api/596/39686#SelectedTableWithField)

	* 新增成员：KafkaInfo


### 第 12 次发布

发布时间：2021-05-20 08:07:49

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeApplications](https://cloud.tencent.com/document/api/596/56109)
* [MergeTablesData](https://cloud.tencent.com/document/api/596/56111)
* [ModifyCensorship](https://cloud.tencent.com/document/api/596/56108)
* [UpdateApply](https://cloud.tencent.com/document/api/596/56110)

修改接口：

* [CreateBackup](https://cloud.tencent.com/document/api/596/41496)

	* 新增出参：ApplicationIds


新增数据结构：

* [Application](https://cloud.tencent.com/document/api/596/39686#Application)
* [ApplyResult](https://cloud.tencent.com/document/api/596/39686#ApplyResult)
* [ApplyStatus](https://cloud.tencent.com/document/api/596/39686#ApplyStatus)
* [CompareTablesInfo](https://cloud.tencent.com/document/api/596/39686#CompareTablesInfo)
* [MergeTableResult](https://cloud.tencent.com/document/api/596/39686#MergeTableResult)
* [MergeTablesInfo](https://cloud.tencent.com/document/api/596/39686#MergeTablesInfo)

修改数据结构：

* [ClusterInfo](https://cloud.tencent.com/document/api/596/39686#ClusterInfo)

	* 新增成员：Censorship, DbaUins

* [Filter](https://cloud.tencent.com/document/api/596/39686#Filter)

	* 新增成员：Values

	* <font color="#dd0000">**修改成员**：</font>Value

* [TableResultNew](https://cloud.tencent.com/document/api/596/39686#TableResultNew)

	* 新增成员：ApplicationId


### 第 11 次发布

发布时间：2021-04-07 08:07:13

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateSnapshots](https://cloud.tencent.com/document/api/596/54350)
* [DeleteSnapshots](https://cloud.tencent.com/document/api/596/54349)
* [DescribeSnapshots](https://cloud.tencent.com/document/api/596/54348)
* [ImportSnapshots](https://cloud.tencent.com/document/api/596/54347)
* [ModifySnapshots](https://cloud.tencent.com/document/api/596/54346)

新增数据结构：

* [KeyFile](https://cloud.tencent.com/document/api/596/39686#KeyFile)
* [SnapshotInfo](https://cloud.tencent.com/document/api/596/39686#SnapshotInfo)
* [SnapshotInfoNew](https://cloud.tencent.com/document/api/596/39686#SnapshotInfoNew)
* [SnapshotResult](https://cloud.tencent.com/document/api/596/39686#SnapshotResult)

### 第 10 次发布

发布时间：2021-01-26 08:07:59

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DisableRestProxy](https://cloud.tencent.com/document/api/596/52503)
* [EnableRestProxy](https://cloud.tencent.com/document/api/596/52502)

### 第 9 次发布

发布时间：2020-12-08 08:07:21

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeMachine](https://cloud.tencent.com/document/api/596/50732)
* [ModifyClusterMachine](https://cloud.tencent.com/document/api/596/50731)

修改接口：

* [CreateCluster](https://cloud.tencent.com/document/api/596/41491)

	* 新增入参：ServerList, ProxyList, ClusterType


新增数据结构：

* [MachineInfo](https://cloud.tencent.com/document/api/596/39686#MachineInfo)
* [PoolInfo](https://cloud.tencent.com/document/api/596/39686#PoolInfo)
* [ProxyDetailInfo](https://cloud.tencent.com/document/api/596/39686#ProxyDetailInfo)
* [ProxyMachineInfo](https://cloud.tencent.com/document/api/596/39686#ProxyMachineInfo)
* [ServerDetailInfo](https://cloud.tencent.com/document/api/596/39686#ServerDetailInfo)
* [ServerMachineInfo](https://cloud.tencent.com/document/api/596/39686#ServerMachineInfo)

修改数据结构：

* [ClusterInfo](https://cloud.tencent.com/document/api/596/39686#ClusterInfo)

	* 新增成员：ClusterType, ClusterStatus, ReadCapacityUnit, WriteCapacityUnit, DiskVolume, ServerList, ProxyList


### 第 8 次发布

发布时间：2020-07-07 08:16:55

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateCluster](https://cloud.tencent.com/document/api/596/41491)

	* 新增入参：Ipv6Enable

* [DescribeClusters](https://cloud.tencent.com/document/api/596/41489)

	* 新增入参：Ipv6Enable


修改数据结构：

* [ClusterInfo](https://cloud.tencent.com/document/api/596/39686#ClusterInfo)

	* 新增成员：ApiAccessIpv6

* [RegionInfo](https://cloud.tencent.com/document/api/596/39686#RegionInfo)

	* 新增成员：Ipv6Enable


### 第 7 次发布

发布时间：2020-06-29 08:16:45

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DeleteTableIndex](https://cloud.tencent.com/document/api/596/45809)
* [SetTableIndex](https://cloud.tencent.com/document/api/596/45808)

新增数据结构：

* [FieldInfo](https://cloud.tencent.com/document/api/596/39686#FieldInfo)
* [SelectedTableWithField](https://cloud.tencent.com/document/api/596/39686#SelectedTableWithField)

### 第 6 次发布

发布时间：2020-06-02 08:16:48

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeClusterTags](https://cloud.tencent.com/document/api/596/45082)
* [DescribeTableGroupTags](https://cloud.tencent.com/document/api/596/45084)
* [DescribeTableTags](https://cloud.tencent.com/document/api/596/45086)
* [ModifyClusterTags](https://cloud.tencent.com/document/api/596/45081)
* [ModifyTableGroupTags](https://cloud.tencent.com/document/api/596/45083)
* [ModifyTableTags](https://cloud.tencent.com/document/api/596/45085)

修改接口：

* [CreateCluster](https://cloud.tencent.com/document/api/596/41491)

	* 新增入参：ResourceTags

* [CreateTableGroup](https://cloud.tencent.com/document/api/596/41495)

	* 新增入参：ResourceTags

* [CreateTables](https://cloud.tencent.com/document/api/596/39667)

	* 新增入参：ResourceTags


新增数据结构：

* [TagInfoUnit](https://cloud.tencent.com/document/api/596/39686#TagInfoUnit)
* [TagsInfoOfCluster](https://cloud.tencent.com/document/api/596/39686#TagsInfoOfCluster)
* [TagsInfoOfTable](https://cloud.tencent.com/document/api/596/39686#TagsInfoOfTable)
* [TagsInfoOfTableGroup](https://cloud.tencent.com/document/api/596/39686#TagsInfoOfTableGroup)

### 第 5 次发布

发布时间：2020-04-14 08:14:54

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [TableInfoNew](https://cloud.tencent.com/document/api/596/39686#TableInfoNew)

	* 新增成员：DbClusterInfoStruct


### 第 4 次发布

发布时间：2020-04-02 08:15:33

本次发布包含了以下内容：

改善已有的文档。

<font color="#dd0000">**删除接口**：</font>

* ModifyAppName

### 第 3 次发布

发布时间：2020-02-26 16:35:12

本次发布包含了以下内容：

改善已有的文档。

<font color="#dd0000">**删除接口**：</font>

* CreateApp
* CreateZone
* DeleteApp
* DeleteZone
* DescribeApps
* DescribeZones
* ModifyAppPassword
* ModifyZoneName

<font color="#dd0000">**删除数据结构**：</font>

* AppInfo
* ZoneInfo

### 第 2 次发布

发布时间：2020-02-24 17:29:38

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateBackup](https://cloud.tencent.com/document/api/596/41496)
* [CreateCluster](https://cloud.tencent.com/document/api/596/41491)
* [CreateTableGroup](https://cloud.tencent.com/document/api/596/41495)
* [DeleteCluster](https://cloud.tencent.com/document/api/596/41490)
* [DeleteTableGroup](https://cloud.tencent.com/document/api/596/41494)
* [DescribeClusters](https://cloud.tencent.com/document/api/596/41489)
* [DescribeTableGroups](https://cloud.tencent.com/document/api/596/41493)
* [ModifyClusterName](https://cloud.tencent.com/document/api/596/41488)
* [ModifyClusterPassword](https://cloud.tencent.com/document/api/596/41487)
* [ModifyTableGroupName](https://cloud.tencent.com/document/api/596/41492)

修改接口：

* [ClearTables](https://cloud.tencent.com/document/api/596/39669)

	* 新增入参：ClusterId

	* <font color="#dd0000">**删除入参**：</font>ApplicationId

	* <font color="#dd0000">**修改入参**：</font>SelectedTables

	* <font color="#dd0000">**修改出参**：</font>TableResults

* [CompareIdlFiles](https://cloud.tencent.com/document/api/596/39668)

	* 新增入参：ClusterId

	* <font color="#dd0000">**删除入参**：</font>ApplicationId

	* <font color="#dd0000">**修改入参**：</font>SelectedTables

	* <font color="#dd0000">**修改出参**：</font>TableInfos

* [CreateTables](https://cloud.tencent.com/document/api/596/39667)

	* 新增入参：ClusterId

	* <font color="#dd0000">**删除入参**：</font>ApplicationId

	* <font color="#dd0000">**修改入参**：</font>SelectedTables

	* <font color="#dd0000">**修改出参**：</font>TableResults

* [DeleteIdlFiles](https://cloud.tencent.com/document/api/596/39683)

	* 新增入参：ClusterId

	* <font color="#dd0000">**删除入参**：</font>ApplicationId

* [DeleteTables](https://cloud.tencent.com/document/api/596/39666)

	* 新增入参：ClusterId

	* <font color="#dd0000">**删除入参**：</font>ApplicationId

	* <font color="#dd0000">**修改入参**：</font>SelectedTables

	* <font color="#dd0000">**修改出参**：</font>TableResults

* [DescribeIdlFileInfos](https://cloud.tencent.com/document/api/596/39665)

	* 新增入参：ClusterId, TableGroupIds

	* <font color="#dd0000">**删除入参**：</font>ApplicationId, LogicZoneIds

* [DescribeTables](https://cloud.tencent.com/document/api/596/39664)

	* 新增入参：ClusterId, TableGroupIds

	* <font color="#dd0000">**删除入参**：</font>ApplicationId, LogicZoneIds

	* <font color="#dd0000">**修改入参**：</font>SelectedTables

	* <font color="#dd0000">**修改出参**：</font>TableInfos

* [DescribeTablesInRecycle](https://cloud.tencent.com/document/api/596/39663)

	* 新增入参：ClusterId, TableGroupIds

	* <font color="#dd0000">**删除入参**：</font>ApplicationId, LogicZoneIds

	* <font color="#dd0000">**修改出参**：</font>TableInfos

* [DescribeTasks](https://cloud.tencent.com/document/api/596/39677)

	* 新增入参：ClusterIds

	* <font color="#dd0000">**删除入参**：</font>ApplicationIds

	* <font color="#dd0000">**修改出参**：</font>TaskInfos

* [ModifyTableMemos](https://cloud.tencent.com/document/api/596/39662)

	* 新增入参：ClusterId

	* <font color="#dd0000">**删除入参**：</font>ApplicationId

	* <font color="#dd0000">**修改入参**：</font>TableMemos

	* <font color="#dd0000">**修改出参**：</font>TableResults

* [ModifyTableQuotas](https://cloud.tencent.com/document/api/596/39661)

	* 新增入参：ClusterId

	* <font color="#dd0000">**删除入参**：</font>ApplicationId

	* <font color="#dd0000">**修改入参**：</font>TableQuotas

	* <font color="#dd0000">**修改出参**：</font>TableResults

* [ModifyTables](https://cloud.tencent.com/document/api/596/39660)

	* 新增入参：ClusterId

	* <font color="#dd0000">**删除入参**：</font>ApplicationId

	* <font color="#dd0000">**修改入参**：</font>SelectedTables

	* <font color="#dd0000">**修改出参**：</font>TableResults

* [RecoverRecycleTables](https://cloud.tencent.com/document/api/596/39659)

	* 新增入参：ClusterId

	* <font color="#dd0000">**删除入参**：</font>ApplicationId

	* <font color="#dd0000">**修改入参**：</font>SelectedTables

	* <font color="#dd0000">**修改出参**：</font>TableResults

* [RollbackTables](https://cloud.tencent.com/document/api/596/39658)

	* 新增入参：ClusterId

	* <font color="#dd0000">**删除入参**：</font>ApplicationId

	* <font color="#dd0000">**修改入参**：</font>SelectedTables

	* <font color="#dd0000">**修改出参**：</font>TableResults

* [VerifyIdlFiles](https://cloud.tencent.com/document/api/596/39657)

	* 新增入参：ClusterId, TableGroupId

	* <font color="#dd0000">**删除入参**：</font>ApplicationId, LogicZoneId

	* <font color="#dd0000">**修改出参**：</font>TableInfos


新增数据结构：

* [ClusterInfo](https://cloud.tencent.com/document/api/596/39686#ClusterInfo)
* [ParsedTableInfoNew](https://cloud.tencent.com/document/api/596/39686#ParsedTableInfoNew)
* [SelectedTableInfoNew](https://cloud.tencent.com/document/api/596/39686#SelectedTableInfoNew)
* [TableGroupInfo](https://cloud.tencent.com/document/api/596/39686#TableGroupInfo)
* [TableInfoNew](https://cloud.tencent.com/document/api/596/39686#TableInfoNew)
* [TableResultNew](https://cloud.tencent.com/document/api/596/39686#TableResultNew)
* [TableRollbackResultNew](https://cloud.tencent.com/document/api/596/39686#TableRollbackResultNew)
* [TaskInfoNew](https://cloud.tencent.com/document/api/596/39686#TaskInfoNew)

<font color="#dd0000">**删除数据结构**：</font>

* ParsedTableInfo
* SelectedTableInfo
* TableInfo
* TableResult
* TableRollbackResult
* TaskInfo

### 第 1 次发布

发布时间：2019-11-26 22:03:46

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [ClearTables](https://cloud.tencent.com/document/api/596/39669)
* [CompareIdlFiles](https://cloud.tencent.com/document/api/596/39668)
* [CreateApp](https://cloud.tencent.com/document/api/596/39685)
* [CreateTables](https://cloud.tencent.com/document/api/596/39667)
* [CreateZone](https://cloud.tencent.com/document/api/596/39674)
* [DeleteApp](https://cloud.tencent.com/document/api/596/39684)
* [DeleteIdlFiles](https://cloud.tencent.com/document/api/596/39683)
* [DeleteTables](https://cloud.tencent.com/document/api/596/39666)
* [DeleteZone](https://cloud.tencent.com/document/api/596/39673)
* [DescribeApps](https://cloud.tencent.com/document/api/596/39682)
* [DescribeIdlFileInfos](https://cloud.tencent.com/document/api/596/39665)
* [DescribeRegions](https://cloud.tencent.com/document/api/596/39678)
* [DescribeTables](https://cloud.tencent.com/document/api/596/39664)
* [DescribeTablesInRecycle](https://cloud.tencent.com/document/api/596/39663)
* [DescribeTasks](https://cloud.tencent.com/document/api/596/39677)
* [DescribeUinInWhitelist](https://cloud.tencent.com/document/api/596/39676)
* [DescribeZones](https://cloud.tencent.com/document/api/596/39672)
* [ModifyAppName](https://cloud.tencent.com/document/api/596/39681)
* [ModifyAppPassword](https://cloud.tencent.com/document/api/596/39680)
* [ModifyTableMemos](https://cloud.tencent.com/document/api/596/39662)
* [ModifyTableQuotas](https://cloud.tencent.com/document/api/596/39661)
* [ModifyTables](https://cloud.tencent.com/document/api/596/39660)
* [ModifyZoneName](https://cloud.tencent.com/document/api/596/39671)
* [RecoverRecycleTables](https://cloud.tencent.com/document/api/596/39659)
* [RollbackTables](https://cloud.tencent.com/document/api/596/39658)
* [VerifyIdlFiles](https://cloud.tencent.com/document/api/596/39657)

新增数据结构：

* [AppInfo](https://cloud.tencent.com/document/api/596/39686#AppInfo)
* [ErrorInfo](https://cloud.tencent.com/document/api/596/39686#ErrorInfo)
* [Filter](https://cloud.tencent.com/document/api/596/39686#Filter)
* [IdlFileInfo](https://cloud.tencent.com/document/api/596/39686#IdlFileInfo)
* [IdlFileInfoWithoutContent](https://cloud.tencent.com/document/api/596/39686#IdlFileInfoWithoutContent)
* [ParsedTableInfo](https://cloud.tencent.com/document/api/596/39686#ParsedTableInfo)
* [RegionInfo](https://cloud.tencent.com/document/api/596/39686#RegionInfo)
* [SelectedTableInfo](https://cloud.tencent.com/document/api/596/39686#SelectedTableInfo)
* [TableInfo](https://cloud.tencent.com/document/api/596/39686#TableInfo)
* [TableResult](https://cloud.tencent.com/document/api/596/39686#TableResult)
* [TableRollbackResult](https://cloud.tencent.com/document/api/596/39686#TableRollbackResult)
* [TaskInfo](https://cloud.tencent.com/document/api/596/39686#TaskInfo)
* [ZoneInfo](https://cloud.tencent.com/document/api/596/39686#ZoneInfo)




## 云开发 CloudBase(tcb) 版本：2018-06-08

### 第 102 次发布

发布时间：2024-05-30 02:08:52

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeWxGateways](https://cloud.tencent.com/document/api/876/94386)

	* 新增入参：GatewayId


修改数据结构：

* [GatewayItem](https://cloud.tencent.com/document/api/876/34822#GatewayItem)

	* 新增成员：WxAppId, CanRenew, AutoRenewFlag, CanDowngrade, LongAccessId, AccessDomain

	* <font color="#dd0000">**修改成员**：</font>VersionNumLimit


### 第 101 次发布

发布时间：2024-01-23 01:27:30

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [CloudBaseProjectVersion](https://cloud.tencent.com/document/api/876/34822#CloudBaseProjectVersion)

	* 新增成员：Uin, BuildFinishTime, DeployFinishTime, BuildId, SourceUrl, FailReasonShort, FirstInitRepo


### 第 100 次发布

发布时间：2023-09-28 01:21:31

本次发布包含了以下内容：

改善已有的文档。

新增数据结构：

* [CustomHeader](https://cloud.tencent.com/document/api/876/34822#CustomHeader)
* [CustomRequestToAdd](https://cloud.tencent.com/document/api/876/34822#CustomRequestToAdd)

修改数据结构：

* [WxGatewayRountItem](https://cloud.tencent.com/document/api/876/34822#WxGatewayRountItem)

	* 新增成员：CustomHeader


### 第 99 次发布

发布时间：2023-08-18 11:40:41

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [WxGatewayRountItem](https://cloud.tencent.com/document/api/876/34822#WxGatewayRountItem)

	* 新增成员：GatewayRoutePathMatchType

	* <font color="#dd0000">**修改成员**：</font>GatewayRouteEnvId


### 第 98 次发布

发布时间：2023-07-14 01:35:07

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeCloudBaseRunServerVersion](https://cloud.tencent.com/document/api/876/49739)

	* <font color="#dd0000">**修改出参**：</font>Cpu, Mem

* [DescribeCurveData](https://cloud.tencent.com/document/api/876/59512)

	* <font color="#dd0000">**修改出参**：</font>NewValues


### 第 97 次发布

发布时间：2023-07-11 01:40:42

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [WxGatewayRountItem](https://cloud.tencent.com/document/api/876/34822#WxGatewayRountItem)

	* 新增成员：GatewayRouteEnvId


### 第 96 次发布

发布时间：2023-06-29 18:45:40

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DeleteGatewayVersion](https://cloud.tencent.com/document/api/876/94391)
* [DescribeBillingInfo](https://cloud.tencent.com/document/api/876/94390)
* [DescribeCbrServerVersion](https://cloud.tencent.com/document/api/876/94389)
* [DescribeGatewayVersions](https://cloud.tencent.com/document/api/876/94388)
* [DescribeGraphData](https://cloud.tencent.com/document/api/876/96277)
* [DescribeWxGatewayRoutes](https://cloud.tencent.com/document/api/876/94387)
* [DescribeWxGateways](https://cloud.tencent.com/document/api/876/94386)
* [ModifyGatewayVersionTraffic](https://cloud.tencent.com/document/api/876/94385)

新增数据结构：

* [BanConfig](https://cloud.tencent.com/document/api/876/34822#BanConfig)
* [CbrPackageInfo](https://cloud.tencent.com/document/api/876/34822#CbrPackageInfo)
* [CbrRepoInfo](https://cloud.tencent.com/document/api/876/34822#CbrRepoInfo)
* [CustomLogConfig](https://cloud.tencent.com/document/api/876/34822#CustomLogConfig)
* [FrequencyLimitConfig](https://cloud.tencent.com/document/api/876/34822#FrequencyLimitConfig)
* [GatewayItem](https://cloud.tencent.com/document/api/876/34822#GatewayItem)
* [GatewayVersionItem](https://cloud.tencent.com/document/api/876/34822#GatewayVersionItem)
* [WxGatewayCustomConfig](https://cloud.tencent.com/document/api/876/34822#WxGatewayCustomConfig)
* [WxGatewayRountItem](https://cloud.tencent.com/document/api/876/34822#WxGatewayRountItem)

修改数据结构：

* [EnvInfo](https://cloud.tencent.com/document/api/876/34822#EnvInfo)

	* 新增成员：ArchitectureType, Recycle


### 第 95 次发布

发布时间：2023-03-29 11:14:58

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreatePostpayPackage](https://cloud.tencent.com/document/api/876/45287)

	* 新增入参：EnvAlias, Extra


### 第 94 次发布

发布时间：2023-03-22 02:25:31

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeGatewayCurveData](https://cloud.tencent.com/document/api/876/89118)

### 第 93 次发布

发布时间：2023-02-16 01:54:52

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateWxCloudBaseRunEnv](https://cloud.tencent.com/document/api/876/55054)

	* 新增入参：Source, Channel


### 第 92 次发布

发布时间：2023-02-08 02:00:35

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeCurveData](https://cloud.tencent.com/document/api/876/59512)

	* 新增出参：NewValues


### 第 91 次发布

发布时间：2023-02-03 01:42:20

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeEnvs](https://cloud.tencent.com/document/api/876/34820)

	* 新增出参：Total


### 第 90 次发布

发布时间：2023-02-02 01:48:18

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeCloudBaseRunVersion](https://cloud.tencent.com/document/api/876/53438)

	* 新增出参：PolicyDetail, Cpu, Mem

* [EstablishCloudBaseRunServer](https://cloud.tencent.com/document/api/876/49626)

	* 新增出参：Result


### 第 89 次发布

发布时间：2022-12-23 01:54:25

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeCloudBaseRunServerVersion](https://cloud.tencent.com/document/api/876/49739)

	* 新增出参：TkeClusterInfo, TkeWorkloadType


新增数据结构：

* [CloudBaseRunServiceVolumeHostPath](https://cloud.tencent.com/document/api/876/34822#CloudBaseRunServiceVolumeHostPath)
* [TkeClusterInfo](https://cloud.tencent.com/document/api/876/34822#TkeClusterInfo)

修改数据结构：

* [CloudRunServiceVolume](https://cloud.tencent.com/document/api/876/34822#CloudRunServiceVolume)

	* 新增成员：HostPath


### 第 88 次发布

发布时间：2022-10-21 06:43:29

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateWxCloudBaseRunServerDBCluster](https://cloud.tencent.com/document/api/876/55636)

	* 新增入参：LowerCaseTableName


### 第 87 次发布

发布时间：2022-10-19 06:42:09

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [ModifyClsTopic](https://cloud.tencent.com/document/api/876/81547)

### 第 86 次发布

发布时间：2022-08-23 06:50:01

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [EnvBillingInfoItem](https://cloud.tencent.com/document/api/876/34822#EnvBillingInfoItem)

	* 新增成员：EnableOverrun, ExtPackageType


### 第 85 次发布

发布时间：2022-08-01 11:52:06

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeBaasPackageList](https://cloud.tencent.com/document/api/876/78167)

新增数据结构：

* [BaasPackageInfo](https://cloud.tencent.com/document/api/876/34822#BaasPackageInfo)

### 第 84 次发布

发布时间：2022-07-30 15:18:11

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [EnvInfo](https://cloud.tencent.com/document/api/876/34822#EnvInfo)

	* 新增成员：PackageType

* [LogServiceInfo](https://cloud.tencent.com/document/api/876/34822#LogServiceInfo)

	* 新增成员：Period


### 第 83 次发布

发布时间：2022-04-26 06:16:06

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeWxCloudBaseRunEnvs](https://cloud.tencent.com/document/api/876/55053)

	* 新增入参：AllRegions


修改数据结构：

* [DatabasesInfo](https://cloud.tencent.com/document/api/876/34822#DatabasesInfo)

	* 新增成员：UpdateTime

* [EnvInfo](https://cloud.tencent.com/document/api/876/34822#EnvInfo)

	* 新增成员：IsDauPackage


### 第 82 次发布

发布时间：2022-03-29 08:15:41

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateWxCloudBaseRunEnv](https://cloud.tencent.com/document/api/876/55054)

	* 新增入参：IsOpenCloudInvoke


### 第 81 次发布

发布时间：2022-03-21 08:16:19

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [FreezeCloudBaseRunServers](https://cloud.tencent.com/document/api/876/71436)
* [UnfreezeCloudBaseRunServers](https://cloud.tencent.com/document/api/876/71435)

### 第 80 次发布

发布时间：2022-01-17 08:12:48

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [EnvInfo](https://cloud.tencent.com/document/api/876/34822#EnvInfo)

	* 新增成员：EnvType


### 第 79 次发布

发布时间：2022-01-14 08:15:31

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateWxCloudBaseRunServerDBCluster](https://cloud.tencent.com/document/api/876/55636)

	* 新增入参：DbVersion


### 第 78 次发布

发布时间：2022-01-13 09:02:45

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [SearchClsLog](https://cloud.tencent.com/document/api/876/68117)

新增数据结构：

* [LogObject](https://cloud.tencent.com/document/api/876/34822#LogObject)
* [LogResObject](https://cloud.tencent.com/document/api/876/34822#LogResObject)

### 第 77 次发布

发布时间：2021-12-07 08:11:30

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CommonServiceAPI](https://cloud.tencent.com/document/api/876/41230)

	* 新增入参：ApiRole


### 第 76 次发布

发布时间：2021-11-26 08:13:21

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeCloudBaseRunOneClickTaskExternal](https://cloud.tencent.com/document/api/876/63779)

	* 新增出参：StartTime, Steps


新增数据结构：

* [OneClickTaskStepInfo](https://cloud.tencent.com/document/api/876/34822#OneClickTaskStepInfo)

### 第 75 次发布

发布时间：2021-11-15 08:13:00

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [ModifyCloudBaseRunServerVersion](https://cloud.tencent.com/document/api/876/63949)

修改数据结构：

* [CloudBaseRunServerVersionItem](https://cloud.tencent.com/document/api/876/34822#CloudBaseRunServerVersionItem)

	* 新增成员：Architecture


### 第 74 次发布

发布时间：2021-11-10 08:11:02

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeCloudBaseRunOneClickTaskExternal](https://cloud.tencent.com/document/api/876/63779)

	* 新增出参：UserEnvId


### 第 73 次发布

发布时间：2021-11-09 08:15:23

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeCloudBaseRunOneClickTaskExternal](https://cloud.tencent.com/document/api/876/63779)
* [DescribeCloudBaseRunServerDomainName](https://cloud.tencent.com/document/api/876/63778)

### 第 72 次发布

发布时间：2021-10-26 08:13:05

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeCloudBaseRunPodList](https://cloud.tencent.com/document/api/876/63345)
* [DescribeCloudBaseRunServer](https://cloud.tencent.com/document/api/876/63346)

新增数据结构：

* [CloudBaseRunKVPriority](https://cloud.tencent.com/document/api/876/34822#CloudBaseRunKVPriority)
* [CloudBaseRunServerVersionItem](https://cloud.tencent.com/document/api/876/34822#CloudBaseRunServerVersionItem)

### 第 71 次发布

发布时间：2021-10-25 08:10:05

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [OrderInfo](https://cloud.tencent.com/document/api/876/34822#OrderInfo)

	* 新增成员：Flag, ReqBody


### 第 70 次发布

发布时间：2021-09-29 08:09:41

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeCloudBaseBuildService](https://cloud.tencent.com/document/api/876/48345)

	* 新增入参：Suffix


### 第 69 次发布

发布时间：2021-09-27 08:16:19

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeCloudBaseRunAllVpcs](https://cloud.tencent.com/document/api/876/61954)
* [DescribeCloudBaseRunOperationTypes](https://cloud.tencent.com/document/api/876/61953)
* [DescribeCloudBaseRunVersionRsByCondition](https://cloud.tencent.com/document/api/876/61952)

### 第 68 次发布

发布时间：2021-09-14 08:08:33

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateCloudBaseRunServerVersion](https://cloud.tencent.com/document/api/876/49627)

	* 新增入参：PolicyDetail

* [DescribeCloudBaseRunServerVersion](https://cloud.tencent.com/document/api/876/49739)

	* 新增出参：PolicyDetail

* [RollUpdateCloudBaseRunServerVersion](https://cloud.tencent.com/document/api/876/55676)

	* 新增入参：PolicyDetail


新增数据结构：

* [HpaPolicy](https://cloud.tencent.com/document/api/876/34822#HpaPolicy)

### 第 67 次发布

发布时间：2021-09-10 08:08:32

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeCloudBaseProjectLatestVersionList](https://cloud.tencent.com/document/api/876/52615)

	* 新增入参：CiId


修改数据结构：

* [CloudBaseProjectVersion](https://cloud.tencent.com/document/api/876/34822#CloudBaseProjectVersion)

	* 新增成员：BuildPercent


### 第 66 次发布

发布时间：2021-09-09 08:08:15

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateCloudBaseRunServerVersion](https://cloud.tencent.com/document/api/876/49627)

	* 新增入参：HasDockerfile, BaseImage, EntryPoint, RepoLanguage, UploadFilename

* [DescribeCloudBaseRunServerVersion](https://cloud.tencent.com/document/api/876/49739)

	* 新增出参：HasDockerfile, BaseImage, EntryPoint, RepoLanguage


修改数据结构：

* [CodeSource](https://cloud.tencent.com/document/api/876/34822#CodeSource)

	* 新增成员：ProjectName


### 第 65 次发布

发布时间：2021-09-06 08:08:19

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeActivityInfo](https://cloud.tencent.com/document/api/876/61163)
* [DescribeUserActivityInfo](https://cloud.tencent.com/document/api/876/61162)

修改接口：

* [DescribeActivityRecord](https://cloud.tencent.com/document/api/876/59181)

	* 新增入参：IsDeletedList

* [ReplaceActivityRecord](https://cloud.tencent.com/document/api/876/59180)

	* <font color="#dd0000">**修改入参**：</font>SubStatus, ChannelToken, Channel


新增数据结构：

* [ActivityInfoItem](https://cloud.tencent.com/document/api/876/34822#ActivityInfoItem)

修改数据结构：

* [ActivityRecordItem](https://cloud.tencent.com/document/api/876/34822#ActivityRecordItem)

	* 新增成员：SubStatusInt, IsDeleted


### 第 64 次发布

发布时间：2021-09-02 08:07:27

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [StandaloneGatewayInfo](https://cloud.tencent.com/document/api/876/34822#StandaloneGatewayInfo)

	* 新增成员：PublicClbIp, InternalClbIp


### 第 63 次发布

发布时间：2021-09-01 08:08:24

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeEnvDealRegion](https://cloud.tencent.com/document/api/876/60995)

### 第 62 次发布

发布时间：2021-08-18 08:08:32

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [CodeSource](https://cloud.tencent.com/document/api/876/34822#CodeSource)

	* 新增成员：ProjectId


### 第 61 次发布

发布时间：2021-08-05 08:08:33

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeCurveData](https://cloud.tencent.com/document/api/876/59512)

新增数据结构：

* [ClsInfo](https://cloud.tencent.com/document/api/876/34822#ClsInfo)

修改数据结构：

* [EnvInfo](https://cloud.tencent.com/document/api/876/34822#EnvInfo)

	* 新增成员：CustomLogServices


### 第 60 次发布

发布时间：2021-08-04 08:08:27

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateStandaloneGateway](https://cloud.tencent.com/document/api/876/59478)
* [DescribeStandaloneGateway](https://cloud.tencent.com/document/api/876/59477)
* [DescribeStandaloneGatewayPackage](https://cloud.tencent.com/document/api/876/59476)
* [DestroyStandaloneGateway](https://cloud.tencent.com/document/api/876/59475)
* [TurnOffStandaloneGateway](https://cloud.tencent.com/document/api/876/59474)
* [TurnOnStandaloneGateway](https://cloud.tencent.com/document/api/876/59473)

修改接口：

* [RollUpdateCloudBaseRunServerVersion](https://cloud.tencent.com/document/api/876/55676)

	* 新增入参：IsUpdateCls


新增数据结构：

* [BackendServiceInfo](https://cloud.tencent.com/document/api/876/34822#BackendServiceInfo)
* [StandaloneGatewayInfo](https://cloud.tencent.com/document/api/876/34822#StandaloneGatewayInfo)
* [StandaloneGatewayPackageInfo](https://cloud.tencent.com/document/api/876/34822#StandaloneGatewayPackageInfo)

### 第 59 次发布

发布时间：2021-07-30 08:08:58

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [BindEnvGateway](https://cloud.tencent.com/document/api/876/59324)

### 第 58 次发布

发布时间：2021-07-28 08:08:45

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeActivityRecord](https://cloud.tencent.com/document/api/876/59181)

	* 新增入参：Statuses


### 第 57 次发布

发布时间：2021-07-27 08:09:41

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeActivityRecord](https://cloud.tencent.com/document/api/876/59181)
* [ReplaceActivityRecord](https://cloud.tencent.com/document/api/876/59180)

新增数据结构：

* [ActivityRecordItem](https://cloud.tencent.com/document/api/876/34822#ActivityRecordItem)

### 第 56 次发布

发布时间：2021-07-16 08:09:05

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeEnvPostpaidDeduct](https://cloud.tencent.com/document/api/876/58755)
* [DescribeSpecialCostItems](https://cloud.tencent.com/document/api/876/58754)

新增数据结构：

* [PostPaidEnvDeductInfo](https://cloud.tencent.com/document/api/876/34822#PostPaidEnvDeductInfo)
* [SpecialCostItem](https://cloud.tencent.com/document/api/876/34822#SpecialCostItem)

### 第 55 次发布

发布时间：2021-07-13 08:11:35

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DeleteCloudBaseProjectLatestVersion](https://cloud.tencent.com/document/api/876/51097)

	* 新增入参：KeepResource

* [DescribeEnvLimit](https://cloud.tencent.com/document/api/876/42146)

	* 新增出参：ChangePayTotal, CurrentChangePayTotal, ChangePayMonthly, CurrentChangePayMonthly


### 第 54 次发布

发布时间：2021-07-12 08:08:34

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DeleteCloudBaseRunServerVersion](https://cloud.tencent.com/document/api/876/58477)

### 第 53 次发布

发布时间：2021-07-07 10:03:19

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeCloudBaseRunConfForGateWay](https://cloud.tencent.com/document/api/876/58233)
* [ModifyCloudBaseRunServerFlowConf](https://cloud.tencent.com/document/api/876/58232)

修改接口：

* [EstablishCloudBaseRunServer](https://cloud.tencent.com/document/api/876/49626)

	* 新增入参：ServerPath


新增数据结构：

* [CloudBaseRunForGatewayConf](https://cloud.tencent.com/document/api/876/34822#CloudBaseRunForGatewayConf)
* [CloudBaseRunVersionFlowItem](https://cloud.tencent.com/document/api/876/34822#CloudBaseRunVersionFlowItem)
* [ObjectKV](https://cloud.tencent.com/document/api/876/34822#ObjectKV)

### 第 52 次发布

发布时间：2021-07-06 08:09:07

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [EstablishCloudBaseRunServer](https://cloud.tencent.com/document/api/876/49626)

	* 新增入参：IsCreatePath


### 第 51 次发布

发布时间：2021-06-18 08:07:55

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeHostingDomainTask](https://cloud.tencent.com/document/api/876/57514)

### 第 50 次发布

发布时间：2021-06-01 08:09:10

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeEnvLimit](https://cloud.tencent.com/document/api/876/42146)

	* 新增出参：MaxFreeTrialNum, CurrentFreeTrialNum


### 第 49 次发布

发布时间：2021-05-31 08:08:10

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [EstablishCloudBaseRunServer](https://cloud.tencent.com/document/api/876/49626)

	* 新增入参：OpenAccessTypes


### 第 48 次发布

发布时间：2021-05-21 08:07:49

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateCloudBaseRunServerVersion](https://cloud.tencent.com/document/api/876/49627)

	* 新增入参：ServiceVolumeMounts


新增数据结构：

* [CloudBaseRunEmptyDirVolumeSource](https://cloud.tencent.com/document/api/876/34822#CloudBaseRunEmptyDirVolumeSource)
* [CloudBaseRunServiceVolumeMount](https://cloud.tencent.com/document/api/876/34822#CloudBaseRunServiceVolumeMount)
* [Tag](https://cloud.tencent.com/document/api/876/34822#Tag)

修改数据结构：

* [CloudRunServiceVolume](https://cloud.tencent.com/document/api/876/34822#CloudRunServiceVolume)

	* 新增成员：EmptyDir

* [EnvInfo](https://cloud.tencent.com/document/api/876/34822#EnvInfo)

	* 新增成员：Tags


### 第 47 次发布

发布时间：2021-05-12 08:07:37

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [RollUpdateCloudBaseRunServerVersion](https://cloud.tencent.com/document/api/876/55676)

修改接口：

* [CreateCloudBaseRunServerVersion](https://cloud.tencent.com/document/api/876/49627)

	* 新增入参：IsCreateJnsGw


### 第 46 次发布

发布时间：2021-05-11 08:08:22

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateWxCloudBaseRunServerDBCluster](https://cloud.tencent.com/document/api/876/55636)

### 第 45 次发布

发布时间：2021-04-30 08:07:30

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeWxCloudBaseRunEnvs](https://cloud.tencent.com/document/api/876/55053)

	* <font color="#dd0000">**修改入参**：</font>WxAppId


### 第 44 次发布

发布时间：2021-04-25 10:17:18

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateWxCloudBaseRunEnv](https://cloud.tencent.com/document/api/876/55054)
* [DescribeWxCloudBaseRunEnvs](https://cloud.tencent.com/document/api/876/55053)
* [DescribeWxCloudBaseRunSubNets](https://cloud.tencent.com/document/api/876/55052)

### 第 43 次发布

发布时间：2021-04-08 08:07:28

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DeleteWxGatewayRoute](https://cloud.tencent.com/document/api/876/54393)
* [EstablishWxGatewayRoute](https://cloud.tencent.com/document/api/876/54392)

### 第 42 次发布

发布时间：2021-04-02 08:07:38

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeCloudBaseProjectVersionList](https://cloud.tencent.com/document/api/876/54302)

修改接口：

* [CreateAndDeployCloudBaseProject](https://cloud.tencent.com/document/api/876/52616)

	* 新增入参：AutoDeployOnCodeChange, RepoUrl


修改数据结构：

* [CodeSource](https://cloud.tencent.com/document/api/876/34822#CodeSource)

	* 新增成员：Branch


### 第 41 次发布

发布时间：2021-03-31 08:07:29

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [CloudBaseProjectVersion](https://cloud.tencent.com/document/api/876/34822#CloudBaseProjectVersion)

	* 新增成员：RepoUrl, AutoDeployOnCodeChange


### 第 40 次发布

发布时间：2021-03-17 08:08:04

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeExtensionUploadInfo](https://cloud.tencent.com/document/api/876/53704)

新增数据结构：

* [ExtensionFile](https://cloud.tencent.com/document/api/876/34822#ExtensionFile)
* [ExtensionFileInfo](https://cloud.tencent.com/document/api/876/34822#ExtensionFileInfo)

### 第 39 次发布

发布时间：2021-03-16 08:08:43

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateCloudBaseRunServerVersion](https://cloud.tencent.com/document/api/876/49627)

	* 新增出参：RunId


### 第 38 次发布

发布时间：2021-03-09 08:08:00

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeCloudBaseRunVersion](https://cloud.tencent.com/document/api/876/53438)

### 第 37 次发布

发布时间：2021-02-24 08:06:59

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeCloudBaseBuildService](https://cloud.tencent.com/document/api/876/48345)

	* 新增出参：OutDate


### 第 36 次发布

发布时间：2021-02-04 08:32:28

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateCloudBaseRunServerVersion](https://cloud.tencent.com/document/api/876/49627)

	* 新增入参：ServiceVolumes


新增数据结构：

* [CloudRunServiceVolume](https://cloud.tencent.com/document/api/876/34822#CloudRunServiceVolume)

修改数据结构：

* [CloudBaseRunSideSpec](https://cloud.tencent.com/document/api/876/34822#CloudBaseRunSideSpec)

	* 新增成员：VolumeMountInfos


### 第 35 次发布

发布时间：2021-02-01 08:06:58

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateCloudBaseRunServerVersion](https://cloud.tencent.com/document/api/876/49627)

	* 新增入参：Security

* [DescribeCloudBaseBuildService](https://cloud.tencent.com/document/api/876/48345)

	* 新增入参：ServiceVersion

	* 新增出参：DownloadUrl, DownloadHeaders


新增数据结构：

* [CloudBaseCapabilities](https://cloud.tencent.com/document/api/876/34822#CloudBaseCapabilities)
* [CloudBaseSecurityContext](https://cloud.tencent.com/document/api/876/34822#CloudBaseSecurityContext)

修改数据结构：

* [CloudBaseRunNfsVolumeSource](https://cloud.tencent.com/document/api/876/34822#CloudBaseRunNfsVolumeSource)

	* 新增成员：SecretName, EnableEmptyDirVolume

* [CloudBaseRunSideSpec](https://cloud.tencent.com/document/api/876/34822#CloudBaseRunSideSpec)

	* 新增成员：Security


### 第 34 次发布

发布时间：2021-01-29 08:07:38

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateAndDeployCloudBaseProject](https://cloud.tencent.com/document/api/876/52616)
* [DescribeCloudBaseProjectLatestVersionList](https://cloud.tencent.com/document/api/876/52615)

新增数据结构：

* [CloudBaseProjectVersion](https://cloud.tencent.com/document/api/876/34822#CloudBaseProjectVersion)
* [CodeSource](https://cloud.tencent.com/document/api/876/34822#CodeSource)

### 第 33 次发布

发布时间：2021-01-25 08:07:04

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeSmsQuotas](https://cloud.tencent.com/document/api/876/52410)

新增数据结构：

* [SmsFreeQuota](https://cloud.tencent.com/document/api/876/34822#SmsFreeQuota)

### 第 32 次发布

发布时间：2021-01-19 08:08:07

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeQuotaData](https://cloud.tencent.com/document/api/876/42145)

	* 新增出参：SubValue


### 第 31 次发布

发布时间：2021-01-18 08:06:55

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateCloudBaseRunServerVersion](https://cloud.tencent.com/document/api/876/49627)

	* 新增入参：ImageReuseKey, SidecarSpecs


新增数据结构：

* [CloudBaseRunSideSpec](https://cloud.tencent.com/document/api/876/34822#CloudBaseRunSideSpec)

### 第 30 次发布

发布时间：2021-01-01 08:06:24

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribePostpayFreeQuotas](https://cloud.tencent.com/document/api/876/51672)

新增数据结构：

* [FreequotaInfo](https://cloud.tencent.com/document/api/876/34822#FreequotaInfo)

### 第 29 次发布

发布时间：2020-12-17 08:07:04

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DeleteCloudBaseProjectLatestVersion](https://cloud.tencent.com/document/api/876/51097)

### 第 28 次发布

发布时间：2020-12-08 08:07:30

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [EstablishCloudBaseRunServer](https://cloud.tencent.com/document/api/876/49626)

	* 新增入参：VpcInfo, PublicAccess


新增数据结构：

* [CloudBaseRunVpcInfo](https://cloud.tencent.com/document/api/876/34822#CloudBaseRunVpcInfo)

### 第 27 次发布

发布时间：2020-11-26 08:06:15

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeCloudBaseRunResourceForExtend](https://cloud.tencent.com/document/api/876/50313)

修改接口：

* [CreateCloudBaseRunServerVersion](https://cloud.tencent.com/document/api/876/49627)

	* 新增入参：ServerPath


### 第 26 次发布

发布时间：2020-11-23 08:07:05

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateCloudBaseRunServerVersion](https://cloud.tencent.com/document/api/876/49627)

	* 新增入参：OperatorRemark

* [EstablishCloudBaseRunServer](https://cloud.tencent.com/document/api/876/49626)

	* 新增入参：OperatorRemark, Source


### 第 25 次发布

发布时间：2020-11-20 08:06:32

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeCloudBaseRunResource](https://cloud.tencent.com/document/api/876/50108)

新增数据结构：

* [CloudBaseRunVpcSubnet](https://cloud.tencent.com/document/api/876/34822#CloudBaseRunVpcSubnet)

### 第 24 次发布

发布时间：2020-11-16 08:06:45

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateStaticStore](https://cloud.tencent.com/document/api/876/42152)

	* 新增入参：EnableUnion


### 第 23 次发布

发布时间：2020-11-06 08:06:11

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeCloudBaseRunServerVersion](https://cloud.tencent.com/document/api/876/49739)

### 第 22 次发布

发布时间：2020-11-03 08:07:08

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateCloudBaseRunResource](https://cloud.tencent.com/document/api/876/49628)
* [CreateCloudBaseRunServerVersion](https://cloud.tencent.com/document/api/876/49627)
* [EstablishCloudBaseRunServer](https://cloud.tencent.com/document/api/876/49626)

新增数据结构：

* [CloudBaseEsInfo](https://cloud.tencent.com/document/api/876/34822#CloudBaseEsInfo)
* [CloudBaseRunImageSecretInfo](https://cloud.tencent.com/document/api/876/34822#CloudBaseRunImageSecretInfo)
* [CloudBaseRunNfsVolumeSource](https://cloud.tencent.com/document/api/876/34822#CloudBaseRunNfsVolumeSource)
* [CloudBaseRunVolumeMount](https://cloud.tencent.com/document/api/876/34822#CloudBaseRunVolumeMount)

### 第 21 次发布

发布时间：2020-10-13 08:06:21

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeDownloadFile](https://cloud.tencent.com/document/api/876/49049)

### 第 20 次发布

发布时间：2020-09-30 08:06:02

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [EnvInfo](https://cloud.tencent.com/document/api/876/34822#EnvInfo)

	* 新增成员：PayMode, IsDefault, Region


### 第 19 次发布

发布时间：2020-09-24 08:06:00

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreatePostpayPackage](https://cloud.tencent.com/document/api/876/45287)

	* 新增入参：Flag


### 第 18 次发布

发布时间：2020-09-21 08:05:50

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeCloudBaseRunVersionSnapshot](https://cloud.tencent.com/document/api/876/48528)

新增数据结构：

* [CloudBaseCodeRepoDetail](https://cloud.tencent.com/document/api/876/34822#CloudBaseCodeRepoDetail)
* [CloudBaseCodeRepoName](https://cloud.tencent.com/document/api/876/34822#CloudBaseCodeRepoName)
* [CloudBaseRunImageInfo](https://cloud.tencent.com/document/api/876/34822#CloudBaseRunImageInfo)
* [CloudRunServiceSimpleVersionSnapshot](https://cloud.tencent.com/document/api/876/34822#CloudRunServiceSimpleVersionSnapshot)

### 第 17 次发布

发布时间：2020-09-15 08:07:15

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeCloudBaseBuildService](https://cloud.tencent.com/document/api/876/48345)

新增数据结构：

* [KVPair](https://cloud.tencent.com/document/api/876/34822#KVPair)

### 第 16 次发布

发布时间：2020-08-14 08:18:36

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DestroyEnv](https://cloud.tencent.com/document/api/876/42149)

	* 新增入参：BypassCheck


### 第 15 次发布

发布时间：2020-07-28 08:17:40

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [OrderInfo](https://cloud.tencent.com/document/api/876/34822#OrderInfo)

	* 新增成员：ExtensionId, ResourceReady


### 第 14 次发布

发布时间：2020-07-23 08:17:31

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreatePostpayPackage](https://cloud.tencent.com/document/api/876/45287)

	* 新增入参：ExtensionId


### 第 13 次发布

发布时间：2020-07-02 08:17:10

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeEndUsers](https://cloud.tencent.com/document/api/876/42150)

	* 新增入参：Offset, Limit

	* <font color="#dd0000">**修改入参**：</font>UUIds


修改数据结构：

* [EndUserInfo](https://cloud.tencent.com/document/api/876/34822#EndUserInfo)

	* 新增成员：UserName


### 第 12 次发布

发布时间：2020-06-23 08:17:01

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [EndUserInfo](https://cloud.tencent.com/document/api/876/34822#EndUserInfo)

	* 新增成员：HasPassword


### 第 11 次发布

发布时间：2020-06-18 08:16:38

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [ModifyEndUser](https://cloud.tencent.com/document/api/876/45625)

### 第 10 次发布

发布时间：2020-06-04 08:16:56

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreatePostpayPackage](https://cloud.tencent.com/document/api/876/45287)

### 第 9 次发布

发布时间：2020-06-01 08:17:35

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribePostpayPackageFreeQuotas](https://cloud.tencent.com/document/api/876/45040)

新增数据结构：

* [PackageFreeQuotaInfo](https://cloud.tencent.com/document/api/876/34822#PackageFreeQuotaInfo)

修改数据结构：

* [EnvInfo](https://cloud.tencent.com/document/api/876/34822#EnvInfo)

	* 新增成员：EnvChannel


### 第 8 次发布

发布时间：2020-05-20 08:16:58

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeEndUserLoginStatistic](https://cloud.tencent.com/document/api/876/44749)
* [DescribeEndUserStatistic](https://cloud.tencent.com/document/api/876/44748)
* [DescribeExtraPkgBillingInfo](https://cloud.tencent.com/document/api/876/44747)

新增数据结构：

* [EnvBillingInfoItem](https://cloud.tencent.com/document/api/876/34822#EnvBillingInfoItem)
* [LoginStatistic](https://cloud.tencent.com/document/api/876/34822#LoginStatistic)
* [OrderInfo](https://cloud.tencent.com/document/api/876/34822#OrderInfo)
* [PlatformStatistic](https://cloud.tencent.com/document/api/876/34822#PlatformStatistic)

### 第 7 次发布

发布时间：2020-04-27 08:15:37

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeEnvFreeQuota](https://cloud.tencent.com/document/api/876/43848)

新增数据结构：

* [PostpayEnvQuota](https://cloud.tencent.com/document/api/876/34822#PostpayEnvQuota)

### 第 6 次发布

发布时间：2020-03-23 08:13:05

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateAuthDomain](https://cloud.tencent.com/document/api/876/42764)

### 第 5 次发布

发布时间：2020-03-20 08:14:00

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeEnvs](https://cloud.tencent.com/document/api/876/34820)

	* 新增入参：IsVisible, Channels


### 第 4 次发布

发布时间：2020-03-12 08:00:30

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CheckTcbService](https://cloud.tencent.com/document/api/876/42154)
* [CreateHostingDomain](https://cloud.tencent.com/document/api/876/42153)
* [CreateStaticStore](https://cloud.tencent.com/document/api/876/42152)
* [DeleteEndUser](https://cloud.tencent.com/document/api/876/42147)
* [DescribeAuthDomains](https://cloud.tencent.com/document/api/876/42151)
* [DescribeEndUsers](https://cloud.tencent.com/document/api/876/42150)
* [DescribeEnvLimit](https://cloud.tencent.com/document/api/876/42146)
* [DescribeQuotaData](https://cloud.tencent.com/document/api/876/42145)
* [DestroyEnv](https://cloud.tencent.com/document/api/876/42149)
* [DestroyStaticStore](https://cloud.tencent.com/document/api/876/42148)
* [ReinstateEnv](https://cloud.tencent.com/document/api/876/42144)

修改接口：

* [ModifyEnv](https://cloud.tencent.com/document/api/876/34818)

	* <font color="#dd0000">**修改入参**：</font>Alias


新增数据结构：

* [AuthDomain](https://cloud.tencent.com/document/api/876/34822#AuthDomain)
* [EndUserInfo](https://cloud.tencent.com/document/api/876/34822#EndUserInfo)

### 第 3 次发布

发布时间：2020-02-24 16:14:08

本次发布包含了以下内容：

改善已有的文档。

<font color="#dd0000">**删除接口**：</font>

* CreateMysqlInstance
* IsolateMysqlInstance
* OfflineMysqlInstance
* UpgradeMysqlInstance

### 第 2 次发布

发布时间：2020-02-13 09:57:24

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CommonServiceAPI](https://cloud.tencent.com/document/api/876/41230)
* [CreateMysqlInstance](https://cloud.tencent.com/document/api/876/41235)
* [IsolateMysqlInstance](https://cloud.tencent.com/document/api/876/41234)
* [OfflineMysqlInstance](https://cloud.tencent.com/document/api/876/41233)
* [UpgradeMysqlInstance](https://cloud.tencent.com/document/api/876/41232)

新增数据结构：

* [LogServiceInfo](https://cloud.tencent.com/document/api/876/34822#LogServiceInfo)
* [StaticStorageInfo](https://cloud.tencent.com/document/api/876/34822#StaticStorageInfo)

修改数据结构：

* [EnvInfo](https://cloud.tencent.com/document/api/876/34822#EnvInfo)

	* 新增成员：LogServices, StaticStorages, IsAutoDegrade


### 第 1 次发布

发布时间：2019-05-09 21:11:35

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeDatabaseACL](https://cloud.tencent.com/document/api/876/34821)
* [DescribeEnvs](https://cloud.tencent.com/document/api/876/34820)
* [ModifyDatabaseACL](https://cloud.tencent.com/document/api/876/34819)
* [ModifyEnv](https://cloud.tencent.com/document/api/876/34818)

新增数据结构：

* [DatabasesInfo](https://cloud.tencent.com/document/api/876/34822#DatabasesInfo)
* [EnvInfo](https://cloud.tencent.com/document/api/876/34822#EnvInfo)
* [FunctionInfo](https://cloud.tencent.com/document/api/876/34822#FunctionInfo)
* [StorageInfo](https://cloud.tencent.com/document/api/876/34822#StorageInfo)




## 云托管 CloudBase Run(tcbr) 版本：2022-02-17

### 第 9 次发布

发布时间：2023-03-08 01:54:20

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateCloudRunEnv](https://cloud.tencent.com/document/api/1243/75707)

	* 新增入参：EnvId


### 第 8 次发布

发布时间：2022-08-23 06:50:39

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [ServerBaseInfo](https://cloud.tencent.com/document/api/1243/75713#ServerBaseInfo)

	* 新增成员：CustomDomainNames


### 第 7 次发布

发布时间：2022-08-15 06:39:26

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [ServerBaseInfo](https://cloud.tencent.com/document/api/1243/75713#ServerBaseInfo)

	* 新增成员：AccessTypes


### 第 6 次发布

发布时间：2022-08-02 06:31:39

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [EnvBaseInfo](https://cloud.tencent.com/document/api/1243/75713#EnvBaseInfo)

	* 新增成员：SubnetIds


### 第 5 次发布

发布时间：2022-07-01 06:17:30

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeCloudRunServers](https://cloud.tencent.com/document/api/1243/75710)

	* 新增入参：PageSize, PageNum

	* 新增出参：Total


### 第 4 次发布

发布时间：2022-06-28 06:16:23

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeCloudRunServerDetail](https://cloud.tencent.com/document/api/1243/75711)

	* 新增出参：OnlineVersionInfos


新增数据结构：

* [OnlineVersionInfo](https://cloud.tencent.com/document/api/1243/75713#OnlineVersionInfo)

### 第 3 次发布

发布时间：2022-06-24 06:17:45

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeServerManageTask](https://cloud.tencent.com/document/api/1243/76021)

新增数据结构：

* [ServerManageTaskInfo](https://cloud.tencent.com/document/api/1243/75713#ServerManageTaskInfo)
* [TaskStepInfo](https://cloud.tencent.com/document/api/1243/75713#TaskStepInfo)

### 第 2 次发布

发布时间：2022-06-22 06:13:21

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [OperateServerManage](https://cloud.tencent.com/document/api/1243/75873)
* [ReleaseGray](https://cloud.tencent.com/document/api/1243/75872)

新增数据结构：

* [ObjectKV](https://cloud.tencent.com/document/api/1243/75713#ObjectKV)
* [VersionFlowInfo](https://cloud.tencent.com/document/api/1243/75713#VersionFlowInfo)

### 第 1 次发布

发布时间：2022-06-16 14:56:04

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateCloudRunEnv](https://cloud.tencent.com/document/api/1243/75707)
* [CreateCloudRunServer](https://cloud.tencent.com/document/api/1243/75712)
* [DescribeCloudRunEnvs](https://cloud.tencent.com/document/api/1243/75706)
* [DescribeCloudRunServerDetail](https://cloud.tencent.com/document/api/1243/75711)
* [DescribeCloudRunServers](https://cloud.tencent.com/document/api/1243/75710)
* [DescribeEnvBaseInfo](https://cloud.tencent.com/document/api/1243/75701)
* [UpdateCloudRunServer](https://cloud.tencent.com/document/api/1243/75709)

新增数据结构：

* [BuildPacksInfo](https://cloud.tencent.com/document/api/1243/75713#BuildPacksInfo)
* [ClsInfo](https://cloud.tencent.com/document/api/1243/75713#ClsInfo)
* [DatabasesInfo](https://cloud.tencent.com/document/api/1243/75713#DatabasesInfo)
* [DeployParam](https://cloud.tencent.com/document/api/1243/75713#DeployParam)
* [EnvBaseInfo](https://cloud.tencent.com/document/api/1243/75713#EnvBaseInfo)
* [EnvInfo](https://cloud.tencent.com/document/api/1243/75713#EnvInfo)
* [FunctionInfo](https://cloud.tencent.com/document/api/1243/75713#FunctionInfo)
* [HpaPolicy](https://cloud.tencent.com/document/api/1243/75713#HpaPolicy)
* [LogServiceInfo](https://cloud.tencent.com/document/api/1243/75713#LogServiceInfo)
* [RepositoryInfo](https://cloud.tencent.com/document/api/1243/75713#RepositoryInfo)
* [ServerBaseConfig](https://cloud.tencent.com/document/api/1243/75713#ServerBaseConfig)
* [ServerBaseInfo](https://cloud.tencent.com/document/api/1243/75713#ServerBaseInfo)
* [StaticStorageInfo](https://cloud.tencent.com/document/api/1243/75713#StaticStorageInfo)
* [StorageInfo](https://cloud.tencent.com/document/api/1243/75713#StorageInfo)
* [Tag](https://cloud.tencent.com/document/api/1243/75713#Tag)




## 腾讯云释义(tcex) 版本：2020-07-27

### 第 1 次发布

发布时间：2020-10-10 17:07:20

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeInvocationResult](https://cloud.tencent.com/document/api/1266/48991)
* [InvokeService](https://cloud.tencent.com/document/api/1266/48990)

新增数据结构：

* [AlgorithmResult](https://cloud.tencent.com/document/api/1266/48992#AlgorithmResult)




## 腾讯云健康看板(tchd) 版本：2023-03-06

### 第 1 次发布

发布时间：2023-07-10 10:40:45

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeEvents](https://cloud.tencent.com/document/api/1688/94858)

新增数据结构：

* [EventDetail](https://cloud.tencent.com/document/api/1688/94859#EventDetail)
* [ProductEventList](https://cloud.tencent.com/document/api/1688/94859#ProductEventList)




## 腾讯智学课堂分析(tci) 版本：2019-03-18

### 第 8 次发布

发布时间：2020-04-09 08:14:51

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [SubmitImageTask](https://cloud.tencent.com/document/api/1059/36008)

	* 新增入参：EventsCallBack


### 第 7 次发布

发布时间：2019-10-28 16:36:56

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeAttendanceResult](https://cloud.tencent.com/document/api/1059/36020)

	* 新增出参：AbsenceSetInLibs

* [DescribeAudioTask](https://cloud.tencent.com/document/api/1059/36002)

	* 新增出参：AllMuteSlice

* [SubmitAudioTask](https://cloud.tencent.com/document/api/1059/35998)

	* 新增入参：MuteThreshold


新增数据结构：

* [AbsenceInfo](https://cloud.tencent.com/document/api/1059/36031#AbsenceInfo)
* [AllMuteSlice](https://cloud.tencent.com/document/api/1059/36031#AllMuteSlice)
* [MuteSlice](https://cloud.tencent.com/document/api/1059/36031#MuteSlice)

修改数据结构：

* [Function](https://cloud.tencent.com/document/api/1059/36031#Function)

	* 新增成员：EnableMuteDetect


### 第 6 次发布

发布时间：2019-09-27 17:11:27

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [SubmitCheckAttendanceTaskPlus](https://cloud.tencent.com/document/api/1059/38219)
* [SubmitImageTaskPlus](https://cloud.tencent.com/document/api/1059/38218)

### 第 5 次发布

发布时间：2019-09-06 19:30:26

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DeletePerson](https://cloud.tencent.com/document/api/1059/36022)

	* <font color="#dd0000">**修改入参**：</font>LibraryId

* [DescribePerson](https://cloud.tencent.com/document/api/1059/36015)

	* <font color="#dd0000">**修改入参**：</font>LibraryId

* [ModifyPerson](https://cloud.tencent.com/document/api/1059/36012)

	* <font color="#dd0000">**修改入参**：</font>LibraryId

* [SubmitConversationTask](https://cloud.tencent.com/document/api/1059/36307)

	* <font color="#dd0000">**修改入参**：</font>StudentUrl, TeacherUrl


新增数据结构：

* [StudentBodyMovementResult](https://cloud.tencent.com/document/api/1059/36031#StudentBodyMovementResult)

修改数据结构：

* [ImageTaskResult](https://cloud.tencent.com/document/api/1059/36031#ImageTaskResult)

	* <font color="#dd0000">**修改成员**：</font>StudentBodyMovement


### 第 4 次发布

发布时间：2019-08-22 20:36:26

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [ModifyPerson](https://cloud.tencent.com/document/api/1059/36012)

	* 新增出参：FaceInfoSet

* [SubmitDoubleVideoHighlights](https://cloud.tencent.com/document/api/1059/36010)

	* <font color="#dd0000">**修改入参**：</font>SimThreshold


### 第 3 次发布

发布时间：2019-08-16 22:46:19

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [SubmitFullBodyClassTask](https://cloud.tencent.com/document/api/1059/37229)
* [SubmitOneByOneClassTask](https://cloud.tencent.com/document/api/1059/37214)
* [SubmitOpenClassTask](https://cloud.tencent.com/document/api/1059/37231)
* [SubmitPartialBodyClassTask](https://cloud.tencent.com/document/api/1059/37228)
* [SubmitTraditionalClassTask](https://cloud.tencent.com/document/api/1059/37230)

<font color="#dd0000">**删除接口**：</font>

* CheckAttendance

修改接口：

* [AIAssistant](https://cloud.tencent.com/document/api/1059/36030)

	* 新增入参：MaxVideoDuration

* [CreatePerson](https://cloud.tencent.com/document/api/1059/36308)

	* 新增入参：Images, Urls

	* 新增出参：FaceInfoSet

* [DeletePerson](https://cloud.tencent.com/document/api/1059/36022)

	* 新增出参：FaceInfoSet

* [DescribeAITaskResult](https://cloud.tencent.com/document/api/1059/36021)

	* 新增出参：Status

* [TransmitAudioStream](https://cloud.tencent.com/document/api/1059/35997)

	* 新增入参：StorageMode

	* 新增出参：AudioUrl


新增数据结构：

* [TeacherOutScreenResult](https://cloud.tencent.com/document/api/1059/36031#TeacherOutScreenResult)

修改数据结构：

* [ExpressRatioStatistic](https://cloud.tencent.com/document/api/1059/36031#ExpressRatioStatistic)

	* 新增成员：RatioUseDuration

	* <font color="#dd0000">**修改成员**：</font>Express, Ratio

* [ImageTaskFunction](https://cloud.tencent.com/document/api/1059/36031#ImageTaskFunction)

	* 新增成员：EnableTeacherOutScreen

* [ImageTaskResult](https://cloud.tencent.com/document/api/1059/36031#ImageTaskResult)

	* 新增成员：TeacherOutScreen


### 第 2 次发布

发布时间：2019-07-18 21:59:22

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreatePerson](https://cloud.tencent.com/document/api/1059/36308)
* [SubmitConversationTask](https://cloud.tencent.com/document/api/1059/36307)

修改接口：

* [DescribeAudioTask](https://cloud.tencent.com/document/api/1059/36002)

	* 新增出参：AllTexts

* [DescribeConversationTask](https://cloud.tencent.com/document/api/1059/36001)

	* 新增出参：AllTexts

* [SubmitAudioTask](https://cloud.tencent.com/document/api/1059/35998)

	* 新增入参：FileType

	* <font color="#dd0000">**删除入参**：</font>ClassId, Identity

* [TransmitAudioStream](https://cloud.tencent.com/document/api/1059/35997)

	* 新增出参：AllTexts


修改数据结构：

* [Function](https://cloud.tencent.com/document/api/1059/36031#Function)

	* 新增成员：EnableAllText

* [VocabDetailInfomation](https://cloud.tencent.com/document/api/1059/36031#VocabDetailInfomation)

	* <font color="#dd0000">**修改成员**：</font>VocabDetailInfo


### 第 1 次发布

发布时间：2019-07-03 18:41:57

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [AIAssistant](https://cloud.tencent.com/document/api/1059/36030)
* [CancelTask](https://cloud.tencent.com/document/api/1059/36029)
* [CheckAttendance](https://cloud.tencent.com/document/api/1059/36028)
* [CheckFacePhoto](https://cloud.tencent.com/document/api/1059/36027)
* [CreateFace](https://cloud.tencent.com/document/api/1059/36026)
* [CreateLibrary](https://cloud.tencent.com/document/api/1059/36025)
* [CreateVocab](https://cloud.tencent.com/document/api/1059/36006)
* [CreateVocabLib](https://cloud.tencent.com/document/api/1059/36005)
* [DeleteFace](https://cloud.tencent.com/document/api/1059/36024)
* [DeleteLibrary](https://cloud.tencent.com/document/api/1059/36023)
* [DeletePerson](https://cloud.tencent.com/document/api/1059/36022)
* [DeleteVocab](https://cloud.tencent.com/document/api/1059/36004)
* [DeleteVocabLib](https://cloud.tencent.com/document/api/1059/36003)
* [DescribeAITaskResult](https://cloud.tencent.com/document/api/1059/36021)
* [DescribeAttendanceResult](https://cloud.tencent.com/document/api/1059/36020)
* [DescribeAudioTask](https://cloud.tencent.com/document/api/1059/36002)
* [DescribeConversationTask](https://cloud.tencent.com/document/api/1059/36001)
* [DescribeHighlightResult](https://cloud.tencent.com/document/api/1059/36019)
* [DescribeImageTask](https://cloud.tencent.com/document/api/1059/36018)
* [DescribeImageTaskStatistic](https://cloud.tencent.com/document/api/1059/36017)
* [DescribeLibraries](https://cloud.tencent.com/document/api/1059/36016)
* [DescribePerson](https://cloud.tencent.com/document/api/1059/36015)
* [DescribePersons](https://cloud.tencent.com/document/api/1059/36014)
* [DescribeVocab](https://cloud.tencent.com/document/api/1059/36000)
* [DescribeVocabLib](https://cloud.tencent.com/document/api/1059/35999)
* [ModifyLibrary](https://cloud.tencent.com/document/api/1059/36013)
* [ModifyPerson](https://cloud.tencent.com/document/api/1059/36012)
* [SubmitAudioTask](https://cloud.tencent.com/document/api/1059/35998)
* [SubmitCheckAttendanceTask](https://cloud.tencent.com/document/api/1059/36011)
* [SubmitDoubleVideoHighlights](https://cloud.tencent.com/document/api/1059/36010)
* [SubmitHighlights](https://cloud.tencent.com/document/api/1059/36009)
* [SubmitImageTask](https://cloud.tencent.com/document/api/1059/36008)
* [TransmitAudioStream](https://cloud.tencent.com/document/api/1059/35997)

新增数据结构：

* [ASRStat](https://cloud.tencent.com/document/api/1059/36031#ASRStat)
* [ActionCountStatistic](https://cloud.tencent.com/document/api/1059/36031#ActionCountStatistic)
* [ActionDurationRatioStatistic](https://cloud.tencent.com/document/api/1059/36031#ActionDurationRatioStatistic)
* [ActionDurationStatistic](https://cloud.tencent.com/document/api/1059/36031#ActionDurationStatistic)
* [ActionInfo](https://cloud.tencent.com/document/api/1059/36031#ActionInfo)
* [ActionStatistic](https://cloud.tencent.com/document/api/1059/36031#ActionStatistic)
* [ActionType](https://cloud.tencent.com/document/api/1059/36031#ActionType)
* [AttendanceInfo](https://cloud.tencent.com/document/api/1059/36031#AttendanceInfo)
* [BodyMovementResult](https://cloud.tencent.com/document/api/1059/36031#BodyMovementResult)
* [DetailInfo](https://cloud.tencent.com/document/api/1059/36031#DetailInfo)
* [DoubleVideoFunction](https://cloud.tencent.com/document/api/1059/36031#DoubleVideoFunction)
* [ExpressRatioStatistic](https://cloud.tencent.com/document/api/1059/36031#ExpressRatioStatistic)
* [Face](https://cloud.tencent.com/document/api/1059/36031#Face)
* [FaceAttrResult](https://cloud.tencent.com/document/api/1059/36031#FaceAttrResult)
* [FaceDetectStatistic](https://cloud.tencent.com/document/api/1059/36031#FaceDetectStatistic)
* [FaceExpressStatistic](https://cloud.tencent.com/document/api/1059/36031#FaceExpressStatistic)
* [FaceExpressionResult](https://cloud.tencent.com/document/api/1059/36031#FaceExpressionResult)
* [FaceIdentifyResult](https://cloud.tencent.com/document/api/1059/36031#FaceIdentifyResult)
* [FaceIdentifyStatistic](https://cloud.tencent.com/document/api/1059/36031#FaceIdentifyStatistic)
* [FaceInfo](https://cloud.tencent.com/document/api/1059/36031#FaceInfo)
* [FaceInfoResult](https://cloud.tencent.com/document/api/1059/36031#FaceInfoResult)
* [FacePoseResult](https://cloud.tencent.com/document/api/1059/36031#FacePoseResult)
* [FrameInfo](https://cloud.tencent.com/document/api/1059/36031#FrameInfo)
* [Function](https://cloud.tencent.com/document/api/1059/36031#Function)
* [GestureResult](https://cloud.tencent.com/document/api/1059/36031#GestureResult)
* [HLFunction](https://cloud.tencent.com/document/api/1059/36031#HLFunction)
* [HandTrackingResult](https://cloud.tencent.com/document/api/1059/36031#HandTrackingResult)
* [HighlightsInfomation](https://cloud.tencent.com/document/api/1059/36031#HighlightsInfomation)
* [ImageTaskFunction](https://cloud.tencent.com/document/api/1059/36031#ImageTaskFunction)
* [ImageTaskResult](https://cloud.tencent.com/document/api/1059/36031#ImageTaskResult)
* [ImageTaskStatistic](https://cloud.tencent.com/document/api/1059/36031#ImageTaskStatistic)
* [Library](https://cloud.tencent.com/document/api/1059/36031#Library)
* [LightDistributionStatistic](https://cloud.tencent.com/document/api/1059/36031#LightDistributionStatistic)
* [LightLevelRatioStatistic](https://cloud.tencent.com/document/api/1059/36031#LightLevelRatioStatistic)
* [LightResult](https://cloud.tencent.com/document/api/1059/36031#LightResult)
* [LightStandard](https://cloud.tencent.com/document/api/1059/36031#LightStandard)
* [LightStatistic](https://cloud.tencent.com/document/api/1059/36031#LightStatistic)
* [Person](https://cloud.tencent.com/document/api/1059/36031#Person)
* [PersonInfo](https://cloud.tencent.com/document/api/1059/36031#PersonInfo)
* [StandardAudioResult](https://cloud.tencent.com/document/api/1059/36031#StandardAudioResult)
* [StandardImageResult](https://cloud.tencent.com/document/api/1059/36031#StandardImageResult)
* [StandardVideoResult](https://cloud.tencent.com/document/api/1059/36031#StandardVideoResult)
* [StatInfo](https://cloud.tencent.com/document/api/1059/36031#StatInfo)
* [SuspectedInfo](https://cloud.tencent.com/document/api/1059/36031#SuspectedInfo)
* [TextItem](https://cloud.tencent.com/document/api/1059/36031#TextItem)
* [TimeInfoResult](https://cloud.tencent.com/document/api/1059/36031#TimeInfoResult)
* [TimeType](https://cloud.tencent.com/document/api/1059/36031#TimeType)
* [VocabDetailInfomation](https://cloud.tencent.com/document/api/1059/36031#VocabDetailInfomation)
* [VocabStatInfomation](https://cloud.tencent.com/document/api/1059/36031#VocabStatInfomation)
* [WholeTextItem](https://cloud.tencent.com/document/api/1059/36031#WholeTextItem)
* [Word](https://cloud.tencent.com/document/api/1059/36031#Word)
* [WordTimePair](https://cloud.tencent.com/document/api/1059/36031#WordTimePair)




## 服务网格(tcm) 版本：2021-04-13

### 第 22 次发布

发布时间：2024-06-17 02:13:16

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [APM](https://cloud.tencent.com/document/api/1261/63843#APM)

	* 新增成员：NeedDelete

* [LoadBalancer](https://cloud.tencent.com/document/api/1261/63843#LoadBalancer)

	* 新增成员：MasterZoneID, SlaveZoneID

* [LoadBalancerStatus](https://cloud.tencent.com/document/api/1261/63843#LoadBalancerStatus)

	* <font color="#dd0000">**修改成员**：</font>LoadBalancerHostname

* [Mesh](https://cloud.tencent.com/document/api/1261/63843#Mesh)

	* <font color="#dd0000">**修改成员**：</font>CreatedTime, UpdatedTime


### 第 21 次发布

发布时间：2023-10-09 01:23:14

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [CLS](https://cloud.tencent.com/document/api/1261/63843#CLS)

	* 新增成员：Region


### 第 20 次发布

发布时间：2023-02-23 01:54:00

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [LoadBalancerStatus](https://cloud.tencent.com/document/api/1261/63843#LoadBalancerStatus)

	* 新增成员：LoadBalancerHostname


### 第 19 次发布

发布时间：2022-11-29 07:19:41

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeAccessLogConfig](https://cloud.tencent.com/document/api/1261/83255)

	* 新增出参：CLS, Address, EnableServer, EnableStdout, Enable


### 第 18 次发布

发布时间：2022-11-24 06:54:17

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeAccessLogConfig](https://cloud.tencent.com/document/api/1261/83255)
* [ModifyAccessLogConfig](https://cloud.tencent.com/document/api/1261/83254)

### 第 17 次发布

发布时间：2022-11-02 06:40:38

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [ModifyTracingConfig](https://cloud.tencent.com/document/api/1261/82278)

### 第 16 次发布

发布时间：2022-11-01 06:43:32

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [LinkPrometheus](https://cloud.tencent.com/document/api/1261/82203)
* [UnlinkPrometheus](https://cloud.tencent.com/document/api/1261/82202)

### 第 15 次发布

发布时间：2022-10-21 06:44:08

本次发布包含了以下内容：

改善已有的文档。

新增数据结构：

* [EgressGatewayStatus](https://cloud.tencent.com/document/api/1261/63843#EgressGatewayStatus)

修改数据结构：

* [EgressGateway](https://cloud.tencent.com/document/api/1261/63843#EgressGateway)

	* 新增成员：Status

* [IngressGatewayStatus](https://cloud.tencent.com/document/api/1261/63843#IngressGatewayStatus)

	* 新增成员：CurrentVersion, DesiredVersion, State

* [Mesh](https://cloud.tencent.com/document/api/1261/63843#Mesh)

	* 新增成员：TagList


### 第 14 次发布

发布时间：2022-10-20 06:40:11

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [LinkClusterList](https://cloud.tencent.com/document/api/1261/81603)
* [UnlinkCluster](https://cloud.tencent.com/document/api/1261/81602)

### 第 13 次发布

发布时间：2022-10-11 06:54:36

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateMesh](https://cloud.tencent.com/document/api/1261/81314)
* [DeleteMesh](https://cloud.tencent.com/document/api/1261/81313)
* [ModifyMesh](https://cloud.tencent.com/document/api/1261/81312)

### 第 12 次发布

发布时间：2022-09-26 06:52:58

本次发布包含了以下内容：

改善已有的文档。

新增数据结构：

* [CrossRegionConfig](https://cloud.tencent.com/document/api/1261/63843#CrossRegionConfig)

修改数据结构：

* [LoadBalancer](https://cloud.tencent.com/document/api/1261/63843#LoadBalancer)

	* 新增成员：CrossRegionConfig


### 第 11 次发布

发布时间：2022-09-15 06:39:35

本次发布包含了以下内容：

改善已有的文档。

新增数据结构：

* [SmartDNSConfig](https://cloud.tencent.com/document/api/1261/63843#SmartDNSConfig)

修改数据结构：

* [CLS](https://cloud.tencent.com/document/api/1261/63843#CLS)

	* 新增成员：NeedDelete

* [IstioConfig](https://cloud.tencent.com/document/api/1261/63843#IstioConfig)

	* 新增成员：EnablePilotHTTP, DisableHTTPRetry, SmartDNS


### 第 10 次发布

发布时间：2022-07-18 06:16:41

本次发布包含了以下内容：

改善已有的文档。

新增数据结构：

* [ExtensiveCluster](https://cloud.tencent.com/document/api/1261/63843#ExtensiveCluster)
* [ExtensiveClusters](https://cloud.tencent.com/document/api/1261/63843#ExtensiveClusters)
* [Tag](https://cloud.tencent.com/document/api/1261/63843#Tag)

修改数据结构：

* [Cluster](https://cloud.tencent.com/document/api/1261/63843#Cluster)

	* 新增成员：HostedNamespaces

* [LoadBalancer](https://cloud.tencent.com/document/api/1261/63843#LoadBalancer)

	* 新增成员：ZoneID, VipIsp, TgwGroupName, AddressIPVersion, Tags, ExtensiveClusters

	* <font color="#dd0000">**修改成员**：</font>LoadBalancerType

* [WorkloadConfig](https://cloud.tencent.com/document/api/1261/63843#WorkloadConfig)

	* 新增成员：DeployMode


### 第 9 次发布

发布时间：2022-06-08 06:15:21

本次发布包含了以下内容：

改善已有的文档。

新增数据结构：

* [CustomPromConfig](https://cloud.tencent.com/document/api/1261/63843#CustomPromConfig)

修改数据结构：

* [AccessLogConfig](https://cloud.tencent.com/document/api/1261/63843#AccessLogConfig)

	* 新增成员：Address, EnableServer, EnableStdout

* [PrometheusConfig](https://cloud.tencent.com/document/api/1261/63843#PrometheusConfig)

	* 新增成员：CustomProm


### 第 8 次发布

发布时间：2022-05-24 06:18:55

本次发布包含了以下内容：

改善已有的文档。

新增数据结构：

* [TracingZipkin](https://cloud.tencent.com/document/api/1261/63843#TracingZipkin)

修改数据结构：

* [TracingConfig](https://cloud.tencent.com/document/api/1261/63843#TracingConfig)

	* 新增成员：Zipkin


### 第 7 次发布

发布时间：2022-05-11 06:15:29

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [PrometheusStatus](https://cloud.tencent.com/document/api/1261/63843#PrometheusStatus)

	* 新增成员：Type


### 第 6 次发布

发布时间：2022-03-22 08:15:02

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [InjectConfig](https://cloud.tencent.com/document/api/1261/63843#InjectConfig)

	* 新增成员：HoldProxyUntilApplicationEnds

* [MeshConfig](https://cloud.tencent.com/document/api/1261/63843#MeshConfig)

	* 新增成员：Tracing, SidecarResources


### 第 5 次发布

发布时间：2022-02-25 08:14:28

本次发布包含了以下内容：

改善已有的文档。

新增数据结构：

* [APM](https://cloud.tencent.com/document/api/1261/63843#APM)

修改数据结构：

* [TracingConfig](https://cloud.tencent.com/document/api/1261/63843#TracingConfig)

	* 新增成员：Enable, APM


### 第 4 次发布

发布时间：2022-02-16 08:11:56

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [AccessLogConfig](https://cloud.tencent.com/document/api/1261/63843#AccessLogConfig)

	* 新增成员：Encoding, Format


### 第 3 次发布

发布时间：2022-01-24 08:14:58

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [MeshStatus](https://cloud.tencent.com/document/api/1261/63843#MeshStatus)

	* 新增成员：TPS


### 第 2 次发布

发布时间：2021-11-18 08:12:32

本次发布包含了以下内容：

改善已有的文档。

新增数据结构：

* [InjectConfig](https://cloud.tencent.com/document/api/1261/63843#InjectConfig)

修改数据结构：

* [IstioConfig](https://cloud.tencent.com/document/api/1261/63843#IstioConfig)

	* 新增成员：DisablePolicyChecks

* [MeshConfig](https://cloud.tencent.com/document/api/1261/63843#MeshConfig)

	* 新增成员：Inject


### 第 1 次发布

发布时间：2021-11-10 15:03:56

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeMesh](https://cloud.tencent.com/document/api/1261/63842)
* [DescribeMeshList](https://cloud.tencent.com/document/api/1261/63841)

新增数据结构：

* [AccessLogConfig](https://cloud.tencent.com/document/api/1261/63843#AccessLogConfig)
* [ActiveOperation](https://cloud.tencent.com/document/api/1261/63843#ActiveOperation)
* [AutoInjectionNamespaceState](https://cloud.tencent.com/document/api/1261/63843#AutoInjectionNamespaceState)
* [CLS](https://cloud.tencent.com/document/api/1261/63843#CLS)
* [Cluster](https://cloud.tencent.com/document/api/1261/63843#Cluster)
* [ClusterConfig](https://cloud.tencent.com/document/api/1261/63843#ClusterConfig)
* [ClusterStatus](https://cloud.tencent.com/document/api/1261/63843#ClusterStatus)
* [DeployConfig](https://cloud.tencent.com/document/api/1261/63843#DeployConfig)
* [EgressGateway](https://cloud.tencent.com/document/api/1261/63843#EgressGateway)
* [Filter](https://cloud.tencent.com/document/api/1261/63843#Filter)
* [GrafanaInfo](https://cloud.tencent.com/document/api/1261/63843#GrafanaInfo)
* [HorizontalPodAutoscalerSpec](https://cloud.tencent.com/document/api/1261/63843#HorizontalPodAutoscalerSpec)
* [IngressGateway](https://cloud.tencent.com/document/api/1261/63843#IngressGateway)
* [IngressGatewayStatus](https://cloud.tencent.com/document/api/1261/63843#IngressGatewayStatus)
* [IstioConfig](https://cloud.tencent.com/document/api/1261/63843#IstioConfig)
* [IstiodConfig](https://cloud.tencent.com/document/api/1261/63843#IstiodConfig)
* [LoadBalancer](https://cloud.tencent.com/document/api/1261/63843#LoadBalancer)
* [LoadBalancerStatus](https://cloud.tencent.com/document/api/1261/63843#LoadBalancerStatus)
* [Mesh](https://cloud.tencent.com/document/api/1261/63843#Mesh)
* [MeshConfig](https://cloud.tencent.com/document/api/1261/63843#MeshConfig)
* [MeshStatus](https://cloud.tencent.com/document/api/1261/63843#MeshStatus)
* [MetricSpec](https://cloud.tencent.com/document/api/1261/63843#MetricSpec)
* [PodsMetricSource](https://cloud.tencent.com/document/api/1261/63843#PodsMetricSource)
* [PrometheusConfig](https://cloud.tencent.com/document/api/1261/63843#PrometheusConfig)
* [PrometheusStatus](https://cloud.tencent.com/document/api/1261/63843#PrometheusStatus)
* [Resource](https://cloud.tencent.com/document/api/1261/63843#Resource)
* [ResourceMetricSource](https://cloud.tencent.com/document/api/1261/63843#ResourceMetricSource)
* [ResourceRequirements](https://cloud.tencent.com/document/api/1261/63843#ResourceRequirements)
* [SelectedItems](https://cloud.tencent.com/document/api/1261/63843#SelectedItems)
* [SelectedRange](https://cloud.tencent.com/document/api/1261/63843#SelectedRange)
* [Service](https://cloud.tencent.com/document/api/1261/63843#Service)
* [TracingConfig](https://cloud.tencent.com/document/api/1261/63843#TracingConfig)
* [WorkloadConfig](https://cloud.tencent.com/document/api/1261/63843#WorkloadConfig)




## 容器镜像服务(tcr) 版本：2019-09-24

### 第 67 次发布

发布时间：2024-07-23 02:04:12

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeImageManifests](https://cloud.tencent.com/document/api/1141/43525)

	* 新增出参：Labels, Size


### 第 66 次发布

发布时间：2024-06-26 01:23:42

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CheckInstanceName](https://cloud.tencent.com/document/api/1141/52212)

	* 新增出参：DetailCode


### 第 65 次发布

发布时间：2024-02-19 10:37:21

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [ModifyServiceAccountPassword](https://cloud.tencent.com/document/api/1141/103857)

### 第 64 次发布

发布时间：2023-12-12 02:27:39

本次发布包含了以下内容：

改善已有的文档。

<font color="#dd0000">**删除接口**：</font>

* DescribeCustomAccounts

<font color="#dd0000">**删除数据结构**：</font>

* CustomAccount

### 第 63 次发布

发布时间：2023-11-27 00:18:18

本次发布包含了以下内容：

改善已有的文档。

<font color="#dd0000">**删除接口**：</font>

* CreateCustomAccount
* DeleteCustomAccount
* ModifyCustomAccount

### 第 62 次发布

发布时间：2023-11-23 01:27:00

本次发布包含了以下内容：

改善已有的文档。

<font color="#dd0000">**预下线接口**：</font>

* CreateCustomAccount
* DeleteCustomAccount
* DescribeCustomAccounts
* ModifyCustomAccount

### 第 61 次发布

发布时间：2023-09-11 02:43:38

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [Registry](https://cloud.tencent.com/document/api/1141/41603#Registry)

	* 新增成员：DeletionProtection


### 第 60 次发布

发布时间：2023-08-15 01:36:55

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DuplicateImage](https://cloud.tencent.com/document/api/1141/96178)

### 第 59 次发布

发布时间：2023-07-07 01:50:00

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateServiceAccount](https://cloud.tencent.com/document/api/1141/94608)
* [DeleteServiceAccount](https://cloud.tencent.com/document/api/1141/94607)
* [DescribeServiceAccounts](https://cloud.tencent.com/document/api/1141/94606)
* [ModifyServiceAccount](https://cloud.tencent.com/document/api/1141/94605)

新增数据结构：

* [ServiceAccount](https://cloud.tencent.com/document/api/1141/41603#ServiceAccount)

### 第 58 次发布

发布时间：2023-07-06 01:44:01

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateInstance](https://cloud.tencent.com/document/api/1141/41572)

	* 新增入参：DeletionProtection

* [ModifyInstance](https://cloud.tencent.com/document/api/1141/60996)

	* 新增入参：DeletionProtection

	* <font color="#dd0000">**修改入参**：</font>RegistryType


### 第 57 次发布

发布时间：2023-06-30 01:44:37

本次发布包含了以下内容：

改善已有的文档。

<font color="#dd0000">**删除接口**：</font>

* CreateImageLifecyclePersonal
* DeleteImageLifecyclePersonal

### 第 56 次发布

发布时间：2023-06-28 01:40:48

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateCustomAccount](https://cloud.tencent.com/document/api/1141/94333)
* [DeleteCustomAccount](https://cloud.tencent.com/document/api/1141/94332)
* [DescribeCustomAccounts](https://cloud.tencent.com/document/api/1141/94331)
* [ModifyCustomAccount](https://cloud.tencent.com/document/api/1141/94330)

新增数据结构：

* [CustomAccount](https://cloud.tencent.com/document/api/1141/41603#CustomAccount)
* [Permission](https://cloud.tencent.com/document/api/1141/41603#Permission)

### 第 55 次发布

发布时间：2023-05-31 01:41:56

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DeleteSecurityPolicy](https://cloud.tencent.com/document/api/1141/53907)

	* 新增入参：CidrBlock

	* <font color="#dd0000">**修改入参**：</font>PolicyIndex, PolicyVersion


### 第 54 次发布

发布时间：2023-03-29 11:15:33

本次发布包含了以下内容：

改善已有的文档。

<font color="#dd0000">**预下线接口**：</font>

* CreateImageLifecyclePersonal
* DeleteImageLifecyclePersonal

### 第 53 次发布

发布时间：2023-03-20 01:55:07

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateInstance](https://cloud.tencent.com/document/api/1141/41572)

	* 新增入参：EnableCosMAZ


### 第 52 次发布

发布时间：2023-03-03 01:45:06

本次发布包含了以下内容：

改善已有的文档。

<font color="#dd0000">**删除接口**：</font>

* DescribeInstanceAll

### 第 51 次发布

发布时间：2023-02-22 01:48:37

本次发布包含了以下内容：

改善已有的文档。

<font color="#dd0000">**预下线接口**：</font>

* DescribeInstanceAll

### 第 50 次发布

发布时间：2023-02-13 02:05:57

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateNamespace](https://cloud.tencent.com/document/api/1141/42729)

	* 新增入参：IsAutoScan, IsPreventVUL, Severity, CVEWhitelistItems

* [ModifyNamespace](https://cloud.tencent.com/document/api/1141/42727)

	* 新增入参：IsAutoScan, IsPreventVUL, Severity, CVEWhitelistItems

	* <font color="#dd0000">**修改入参**：</font>IsPublic


新增数据结构：

* [CVEWhitelistItem](https://cloud.tencent.com/document/api/1141/41603#CVEWhitelistItem)

修改数据结构：

* [TcrNamespaceInfo](https://cloud.tencent.com/document/api/1141/41603#TcrNamespaceInfo)

	* 新增成员：CVEWhitelistItems, AutoScan, PreventVUL, Severity


### 第 49 次发布

发布时间：2023-01-11 01:40:34

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateInstance](https://cloud.tencent.com/document/api/1141/41572)

	* 新增入参：RegistryChargePrepaid


### 第 48 次发布

发布时间：2022-12-30 01:44:00

本次发布包含了以下内容：

改善已有的文档。

<font color="#dd0000">**删除接口**：</font>

* CreateSecurityPolicies

### 第 47 次发布

发布时间：2022-12-07 07:02:05

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [TagInfo](https://cloud.tencent.com/document/api/1141/41603#TagInfo)

	* 新增成员：Kind


### 第 46 次发布

发布时间：2022-11-08 06:41:24

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeImages](https://cloud.tencent.com/document/api/1141/42723)

	* 新增入参：ExactMatch


### 第 45 次发布

发布时间：2022-11-07 06:36:31

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateInternalEndpointDns](https://cloud.tencent.com/document/api/1141/53131)

	* 新增入参：RegionId


### 第 44 次发布

发布时间：2022-11-02 06:40:49

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeInstanceAllNamespaces](https://cloud.tencent.com/document/api/1141/79582)

	* 新增入参：Limit, Offset


### 第 43 次发布

发布时间：2022-08-25 06:49:32

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateImageAccelerationService](https://cloud.tencent.com/document/api/1141/79580)
* [CreateInstanceCustomizedDomain](https://cloud.tencent.com/document/api/1141/79579)
* [CreateSecurityPolicies](https://cloud.tencent.com/document/api/1141/79578)
* [CreateSignature](https://cloud.tencent.com/document/api/1141/79571)
* [CreateSignaturePolicy](https://cloud.tencent.com/document/api/1141/79584)
* [DeleteImageAccelerateService](https://cloud.tencent.com/document/api/1141/79577)
* [DeleteInstanceCustomizedDomain](https://cloud.tencent.com/document/api/1141/79576)
* [DeleteReplicationInstance](https://cloud.tencent.com/document/api/1141/79581)
* [DeleteRepositoryTags](https://cloud.tencent.com/document/api/1141/79570)
* [DeleteSignaturePolicy](https://cloud.tencent.com/document/api/1141/79583)
* [DescribeGCJobs](https://cloud.tencent.com/document/api/1141/79569)
* [DescribeImageAccelerateService](https://cloud.tencent.com/document/api/1141/79575)
* [DescribeInstanceAll](https://cloud.tencent.com/document/api/1141/79574)
* [DescribeInstanceAllNamespaces](https://cloud.tencent.com/document/api/1141/79582)
* [DescribeInstanceCustomizedDomain](https://cloud.tencent.com/document/api/1141/79573)
* [DescribeRegions](https://cloud.tencent.com/document/api/1141/79572)

新增数据结构：

* [CustomizedDomainInfo](https://cloud.tencent.com/document/api/1141/41603#CustomizedDomainInfo)
* [GCJobInfo](https://cloud.tencent.com/document/api/1141/41603#GCJobInfo)
* [Region](https://cloud.tencent.com/document/api/1141/41603#Region)
* [Schedule](https://cloud.tencent.com/document/api/1141/41603#Schedule)

### 第 42 次发布

发布时间：2022-08-15 06:39:36

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeImages](https://cloud.tencent.com/document/api/1141/42723)

	* 新增入参：Digest

* [DescribeNamespaces](https://cloud.tencent.com/document/api/1141/42765)

	* 新增入参：KmsSignPolicy


新增数据结构：

* [KeyValueString](https://cloud.tencent.com/document/api/1141/41603#KeyValueString)

修改数据结构：

* [TcrImageInfo](https://cloud.tencent.com/document/api/1141/41603#TcrImageInfo)

	* 新增成员：Kind, KmsSignature

* [TcrNamespaceInfo](https://cloud.tencent.com/document/api/1141/41603#TcrNamespaceInfo)

	* 新增成员：Metadata


### 第 41 次发布

发布时间：2022-07-07 06:16:05

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateNamespace](https://cloud.tencent.com/document/api/1141/42729)

	* 新增入参：TagSpecification

* [DescribeNamespaces](https://cloud.tencent.com/document/api/1141/42765)

	* 新增入参：All, Filters


修改数据结构：

* [TcrNamespaceInfo](https://cloud.tencent.com/document/api/1141/41603#TcrNamespaceInfo)

	* 新增成员：TagSpecification


### 第 40 次发布

发布时间：2022-06-13 06:17:36

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateInstance](https://cloud.tencent.com/document/api/1141/41572)

	* 新增入参：SyncTag

* [CreateReplicationInstance](https://cloud.tencent.com/document/api/1141/54178)

	* 新增入参：SyncTag

* [DeleteInstance](https://cloud.tencent.com/document/api/1141/49983)

	* 新增入参：DryRun


### 第 39 次发布

发布时间：2021-10-21 11:37:27

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateInternalEndpointDns](https://cloud.tencent.com/document/api/1141/53131)

	* 新增入参：RegionName

* [DeleteInternalEndpointDns](https://cloud.tencent.com/document/api/1141/53130)

	* 新增入参：RegionName


修改数据结构：

* [VpcAndDomainInfo](https://cloud.tencent.com/document/api/1141/41603#VpcAndDomainInfo)

	* 新增成员：RegionName


### 第 38 次发布

发布时间：2021-10-12 08:10:36

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeReplicationInstanceSyncStatus](https://cloud.tencent.com/document/api/1141/55297)

	* 新增入参：ShowReplicationLog, Offset, Limit

	* <font color="#dd0000">**修改入参**：</font>ReplicationRegionId

	* 新增出参：ReplicationLog


新增数据结构：

* [ReplicationLog](https://cloud.tencent.com/document/api/1141/41603#ReplicationLog)

### 第 37 次发布

发布时间：2021-10-09 11:19:12

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateReplicationInstance](https://cloud.tencent.com/document/api/1141/54178)

	* 新增入参：ReplicationRegionName

	* <font color="#dd0000">**修改入参**：</font>ReplicationRegionId

* [ManageInternalEndpoint](https://cloud.tencent.com/document/api/1141/50733)

	* 新增入参：RegionName


### 第 36 次发布

发布时间：2021-09-01 08:10:20

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [ModifyInstance](https://cloud.tencent.com/document/api/1141/60996)

### 第 35 次发布

发布时间：2021-07-14 08:10:43

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CheckInstance](https://cloud.tencent.com/document/api/1141/58595)

修改接口：

* [ManageReplication](https://cloud.tencent.com/document/api/1141/54138)

	* 新增入参：PeerReplicationOption


新增数据结构：

* [PeerReplicationOption](https://cloud.tencent.com/document/api/1141/41603#PeerReplicationOption)

### 第 34 次发布

发布时间：2021-07-06 08:11:25

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateImmutableTagRules](https://cloud.tencent.com/document/api/1141/58197)
* [DeleteImmutableTagRules](https://cloud.tencent.com/document/api/1141/58196)
* [DescribeImmutableTagRules](https://cloud.tencent.com/document/api/1141/58195)
* [ModifyImmutableTagRules](https://cloud.tencent.com/document/api/1141/58194)

新增数据结构：

* [ImmutableTagRule](https://cloud.tencent.com/document/api/1141/41603#ImmutableTagRule)

### 第 33 次发布

发布时间：2021-06-02 08:09:52

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateMultipleSecurityPolicy](https://cloud.tencent.com/document/api/1141/56524)
* [DeleteMultipleSecurityPolicy](https://cloud.tencent.com/document/api/1141/56523)

修改数据结构：

* [SecurityPolicy](https://cloud.tencent.com/document/api/1141/41603#SecurityPolicy)

	* <font color="#dd0000">**修改成员**：</font>PolicyIndex, Description, CidrBlock, PolicyVersion


### 第 32 次发布

发布时间：2021-05-14 08:09:55

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeChartDownloadInfo](https://cloud.tencent.com/document/api/1141/55759)

### 第 31 次发布

发布时间：2021-05-11 08:10:44

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [ModifyInstanceToken](https://cloud.tencent.com/document/api/1141/42910)

	* 新增入参：Desc, ModifyFlag

	* <font color="#dd0000">**修改入参**：</font>Enable


### 第 30 次发布

发布时间：2021-04-29 08:09:13

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeReplicationInstanceSyncStatus](https://cloud.tencent.com/document/api/1141/55297)

### 第 29 次发布

发布时间：2021-04-20 08:10:24

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateTagRetentionExecution](https://cloud.tencent.com/document/api/1141/54804)
* [CreateTagRetentionRule](https://cloud.tencent.com/document/api/1141/54803)
* [DeleteTagRetentionRule](https://cloud.tencent.com/document/api/1141/54802)
* [DescribeTagRetentionExecution](https://cloud.tencent.com/document/api/1141/54801)
* [DescribeTagRetentionExecutionTask](https://cloud.tencent.com/document/api/1141/54800)
* [DescribeTagRetentionRules](https://cloud.tencent.com/document/api/1141/54799)
* [ModifyTagRetentionRule](https://cloud.tencent.com/document/api/1141/54798)

新增数据结构：

* [RetentionExecution](https://cloud.tencent.com/document/api/1141/41603#RetentionExecution)
* [RetentionPolicy](https://cloud.tencent.com/document/api/1141/41603#RetentionPolicy)
* [RetentionRule](https://cloud.tencent.com/document/api/1141/41603#RetentionRule)
* [RetentionTask](https://cloud.tencent.com/document/api/1141/41603#RetentionTask)

### 第 28 次发布

发布时间：2021-04-15 08:09:20

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DownloadHelmChart](https://cloud.tencent.com/document/api/1141/54732)

### 第 27 次发布

发布时间：2021-03-30 08:10:59

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [ManageReplication](https://cloud.tencent.com/document/api/1141/54138)

	* 新增入参：DestinationRegionId


### 第 26 次发布

发布时间：2021-03-29 08:09:11

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateReplicationInstance](https://cloud.tencent.com/document/api/1141/54178)

### 第 25 次发布

发布时间：2021-03-26 08:09:08

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [ManageReplication](https://cloud.tencent.com/document/api/1141/54138)

新增数据结构：

* [ReplicationFilter](https://cloud.tencent.com/document/api/1141/41603#ReplicationFilter)
* [ReplicationRule](https://cloud.tencent.com/document/api/1141/41603#ReplicationRule)

### 第 24 次发布

发布时间：2021-03-22 08:09:47

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateSecurityPolicy](https://cloud.tencent.com/document/api/1141/53908)
* [DeleteSecurityPolicy](https://cloud.tencent.com/document/api/1141/53907)
* [DescribeSecurityPolicies](https://cloud.tencent.com/document/api/1141/53906)
* [ModifySecurityPolicy](https://cloud.tencent.com/document/api/1141/53905)

新增数据结构：

* [SecurityPolicy](https://cloud.tencent.com/document/api/1141/41603#SecurityPolicy)

### 第 23 次发布

发布时间：2021-03-16 08:11:07

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeExternalEndpointStatus](https://cloud.tencent.com/document/api/1141/53642)

### 第 22 次发布

发布时间：2021-03-15 08:08:42

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [ManageExternalEndpoint](https://cloud.tencent.com/document/api/1141/53597)

### 第 21 次发布

发布时间：2021-02-25 08:09:08

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateInternalEndpointDns](https://cloud.tencent.com/document/api/1141/53131)
* [DeleteInternalEndpointDns](https://cloud.tencent.com/document/api/1141/53130)
* [DescribeInternalEndpointDnsStatus](https://cloud.tencent.com/document/api/1141/53129)

新增数据结构：

* [VpcAndDomainInfo](https://cloud.tencent.com/document/api/1141/41603#VpcAndDomainInfo)
* [VpcPrivateDomainStatus](https://cloud.tencent.com/document/api/1141/41603#VpcPrivateDomainStatus)

### 第 20 次发布

发布时间：2021-01-20 08:09:15

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CheckInstanceName](https://cloud.tencent.com/document/api/1141/52212)

### 第 19 次发布

发布时间：2021-01-07 08:10:20

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [RenewInstance](https://cloud.tencent.com/document/api/1141/51792)

修改接口：

* [CreateInstance](https://cloud.tencent.com/document/api/1141/41572)

	* 新增入参：RegistryChargeType


新增数据结构：

* [RegistryChargePrepaid](https://cloud.tencent.com/document/api/1141/41603#RegistryChargePrepaid)

修改数据结构：

* [Registry](https://cloud.tencent.com/document/api/1141/41603#Registry)

	* 新增成员：ExpiredAt, PayMod, RenewFlag


### 第 18 次发布

发布时间：2020-12-08 08:09:55

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeInternalEndpoints](https://cloud.tencent.com/document/api/1141/50734)
* [ManageInternalEndpoint](https://cloud.tencent.com/document/api/1141/50733)

新增数据结构：

* [AccessVpc](https://cloud.tencent.com/document/api/1141/41603#AccessVpc)

### 第 17 次发布

发布时间：2020-11-24 08:10:04

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateInstanceToken](https://cloud.tencent.com/document/api/1141/41571)

	* 新增出参：TokenId


### 第 16 次发布

发布时间：2020-11-17 08:09:54

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DeleteInstance](https://cloud.tencent.com/document/api/1141/49983)

### 第 15 次发布

发布时间：2020-10-16 08:07:58

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeReplicationInstanceCreateTasks](https://cloud.tencent.com/document/api/1141/49202)
* [DescribeReplicationInstances](https://cloud.tencent.com/document/api/1141/49201)

新增数据结构：

* [ReplicationRegistry](https://cloud.tencent.com/document/api/1141/41603#ReplicationRegistry)
* [TaskDetail](https://cloud.tencent.com/document/api/1141/41603#TaskDetail)

### 第 14 次发布

发布时间：2020-08-11 08:28:16

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DeleteImage](https://cloud.tencent.com/document/api/1141/47331)

### 第 13 次发布

发布时间：2020-07-29 08:21:59

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateInstance](https://cloud.tencent.com/document/api/1141/41572)

	* 新增入参：TagSpecification


新增数据结构：

* [Tag](https://cloud.tencent.com/document/api/1141/41603#Tag)
* [TagSpecification](https://cloud.tencent.com/document/api/1141/41603#TagSpecification)

修改数据结构：

* [Registry](https://cloud.tencent.com/document/api/1141/41603#Registry)

	* 新增成员：TagSpecification


### 第 12 次发布

发布时间：2020-05-13 08:20:16

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateWebhookTrigger](https://cloud.tencent.com/document/api/1141/43531)

	* 新增出参：Trigger


### 第 11 次发布

发布时间：2020-05-12 08:20:13

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [WebhookTrigger](https://cloud.tencent.com/document/api/1141/41603#WebhookTrigger)

	* 新增成员：NamespaceId


### 第 10 次发布

发布时间：2020-04-29 08:21:18

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [Registry](https://cloud.tencent.com/document/api/1141/41603#Registry)

	* 新增成员：InternalEndpoint


### 第 9 次发布

发布时间：2020-04-21 08:20:28

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [TcrImageInfo](https://cloud.tencent.com/document/api/1141/41603#TcrImageInfo)

	* 新增成员：UpdateTime


### 第 8 次发布

发布时间：2020-04-20 08:19:47

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateWebhookTrigger](https://cloud.tencent.com/document/api/1141/43531)
* [DeleteWebhookTrigger](https://cloud.tencent.com/document/api/1141/43530)
* [DescribeImageManifests](https://cloud.tencent.com/document/api/1141/43525)
* [DescribeWebhookTrigger](https://cloud.tencent.com/document/api/1141/43529)
* [DescribeWebhookTriggerLog](https://cloud.tencent.com/document/api/1141/43528)
* [ModifyWebhookTrigger](https://cloud.tencent.com/document/api/1141/43527)

新增数据结构：

* [Header](https://cloud.tencent.com/document/api/1141/41603#Header)
* [WebhookTarget](https://cloud.tencent.com/document/api/1141/41603#WebhookTarget)
* [WebhookTrigger](https://cloud.tencent.com/document/api/1141/41603#WebhookTrigger)
* [WebhookTriggerLog](https://cloud.tencent.com/document/api/1141/41603#WebhookTriggerLog)

### 第 7 次发布

发布时间：2020-03-30 08:48:28

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateInstanceToken](https://cloud.tencent.com/document/api/1141/41571)

	* 新增出参：Username


### 第 6 次发布

发布时间：2020-03-27 08:17:23

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [TcrNamespaceInfo](https://cloud.tencent.com/document/api/1141/41603#TcrNamespaceInfo)

	* 新增成员：NamespaceId


### 第 5 次发布

发布时间：2020-03-26 08:16:53

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DeleteInstanceToken](https://cloud.tencent.com/document/api/1141/42912)
* [DescribeInstanceToken](https://cloud.tencent.com/document/api/1141/42911)
* [ModifyInstanceToken](https://cloud.tencent.com/document/api/1141/42910)

修改接口：

* [CreateInstanceToken](https://cloud.tencent.com/document/api/1141/41571)

	* 新增入参：TokenType, Desc


新增数据结构：

* [TcrInstanceToken](https://cloud.tencent.com/document/api/1141/41603#TcrInstanceToken)

### 第 4 次发布

发布时间：2020-03-23 08:16:53

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeNamespaces](https://cloud.tencent.com/document/api/1141/42765)

新增数据结构：

* [TcrNamespaceInfo](https://cloud.tencent.com/document/api/1141/41603#TcrNamespaceInfo)

### 第 3 次发布

发布时间：2020-03-20 08:17:51

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateNamespace](https://cloud.tencent.com/document/api/1141/42729)
* [CreateRepository](https://cloud.tencent.com/document/api/1141/42725)
* [DeleteNamespace](https://cloud.tencent.com/document/api/1141/42728)
* [DeleteRepository](https://cloud.tencent.com/document/api/1141/42724)
* [DescribeImages](https://cloud.tencent.com/document/api/1141/42723)
* [DescribeRepositories](https://cloud.tencent.com/document/api/1141/42722)
* [ModifyNamespace](https://cloud.tencent.com/document/api/1141/42727)
* [ModifyRepository](https://cloud.tencent.com/document/api/1141/42721)

新增数据结构：

* [TcrImageInfo](https://cloud.tencent.com/document/api/1141/41603#TcrImageInfo)
* [TcrRepositoryInfo](https://cloud.tencent.com/document/api/1141/41603#TcrRepositoryInfo)

### 第 2 次发布

发布时间：2020-03-12 08:00:46

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DeleteImageLifecycleGlobalPersonal](https://cloud.tencent.com/document/api/1141/42157)
* [DescribeImageLifecycleGlobalPersonal](https://cloud.tencent.com/document/api/1141/42156)
* [ManageImageLifecycleGlobalPersonal](https://cloud.tencent.com/document/api/1141/42155)

### 第 1 次发布

发布时间：2020-02-27 11:27:50

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [BatchDeleteImagePersonal](https://cloud.tencent.com/document/api/1141/41602)
* [BatchDeleteRepositoryPersonal](https://cloud.tencent.com/document/api/1141/41601)
* [CreateApplicationTriggerPersonal](https://cloud.tencent.com/document/api/1141/41600)
* [CreateImageLifecyclePersonal](https://cloud.tencent.com/document/api/1141/41599)
* [CreateInstance](https://cloud.tencent.com/document/api/1141/41572)
* [CreateInstanceToken](https://cloud.tencent.com/document/api/1141/41571)
* [CreateNamespacePersonal](https://cloud.tencent.com/document/api/1141/41598)
* [CreateRepositoryPersonal](https://cloud.tencent.com/document/api/1141/41597)
* [CreateUserPersonal](https://cloud.tencent.com/document/api/1141/41596)
* [DeleteApplicationTriggerPersonal](https://cloud.tencent.com/document/api/1141/41595)
* [DeleteImageLifecyclePersonal](https://cloud.tencent.com/document/api/1141/41594)
* [DeleteImagePersonal](https://cloud.tencent.com/document/api/1141/41593)
* [DeleteNamespacePersonal](https://cloud.tencent.com/document/api/1141/41592)
* [DeleteRepositoryPersonal](https://cloud.tencent.com/document/api/1141/41591)
* [DescribeApplicationTriggerLogPersonal](https://cloud.tencent.com/document/api/1141/41590)
* [DescribeApplicationTriggerPersonal](https://cloud.tencent.com/document/api/1141/41589)
* [DescribeFavorRepositoryPersonal](https://cloud.tencent.com/document/api/1141/41588)
* [DescribeImageFilterPersonal](https://cloud.tencent.com/document/api/1141/41587)
* [DescribeImageLifecyclePersonal](https://cloud.tencent.com/document/api/1141/41567)
* [DescribeImagePersonal](https://cloud.tencent.com/document/api/1141/41586)
* [DescribeInstanceStatus](https://cloud.tencent.com/document/api/1141/41570)
* [DescribeInstances](https://cloud.tencent.com/document/api/1141/41569)
* [DescribeNamespacePersonal](https://cloud.tencent.com/document/api/1141/41585)
* [DescribeRepositoryFilterPersonal](https://cloud.tencent.com/document/api/1141/41584)
* [DescribeRepositoryOwnerPersonal](https://cloud.tencent.com/document/api/1141/41583)
* [DescribeRepositoryPersonal](https://cloud.tencent.com/document/api/1141/41582)
* [DescribeUserQuotaPersonal](https://cloud.tencent.com/document/api/1141/41581)
* [DuplicateImagePersonal](https://cloud.tencent.com/document/api/1141/41580)
* [ModifyApplicationTriggerPersonal](https://cloud.tencent.com/document/api/1141/41579)
* [ModifyRepositoryAccessPersonal](https://cloud.tencent.com/document/api/1141/41578)
* [ModifyRepositoryInfoPersonal](https://cloud.tencent.com/document/api/1141/41577)
* [ModifyUserPasswordPersonal](https://cloud.tencent.com/document/api/1141/41576)
* [ValidateNamespaceExistPersonal](https://cloud.tencent.com/document/api/1141/41575)
* [ValidateRepositoryExistPersonal](https://cloud.tencent.com/document/api/1141/41574)

新增数据结构：

* [AutoDelStrategyInfo](https://cloud.tencent.com/document/api/1141/41603#AutoDelStrategyInfo)
* [AutoDelStrategyInfoResp](https://cloud.tencent.com/document/api/1141/41603#AutoDelStrategyInfoResp)
* [DescribeApplicationTriggerLogPersonalResp](https://cloud.tencent.com/document/api/1141/41603#DescribeApplicationTriggerLogPersonalResp)
* [DescribeApplicationTriggerPersonalResp](https://cloud.tencent.com/document/api/1141/41603#DescribeApplicationTriggerPersonalResp)
* [DupImageTagResp](https://cloud.tencent.com/document/api/1141/41603#DupImageTagResp)
* [FavorResp](https://cloud.tencent.com/document/api/1141/41603#FavorResp)
* [Favors](https://cloud.tencent.com/document/api/1141/41603#Favors)
* [Filter](https://cloud.tencent.com/document/api/1141/41603#Filter)
* [Limit](https://cloud.tencent.com/document/api/1141/41603#Limit)
* [NamespaceInfo](https://cloud.tencent.com/document/api/1141/41603#NamespaceInfo)
* [NamespaceInfoResp](https://cloud.tencent.com/document/api/1141/41603#NamespaceInfoResp)
* [NamespaceIsExistsResp](https://cloud.tencent.com/document/api/1141/41603#NamespaceIsExistsResp)
* [Registry](https://cloud.tencent.com/document/api/1141/41603#Registry)
* [RegistryCondition](https://cloud.tencent.com/document/api/1141/41603#RegistryCondition)
* [RegistryStatus](https://cloud.tencent.com/document/api/1141/41603#RegistryStatus)
* [RepoInfo](https://cloud.tencent.com/document/api/1141/41603#RepoInfo)
* [RepoInfoResp](https://cloud.tencent.com/document/api/1141/41603#RepoInfoResp)
* [RepoIsExistResp](https://cloud.tencent.com/document/api/1141/41603#RepoIsExistResp)
* [RepositoryInfoResp](https://cloud.tencent.com/document/api/1141/41603#RepositoryInfoResp)
* [RespLimit](https://cloud.tencent.com/document/api/1141/41603#RespLimit)
* [SameImagesResp](https://cloud.tencent.com/document/api/1141/41603#SameImagesResp)
* [SearchUserRepositoryResp](https://cloud.tencent.com/document/api/1141/41603#SearchUserRepositoryResp)
* [TagInfo](https://cloud.tencent.com/document/api/1141/41603#TagInfo)
* [TagInfoResp](https://cloud.tencent.com/document/api/1141/41603#TagInfoResp)
* [TriggerInvokeCondition](https://cloud.tencent.com/document/api/1141/41603#TriggerInvokeCondition)
* [TriggerInvokePara](https://cloud.tencent.com/document/api/1141/41603#TriggerInvokePara)
* [TriggerInvokeResult](https://cloud.tencent.com/document/api/1141/41603#TriggerInvokeResult)
* [TriggerLogResp](https://cloud.tencent.com/document/api/1141/41603#TriggerLogResp)
* [TriggerResp](https://cloud.tencent.com/document/api/1141/41603#TriggerResp)




## 容器安全服务(tcss) 版本：2020-11-01

### 第 63 次发布

发布时间：2024-06-26 01:23:56

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribePurchaseStateInfo](https://cloud.tencent.com/document/api/1285/65466)

	* 新增出参：AllCoresCnt, UndefendCoresCnt, GivenAuthorizedCoresCnt, CurrentFlexibleCoresCnt, DefendPolicy, FlexibleCoresLimit, DefendClusterCoresCnt, DefendHostCoresCnt


修改数据结构：

* [ClusterInfoItem](https://cloud.tencent.com/document/api/1285/65614#ClusterInfoItem)

	* 新增成员：MasterAddresses, CoresCnt

* [HostInfo](https://cloud.tencent.com/document/api/1285/65614#HostInfo)

	* 新增成员：CoresCnt


### 第 62 次发布

发布时间：2024-05-31 02:10:49

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateAssetImageScanSetting](https://cloud.tencent.com/document/api/1285/65591)

	* 新增入参：ExcludeImages

* [DescribeAssetImageScanSetting](https://cloud.tencent.com/document/api/1285/65487)

	* 新增出参：ExcludeImages

* [DescribeImageRegistryTimingScanTask](https://cloud.tencent.com/document/api/1285/65472)

	* 新增出参：ExcludeImageAssetIds

* [UpdateImageRegistryTimingScanTask](https://cloud.tencent.com/document/api/1285/65457)

	* 新增入参：ExcludeImageAssetIds


### 第 61 次发布

发布时间：2024-05-16 02:21:16

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeEventEscapeImageList](https://cloud.tencent.com/document/api/1285/106209)

新增数据结构：

* [EventEscapeImageInfo](https://cloud.tencent.com/document/api/1285/65614#EventEscapeImageInfo)

### 第 60 次发布

发布时间：2024-02-02 01:21:42

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeImageAuthorizedInfo](https://cloud.tencent.com/document/api/1285/65473)

	* 新增出参：TrialAuthorizedCnt, UsedTrialAuthorizedCnt, PurchasedAuthorizedCnt, UsedPurchasedAuthorizedCnt, CanApplyFreeImageAuthorize


### 第 59 次发布

发布时间：2024-01-05 01:25:17

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribePurchaseStateInfo](https://cloud.tencent.com/document/api/1285/65466)

	* 新增出参：InquireKey


### 第 58 次发布

发布时间：2024-01-03 01:24:22

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeAssetSuperNodeList](https://cloud.tencent.com/document/api/1285/102813)
* [DescribeClusterNodes](https://cloud.tencent.com/document/api/1285/102811)
* [DescribeSuperNodePodList](https://cloud.tencent.com/document/api/1285/102812)
* [DescribeUserPodList](https://cloud.tencent.com/document/api/1285/102810)

新增数据结构：

* [ClusterNodeInfo](https://cloud.tencent.com/document/api/1285/65614#ClusterNodeInfo)
* [ClusterPodInfo](https://cloud.tencent.com/document/api/1285/65614#ClusterPodInfo)
* [SuperNodeListItem](https://cloud.tencent.com/document/api/1285/65614#SuperNodeListItem)
* [SuperNodePodListItem](https://cloud.tencent.com/document/api/1285/65614#SuperNodePodListItem)

### 第 57 次发布

发布时间：2023-12-29 01:24:30

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [ClusterInfoItem](https://cloud.tencent.com/document/api/1285/65614#ClusterInfoItem)

	* 新增成员：ChargeCoresCnt

* [HostInfo](https://cloud.tencent.com/document/api/1285/65614#HostInfo)

	* 新增成员：ChargeCoresCnt, DefendStatus


### 第 56 次发布

发布时间：2023-11-29 02:03:30

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeAssetSyncLastTime](https://cloud.tencent.com/document/api/1285/81683)

	* 新增出参：TaskStatus, TaskProcess

* [DescribeRiskDnsEventDetail](https://cloud.tencent.com/document/api/1285/96162)

	* 新增出参：Namespace, WorkloadType

* [DescribeVirusDetail](https://cloud.tencent.com/document/api/1285/65583)

	* 新增出参：Namespace, WorkloadType


修改数据结构：

* [RunTimeEventBaseInfo](https://cloud.tencent.com/document/api/1285/65614#RunTimeEventBaseInfo)

	* 新增成员：Namespace, WorkloadType

	* <font color="#dd0000">**修改成员**：</font>EventId, FoundTime, ContainerId, ContainerName, ImageId, ImageName, NodeName, Status, EventName, EventType, EventCount, LatestFoundTime, HostIP, ClientIP, ContainerNetStatus, ContainerNetSubStatus, ContainerIsolateOperationSrc, NodeID, NodeType, NodeSubNetID, NodeSubNetName, NodeSubNetCIDR, PodName, PodIP, PodStatus, ClusterID, ClusterName, NodeUniqueID, HostID

* [VulDefenceEventDetail](https://cloud.tencent.com/document/api/1285/65614#VulDefenceEventDetail)

	* 新增成员：Namespace, WorkloadType

	* <font color="#dd0000">**修改成员**：</font>NodeSubNetName, NodeSubNetCIDR, PodIP, NodeType, NodeID, NodeUniqueID, NodeSubNetID, ClusterID, ClusterName


### 第 55 次发布

发布时间：2023-11-21 01:33:13

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [AddAssetImageRegistryRegistryDetail](https://cloud.tencent.com/document/api/1285/65560)

	* 新增入参：NeedScan

* [AddEditImageAutoAuthorizedRule](https://cloud.tencent.com/document/api/1285/81638)

	* 新增入参：AutoScanEnabled, ScanType

* [CreateAssetImageScanSetting](https://cloud.tencent.com/document/api/1285/65591)

	* 新增入参：ContainerRunning, ScanScope, ScanEndTime

	* <font color="#dd0000">**修改入参**：</font>All

* [CreateAssetImageScanTask](https://cloud.tencent.com/document/api/1285/65515)

	* 新增入参：ContainerRunning, ScanScope, Timeout

* [DescribeAssetImageDetail](https://cloud.tencent.com/document/api/1285/65506)

	* 新增出参：ImageDigest

* [DescribeAssetImageScanSetting](https://cloud.tencent.com/document/api/1285/65487)

	* 新增出参：ContainerRunning, ScanScope, ScanEndTime

* [DescribeAssetSummary](https://cloud.tencent.com/document/api/1285/65477)

	* 新增出参：TodayNewImageCnt, TodayUnsafeImageCnt, RecommendedFixImageCnt, ScannedImageCnt

* [DescribeImageAutoAuthorizedRule](https://cloud.tencent.com/document/api/1285/81628)

	* 新增出参：AutoScanEnabled, ScanType

* [RenewImageAuthorizeState](https://cloud.tencent.com/document/api/1285/65459)

	* 新增入参：NeedScan, ScanType

* [SyncAssetImageRegistryAsset](https://cloud.tencent.com/document/api/1285/65458)

	* 新增入参：All, RegistryIds


新增数据结构：

* [ImageVulLayerInfo](https://cloud.tencent.com/document/api/1285/65614#ImageVulLayerInfo)

修改数据结构：

* [ImageRepoInfo](https://cloud.tencent.com/document/api/1285/65614#ImageRepoInfo)

	* 新增成员：RecommendedFix

* [ImageVul](https://cloud.tencent.com/document/api/1285/65614#ImageVul)

	* 新增成员：LayerInfos

* [ImagesInfo](https://cloud.tencent.com/document/api/1285/65614#ImagesInfo)

	* 新增成员：CriticalLevelVulCnt, HighLevelVulCnt, MediumLevelVulCnt, LowLevelVulCnt, IsLatestImage, RecommendedFix

* [ImagesVul](https://cloud.tencent.com/document/api/1285/65614#ImagesVul)

	* 新增成员：AttackLevel


### 第 54 次发布

发布时间：2023-11-01 01:21:35

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeAssetImageRegistryDetail](https://cloud.tencent.com/document/api/1285/65501)

	* 新增出参：Id


### 第 53 次发布

发布时间：2023-10-31 02:25:36

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeEscapeEventDetail](https://cloud.tencent.com/document/api/1285/65538)

	* 新增入参：EventType


修改数据结构：

* [CompliancePolicyItemSummary](https://cloud.tencent.com/document/api/1285/65614#CompliancePolicyItemSummary)

	* 新增成员：Description, AuditProcedure


### 第 52 次发布

发布时间：2023-09-22 02:29:25

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateRefreshTask](https://cloud.tencent.com/document/api/1285/65453)

	* 新增入参：ClusterIDs, IsSyncListOnly

	* 新增出参：NewTaskID


### 第 51 次发布

发布时间：2023-09-14 02:23:36

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateAssetImageRegistryScanTaskOneKey](https://cloud.tencent.com/document/api/1285/65516)

	* 新增入参：IsLatest, ScanScope, RegistryType, Namespace, ContainerRunning, Timeout

* [DescribeAssetImageRegistryDetail](https://cloud.tencent.com/document/api/1285/65501)

	* 新增出参：SensitiveInfoCnt

* [DescribeAssetImageRegistryList](https://cloud.tencent.com/document/api/1285/65500)

	* 新增入参：IsRunning

* [DescribeAssetImageRegistrySummary](https://cloud.tencent.com/document/api/1285/65494)

	* 新增入参：Filters

* [DescribeImageRegistryNamespaceList](https://cloud.tencent.com/document/api/1285/81791)

	* 新增出参：NamespaceDetail

* [DescribeImageRegistryTimingScanTask](https://cloud.tencent.com/document/api/1285/65472)

	* 新增出参：ScanEndTime, RegistryType, ContainerRunning, ScanScope, Namespace

* [UpdateImageRegistryTimingScanTask](https://cloud.tencent.com/document/api/1285/65457)

	* 新增入参：ContainerRunning, ScanEndTime, ScanScope, RegistryType, Namespace


新增数据结构：

* [NamespaceInfo](https://cloud.tencent.com/document/api/1285/65614#NamespaceInfo)

修改数据结构：

* [ContainerInfo](https://cloud.tencent.com/document/api/1285/65614#ContainerInfo)

	* 新增成员：ClusterName, ClusterID, PodUid

	* <font color="#dd0000">**修改成员**：</font>NodeID, PodIP, PodName, NodeType, NodeUniqueID, PodCpu, PodMem

* [ImageRepoInfo](https://cloud.tencent.com/document/api/1285/65614#ImageRepoInfo)

	* 新增成员：LowLevelVulCnt, MediumLevelVulCnt, HighLevelVulCnt, CriticalLevelVulCnt, ContainerCnt, ComponentCnt, IsRunning, HasNeedFixVul, SensitiveInfoCnt

* [ImageVul](https://cloud.tencent.com/document/api/1285/65614#ImageVul)

	* 新增成员：AttackLevel


### 第 50 次发布

发布时间：2023-08-15 01:37:37

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateClusterCheckTask](https://cloud.tencent.com/document/api/1285/65454)

	* 新增出参：NewTaskID

* [DescribeAssetHostDetail](https://cloud.tencent.com/document/api/1285/65508)

	* 新增出参：ClusterID, ClusterName, ClusterAccessedStatus

* [DescribeClusterSummary](https://cloud.tencent.com/document/api/1285/65447)

	* 新增出参：TkeClusterCount, UserCreateTencentClusterCount, UserCreateHybridClusterCount

* [DescribeRefreshTask](https://cloud.tencent.com/document/api/1285/65446)

	* 新增入参：NewTaskID

* [DescribeUnfinishRefreshTask](https://cloud.tencent.com/document/api/1285/65443)

	* 新增出参：NewTaskID


修改数据结构：

* [AffectedNodeItem](https://cloud.tencent.com/document/api/1285/65614#AffectedNodeItem)

	* <font color="#dd0000">**修改成员**：</font>NodeName

* [ClusterInfoItem](https://cloud.tencent.com/document/api/1285/65614#ClusterInfoItem)

	* 新增成员：AccessedStatus, AccessedSubStatus, NodeCount, OffLineNodeCount, UnInstallAgentNodeCount

* [HostInfo](https://cloud.tencent.com/document/api/1285/65614#HostInfo)

	* 新增成员：ClusterName, ClusterAccessedStatus

	* <font color="#dd0000">**修改成员**：</font>ClusterID


### 第 49 次发布

发布时间：2023-08-14 01:39:44

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeRiskDnsEventDetail](https://cloud.tencent.com/document/api/1285/96162)
* [DescribeRiskDnsList](https://cloud.tencent.com/document/api/1285/96161)

新增数据结构：

* [RiskDnsEventInfo](https://cloud.tencent.com/document/api/1285/65614#RiskDnsEventInfo)

### 第 48 次发布

发布时间：2023-07-28 01:47:50

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [AddAssetImageRegistryRegistryDetail](https://cloud.tencent.com/document/api/1285/65560)

	* 新增入参：ConnDetectConfig

* [CreateAssetImageRegistryScanTask](https://cloud.tencent.com/document/api/1285/65517)

	* 新增出参：TaskID

* [CreateAssetImageRegistryScanTaskOneKey](https://cloud.tencent.com/document/api/1285/65516)

	* 新增出参：TaskID

* [DescribeAssetImageRegistryRegistryDetail](https://cloud.tencent.com/document/api/1285/65539)

	* 新增出参：ConnDetectDetail, InstanceID

* [DescribeAssetImageRegistryScanStatusOneKey](https://cloud.tencent.com/document/api/1285/65495)

	* 新增入参：TaskID

* [ModifyAssetImageRegistryScanStop](https://cloud.tencent.com/document/api/1285/65462)

	* 新增入参：TaskID

* [ModifyAssetImageRegistryScanStopOneKey](https://cloud.tencent.com/document/api/1285/65461)

	* 新增入参：TaskID

* [UpdateAssetImageRegistryRegistryDetail](https://cloud.tencent.com/document/api/1285/65519)

	* 新增入参：ConnDetectConfig


新增数据结构：

* [ConnDetectConfig](https://cloud.tencent.com/document/api/1285/65614#ConnDetectConfig)
* [RegistryConnDetectResult](https://cloud.tencent.com/document/api/1285/65614#RegistryConnDetectResult)

### 第 47 次发布

发布时间：2023-06-30 01:45:16

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [ComplianceHostDetailInfo](https://cloud.tencent.com/document/api/1285/65614#ComplianceHostDetailInfo)

	* 新增成员：ContainerdVersion


### 第 46 次发布

发布时间：2023-06-07 01:46:42

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeAgentDaemonSetCmd](https://cloud.tencent.com/document/api/1285/81685)

	* 新增入参：ClusterCustomParameters


新增数据结构：

* [ClusterCustomParameters](https://cloud.tencent.com/document/api/1285/65614#ClusterCustomParameters)

### 第 45 次发布

发布时间：2023-06-02 01:46:04

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeVulRegistryImageList](https://cloud.tencent.com/document/api/1285/93095)

新增数据结构：

* [VulAffectedRegistryImageInfo](https://cloud.tencent.com/document/api/1285/65614#VulAffectedRegistryImageInfo)

### 第 44 次发布

发布时间：2023-05-30 01:34:13

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [ComponentsInfo](https://cloud.tencent.com/document/api/1285/65614#ComponentsInfo)

	* 新增成员：FixedVersion, Path, Type, Name

	* <font color="#dd0000">**修改成员**：</font>Component


### 第 43 次发布

发布时间：2023-05-29 01:41:32

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [NetworkClusterInfoItem](https://cloud.tencent.com/document/api/1285/65614#NetworkClusterInfoItem)

	* 新增成员：ClusterNetworkSettings


### 第 42 次发布

发布时间：2023-05-23 01:40:44

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [HostInfo](https://cloud.tencent.com/document/api/1285/65614#HostInfo)

	* 新增成员：ClusterID


### 第 41 次发布

发布时间：2023-05-19 01:59:31

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeAssetContainerDetail](https://cloud.tencent.com/document/api/1285/65511)

	* 新增出参：NodeID, NodeName, NodeSubNetID, NodeSubNetName, NodeSubNetCIDR, PodName, PodIP, PodStatus, ClusterID, ClusterName, NodeType, NodeUniqueID, PublicIP

* [DescribeAssetSummary](https://cloud.tencent.com/document/api/1285/65477)

	* 新增出参：SuperNodeCnt, SuperNodeRunningCnt

* [DescribeClusterSummary](https://cloud.tencent.com/document/api/1285/65447)

	* 新增出参：ServerlessClusterCount

* [DescribeContainerAssetSummary](https://cloud.tencent.com/document/api/1285/65475)

	* 新增出参：HostSuperNodeCnt

* [DescribeVirusDetail](https://cloud.tencent.com/document/api/1285/65583)

	* 新增出参：NodeSubNetID, NodeSubNetName, NodeSubNetCIDR, ClusterID, PodIP, PodStatus, NodeUniqueID, NodeType, NodeID, ClusterName

* [DescribeVulDefenceSetting](https://cloud.tencent.com/document/api/1285/81617)

	* 新增出参：HostNodeCount, SuperScope, SuperNodeCount, SuperNodeIds, NodeTotalCount

* [ModifySecLogJoinObjects](https://cloud.tencent.com/document/api/1285/81721)

	* 新增入参：NodeType

* [ModifyVulDefenceSetting](https://cloud.tencent.com/document/api/1285/81605)

	* 新增入参：SuperScope, NodeIds


修改数据结构：

* [AbnormalProcessEventInfo](https://cloud.tencent.com/document/api/1285/65614#AbnormalProcessEventInfo)

	* 新增成员：ClusterID, NodeType, PodName, PodIP, NodeUniqueID, PublicIP, NodeName, NodeID, HostID, HostIP, ClusterName

* [AccessControlEventInfo](https://cloud.tencent.com/document/api/1285/65614#AccessControlEventInfo)

	* 新增成员：NodeName, PodName, PodIP, NodeType, ClusterID, NodeUniqueID, PublicIP, NodeID, HostID, HostIP, ClusterName

* [AffectedNodeItem](https://cloud.tencent.com/document/api/1285/65614#AffectedNodeItem)

	* 新增成员：NodeName

* [AssetClusterListItem](https://cloud.tencent.com/document/api/1285/65614#AssetClusterListItem)

	* 新增成员：ClusterVersion, MemLimit, CpuLimit

* [ContainerInfo](https://cloud.tencent.com/document/api/1285/65614#ContainerInfo)

	* 新增成员：NodeID, PodIP, PodName, NodeType, NodeUniqueID, PodCpu, PodMem

* [EscapeEventInfo](https://cloud.tencent.com/document/api/1285/65614#EscapeEventInfo)

	* 新增成员：ClusterID, NodeType, PodIP, NodeUniqueID, PublicIP, NodeID, HostIP, ClusterName

* [PortInfo](https://cloud.tencent.com/document/api/1285/65614#PortInfo)

	* 新增成员：NodeID, PodIP, PodName, NodeType, NodeUniqueID

* [ProcessInfo](https://cloud.tencent.com/document/api/1285/65614#ProcessInfo)

	* 新增成员：NodeID, PodIP, PodName, NodeType, NodeUniqueID

* [RiskSyscallEventInfo](https://cloud.tencent.com/document/api/1285/65614#RiskSyscallEventInfo)

	* 新增成员：NodeType, ClusterID, PodIP, NodeUniqueID, PublicIP, NodeID, HostID, HostIP, ClusterName

* [RunTimeEventBaseInfo](https://cloud.tencent.com/document/api/1285/65614#RunTimeEventBaseInfo)

	* 新增成员：NodeID, NodeType, NodeSubNetID, NodeSubNetName, NodeSubNetCIDR, PodIP, PodStatus, ClusterID, ClusterName, NodeUniqueID, HostID

	* <font color="#dd0000">**修改成员**：</font>EventId, FoundTime, ContainerId, ContainerName, ImageId, ImageName, NodeName, Status, EventName, EventType, EventCount, LatestFoundTime, HostIP, ClientIP, ContainerNetStatus, ContainerNetSubStatus, ContainerIsolateOperationSrc, PodName

* [SecLogJoinInfo](https://cloud.tencent.com/document/api/1285/65614#SecLogJoinInfo)

	* 新增成员：SuperNodeCount

* [ServiceInfo](https://cloud.tencent.com/document/api/1285/65614#ServiceInfo)

	* 新增成员：NodeID, PodIP, PodName, NodeType, NodeUniqueID

* [VirusInfo](https://cloud.tencent.com/document/api/1285/65614#VirusInfo)

	* 新增成员：NodeID, NodeName, PodIP, PodName, ClusterID, NodeType, PublicIP, InnerIP, NodeUniqueID, HostID, ClusterName

* [VirusTaskInfo](https://cloud.tencent.com/document/api/1285/65614#VirusTaskInfo)

	* 新增成员：NodeType, PublicIP, NodeID

* [VulAffectedContainerInfo](https://cloud.tencent.com/document/api/1285/65614#VulAffectedContainerInfo)

	* 新增成员：ClusterID, ClusterName, NodeType, NodeUniqueID, NodeID, NodeName

* [VulDefenceEvent](https://cloud.tencent.com/document/api/1285/65614#VulDefenceEvent)

	* 新增成员：NodeType, PublicIP, NodeUniqueID, NodeID, ClusterID, ClusterName

* [VulDefenceEventDetail](https://cloud.tencent.com/document/api/1285/65614#VulDefenceEventDetail)

	* 新增成员：NodeSubNetName, NodeSubNetCIDR, PodIP, NodeType, NodeID, NodeUniqueID, NodeSubNetID, ClusterID, ClusterName

* [VulDefenceHost](https://cloud.tencent.com/document/api/1285/65614#VulDefenceHost)

	* 新增成员：NodeType, NodeSubNetName, NodeSubNetCIDR, NodeSubNetID, NodeUniqueID, NodeID, PodIP, PodName


### 第 40 次发布

发布时间：2023-05-18 01:52:21

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeImageRegistryTimingScanTask](https://cloud.tencent.com/document/api/1285/65472)

	* 新增出参：Latest

* [UpdateImageRegistryTimingScanTask](https://cloud.tencent.com/document/api/1285/65457)

	* 新增入参：Latest


### 第 39 次发布

发布时间：2023-05-12 01:48:26

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [NetworkAuditRecord](https://cloud.tencent.com/document/api/1285/65614#NetworkAuditRecord)

	* 新增成员：PolicyId


### 第 38 次发布

发布时间：2023-04-03 01:33:45

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeClusterDetail](https://cloud.tencent.com/document/api/1285/65448)

	* 新增出参：MasterIps

* [DescribeClusterSummary](https://cloud.tencent.com/document/api/1285/65447)

	* 新增出参：NotImportedClusterCount


### 第 37 次发布

发布时间：2023-03-28 02:03:24

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeVulSummary](https://cloud.tencent.com/document/api/1285/81610)

	* 新增出参：SystemVulnerabilityFocusCount, WebVulnerabilityFocusCount, SeriousVulnerabilityLocalImageCount, SeriousVulnerabilityRegistryImageCount, EmergencyVulnerabilityCount


### 第 36 次发布

发布时间：2023-03-20 01:55:56

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateVirusScanTask](https://cloud.tencent.com/document/api/1285/65584)

	* 新增入参：ScanPathMode

* [DescribeVirusDetail](https://cloud.tencent.com/document/api/1285/65583)

	* 新增出参：FileAccessTime, FileModifyTime

* [DescribeVirusMonitorSetting](https://cloud.tencent.com/document/api/1285/65581)

	* 新增出参：ScanPathMode

* [DescribeVirusScanSetting](https://cloud.tencent.com/document/api/1285/65580)

	* 新增出参：ScanPathMode

* [ModifyVirusMonitorSetting](https://cloud.tencent.com/document/api/1285/65573)

	* 新增入参：ScanPathMode

* [ModifyVirusScanSetting](https://cloud.tencent.com/document/api/1285/65572)

	* 新增入参：ScanPathMode


### 第 35 次发布

发布时间：2023-01-12 01:37:30

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [ComplianceAffectedAsset](https://cloud.tencent.com/document/api/1285/65614#ComplianceAffectedAsset)

	* 新增成员：InstanceId

* [ComplianceAssetInfo](https://cloud.tencent.com/document/api/1285/65614#ComplianceAssetInfo)

	* 新增成员：InstanceId


### 第 34 次发布

发布时间：2022-12-07 07:02:56

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateAbnormalProcessRulesExportJob](https://cloud.tencent.com/document/api/1285/83731)
* [CreateAccessControlsRuleExportJob](https://cloud.tencent.com/document/api/1285/83730)

### 第 33 次发布

发布时间：2022-11-25 06:59:05

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateK8sApiAbnormalEventExportJob](https://cloud.tencent.com/document/api/1285/83380)
* [CreateK8sApiAbnormalRuleExportJob](https://cloud.tencent.com/document/api/1285/83379)
* [CreateK8sApiAbnormalRuleInfo](https://cloud.tencent.com/document/api/1285/83378)
* [DeleteK8sApiAbnormalRule](https://cloud.tencent.com/document/api/1285/83377)
* [DescribeAssetClusterList](https://cloud.tencent.com/document/api/1285/83376)
* [DescribeK8sApiAbnormalEventInfo](https://cloud.tencent.com/document/api/1285/83375)
* [DescribeK8sApiAbnormalEventList](https://cloud.tencent.com/document/api/1285/83374)
* [DescribeK8sApiAbnormalRuleInfo](https://cloud.tencent.com/document/api/1285/83373)
* [DescribeK8sApiAbnormalRuleList](https://cloud.tencent.com/document/api/1285/83372)
* [DescribeK8sApiAbnormalRuleScopeList](https://cloud.tencent.com/document/api/1285/83371)
* [DescribeK8sApiAbnormalSummary](https://cloud.tencent.com/document/api/1285/83370)
* [DescribeK8sApiAbnormalTendency](https://cloud.tencent.com/document/api/1285/83369)
* [ModifyK8sApiAbnormalEventStatus](https://cloud.tencent.com/document/api/1285/83368)
* [ModifyK8sApiAbnormalRuleInfo](https://cloud.tencent.com/document/api/1285/83367)
* [ModifyK8sApiAbnormalRuleStatus](https://cloud.tencent.com/document/api/1285/83366)

新增数据结构：

* [AssetClusterListItem](https://cloud.tencent.com/document/api/1285/65614#AssetClusterListItem)
* [K8sApiAbnormalEventInfo](https://cloud.tencent.com/document/api/1285/65614#K8sApiAbnormalEventInfo)
* [K8sApiAbnormalEventListItem](https://cloud.tencent.com/document/api/1285/65614#K8sApiAbnormalEventListItem)
* [K8sApiAbnormalRuleInfo](https://cloud.tencent.com/document/api/1285/65614#K8sApiAbnormalRuleInfo)
* [K8sApiAbnormalRuleListItem](https://cloud.tencent.com/document/api/1285/65614#K8sApiAbnormalRuleListItem)
* [K8sApiAbnormalRuleScopeInfo](https://cloud.tencent.com/document/api/1285/65614#K8sApiAbnormalRuleScopeInfo)
* [K8sApiAbnormalTendencyItem](https://cloud.tencent.com/document/api/1285/65614#K8sApiAbnormalTendencyItem)

### 第 32 次发布

发布时间：2022-11-24 06:55:26

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateHostExportJob](https://cloud.tencent.com/document/api/1285/81688)

	* <font color="#dd0000">**修改入参**：</font>ExportField

* [DescribeAssetHostDetail](https://cloud.tencent.com/document/api/1285/65508)

	* 新增出参：Project, Tags


新增数据结构：

* [ProjectInfo](https://cloud.tencent.com/document/api/1285/65614#ProjectInfo)
* [TagInfo](https://cloud.tencent.com/document/api/1285/65614#TagInfo)

修改数据结构：

* [HostInfo](https://cloud.tencent.com/document/api/1285/65614#HostInfo)

	* 新增成员：Project, Tags


### 第 31 次发布

发布时间：2022-11-02 06:41:34

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateRiskDnsEventExportJob](https://cloud.tencent.com/document/api/1285/82279)

### 第 30 次发布

发布时间：2022-11-01 06:44:24

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeContainerSecEventSummary](https://cloud.tencent.com/document/api/1285/65474)

	* 新增出参：UnhandledMaliciousConnectionEventCnt, UnhandledK8sApiEventCnt


新增数据结构：

* [RaspInfo](https://cloud.tencent.com/document/api/1285/65614#RaspInfo)

修改数据结构：

* [VulDefenceEventDetail](https://cloud.tencent.com/document/api/1285/65614#VulDefenceEventDetail)

	* 新增成员：RaspDetail


### 第 29 次发布

发布时间：2022-10-25 06:57:07

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeExportJobDownloadURL](https://cloud.tencent.com/document/api/1285/81886)
* [DescribeExportJobManageList](https://cloud.tencent.com/document/api/1285/81885)

修改接口：

* [CreateImageExportJob](https://cloud.tencent.com/document/api/1285/81635)

	* <font color="#dd0000">**修改入参**：</font>ExportField

* [DescribeSecLogDeliveryKafkaOptions](https://cloud.tencent.com/document/api/1285/81730)

	* 新增入参：RegionID

	* 新增出参：RegionList

* [DescribeSecLogDeliveryKafkaSetting](https://cloud.tencent.com/document/api/1285/81729)

	* 新增出参：RegionID

* [ModifySecLogDeliveryKafkaSetting](https://cloud.tencent.com/document/api/1285/81722)

	* 新增入参：RegionID


新增数据结构：

* [ExportJobInfo](https://cloud.tencent.com/document/api/1285/65614#ExportJobInfo)

修改数据结构：

* [CompliancePolicyItemSummary](https://cloud.tencent.com/document/api/1285/65614#CompliancePolicyItemSummary)

	* 新增成员：ApplicableVersion

* [FileAttributeInfo](https://cloud.tencent.com/document/api/1285/65614#FileAttributeInfo)

	* 新增成员：NewFile, FileDiff


### 第 28 次发布

发布时间：2022-10-21 06:44:56

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [AddComplianceAssetPolicySetToWhitelist](https://cloud.tencent.com/document/api/1285/81795)
* [AddCompliancePolicyAssetSetToWhitelist](https://cloud.tencent.com/document/api/1285/81794)
* [DeleteComplianceAssetPolicySetFromWhitelist](https://cloud.tencent.com/document/api/1285/81793)
* [DeleteCompliancePolicyAssetSetFromWhitelist](https://cloud.tencent.com/document/api/1285/81792)
* [DescribeImageRegistryNamespaceList](https://cloud.tencent.com/document/api/1285/81791)

新增数据结构：

* [ComplianceAssetPolicySetItem](https://cloud.tencent.com/document/api/1285/65614#ComplianceAssetPolicySetItem)
* [CompliancePolicyAssetSetItem](https://cloud.tencent.com/document/api/1285/65614#CompliancePolicyAssetSetItem)

### 第 27 次发布

发布时间：2022-10-20 06:40:56

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [AddAndPublishNetworkFirewallPolicyDetail](https://cloud.tencent.com/document/api/1285/81716)
* [AddAndPublishNetworkFirewallPolicyYamlDetail](https://cloud.tencent.com/document/api/1285/81715)
* [AddEditImageAutoAuthorizedRule](https://cloud.tencent.com/document/api/1285/81638)
* [AddEscapeWhiteList](https://cloud.tencent.com/document/api/1285/81667)
* [AddIgnoreVul](https://cloud.tencent.com/document/api/1285/81637)
* [AddNetworkFirewallPolicyDetail](https://cloud.tencent.com/document/api/1285/81714)
* [AddNetworkFirewallPolicyYamlDetail](https://cloud.tencent.com/document/api/1285/81713)
* [CheckNetworkFirewallPolicyYaml](https://cloud.tencent.com/document/api/1285/81712)
* [ConfirmNetworkFirewallPolicy](https://cloud.tencent.com/document/api/1285/81711)
* [CreateAssetImageVirusExportJob](https://cloud.tencent.com/document/api/1285/81689)
* [CreateComponentExportJob](https://cloud.tencent.com/document/api/1285/81636)
* [CreateDefenceVulExportJob](https://cloud.tencent.com/document/api/1285/81666)
* [CreateEmergencyVulExportJob](https://cloud.tencent.com/document/api/1285/81665)
* [CreateEscapeEventsExportJob](https://cloud.tencent.com/document/api/1285/81664)
* [CreateEscapeWhiteListExportJob](https://cloud.tencent.com/document/api/1285/81663)
* [CreateHostExportJob](https://cloud.tencent.com/document/api/1285/81688)
* [CreateImageExportJob](https://cloud.tencent.com/document/api/1285/81635)
* [CreateNetworkFirewallClusterRefresh](https://cloud.tencent.com/document/api/1285/81710)
* [CreateNetworkFirewallPolicyDiscover](https://cloud.tencent.com/document/api/1285/81709)
* [CreateNetworkFirewallPublish](https://cloud.tencent.com/document/api/1285/81708)
* [CreateNetworkFirewallUndoPublish](https://cloud.tencent.com/document/api/1285/81707)
* [CreateProcessEventsExportJob](https://cloud.tencent.com/document/api/1285/81662)
* [CreateSearchTemplate](https://cloud.tencent.com/document/api/1285/81744)
* [CreateSystemVulExportJob](https://cloud.tencent.com/document/api/1285/81661)
* [CreateVulContainerExportJob](https://cloud.tencent.com/document/api/1285/81660)
* [CreateVulDefenceEventExportJob](https://cloud.tencent.com/document/api/1285/81634)
* [CreateVulDefenceHostExportJob](https://cloud.tencent.com/document/api/1285/81633)
* [CreateVulExportJob](https://cloud.tencent.com/document/api/1285/81632)
* [CreateVulImageExportJob](https://cloud.tencent.com/document/api/1285/81659)
* [CreateVulScanTask](https://cloud.tencent.com/document/api/1285/81658)
* [CreateWebVulExportJob](https://cloud.tencent.com/document/api/1285/81657)
* [DeleteEscapeWhiteList](https://cloud.tencent.com/document/api/1285/81656)
* [DeleteIgnoreVul](https://cloud.tencent.com/document/api/1285/81631)
* [DeleteMachine](https://cloud.tencent.com/document/api/1285/81687)
* [DeleteNetworkFirewallPolicyDetail](https://cloud.tencent.com/document/api/1285/81706)
* [DeleteReverseShellEvents](https://cloud.tencent.com/document/api/1285/81655)
* [DeleteRiskSyscallEvents](https://cloud.tencent.com/document/api/1285/81668)
* [DeleteSearchTemplate](https://cloud.tencent.com/document/api/1285/81743)
* [DescribeABTestConfig](https://cloud.tencent.com/document/api/1285/81686)
* [DescribeAbnormalProcessEventTendency](https://cloud.tencent.com/document/api/1285/81654)
* [DescribeAbnormalProcessLevelSummary](https://cloud.tencent.com/document/api/1285/81653)
* [DescribeAgentDaemonSetCmd](https://cloud.tencent.com/document/api/1285/81685)
* [DescribeAgentInstallCommand](https://cloud.tencent.com/document/api/1285/81684)
* [DescribeAssetSyncLastTime](https://cloud.tencent.com/document/api/1285/81683)
* [DescribeAutoAuthorizedRuleHost](https://cloud.tencent.com/document/api/1285/81630)
* [DescribeESAggregations](https://cloud.tencent.com/document/api/1285/81742)
* [DescribeESHits](https://cloud.tencent.com/document/api/1285/81741)
* [DescribeEmergencyVulList](https://cloud.tencent.com/document/api/1285/81652)
* [DescribeEscapeEventTendency](https://cloud.tencent.com/document/api/1285/81651)
* [DescribeEscapeEventTypeSummary](https://cloud.tencent.com/document/api/1285/81650)
* [DescribeEscapeWhiteList](https://cloud.tencent.com/document/api/1285/81649)
* [DescribeImageAutoAuthorizedLogList](https://cloud.tencent.com/document/api/1285/81629)
* [DescribeImageAutoAuthorizedRule](https://cloud.tencent.com/document/api/1285/81628)
* [DescribeImageAutoAuthorizedTaskList](https://cloud.tencent.com/document/api/1285/81627)
* [DescribeImageComponentList](https://cloud.tencent.com/document/api/1285/81626)
* [DescribeIndexList](https://cloud.tencent.com/document/api/1285/81740)
* [DescribeInspectionReport](https://cloud.tencent.com/document/api/1285/81682)
* [DescribeLogStorageStatistic](https://cloud.tencent.com/document/api/1285/81739)
* [DescribeNetworkFirewallAuditRecord](https://cloud.tencent.com/document/api/1285/81705)
* [DescribeNetworkFirewallClusterList](https://cloud.tencent.com/document/api/1285/81704)
* [DescribeNetworkFirewallClusterRefreshStatus](https://cloud.tencent.com/document/api/1285/81703)
* [DescribeNetworkFirewallNamespaceLabelList](https://cloud.tencent.com/document/api/1285/81702)
* [DescribeNetworkFirewallNamespaceList](https://cloud.tencent.com/document/api/1285/81701)
* [DescribeNetworkFirewallPodLabelsList](https://cloud.tencent.com/document/api/1285/81700)
* [DescribeNetworkFirewallPolicyDetail](https://cloud.tencent.com/document/api/1285/81699)
* [DescribeNetworkFirewallPolicyDiscover](https://cloud.tencent.com/document/api/1285/81698)
* [DescribeNetworkFirewallPolicyList](https://cloud.tencent.com/document/api/1285/81697)
* [DescribeNetworkFirewallPolicyStatus](https://cloud.tencent.com/document/api/1285/81696)
* [DescribeNetworkFirewallPolicyYamlDetail](https://cloud.tencent.com/document/api/1285/81695)
* [DescribeNewestVul](https://cloud.tencent.com/document/api/1285/81625)
* [DescribePromotionActivity](https://cloud.tencent.com/document/api/1285/81681)
* [DescribePublicKey](https://cloud.tencent.com/document/api/1285/81738)
* [DescribeScanIgnoreVulList](https://cloud.tencent.com/document/api/1285/81624)
* [DescribeSearchExportList](https://cloud.tencent.com/document/api/1285/81737)
* [DescribeSearchLogs](https://cloud.tencent.com/document/api/1285/81736)
* [DescribeSearchTemplates](https://cloud.tencent.com/document/api/1285/81735)
* [DescribeSecLogAlertMsg](https://cloud.tencent.com/document/api/1285/81734)
* [DescribeSecLogCleanSettingInfo](https://cloud.tencent.com/document/api/1285/81733)
* [DescribeSecLogDeliveryClsOptions](https://cloud.tencent.com/document/api/1285/81732)
* [DescribeSecLogDeliveryClsSetting](https://cloud.tencent.com/document/api/1285/81731)
* [DescribeSecLogDeliveryKafkaOptions](https://cloud.tencent.com/document/api/1285/81730)
* [DescribeSecLogDeliveryKafkaSetting](https://cloud.tencent.com/document/api/1285/81729)
* [DescribeSecLogJoinObjectList](https://cloud.tencent.com/document/api/1285/81728)
* [DescribeSecLogJoinTypeList](https://cloud.tencent.com/document/api/1285/81727)
* [DescribeSecLogKafkaUIN](https://cloud.tencent.com/document/api/1285/81726)
* [DescribeSecLogVasInfo](https://cloud.tencent.com/document/api/1285/81725)
* [DescribeSupportDefenceVul](https://cloud.tencent.com/document/api/1285/81648)
* [DescribeSystemVulList](https://cloud.tencent.com/document/api/1285/81623)
* [DescribeTcssSummary](https://cloud.tencent.com/document/api/1285/81680)
* [DescribeUnauthorizedCoresTendency](https://cloud.tencent.com/document/api/1285/81679)
* [DescribeVirusAutoIsolateSampleDetail](https://cloud.tencent.com/document/api/1285/81677)
* [DescribeVirusAutoIsolateSampleDownloadURL](https://cloud.tencent.com/document/api/1285/81676)
* [DescribeVirusAutoIsolateSampleList](https://cloud.tencent.com/document/api/1285/81675)
* [DescribeVirusAutoIsolateSetting](https://cloud.tencent.com/document/api/1285/81674)
* [DescribeVirusEventTendency](https://cloud.tencent.com/document/api/1285/81673)
* [DescribeVirusManualScanEstimateTimeout](https://cloud.tencent.com/document/api/1285/81672)
* [DescribeVirusSampleDownloadUrl](https://cloud.tencent.com/document/api/1285/81671)
* [DescribeVulContainerList](https://cloud.tencent.com/document/api/1285/81647)
* [DescribeVulDefenceEvent](https://cloud.tencent.com/document/api/1285/81622)
* [DescribeVulDefenceEventDetail](https://cloud.tencent.com/document/api/1285/81621)
* [DescribeVulDefenceEventTendency](https://cloud.tencent.com/document/api/1285/81620)
* [DescribeVulDefenceHost](https://cloud.tencent.com/document/api/1285/81619)
* [DescribeVulDefencePlugin](https://cloud.tencent.com/document/api/1285/81618)
* [DescribeVulDefenceSetting](https://cloud.tencent.com/document/api/1285/81617)
* [DescribeVulDetail](https://cloud.tencent.com/document/api/1285/81646)
* [DescribeVulIgnoreLocalImageList](https://cloud.tencent.com/document/api/1285/81616)
* [DescribeVulIgnoreRegistryImageList](https://cloud.tencent.com/document/api/1285/81615)
* [DescribeVulImageList](https://cloud.tencent.com/document/api/1285/81645)
* [DescribeVulImageSummary](https://cloud.tencent.com/document/api/1285/81614)
* [DescribeVulLevelImageSummary](https://cloud.tencent.com/document/api/1285/81613)
* [DescribeVulLevelSummary](https://cloud.tencent.com/document/api/1285/81612)
* [DescribeVulScanAuthorizedImageSummary](https://cloud.tencent.com/document/api/1285/81611)
* [DescribeVulScanInfo](https://cloud.tencent.com/document/api/1285/81644)
* [DescribeVulScanLocalImageList](https://cloud.tencent.com/document/api/1285/81643)
* [DescribeVulSummary](https://cloud.tencent.com/document/api/1285/81610)
* [DescribeVulTendency](https://cloud.tencent.com/document/api/1285/81609)
* [DescribeVulTopRanking](https://cloud.tencent.com/document/api/1285/81608)
* [DescribeWebVulList](https://cloud.tencent.com/document/api/1285/81642)
* [ModifyContainerNetStatus](https://cloud.tencent.com/document/api/1285/81678)
* [ModifyEscapeWhiteList](https://cloud.tencent.com/document/api/1285/81641)
* [ModifyImageAuthorized](https://cloud.tencent.com/document/api/1285/81607)
* [ModifySecLogCleanSettingInfo](https://cloud.tencent.com/document/api/1285/81724)
* [ModifySecLogDeliveryClsSetting](https://cloud.tencent.com/document/api/1285/81723)
* [ModifySecLogDeliveryKafkaSetting](https://cloud.tencent.com/document/api/1285/81722)
* [ModifySecLogJoinObjects](https://cloud.tencent.com/document/api/1285/81721)
* [ModifySecLogJoinState](https://cloud.tencent.com/document/api/1285/81720)
* [ModifySecLogKafkaUIN](https://cloud.tencent.com/document/api/1285/81719)
* [ModifyVirusAutoIsolateExampleSwitch](https://cloud.tencent.com/document/api/1285/81670)
* [ModifyVirusAutoIsolateSetting](https://cloud.tencent.com/document/api/1285/81669)
* [ModifyVulDefenceEventStatus](https://cloud.tencent.com/document/api/1285/81606)
* [ModifyVulDefenceSetting](https://cloud.tencent.com/document/api/1285/81605)
* [OpenTcssTrial](https://cloud.tencent.com/document/api/1285/81640)
* [ResetSecLogTopicConfig](https://cloud.tencent.com/document/api/1285/81718)
* [StopVulScanTask](https://cloud.tencent.com/document/api/1285/81639)
* [SwitchImageAutoAuthorizedRule](https://cloud.tencent.com/document/api/1285/81604)
* [UpdateAndPublishNetworkFirewallPolicyDetail](https://cloud.tencent.com/document/api/1285/81694)
* [UpdateAndPublishNetworkFirewallPolicyYamlDetail](https://cloud.tencent.com/document/api/1285/81693)
* [UpdateNetworkFirewallPolicyDetail](https://cloud.tencent.com/document/api/1285/81692)
* [UpdateNetworkFirewallPolicyYamlDetail](https://cloud.tencent.com/document/api/1285/81691)

新增数据结构：

* [ABTestConfig](https://cloud.tencent.com/document/api/1285/65614#ABTestConfig)
* [AbnormalProcessEventTendencyInfo](https://cloud.tencent.com/document/api/1285/65614#AbnormalProcessEventTendencyInfo)
* [AutoAuthorizedImageInfo](https://cloud.tencent.com/document/api/1285/65614#AutoAuthorizedImageInfo)
* [AutoAuthorizedRuleHostInfo](https://cloud.tencent.com/document/api/1285/65614#AutoAuthorizedRuleHostInfo)
* [CKafkaInstanceInfo](https://cloud.tencent.com/document/api/1285/65614#CKafkaInstanceInfo)
* [CKafkaTopicInfo](https://cloud.tencent.com/document/api/1285/65614#CKafkaTopicInfo)
* [CkafkaRouteInfo](https://cloud.tencent.com/document/api/1285/65614#CkafkaRouteInfo)
* [ClsLogsetInfo](https://cloud.tencent.com/document/api/1285/65614#ClsLogsetInfo)
* [ClsTopicInfo](https://cloud.tencent.com/document/api/1285/65614#ClsTopicInfo)
* [EmergencyVulInfo](https://cloud.tencent.com/document/api/1285/65614#EmergencyVulInfo)
* [EscapeEventTendencyInfo](https://cloud.tencent.com/document/api/1285/65614#EscapeEventTendencyInfo)
* [EscapeWhiteListInfo](https://cloud.tencent.com/document/api/1285/65614#EscapeWhiteListInfo)
* [ImageAutoAuthorizedTask](https://cloud.tencent.com/document/api/1285/65614#ImageAutoAuthorizedTask)
* [ImageComponent](https://cloud.tencent.com/document/api/1285/65614#ImageComponent)
* [ModifyIgnoreVul](https://cloud.tencent.com/document/api/1285/65614#ModifyIgnoreVul)
* [NetworkAuditRecord](https://cloud.tencent.com/document/api/1285/65614#NetworkAuditRecord)
* [NetworkClusterInfoItem](https://cloud.tencent.com/document/api/1285/65614#NetworkClusterInfoItem)
* [NetworkClusterNamespaceInfo](https://cloud.tencent.com/document/api/1285/65614#NetworkClusterNamespaceInfo)
* [NetworkClusterNamespaceLabelInfo](https://cloud.tencent.com/document/api/1285/65614#NetworkClusterNamespaceLabelInfo)
* [NetworkClusterPodInfo](https://cloud.tencent.com/document/api/1285/65614#NetworkClusterPodInfo)
* [NetworkCustomPolicy](https://cloud.tencent.com/document/api/1285/65614#NetworkCustomPolicy)
* [NetworkPeer](https://cloud.tencent.com/document/api/1285/65614#NetworkPeer)
* [NetworkPolicyInfoItem](https://cloud.tencent.com/document/api/1285/65614#NetworkPolicyInfoItem)
* [NetworkPorts](https://cloud.tencent.com/document/api/1285/65614#NetworkPorts)
* [PromotionActivityContent](https://cloud.tencent.com/document/api/1285/65614#PromotionActivityContent)
* [RegionInfo](https://cloud.tencent.com/document/api/1285/65614#RegionInfo)
* [ScanIgnoreVul](https://cloud.tencent.com/document/api/1285/65614#ScanIgnoreVul)
* [SearchTemplate](https://cloud.tencent.com/document/api/1285/65614#SearchTemplate)
* [SecLogAlertMsgInfo](https://cloud.tencent.com/document/api/1285/65614#SecLogAlertMsgInfo)
* [SecLogDeliveryClsSettingInfo](https://cloud.tencent.com/document/api/1285/65614#SecLogDeliveryClsSettingInfo)
* [SecLogDeliveryKafkaSettingInfo](https://cloud.tencent.com/document/api/1285/65614#SecLogDeliveryKafkaSettingInfo)
* [SecLogJoinInfo](https://cloud.tencent.com/document/api/1285/65614#SecLogJoinInfo)
* [SecLogJoinObjectInfo](https://cloud.tencent.com/document/api/1285/65614#SecLogJoinObjectInfo)
* [SupportDefenceVul](https://cloud.tencent.com/document/api/1285/65614#SupportDefenceVul)
* [UnauthorizedCoresTendency](https://cloud.tencent.com/document/api/1285/65614#UnauthorizedCoresTendency)
* [VirusAutoIsolateSampleInfo](https://cloud.tencent.com/document/api/1285/65614#VirusAutoIsolateSampleInfo)
* [VirusTendencyInfo](https://cloud.tencent.com/document/api/1285/65614#VirusTendencyInfo)
* [VulAffectedComponentInfo](https://cloud.tencent.com/document/api/1285/65614#VulAffectedComponentInfo)
* [VulAffectedContainerInfo](https://cloud.tencent.com/document/api/1285/65614#VulAffectedContainerInfo)
* [VulAffectedImageComponentInfo](https://cloud.tencent.com/document/api/1285/65614#VulAffectedImageComponentInfo)
* [VulAffectedImageInfo](https://cloud.tencent.com/document/api/1285/65614#VulAffectedImageInfo)
* [VulDefenceEvent](https://cloud.tencent.com/document/api/1285/65614#VulDefenceEvent)
* [VulDefenceEventDetail](https://cloud.tencent.com/document/api/1285/65614#VulDefenceEventDetail)
* [VulDefenceEventTendency](https://cloud.tencent.com/document/api/1285/65614#VulDefenceEventTendency)
* [VulDefenceHost](https://cloud.tencent.com/document/api/1285/65614#VulDefenceHost)
* [VulDefencePlugin](https://cloud.tencent.com/document/api/1285/65614#VulDefencePlugin)
* [VulDetailInfo](https://cloud.tencent.com/document/api/1285/65614#VulDetailInfo)
* [VulIgnoreLocalImage](https://cloud.tencent.com/document/api/1285/65614#VulIgnoreLocalImage)
* [VulIgnoreRegistryImage](https://cloud.tencent.com/document/api/1285/65614#VulIgnoreRegistryImage)
* [VulInfo](https://cloud.tencent.com/document/api/1285/65614#VulInfo)
* [VulScanImageInfo](https://cloud.tencent.com/document/api/1285/65614#VulScanImageInfo)
* [VulTendencyInfo](https://cloud.tencent.com/document/api/1285/65614#VulTendencyInfo)
* [VulTopRankingInfo](https://cloud.tencent.com/document/api/1285/65614#VulTopRankingInfo)

### 第 26 次发布

发布时间：2022-09-08 06:41:25

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [ComplianceAffectedAsset](https://cloud.tencent.com/document/api/1285/65614#ComplianceAffectedAsset)

	* 新增成员：VerifyInfo

* [ComplianceAssetPolicyItem](https://cloud.tencent.com/document/api/1285/65614#ComplianceAssetPolicyItem)

	* 新增成员：VerifyInfo


### 第 25 次发布

发布时间：2022-08-23 06:51:30

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [ModifyEscapeEventStatus](https://cloud.tencent.com/document/api/1285/65523)

	* 新增入参：ImageIDs, EventType


### 第 24 次发布

发布时间：2022-08-15 06:40:11

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeClusterSummary](https://cloud.tencent.com/document/api/1285/65447)

	* 新增出参：CheckedClusterCount, AutoCheckClusterCount, ManualCheckClusterCount, FailedClusterCount


### 第 23 次发布

发布时间：2022-08-11 06:51:30

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeAssetImageVirusListExport](https://cloud.tencent.com/document/api/1285/65482)

	* 新增出参：JobId

* [DescribeVirusDetail](https://cloud.tencent.com/document/api/1285/65583)

	* 新增出参：CheckPlatform


修改数据结构：

* [ImageVirusInfo](https://cloud.tencent.com/document/api/1285/65614#ImageVirusInfo)

	* 新增成员：CheckPlatform

* [VirusInfo](https://cloud.tencent.com/document/api/1285/65614#VirusInfo)

	* 新增成员：RiskLevel, CheckPlatform


### 第 22 次发布

发布时间：2022-08-09 12:25:45

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeAssetSummary](https://cloud.tencent.com/document/api/1285/65477)

	* 新增出参：HostUnInstallCnt

* [DescribeContainerAssetSummary](https://cloud.tencent.com/document/api/1285/65475)

	* 新增出参：HostUnInstallCnt


### 第 21 次发布

发布时间：2022-07-07 06:16:19

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [AbnormalProcessEventInfo](https://cloud.tencent.com/document/api/1285/65614#AbnormalProcessEventInfo)

	* 新增成员：ContainerStatus

* [AccessControlEventInfo](https://cloud.tencent.com/document/api/1285/65614#AccessControlEventInfo)

	* 新增成员：ContainerStatus

* [EscapeEventInfo](https://cloud.tencent.com/document/api/1285/65614#EscapeEventInfo)

	* 新增成员：ContainerStatus

* [ReverseShellEventInfo](https://cloud.tencent.com/document/api/1285/65614#ReverseShellEventInfo)

	* 新增成员：ContainerStatus

* [RiskSyscallEventInfo](https://cloud.tencent.com/document/api/1285/65614#RiskSyscallEventInfo)

	* 新增成员：ContainerStatus


### 第 20 次发布

发布时间：2022-07-06 06:18:51

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribePurchaseStateInfo](https://cloud.tencent.com/document/api/1285/65466)

	* 新增出参：BeginTime, SubState


### 第 19 次发布

发布时间：2022-06-21 06:13:45

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [ClusterCheckItem](https://cloud.tencent.com/document/api/1285/65614#ClusterCheckItem)

	* 新增成员：IgnoredAssetNum, IsIgnored, RiskAssessment


### 第 18 次发布

发布时间：2022-06-08 06:15:35

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeVirusSummary](https://cloud.tencent.com/document/api/1285/65577)

	* 新增出参：IsolateIncrease, IsolateCnt


### 第 17 次发布

发布时间：2022-05-25 06:15:02

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeAccessControlEventsExport](https://cloud.tencent.com/document/api/1285/65544)

	* <font color="#dd0000">**修改入参**：</font>ExportField

	* 新增出参：JobId

* [DescribeAssetContainerDetail](https://cloud.tencent.com/document/api/1285/65511)

	* 新增出参：NetStatus, NetSubStatus, IsolateSource, IsolateTime

* [DescribeReverseShellEventsExport](https://cloud.tencent.com/document/api/1285/65531)

	* <font color="#dd0000">**修改入参**：</font>ExportField

	* 新增出参：JobId

* [DescribeRiskSyscallEventsExport](https://cloud.tencent.com/document/api/1285/65566)

	* <font color="#dd0000">**修改入参**：</font>ExportField

	* 新增出参：JobId

* [DescribeVirusDetail](https://cloud.tencent.com/document/api/1285/65583)

	* 新增出参：ContainerNetStatus, ContainerNetSubStatus, ContainerIsolateOperationSrc

* [ModifyVirusFileStatus](https://cloud.tencent.com/document/api/1285/65574)

	* 新增入参：AutoIsolate


修改数据结构：

* [AbnormalProcessEventInfo](https://cloud.tencent.com/document/api/1285/65614#AbnormalProcessEventInfo)

	* 新增成员：ContainerNetStatus, ContainerNetSubStatus, ContainerIsolateOperationSrc

* [AccessControlEventInfo](https://cloud.tencent.com/document/api/1285/65614#AccessControlEventInfo)

	* 新增成员：ContainerNetStatus, ContainerNetSubStatus, ContainerIsolateOperationSrc

* [ContainerInfo](https://cloud.tencent.com/document/api/1285/65614#ContainerInfo)

	* 新增成员：NetStatus, NetSubStatus, IsolateSource, IsolateTime

* [EscapeEventInfo](https://cloud.tencent.com/document/api/1285/65614#EscapeEventInfo)

	* 新增成员：ContainerNetStatus, ContainerNetSubStatus, ContainerIsolateOperationSrc

* [ReverseShellEventInfo](https://cloud.tencent.com/document/api/1285/65614#ReverseShellEventInfo)

	* 新增成员：ContainerNetStatus, ContainerNetSubStatus, ContainerIsolateOperationSrc

* [RiskSyscallEventInfo](https://cloud.tencent.com/document/api/1285/65614#RiskSyscallEventInfo)

	* 新增成员：ContainerNetStatus, ContainerNetSubStatus, ContainerIsolateOperationSrc

* [VirusInfo](https://cloud.tencent.com/document/api/1285/65614#VirusInfo)

	* 新增成员：ContainerNetStatus, ContainerNetSubStatus, ContainerIsolateOperationSrc, MD5


### 第 16 次发布

发布时间：2022-05-09 06:14:07

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeClusterDetail](https://cloud.tencent.com/document/api/1285/65448)

	* 新增出参：NetworkType, ApiServerAddress, NodeCount, NamespaceCount, WorkloadCount, PodCount, ServiceCount, IngressCount


### 第 15 次发布

发布时间：2022-04-20 06:13:52

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [AbnormalProcessChildRuleInfo](https://cloud.tencent.com/document/api/1285/65614#AbnormalProcessChildRuleInfo)

	* 新增成员：RuleLevel

* [AbnormalProcessEventDescription](https://cloud.tencent.com/document/api/1285/65614#AbnormalProcessEventDescription)

	* 新增成员：GroupName

* [AbnormalProcessEventInfo](https://cloud.tencent.com/document/api/1285/65614#AbnormalProcessEventInfo)

	* 新增成员：MatchGroupName, MatchRuleLevel

* [AbnormalProcessSystemChildRuleInfo](https://cloud.tencent.com/document/api/1285/65614#AbnormalProcessSystemChildRuleInfo)

	* 新增成员：RuleLevel

* [EscapeEventInfo](https://cloud.tencent.com/document/api/1285/65614#EscapeEventInfo)

	* 新增成员：NodeIP, HostID

* [EscapeRule](https://cloud.tencent.com/document/api/1285/65614#EscapeRule)

	* 新增成员：Group

* [RunTimeEventBaseInfo](https://cloud.tencent.com/document/api/1285/65614#RunTimeEventBaseInfo)

	* 新增成员：ContainerNetStatus, ContainerNetSubStatus, ContainerIsolateOperationSrc


### 第 14 次发布

发布时间：2022-04-12 06:21:48

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeProVersionInfo](https://cloud.tencent.com/document/api/1285/65467)

	* 新增出参：BuyStatus, IsPurchased


### 第 13 次发布

发布时间：2022-03-29 08:16:06

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [ComplianceAssetSummary](https://cloud.tencent.com/document/api/1285/65614#ComplianceAssetSummary)

	* 新增成员：OpenPolicyItemCount, IgnoredPolicyItemCount

* [CompliancePeriodTaskRule](https://cloud.tencent.com/document/api/1285/65614#CompliancePeriodTaskRule)

	* 新增成员：Enable


### 第 12 次发布

发布时间：2022-03-23 08:12:32

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeAbnormalProcessDetail](https://cloud.tencent.com/document/api/1285/65552)

	* 新增出参：AncestorProcessInfo

* [DescribeAbnormalProcessRuleDetail](https://cloud.tencent.com/document/api/1285/65549)

	* 新增入参：Limit, Offset

* [DescribeAccessControlDetail](https://cloud.tencent.com/document/api/1285/65546)

	* 新增出参：ParentProcessInfo, AncestorProcessInfo

* [DescribeAccessControlRuleDetail](https://cloud.tencent.com/document/api/1285/65543)

	* 新增入参：Limit, Offset

* [DescribeEscapeEventDetail](https://cloud.tencent.com/document/api/1285/65538)

	* 新增出参：ParentProcessInfo, AncestorProcessInfo

* [DescribeReverseShellDetail](https://cloud.tencent.com/document/api/1285/65533)

	* 新增出参：AncestorProcessInfo

* [DescribeRiskSyscallDetail](https://cloud.tencent.com/document/api/1285/65528)

	* 新增出参：AncestorProcessInfo

* [DescribeVirusDetail](https://cloud.tencent.com/document/api/1285/65583)

	* 新增出参：PProcessStartUser, PProcessUserGroup, PProcessPath, PProcessParam, AncestorProcessStartUser, AncestorProcessUserGroup, AncestorProcessPath, AncestorProcessParam, OperationTime


新增数据结构：

* [ProcessBaseInfo](https://cloud.tencent.com/document/api/1285/65614#ProcessBaseInfo)

修改数据结构：

* [AbnormalProcessEventDescription](https://cloud.tencent.com/document/api/1285/65614#AbnormalProcessEventDescription)

	* 新增成员：OperationTime

* [AbnormalProcessRuleInfo](https://cloud.tencent.com/document/api/1285/65614#AbnormalProcessRuleInfo)

	* 新增成员：IsDefault

* [AccessControlEventDescription](https://cloud.tencent.com/document/api/1285/65614#AccessControlEventDescription)

	* 新增成员：OperationTime

* [AccessControlRuleInfo](https://cloud.tencent.com/document/api/1285/65614#AccessControlRuleInfo)

	* 新增成员：IsDefault

* [EscapeEventDescription](https://cloud.tencent.com/document/api/1285/65614#EscapeEventDescription)

	* 新增成员：OperationTime

* [ReverseShellEventDescription](https://cloud.tencent.com/document/api/1285/65614#ReverseShellEventDescription)

	* 新增成员：OperationTime

* [RiskSyscallEventDescription](https://cloud.tencent.com/document/api/1285/65614#RiskSyscallEventDescription)

	* 新增成员：OperationTime


### 第 11 次发布

发布时间：2022-03-08 08:18:39

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [ImagesInfo](https://cloud.tencent.com/document/api/1285/65614#ImagesInfo)

	* 新增成员：ComponentCnt


### 第 10 次发布

发布时间：2022-03-02 08:15:58

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [AddAssetImageRegistryRegistryDetail](https://cloud.tencent.com/document/api/1285/65560)

	* 新增入参：Insecure

* [DescribeAssetImageRegistryRegistryDetail](https://cloud.tencent.com/document/api/1285/65539)

	* 新增出参：Insecure

* [DescribeComplianceWhitelistItemList](https://cloud.tencent.com/document/api/1285/65600)

	* 新增入参：By, Order

* [UpdateAssetImageRegistryRegistryDetail](https://cloud.tencent.com/document/api/1285/65519)

	* 新增入参：Insecure


### 第 9 次发布

发布时间：2022-02-15 08:13:53

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeAssetImageRegistryDetail](https://cloud.tencent.com/document/api/1285/65501)

	* 新增入参：ImageId


修改数据结构：

* [ComplianceK8SDetailInfo](https://cloud.tencent.com/document/api/1285/65614#ComplianceK8SDetailInfo)

	* 新增成员：ClusterVersion


### 第 8 次发布

发布时间：2022-01-24 08:15:12

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateAssetImageScanTask](https://cloud.tencent.com/document/api/1285/65515)

	* 新增入参：Filters, ExcludeImageIds

* [DescribeImageAuthorizedInfo](https://cloud.tencent.com/document/api/1285/65473)

	* 新增出参：NotScannedLocalImageCnt

* [ModifyAssetImageScanStop](https://cloud.tencent.com/document/api/1285/65460)

	* 新增入参：Filters, ExcludeImageIds


### 第 7 次发布

发布时间：2022-01-20 19:50:27

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeAssetImageRegistryDetail](https://cloud.tencent.com/document/api/1285/65501)

	* 新增出参：RegistryType, ImageName, ImageTag, ScanTime, ScanStatus, VulCnt, VirusCnt, RiskCnt, SentiveInfoCnt, OsName, ScanVirusError, ScanVulError, LayerInfo, InstanceId, InstanceName, Namespace, ScanRiskError, ScanVirusProgress, ScanVulProgress, ScanRiskProgress, ScanRemainTime, CveStatus, RiskStatus, VirusStatus, Progress, IsAuthorized, ImageSize, ImageId, RegistryRegion, ImageCreateTime


### 第 6 次发布

发布时间：2022-01-20 19:25:42

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateAssetImageRegistryScanTask](https://cloud.tencent.com/document/api/1285/65517)

	* 新增入参：Filters, ExcludeImageList, OnlyScanLatest

* [DescribeAssetImageRegistryDetail](https://cloud.tencent.com/document/api/1285/65501)

	* 新增入参：Id

* [DescribeAssetImageRegistryList](https://cloud.tencent.com/document/api/1285/65500)

	* 新增入参：Limit, Offset, Filters, By, Order, OnlyShowLatest

	* 新增出参：List, TotalCount

* [DescribeAssetImageRegistryListExport](https://cloud.tencent.com/document/api/1285/65499)

	* 新增入参：OnlyShowLatest

* [ModifyAssetImageRegistryScanStop](https://cloud.tencent.com/document/api/1285/65462)

	* 新增入参：Filters, ExcludeImageList, OnlyScanLatest


新增数据结构：

* [ImageRepoInfo](https://cloud.tencent.com/document/api/1285/65614#ImageRepoInfo)

### 第 5 次发布

发布时间：2022-01-14 08:15:55

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeContainerSecEventSummary](https://cloud.tencent.com/document/api/1285/65474)

	* 新增出参：UnhandledVirusEventCnt

* [ModifyVirusScanSetting](https://cloud.tencent.com/document/api/1285/65572)

	* <font color="#dd0000">**修改入参**：</font>ScanIds, ScanPath


### 第 4 次发布

发布时间：2022-01-07 08:13:42

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeAssetHostDetail](https://cloud.tencent.com/document/api/1285/65508)

	* 新增出参：InstanceID, RegionID


修改数据结构：

* [HostInfo](https://cloud.tencent.com/document/api/1285/65614#HostInfo)

	* 新增成员：InstanceID, RegionID


### 第 3 次发布

发布时间：2021-12-22 08:16:46

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeVirusDetail](https://cloud.tencent.com/document/api/1285/65583)

	* 新增出参：HostIP, ClientIP


修改数据结构：

* [RunTimeEventBaseInfo](https://cloud.tencent.com/document/api/1285/65614#RunTimeEventBaseInfo)

	* 新增成员：HostIP, ClientIP


### 第 2 次发布

发布时间：2021-12-08 08:15:31

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeAssetHostDetail](https://cloud.tencent.com/document/api/1285/65508)

	* 新增出参：IsContainerd, MachineType, PublicIp


修改数据结构：

* [ContainerInfo](https://cloud.tencent.com/document/api/1285/65614#ContainerInfo)

	* 新增成员：PublicIp

* [HostInfo](https://cloud.tencent.com/document/api/1285/65614#HostInfo)

	* 新增成员：IsContainerd, MachineType, PublicIp, Uuid

* [PortInfo](https://cloud.tencent.com/document/api/1285/65614#PortInfo)

	* 新增成员：HostName, PublicIp

* [ProcessInfo](https://cloud.tencent.com/document/api/1285/65614#ProcessInfo)

	* 新增成员：HostName, PublicIp

* [ServiceInfo](https://cloud.tencent.com/document/api/1285/65614#ServiceInfo)

	* 新增成员：HostName, PublicIp


### 第 1 次发布

发布时间：2021-12-06 10:01:05

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [AddAssetImageRegistryRegistryDetail](https://cloud.tencent.com/document/api/1285/65560)
* [AddCompliancePolicyItemToWhitelist](https://cloud.tencent.com/document/api/1285/65613)
* [AddEditAbnormalProcessRule](https://cloud.tencent.com/document/api/1285/65559)
* [AddEditAccessControlRule](https://cloud.tencent.com/document/api/1285/65558)
* [AddEditReverseShellWhiteList](https://cloud.tencent.com/document/api/1285/65589)
* [AddEditRiskSyscallWhiteList](https://cloud.tencent.com/document/api/1285/65557)
* [AddEditWarningRules](https://cloud.tencent.com/document/api/1285/65588)
* [CheckRepeatAssetImageRegistry](https://cloud.tencent.com/document/api/1285/65556)
* [CreateAssetImageRegistryScanTask](https://cloud.tencent.com/document/api/1285/65517)
* [CreateAssetImageRegistryScanTaskOneKey](https://cloud.tencent.com/document/api/1285/65516)
* [CreateAssetImageScanSetting](https://cloud.tencent.com/document/api/1285/65591)
* [CreateAssetImageScanTask](https://cloud.tencent.com/document/api/1285/65515)
* [CreateCheckComponent](https://cloud.tencent.com/document/api/1285/65455)
* [CreateClusterCheckTask](https://cloud.tencent.com/document/api/1285/65454)
* [CreateComplianceTask](https://cloud.tencent.com/document/api/1285/65612)
* [CreateExportComplianceStatusListJob](https://cloud.tencent.com/document/api/1285/65611)
* [CreateOrModifyPostPayCores](https://cloud.tencent.com/document/api/1285/65514)
* [CreateRefreshTask](https://cloud.tencent.com/document/api/1285/65453)
* [CreateVirusScanAgain](https://cloud.tencent.com/document/api/1285/65585)
* [CreateVirusScanTask](https://cloud.tencent.com/document/api/1285/65584)
* [DeleteAbnormalProcessRules](https://cloud.tencent.com/document/api/1285/65555)
* [DeleteAccessControlRules](https://cloud.tencent.com/document/api/1285/65554)
* [DeleteCompliancePolicyItemFromWhitelist](https://cloud.tencent.com/document/api/1285/65610)
* [DeleteReverseShellWhiteLists](https://cloud.tencent.com/document/api/1285/65553)
* [DeleteRiskSyscallWhiteLists](https://cloud.tencent.com/document/api/1285/65568)
* [DescribeAbnormalProcessDetail](https://cloud.tencent.com/document/api/1285/65552)
* [DescribeAbnormalProcessEvents](https://cloud.tencent.com/document/api/1285/65551)
* [DescribeAbnormalProcessEventsExport](https://cloud.tencent.com/document/api/1285/65550)
* [DescribeAbnormalProcessRuleDetail](https://cloud.tencent.com/document/api/1285/65549)
* [DescribeAbnormalProcessRules](https://cloud.tencent.com/document/api/1285/65548)
* [DescribeAbnormalProcessRulesExport](https://cloud.tencent.com/document/api/1285/65547)
* [DescribeAccessControlDetail](https://cloud.tencent.com/document/api/1285/65546)
* [DescribeAccessControlEvents](https://cloud.tencent.com/document/api/1285/65545)
* [DescribeAccessControlEventsExport](https://cloud.tencent.com/document/api/1285/65544)
* [DescribeAccessControlRuleDetail](https://cloud.tencent.com/document/api/1285/65543)
* [DescribeAccessControlRules](https://cloud.tencent.com/document/api/1285/65542)
* [DescribeAccessControlRulesExport](https://cloud.tencent.com/document/api/1285/65541)
* [DescribeAffectedClusterCount](https://cloud.tencent.com/document/api/1285/65452)
* [DescribeAffectedNodeList](https://cloud.tencent.com/document/api/1285/65451)
* [DescribeAffectedWorkloadList](https://cloud.tencent.com/document/api/1285/65450)
* [DescribeAssetAppServiceList](https://cloud.tencent.com/document/api/1285/65513)
* [DescribeAssetComponentList](https://cloud.tencent.com/document/api/1285/65512)
* [DescribeAssetContainerDetail](https://cloud.tencent.com/document/api/1285/65511)
* [DescribeAssetContainerList](https://cloud.tencent.com/document/api/1285/65510)
* [DescribeAssetDBServiceList](https://cloud.tencent.com/document/api/1285/65509)
* [DescribeAssetHostDetail](https://cloud.tencent.com/document/api/1285/65508)
* [DescribeAssetHostList](https://cloud.tencent.com/document/api/1285/65507)
* [DescribeAssetImageBindRuleInfo](https://cloud.tencent.com/document/api/1285/65540)
* [DescribeAssetImageDetail](https://cloud.tencent.com/document/api/1285/65506)
* [DescribeAssetImageHostList](https://cloud.tencent.com/document/api/1285/65505)
* [DescribeAssetImageList](https://cloud.tencent.com/document/api/1285/65504)
* [DescribeAssetImageListExport](https://cloud.tencent.com/document/api/1285/65503)
* [DescribeAssetImageRegistryAssetStatus](https://cloud.tencent.com/document/api/1285/65502)
* [DescribeAssetImageRegistryDetail](https://cloud.tencent.com/document/api/1285/65501)
* [DescribeAssetImageRegistryList](https://cloud.tencent.com/document/api/1285/65500)
* [DescribeAssetImageRegistryListExport](https://cloud.tencent.com/document/api/1285/65499)
* [DescribeAssetImageRegistryRegistryDetail](https://cloud.tencent.com/document/api/1285/65539)
* [DescribeAssetImageRegistryRegistryList](https://cloud.tencent.com/document/api/1285/65498)
* [DescribeAssetImageRegistryRiskInfoList](https://cloud.tencent.com/document/api/1285/65497)
* [DescribeAssetImageRegistryRiskListExport](https://cloud.tencent.com/document/api/1285/65496)
* [DescribeAssetImageRegistryScanStatusOneKey](https://cloud.tencent.com/document/api/1285/65495)
* [DescribeAssetImageRegistrySummary](https://cloud.tencent.com/document/api/1285/65494)
* [DescribeAssetImageRegistryVirusList](https://cloud.tencent.com/document/api/1285/65493)
* [DescribeAssetImageRegistryVirusListExport](https://cloud.tencent.com/document/api/1285/65492)
* [DescribeAssetImageRegistryVulList](https://cloud.tencent.com/document/api/1285/65491)
* [DescribeAssetImageRegistryVulListExport](https://cloud.tencent.com/document/api/1285/65490)
* [DescribeAssetImageRiskList](https://cloud.tencent.com/document/api/1285/65489)
* [DescribeAssetImageRiskListExport](https://cloud.tencent.com/document/api/1285/65488)
* [DescribeAssetImageScanSetting](https://cloud.tencent.com/document/api/1285/65487)
* [DescribeAssetImageScanStatus](https://cloud.tencent.com/document/api/1285/65486)
* [DescribeAssetImageScanTask](https://cloud.tencent.com/document/api/1285/65485)
* [DescribeAssetImageSimpleList](https://cloud.tencent.com/document/api/1285/65484)
* [DescribeAssetImageVirusList](https://cloud.tencent.com/document/api/1285/65483)
* [DescribeAssetImageVirusListExport](https://cloud.tencent.com/document/api/1285/65482)
* [DescribeAssetImageVulList](https://cloud.tencent.com/document/api/1285/65481)
* [DescribeAssetImageVulListExport](https://cloud.tencent.com/document/api/1285/65480)
* [DescribeAssetPortList](https://cloud.tencent.com/document/api/1285/65479)
* [DescribeAssetProcessList](https://cloud.tencent.com/document/api/1285/65478)
* [DescribeAssetSummary](https://cloud.tencent.com/document/api/1285/65477)
* [DescribeAssetWebServiceList](https://cloud.tencent.com/document/api/1285/65476)
* [DescribeCheckItemList](https://cloud.tencent.com/document/api/1285/65449)
* [DescribeClusterDetail](https://cloud.tencent.com/document/api/1285/65448)
* [DescribeClusterSummary](https://cloud.tencent.com/document/api/1285/65447)
* [DescribeComplianceAssetDetailInfo](https://cloud.tencent.com/document/api/1285/65609)
* [DescribeComplianceAssetList](https://cloud.tencent.com/document/api/1285/65608)
* [DescribeComplianceAssetPolicyItemList](https://cloud.tencent.com/document/api/1285/65607)
* [DescribeCompliancePeriodTaskList](https://cloud.tencent.com/document/api/1285/65606)
* [DescribeCompliancePolicyItemAffectedAssetList](https://cloud.tencent.com/document/api/1285/65605)
* [DescribeCompliancePolicyItemAffectedSummary](https://cloud.tencent.com/document/api/1285/65604)
* [DescribeComplianceScanFailedAssetList](https://cloud.tencent.com/document/api/1285/65603)
* [DescribeComplianceTaskAssetSummary](https://cloud.tencent.com/document/api/1285/65602)
* [DescribeComplianceTaskPolicyItemSummaryList](https://cloud.tencent.com/document/api/1285/65601)
* [DescribeComplianceWhitelistItemList](https://cloud.tencent.com/document/api/1285/65600)
* [DescribeContainerAssetSummary](https://cloud.tencent.com/document/api/1285/65475)
* [DescribeContainerSecEventSummary](https://cloud.tencent.com/document/api/1285/65474)
* [DescribeEscapeEventDetail](https://cloud.tencent.com/document/api/1285/65538)
* [DescribeEscapeEventInfo](https://cloud.tencent.com/document/api/1285/65537)
* [DescribeEscapeEventsExport](https://cloud.tencent.com/document/api/1285/65536)
* [DescribeEscapeRuleInfo](https://cloud.tencent.com/document/api/1285/65535)
* [DescribeEscapeSafeState](https://cloud.tencent.com/document/api/1285/65534)
* [DescribeExportJobResult](https://cloud.tencent.com/document/api/1285/65599)
* [DescribeImageAuthorizedInfo](https://cloud.tencent.com/document/api/1285/65473)
* [DescribeImageRegistryTimingScanTask](https://cloud.tencent.com/document/api/1285/65472)
* [DescribeImageRiskSummary](https://cloud.tencent.com/document/api/1285/65471)
* [DescribeImageRiskTendency](https://cloud.tencent.com/document/api/1285/65470)
* [DescribeImageSimpleList](https://cloud.tencent.com/document/api/1285/65469)
* [DescribePostPayDetail](https://cloud.tencent.com/document/api/1285/65468)
* [DescribeProVersionInfo](https://cloud.tencent.com/document/api/1285/65467)
* [DescribePurchaseStateInfo](https://cloud.tencent.com/document/api/1285/65466)
* [DescribeRefreshTask](https://cloud.tencent.com/document/api/1285/65446)
* [DescribeReverseShellDetail](https://cloud.tencent.com/document/api/1285/65533)
* [DescribeReverseShellEvents](https://cloud.tencent.com/document/api/1285/65532)
* [DescribeReverseShellEventsExport](https://cloud.tencent.com/document/api/1285/65531)
* [DescribeReverseShellWhiteListDetail](https://cloud.tencent.com/document/api/1285/65530)
* [DescribeReverseShellWhiteLists](https://cloud.tencent.com/document/api/1285/65529)
* [DescribeRiskList](https://cloud.tencent.com/document/api/1285/65445)
* [DescribeRiskSyscallDetail](https://cloud.tencent.com/document/api/1285/65528)
* [DescribeRiskSyscallEvents](https://cloud.tencent.com/document/api/1285/65567)
* [DescribeRiskSyscallEventsExport](https://cloud.tencent.com/document/api/1285/65566)
* [DescribeRiskSyscallNames](https://cloud.tencent.com/document/api/1285/65565)
* [DescribeRiskSyscallWhiteListDetail](https://cloud.tencent.com/document/api/1285/65564)
* [DescribeRiskSyscallWhiteLists](https://cloud.tencent.com/document/api/1285/65563)
* [DescribeSecEventsTendency](https://cloud.tencent.com/document/api/1285/65465)
* [DescribeTaskResultSummary](https://cloud.tencent.com/document/api/1285/65444)
* [DescribeUnfinishRefreshTask](https://cloud.tencent.com/document/api/1285/65443)
* [DescribeUserCluster](https://cloud.tencent.com/document/api/1285/65442)
* [DescribeValueAddedSrvInfo](https://cloud.tencent.com/document/api/1285/65464)
* [DescribeVirusDetail](https://cloud.tencent.com/document/api/1285/65583)
* [DescribeVirusList](https://cloud.tencent.com/document/api/1285/65582)
* [DescribeVirusMonitorSetting](https://cloud.tencent.com/document/api/1285/65581)
* [DescribeVirusScanSetting](https://cloud.tencent.com/document/api/1285/65580)
* [DescribeVirusScanTaskStatus](https://cloud.tencent.com/document/api/1285/65579)
* [DescribeVirusScanTimeoutSetting](https://cloud.tencent.com/document/api/1285/65578)
* [DescribeVirusSummary](https://cloud.tencent.com/document/api/1285/65577)
* [DescribeVirusTaskList](https://cloud.tencent.com/document/api/1285/65576)
* [DescribeWarningRules](https://cloud.tencent.com/document/api/1285/65587)
* [ExportVirusList](https://cloud.tencent.com/document/api/1285/65575)
* [InitializeUserComplianceEnvironment](https://cloud.tencent.com/document/api/1285/65598)
* [ModifyAbnormalProcessRuleStatus](https://cloud.tencent.com/document/api/1285/65527)
* [ModifyAbnormalProcessStatus](https://cloud.tencent.com/document/api/1285/65526)
* [ModifyAccessControlRuleStatus](https://cloud.tencent.com/document/api/1285/65525)
* [ModifyAccessControlStatus](https://cloud.tencent.com/document/api/1285/65524)
* [ModifyAsset](https://cloud.tencent.com/document/api/1285/65463)
* [ModifyAssetImageRegistryScanStop](https://cloud.tencent.com/document/api/1285/65462)
* [ModifyAssetImageRegistryScanStopOneKey](https://cloud.tencent.com/document/api/1285/65461)
* [ModifyAssetImageScanStop](https://cloud.tencent.com/document/api/1285/65460)
* [ModifyCompliancePeriodTask](https://cloud.tencent.com/document/api/1285/65597)
* [ModifyEscapeEventStatus](https://cloud.tencent.com/document/api/1285/65523)
* [ModifyEscapeRule](https://cloud.tencent.com/document/api/1285/65522)
* [ModifyReverseShellStatus](https://cloud.tencent.com/document/api/1285/65521)
* [ModifyRiskSyscallStatus](https://cloud.tencent.com/document/api/1285/65562)
* [ModifyVirusFileStatus](https://cloud.tencent.com/document/api/1285/65574)
* [ModifyVirusMonitorSetting](https://cloud.tencent.com/document/api/1285/65573)
* [ModifyVirusScanSetting](https://cloud.tencent.com/document/api/1285/65572)
* [ModifyVirusScanTimeoutSetting](https://cloud.tencent.com/document/api/1285/65571)
* [RemoveAssetImageRegistryRegistryDetail](https://cloud.tencent.com/document/api/1285/65520)
* [RenewImageAuthorizeState](https://cloud.tencent.com/document/api/1285/65459)
* [ScanComplianceAssets](https://cloud.tencent.com/document/api/1285/65596)
* [ScanComplianceAssetsByPolicyItem](https://cloud.tencent.com/document/api/1285/65595)
* [ScanCompliancePolicyItems](https://cloud.tencent.com/document/api/1285/65594)
* [ScanComplianceScanFailedAssets](https://cloud.tencent.com/document/api/1285/65593)
* [SetCheckMode](https://cloud.tencent.com/document/api/1285/65441)
* [StopVirusScanTask](https://cloud.tencent.com/document/api/1285/65570)
* [SyncAssetImageRegistryAsset](https://cloud.tencent.com/document/api/1285/65458)
* [UpdateAssetImageRegistryRegistryDetail](https://cloud.tencent.com/document/api/1285/65519)
* [UpdateImageRegistryTimingScanTask](https://cloud.tencent.com/document/api/1285/65457)

新增数据结构：

* [AbnormalProcessChildRuleInfo](https://cloud.tencent.com/document/api/1285/65614#AbnormalProcessChildRuleInfo)
* [AbnormalProcessEventDescription](https://cloud.tencent.com/document/api/1285/65614#AbnormalProcessEventDescription)
* [AbnormalProcessEventInfo](https://cloud.tencent.com/document/api/1285/65614#AbnormalProcessEventInfo)
* [AbnormalProcessRuleInfo](https://cloud.tencent.com/document/api/1285/65614#AbnormalProcessRuleInfo)
* [AbnormalProcessSystemChildRuleInfo](https://cloud.tencent.com/document/api/1285/65614#AbnormalProcessSystemChildRuleInfo)
* [AccessControlChildRuleInfo](https://cloud.tencent.com/document/api/1285/65614#AccessControlChildRuleInfo)
* [AccessControlEventDescription](https://cloud.tencent.com/document/api/1285/65614#AccessControlEventDescription)
* [AccessControlEventInfo](https://cloud.tencent.com/document/api/1285/65614#AccessControlEventInfo)
* [AccessControlRuleInfo](https://cloud.tencent.com/document/api/1285/65614#AccessControlRuleInfo)
* [AccessControlSystemChildRuleInfo](https://cloud.tencent.com/document/api/1285/65614#AccessControlSystemChildRuleInfo)
* [AffectedNodeItem](https://cloud.tencent.com/document/api/1285/65614#AffectedNodeItem)
* [AffectedWorkloadItem](https://cloud.tencent.com/document/api/1285/65614#AffectedWorkloadItem)
* [AssetFilters](https://cloud.tencent.com/document/api/1285/65614#AssetFilters)
* [AssetSimpleImageInfo](https://cloud.tencent.com/document/api/1285/65614#AssetSimpleImageInfo)
* [ClusterCheckItem](https://cloud.tencent.com/document/api/1285/65614#ClusterCheckItem)
* [ClusterCheckTaskItem](https://cloud.tencent.com/document/api/1285/65614#ClusterCheckTaskItem)
* [ClusterCreateComponentItem](https://cloud.tencent.com/document/api/1285/65614#ClusterCreateComponentItem)
* [ClusterInfoItem](https://cloud.tencent.com/document/api/1285/65614#ClusterInfoItem)
* [ClusterRiskItem](https://cloud.tencent.com/document/api/1285/65614#ClusterRiskItem)
* [ComplianceAffectedAsset](https://cloud.tencent.com/document/api/1285/65614#ComplianceAffectedAsset)
* [ComplianceAssetDetailInfo](https://cloud.tencent.com/document/api/1285/65614#ComplianceAssetDetailInfo)
* [ComplianceAssetInfo](https://cloud.tencent.com/document/api/1285/65614#ComplianceAssetInfo)
* [ComplianceAssetPolicyItem](https://cloud.tencent.com/document/api/1285/65614#ComplianceAssetPolicyItem)
* [ComplianceAssetSummary](https://cloud.tencent.com/document/api/1285/65614#ComplianceAssetSummary)
* [ComplianceBenchmarkStandard](https://cloud.tencent.com/document/api/1285/65614#ComplianceBenchmarkStandard)
* [ComplianceBenchmarkStandardEnable](https://cloud.tencent.com/document/api/1285/65614#ComplianceBenchmarkStandardEnable)
* [ComplianceContainerDetailInfo](https://cloud.tencent.com/document/api/1285/65614#ComplianceContainerDetailInfo)
* [ComplianceFilters](https://cloud.tencent.com/document/api/1285/65614#ComplianceFilters)
* [ComplianceHostDetailInfo](https://cloud.tencent.com/document/api/1285/65614#ComplianceHostDetailInfo)
* [ComplianceImageDetailInfo](https://cloud.tencent.com/document/api/1285/65614#ComplianceImageDetailInfo)
* [ComplianceK8SDetailInfo](https://cloud.tencent.com/document/api/1285/65614#ComplianceK8SDetailInfo)
* [CompliancePeriodTask](https://cloud.tencent.com/document/api/1285/65614#CompliancePeriodTask)
* [CompliancePeriodTaskRule](https://cloud.tencent.com/document/api/1285/65614#CompliancePeriodTaskRule)
* [CompliancePolicyItemSummary](https://cloud.tencent.com/document/api/1285/65614#CompliancePolicyItemSummary)
* [ComplianceScanFailedAsset](https://cloud.tencent.com/document/api/1285/65614#ComplianceScanFailedAsset)
* [ComplianceWhitelistItem](https://cloud.tencent.com/document/api/1285/65614#ComplianceWhitelistItem)
* [ComponentInfo](https://cloud.tencent.com/document/api/1285/65614#ComponentInfo)
* [ComponentsInfo](https://cloud.tencent.com/document/api/1285/65614#ComponentsInfo)
* [ContainerInfo](https://cloud.tencent.com/document/api/1285/65614#ContainerInfo)
* [ContainerMount](https://cloud.tencent.com/document/api/1285/65614#ContainerMount)
* [ContainerNetwork](https://cloud.tencent.com/document/api/1285/65614#ContainerNetwork)
* [EscapeEventDescription](https://cloud.tencent.com/document/api/1285/65614#EscapeEventDescription)
* [EscapeEventInfo](https://cloud.tencent.com/document/api/1285/65614#EscapeEventInfo)
* [EscapeRule](https://cloud.tencent.com/document/api/1285/65614#EscapeRule)
* [EscapeRuleEnabled](https://cloud.tencent.com/document/api/1285/65614#EscapeRuleEnabled)
* [FileAttributeInfo](https://cloud.tencent.com/document/api/1285/65614#FileAttributeInfo)
* [HostInfo](https://cloud.tencent.com/document/api/1285/65614#HostInfo)
* [ImageHost](https://cloud.tencent.com/document/api/1285/65614#ImageHost)
* [ImageInfo](https://cloud.tencent.com/document/api/1285/65614#ImageInfo)
* [ImageProgress](https://cloud.tencent.com/document/api/1285/65614#ImageProgress)
* [ImageRisk](https://cloud.tencent.com/document/api/1285/65614#ImageRisk)
* [ImageRiskInfo](https://cloud.tencent.com/document/api/1285/65614#ImageRiskInfo)
* [ImageRiskTendencyInfo](https://cloud.tencent.com/document/api/1285/65614#ImageRiskTendencyInfo)
* [ImageSimpleInfo](https://cloud.tencent.com/document/api/1285/65614#ImageSimpleInfo)
* [ImageVirus](https://cloud.tencent.com/document/api/1285/65614#ImageVirus)
* [ImageVirusInfo](https://cloud.tencent.com/document/api/1285/65614#ImageVirusInfo)
* [ImageVul](https://cloud.tencent.com/document/api/1285/65614#ImageVul)
* [ImagesBindRuleInfo](https://cloud.tencent.com/document/api/1285/65614#ImagesBindRuleInfo)
* [ImagesInfo](https://cloud.tencent.com/document/api/1285/65614#ImagesInfo)
* [ImagesVul](https://cloud.tencent.com/document/api/1285/65614#ImagesVul)
* [PortInfo](https://cloud.tencent.com/document/api/1285/65614#PortInfo)
* [ProcessDetailBaseInfo](https://cloud.tencent.com/document/api/1285/65614#ProcessDetailBaseInfo)
* [ProcessDetailInfo](https://cloud.tencent.com/document/api/1285/65614#ProcessDetailInfo)
* [ProcessInfo](https://cloud.tencent.com/document/api/1285/65614#ProcessInfo)
* [ReverseShellEventDescription](https://cloud.tencent.com/document/api/1285/65614#ReverseShellEventDescription)
* [ReverseShellEventInfo](https://cloud.tencent.com/document/api/1285/65614#ReverseShellEventInfo)
* [ReverseShellWhiteListBaseInfo](https://cloud.tencent.com/document/api/1285/65614#ReverseShellWhiteListBaseInfo)
* [ReverseShellWhiteListInfo](https://cloud.tencent.com/document/api/1285/65614#ReverseShellWhiteListInfo)
* [RiskSyscallEventDescription](https://cloud.tencent.com/document/api/1285/65614#RiskSyscallEventDescription)
* [RiskSyscallEventInfo](https://cloud.tencent.com/document/api/1285/65614#RiskSyscallEventInfo)
* [RiskSyscallWhiteListBaseInfo](https://cloud.tencent.com/document/api/1285/65614#RiskSyscallWhiteListBaseInfo)
* [RiskSyscallWhiteListInfo](https://cloud.tencent.com/document/api/1285/65614#RiskSyscallWhiteListInfo)
* [RuleBaseInfo](https://cloud.tencent.com/document/api/1285/65614#RuleBaseInfo)
* [RunTimeEventBaseInfo](https://cloud.tencent.com/document/api/1285/65614#RunTimeEventBaseInfo)
* [RunTimeFilters](https://cloud.tencent.com/document/api/1285/65614#RunTimeFilters)
* [RunTimeRiskInfo](https://cloud.tencent.com/document/api/1285/65614#RunTimeRiskInfo)
* [RunTimeTendencyInfo](https://cloud.tencent.com/document/api/1285/65614#RunTimeTendencyInfo)
* [SecTendencyEventInfo](https://cloud.tencent.com/document/api/1285/65614#SecTendencyEventInfo)
* [ServiceInfo](https://cloud.tencent.com/document/api/1285/65614#ServiceInfo)
* [SoftQuotaDayInfo](https://cloud.tencent.com/document/api/1285/65614#SoftQuotaDayInfo)
* [VirusInfo](https://cloud.tencent.com/document/api/1285/65614#VirusInfo)
* [VirusTaskInfo](https://cloud.tencent.com/document/api/1285/65614#VirusTaskInfo)
* [WarningRule](https://cloud.tencent.com/document/api/1285/65614#WarningRule)




## TDSQL-C PostgreSQL 版(tdcpg) 版本：2021-11-18

### 第 4 次发布

发布时间：2022-10-21 06:47:14

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CloneClusterToPointInTime](https://cloud.tencent.com/document/api/1556/70694)

	* 新增入参：StoragePayMode, Storage


### 第 3 次发布

发布时间：2022-10-14 06:51:40

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateCluster](https://cloud.tencent.com/document/api/1556/70670)

	* 新增入参：StoragePayMode, Storage


修改数据结构：

* [Cluster](https://cloud.tencent.com/document/api/1556/70695#Cluster)

	* 新增成员：StoragePayMode


### 第 2 次发布

发布时间：2022-07-05 06:21:49

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateCluster](https://cloud.tencent.com/document/api/1556/70670)

	* 新增入参：DBMajorVersion, DBKernelVersion

	* <font color="#dd0000">**修改入参**：</font>DBVersion


修改数据结构：

* [Cluster](https://cloud.tencent.com/document/api/1556/70695#Cluster)

	* 新增成员：DBMajorVersion, DBKernelVersion

* [Instance](https://cloud.tencent.com/document/api/1556/70695#Instance)

	* 新增成员：DBMajorVersion, DBKernelVersion


### 第 1 次发布

发布时间：2022-03-01 10:49:12

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CloneClusterToPointInTime](https://cloud.tencent.com/document/api/1556/70694)
* [CreateCluster](https://cloud.tencent.com/document/api/1556/70670)
* [CreateClusterInstances](https://cloud.tencent.com/document/api/1556/70690)
* [DeleteCluster](https://cloud.tencent.com/document/api/1556/70669)
* [DeleteClusterInstances](https://cloud.tencent.com/document/api/1556/70689)
* [DescribeAccounts](https://cloud.tencent.com/document/api/1556/70674)
* [DescribeClusterBackups](https://cloud.tencent.com/document/api/1556/70693)
* [DescribeClusterEndpoints](https://cloud.tencent.com/document/api/1556/70682)
* [DescribeClusterInstances](https://cloud.tencent.com/document/api/1556/70688)
* [DescribeClusterRecoveryTimeRange](https://cloud.tencent.com/document/api/1556/70692)
* [DescribeClusters](https://cloud.tencent.com/document/api/1556/70668)
* [DescribeResourcesByDealName](https://cloud.tencent.com/document/api/1556/70679)
* [IsolateCluster](https://cloud.tencent.com/document/api/1556/70667)
* [IsolateClusterInstances](https://cloud.tencent.com/document/api/1556/70687)
* [ModifyAccountDescription](https://cloud.tencent.com/document/api/1556/70673)
* [ModifyClusterEndpointWanStatus](https://cloud.tencent.com/document/api/1556/70681)
* [ModifyClusterInstancesSpec](https://cloud.tencent.com/document/api/1556/70686)
* [ModifyClusterName](https://cloud.tencent.com/document/api/1556/70666)
* [ModifyClustersAutoRenewFlag](https://cloud.tencent.com/document/api/1556/70678)
* [RecoverCluster](https://cloud.tencent.com/document/api/1556/70665)
* [RecoverClusterInstances](https://cloud.tencent.com/document/api/1556/70685)
* [RenewCluster](https://cloud.tencent.com/document/api/1556/70677)
* [ResetAccountPassword](https://cloud.tencent.com/document/api/1556/70672)
* [RestartClusterInstances](https://cloud.tencent.com/document/api/1556/70684)
* [TransformClusterPayMode](https://cloud.tencent.com/document/api/1556/70676)

新增数据结构：

* [Account](https://cloud.tencent.com/document/api/1556/70695#Account)
* [AvailableRecoveryTimeRange](https://cloud.tencent.com/document/api/1556/70695#AvailableRecoveryTimeRange)
* [Backup](https://cloud.tencent.com/document/api/1556/70695#Backup)
* [Cluster](https://cloud.tencent.com/document/api/1556/70695#Cluster)
* [Endpoint](https://cloud.tencent.com/document/api/1556/70695#Endpoint)
* [Filter](https://cloud.tencent.com/document/api/1556/70695#Filter)
* [Instance](https://cloud.tencent.com/document/api/1556/70695#Instance)
* [ResourceIdInfo](https://cloud.tencent.com/document/api/1556/70695#ResourceIdInfo)




## 分布式身份(tdid) 版本：2021-05-19

### 第 12 次发布

发布时间：2024-01-12 01:24:00

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateDisclosedCredential](https://cloud.tencent.com/document/api/1439/102997)
* [CreatePresentation](https://cloud.tencent.com/document/api/1439/102996)
* [GetAppSummary](https://cloud.tencent.com/document/api/1439/102993)
* [GetOverSummary](https://cloud.tencent.com/document/api/1439/102992)
* [GetTDidByObjectId](https://cloud.tencent.com/document/api/1439/103001)
* [GetTDidPubKey](https://cloud.tencent.com/document/api/1439/103000)
* [QueryAuthorityInfo](https://cloud.tencent.com/document/api/1439/102999)
* [QueryCPT](https://cloud.tencent.com/document/api/1439/102995)
* [SetTDidAttribute](https://cloud.tencent.com/document/api/1439/102998)
* [VerifyPresentation](https://cloud.tencent.com/document/api/1439/102994)

<font color="#dd0000">**删除接口**：</font>

* CheckNewPurchase

新增数据结构：

* [CredentialProof](https://cloud.tencent.com/document/api/1439/60283#CredentialProof)
* [DidAttribute](https://cloud.tencent.com/document/api/1439/60283#DidAttribute)
* [ResourceCounterData](https://cloud.tencent.com/document/api/1439/60283#ResourceCounterData)

### 第 11 次发布

发布时间：2024-01-11 10:56:14

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CheckNewPurchase](https://cloud.tencent.com/document/api/#/#)
* [CreateTDidByHost](https://cloud.tencent.com/document/api/1439/102970)
* [CreateTDidByPubKey](https://cloud.tencent.com/document/api/1439/102969)
* [DeactivateTDid](https://cloud.tencent.com/document/api/1439/102968)
* [GetCredentialState](https://cloud.tencent.com/document/api/1439/102966)
* [GetTDidDocument](https://cloud.tencent.com/document/api/1439/102967)
* [IssueCredential](https://cloud.tencent.com/document/api/1439/102965)
* [UpdateCredentialState](https://cloud.tencent.com/document/api/1439/102964)
* [VerifyCredentials](https://cloud.tencent.com/document/api/1439/102963)

<font color="#dd0000">**删除接口**：</font>

* CheckChain
* CreateCredential
* CreateSelectiveCredential
* CreateTDid
* CreateTDidByPrivateKey
* CreateTDidByPublicKey
* GetAuthorityIssuer
* GetCptInfo
* GetCredentialStatus
* GetDidDocument
* RegisterCpt
* SetCredentialStatus
* VerifyCredential

新增数据结构：

* [CRDLArg](https://cloud.tencent.com/document/api/1439/60283#CRDLArg)
* [ChainTransaction](https://cloud.tencent.com/document/api/1439/60283#ChainTransaction)
* [CredentialState](https://cloud.tencent.com/document/api/1439/60283#CredentialState)

<font color="#dd0000">**删除数据结构**：</font>

* CredentialStatus
* FunctionArg
* Proof
* TransactionArg
* VerifyFunctionArg

### 第 10 次发布

发布时间：2023-07-24 01:49:20

本次发布包含了以下内容：

改善已有的文档。

<font color="#dd0000">**删除接口**：</font>

* AddLabel
* GetAgencyTDid

<font color="#dd0000">**删除数据结构**：</font>

* Identity

### 第 9 次发布

发布时间：2023-07-21 01:42:20

本次发布包含了以下内容：

改善已有的文档。

<font color="#dd0000">**删除接口**：</font>

* GetConsortiumClusterList
* GetConsortiumList
* GetCredentialCptRank

<font color="#dd0000">**删除数据结构**：</font>

* BcosClusterItem
* ConsortiumItem
* CptIssueRank

### 第 8 次发布

发布时间：2023-06-27 01:43:11

本次发布包含了以下内容：

改善已有的文档。

<font color="#dd0000">**删除接口**：</font>

* GetDidClusterDetail
* GetDidClusterList

<font color="#dd0000">**预下线接口**：</font>

* CheckChain
* CreateCredential
* CreateSelectiveCredential
* CreateTDid
* CreateTDidByPrivateKey
* CreateTDidByPublicKey
* GetAuthorityIssuer
* GetCptInfo
* GetCredentialStatus
* GetDidDocument
* RegisterCpt
* SetCredentialStatus
* VerifyCredential

<font color="#dd0000">**删除数据结构**：</font>

* DidCluster

### 第 7 次发布

发布时间：2023-06-26 01:54:56

本次发布包含了以下内容：

改善已有的文档。

<font color="#dd0000">**删除接口**：</font>

* CancelAuthorityIssuer
* CheckDidDeploy
* CreateDidService
* CreateLabel
* DeployByName
* DownCpt
* EnableHash
* GetAuthoritiesList
* GetCptList
* GetCredentialIssueRank
* GetCredentialIssueTrend
* GetDataPanel
* GetDeployInfo
* GetDeployList
* GetDidDetail
* GetDidList
* GetDidRegisterTrend
* GetDidServiceDetail
* GetDidServiceList
* GetGroupList
* GetLabelList
* GetPolicyList
* GetPublicKey
* QueryPolicy
* RecognizeAuthorityIssuer
* RegisterClaimPolicy
* RegisterIssuer
* RemoveHash

<font color="#dd0000">**删除数据结构**：</font>

* Authority
* Contract
* CptListData
* DidData
* DidServiceInfo
* Group
* Label
* Policy
* Task
* Trend

### 第 6 次发布

发布时间：2023-03-27 02:39:51

本次发布包含了以下内容：

改善已有的文档。

<font color="#dd0000">**预下线接口**：</font>

* AddLabel
* CancelAuthorityIssuer
* CheckDidDeploy
* CreateDidService
* CreateLabel
* DeployByName
* DownCpt
* EnableHash
* GetAuthoritiesList
* GetConsortiumClusterList
* GetConsortiumList
* GetCptList
* GetCredentialCptRank
* GetCredentialIssueRank
* GetCredentialIssueTrend
* GetDataPanel
* GetDeployInfo
* GetDeployList
* GetDidClusterDetail
* GetDidClusterList
* GetDidDetail
* GetDidList
* GetDidRegisterTrend
* GetDidServiceDetail
* GetDidServiceList
* GetGroupList
* GetLabelList
* GetPolicyList
* GetPublicKey
* QueryPolicy
* RecognizeAuthorityIssuer
* RegisterClaimPolicy
* RegisterIssuer
* RemoveHash

### 第 5 次发布

发布时间：2023-01-31 01:58:44

本次发布包含了以下内容：

改善已有的文档。

<font color="#dd0000">**删除接口**：</font>

* VerifyPurchase

### 第 4 次发布

发布时间：2022-11-17 06:47:13

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [AddLabel](https://cloud.tencent.com/document/api/1439/83041)
* [CancelAuthorityIssuer](https://cloud.tencent.com/document/api/1439/83040)
* [CheckChain](https://cloud.tencent.com/document/api/1439/83039)
* [CheckDidDeploy](https://cloud.tencent.com/document/api/1439/83038)
* [CreateDidService](https://cloud.tencent.com/document/api/1439/83037)
* [CreateLabel](https://cloud.tencent.com/document/api/1439/83036)
* [CreateTDidByPrivateKey](https://cloud.tencent.com/document/api/1439/83035)
* [DeployByName](https://cloud.tencent.com/document/api/1439/83034)
* [DownCpt](https://cloud.tencent.com/document/api/1439/83033)
* [EnableHash](https://cloud.tencent.com/document/api/1439/83032)
* [GetAgencyTDid](https://cloud.tencent.com/document/api/1439/83031)
* [GetAuthoritiesList](https://cloud.tencent.com/document/api/1439/83030)
* [GetConsortiumClusterList](https://cloud.tencent.com/document/api/1439/83029)
* [GetConsortiumList](https://cloud.tencent.com/document/api/1439/83028)
* [GetCptInfo](https://cloud.tencent.com/document/api/1439/83027)
* [GetCptList](https://cloud.tencent.com/document/api/1439/83026)
* [GetCredentialCptRank](https://cloud.tencent.com/document/api/1439/83025)
* [GetCredentialIssueRank](https://cloud.tencent.com/document/api/1439/83024)
* [GetCredentialIssueTrend](https://cloud.tencent.com/document/api/1439/83023)
* [GetCredentialStatus](https://cloud.tencent.com/document/api/1439/83022)
* [GetDataPanel](https://cloud.tencent.com/document/api/1439/83021)
* [GetDeployInfo](https://cloud.tencent.com/document/api/1439/83020)
* [GetDeployList](https://cloud.tencent.com/document/api/1439/83019)
* [GetDidClusterDetail](https://cloud.tencent.com/document/api/1439/83018)
* [GetDidClusterList](https://cloud.tencent.com/document/api/1439/83017)
* [GetDidDetail](https://cloud.tencent.com/document/api/1439/83016)
* [GetDidList](https://cloud.tencent.com/document/api/1439/83015)
* [GetDidRegisterTrend](https://cloud.tencent.com/document/api/1439/83014)
* [GetDidServiceDetail](https://cloud.tencent.com/document/api/1439/83013)
* [GetDidServiceList](https://cloud.tencent.com/document/api/1439/83012)
* [GetGroupList](https://cloud.tencent.com/document/api/1439/83011)
* [GetLabelList](https://cloud.tencent.com/document/api/1439/83010)
* [GetPolicyList](https://cloud.tencent.com/document/api/1439/83009)
* [GetPublicKey](https://cloud.tencent.com/document/api/1439/83008)
* [QueryPolicy](https://cloud.tencent.com/document/api/1439/83007)
* [RecognizeAuthorityIssuer](https://cloud.tencent.com/document/api/1439/83006)
* [RegisterClaimPolicy](https://cloud.tencent.com/document/api/1439/83005)
* [RegisterCpt](https://cloud.tencent.com/document/api/1439/83004)
* [RegisterIssuer](https://cloud.tencent.com/document/api/1439/83003)
* [RemoveHash](https://cloud.tencent.com/document/api/1439/83002)
* [VerifyPurchase](https://cloud.tencent.com/document/api/1439/83001)

新增数据结构：

* [Authority](https://cloud.tencent.com/document/api/1439/60283#Authority)
* [BcosClusterItem](https://cloud.tencent.com/document/api/1439/60283#BcosClusterItem)
* [ConsortiumItem](https://cloud.tencent.com/document/api/1439/60283#ConsortiumItem)
* [Contract](https://cloud.tencent.com/document/api/1439/60283#Contract)
* [CptIssueRank](https://cloud.tencent.com/document/api/1439/60283#CptIssueRank)
* [CptListData](https://cloud.tencent.com/document/api/1439/60283#CptListData)
* [DidCluster](https://cloud.tencent.com/document/api/1439/60283#DidCluster)
* [DidData](https://cloud.tencent.com/document/api/1439/60283#DidData)
* [DidServiceInfo](https://cloud.tencent.com/document/api/1439/60283#DidServiceInfo)
* [Group](https://cloud.tencent.com/document/api/1439/60283#Group)
* [Identity](https://cloud.tencent.com/document/api/1439/60283#Identity)
* [Label](https://cloud.tencent.com/document/api/1439/60283#Label)
* [Policy](https://cloud.tencent.com/document/api/1439/60283#Policy)
* [Task](https://cloud.tencent.com/document/api/1439/60283#Task)
* [Trend](https://cloud.tencent.com/document/api/1439/60283#Trend)

### 第 3 次发布

发布时间：2022-03-01 15:05:45

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [SetCredentialStatus](https://cloud.tencent.com/document/api/1439/70457)

新增数据结构：

* [CredentialStatus](https://cloud.tencent.com/document/api/1439/60283#CredentialStatus)

### 第 2 次发布

发布时间：2022-03-01 14:59:32

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateTDidByPublicKey](https://cloud.tencent.com/document/api/1439/70456)
* [GetAuthorityIssuer](https://cloud.tencent.com/document/api/1439/70455)
* [GetDidDocument](https://cloud.tencent.com/document/api/1439/70454)

修改接口：

* [CreateCredential](https://cloud.tencent.com/document/api/1439/60282)

	* 新增入参：UnSigned


### 第 1 次发布

发布时间：2021-08-16 08:00:04

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateCredential](https://cloud.tencent.com/document/api/1439/60282)
* [CreateSelectiveCredential](https://cloud.tencent.com/document/api/1439/60281)
* [CreateTDid](https://cloud.tencent.com/document/api/1439/60280)
* [VerifyCredential](https://cloud.tencent.com/document/api/1439/60279)

新增数据结构：

* [FunctionArg](https://cloud.tencent.com/document/api/1439/60283#FunctionArg)
* [Proof](https://cloud.tencent.com/document/api/1439/60283#Proof)
* [TransactionArg](https://cloud.tencent.com/document/api/1439/60283#TransactionArg)
* [VerifyFunctionArg](https://cloud.tencent.com/document/api/1439/60283#VerifyFunctionArg)




## 消息队列 TDMQ(tdmq) 版本：2020-02-17

### 第 119 次发布

发布时间：2024-07-17 01:25:48

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeRocketMQTopicStats](https://cloud.tencent.com/document/api/1179/108864)
* [DescribeRocketMQTopicsByGroup](https://cloud.tencent.com/document/api/1179/108863)
* [ModifyRocketMQInstance](https://cloud.tencent.com/document/api/1179/108862)

新增数据结构：

* [TopicStats](https://cloud.tencent.com/document/api/1179/46089#TopicStats)

### 第 118 次发布

发布时间：2024-07-03 01:24:52

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateRabbitMQVipInstance](https://cloud.tencent.com/document/api/1179/88134)

	* 新增入参：EnablePublicAccess

* [CreateRole](https://cloud.tencent.com/document/api/1179/62401)

	* <font color="#dd0000">**修改入参**：</font>Remark, ClusterId


修改数据结构：

* [RabbitMQVirtualHostInfo](https://cloud.tencent.com/document/api/1179/46089#RabbitMQVirtualHostInfo)

	* 新增成员：TraceFlag


### 第 117 次发布

发布时间：2024-06-28 01:20:13

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateRabbitMQVipInstance](https://cloud.tencent.com/document/api/1179/88134)

	* 新增入参：PayMode, ClusterVersion, IsIntl, ResourceTags, Bandwidth

* [DeleteRabbitMQVipInstance](https://cloud.tencent.com/document/api/1179/94833)

	* 新增入参：IsIntl


修改数据结构：

* [RabbitMQUser](https://cloud.tencent.com/document/api/1179/46089#RabbitMQUser)

	* 新增成员：MaxConnections, MaxChannels

* [RabbitMQVipInstance](https://cloud.tencent.com/document/api/1179/46089#RabbitMQVipInstance)

	* 新增成员：CreateTime

* [RocketMQInstanceConfig](https://cloud.tencent.com/document/api/1179/46089#RocketMQInstanceConfig)

	* 新增成员：MaxRetention, MinRetention, Retention, TopicNumLowerLimit, TopicNumUpperLimit

	* <font color="#dd0000">**修改成员**：</font>MaxTpsPerNamespace, MaxNamespaceNum, UsedNamespaceNum, MaxTopicNum, UsedTopicNum, MaxGroupNum, UsedGroupNum, ConfigDisplay, NodeCount, NodeDistribution, TopicDistribution, MaxQueuesPerTopic


### 第 116 次发布

发布时间：2024-06-25 01:23:14

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeRabbitMQExchanges](https://cloud.tencent.com/document/api/1179/107675)

新增数据结构：

* [RabbitMQExchangeListInfo](https://cloud.tencent.com/document/api/1179/46089#RabbitMQExchangeListInfo)

### 第 115 次发布

发布时间：2024-06-24 01:23:04

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [RocketMQClusterInfo](https://cloud.tencent.com/document/api/1179/46089#RocketMQClusterInfo)

	* 新增成员：ZoneId, ZoneIds


### 第 114 次发布

发布时间：2024-06-20 15:41:09

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateRocketMQEnvironmentRole](https://cloud.tencent.com/document/api/1179/107539)
* [CreateRocketMQRole](https://cloud.tencent.com/document/api/1179/107538)
* [DeleteRocketMQEnvironmentRoles](https://cloud.tencent.com/document/api/1179/107537)
* [DeleteRocketMQRoles](https://cloud.tencent.com/document/api/1179/107536)
* [DescribeRocketMQEnvironmentRoles](https://cloud.tencent.com/document/api/1179/107535)
* [DescribeRocketMQRoles](https://cloud.tencent.com/document/api/1179/107534)
* [ModifyRocketMQEnvironmentRole](https://cloud.tencent.com/document/api/1179/107533)
* [ModifyRocketMQRole](https://cloud.tencent.com/document/api/1179/107532)

### 第 113 次发布

发布时间：2024-06-17 02:17:28

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [RabbitMQClusterInfo](https://cloud.tencent.com/document/api/1179/46089#RabbitMQClusterInfo)

	* 新增成员：PayMode

* [RabbitMQUser](https://cloud.tencent.com/document/api/1179/46089#RabbitMQUser)

	* <font color="#dd0000">**修改成员**：</font>InstanceId, User, Password, Description, Tags, CreateTime, ModifyTime, Type


### 第 112 次发布

发布时间：2024-05-29 02:13:49

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [PulsarNetworkAccessPointInfo](https://cloud.tencent.com/document/api/1179/46089#PulsarNetworkAccessPointInfo)

	* 新增成员：AccessPointsType


### 第 111 次发布

发布时间：2024-05-17 02:19:56

本次发布包含了以下内容：

改善已有的文档。

<font color="#dd0000">**预下线接口**：</font>

* DescribeCmqDeadLetterSourceQueues

### 第 110 次发布

发布时间：2024-05-10 02:29:12

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [Environment](https://cloud.tencent.com/document/api/1179/46089#Environment)

	* <font color="#dd0000">**修改成员**：</font>AutoSubscriptionCreation


### 第 109 次发布

发布时间：2024-05-09 01:24:25

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeRabbitMQQueueDetail](https://cloud.tencent.com/document/api/1179/100810)

	* 新增出参：Exclusive, Policy, Arguments


### 第 108 次发布

发布时间：2024-05-08 01:27:51

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [RabbitMQClusterInfo](https://cloud.tencent.com/document/api/1179/46089#RabbitMQClusterInfo)

	* 新增成员：MessageConsumeRate, ClusterVersion

* [RabbitMQQueueListInfo](https://cloud.tencent.com/document/api/1179/46089#RabbitMQQueueListInfo)

	* 新增成员：Durable, AutoDelete, InstanceId, VirtualHost, Node, Policy, Arguments, Exclusive

* [RabbitMQVirtualHostInfo](https://cloud.tencent.com/document/api/1179/46089#RabbitMQVirtualHostInfo)

	* 新增成员：MirrorQueuePolicyFlag


### 第 107 次发布

发布时间：2024-04-24 01:21:13

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateRabbitMQVirtualHost](https://cloud.tencent.com/document/api/1179/90854)

	* 新增入参：MirrorQueuePolicyFlag

* [DescribeRabbitMQQueueDetail](https://cloud.tencent.com/document/api/1179/100810)

	* 新增出参：DeadLetterStrategy, QueueLeaderLocator, QuorumInitialGroupSize


### 第 106 次发布

发布时间：2024-04-02 01:23:41

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateRocketMQVipInstance](https://cloud.tencent.com/document/api/1179/95721)

	* 新增入参：SupportsMigrateToCloud, EnablePublic, Bandwidth, IpRules, Tags


### 第 105 次发布

发布时间：2024-03-11 01:24:01

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeRocketMQMsgTrace](https://cloud.tencent.com/document/api/1179/97760)

	* 新增入参：QueryDeadLetterMessage


### 第 104 次发布

发布时间：2024-03-08 01:24:44

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeRocketMQPublicAccessMonitorData](https://cloud.tencent.com/document/api/1179/104161)

修改接口：

* [DescribeRocketMQMsg](https://cloud.tencent.com/document/api/1179/91055)

	* 新增入参：QueryDeadLetterMessage, Offset, Limit, FilterTrackGroup

	* 新增出参：MessageTracksCount


新增数据结构：

* [RocketMQDataPoint](https://cloud.tencent.com/document/api/1179/46089#RocketMQDataPoint)

### 第 103 次发布

发布时间：2024-03-06 01:24:29

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeMsg](https://cloud.tencent.com/document/api/1179/104108)

### 第 102 次发布

发布时间：2024-03-05 16:41:09

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeMqMsgTrace](https://cloud.tencent.com/document/api/1179/104106)

<font color="#dd0000">**删除接口**：</font>

* DeleteProClusters

修改接口：

* [DescribeRabbitMQQueues](https://cloud.tencent.com/document/api/1179/100809)

	* <font color="#dd0000">**修改入参**：</font>VirtualHost


修改数据结构：

* [PulsarProClusterInfo](https://cloud.tencent.com/document/api/1179/46089#PulsarProClusterInfo)

	* 新增成员：BillingLabelVersion

	* <font color="#dd0000">**修改成员**：</font>ClusterId, ClusterName, Remark, CreateTime, Status, Version, NodeDistribution, MaxStorage, CanEditRoute

* [PulsarProInstance](https://cloud.tencent.com/document/api/1179/46089#PulsarProInstance)

	* 新增成员：BillingLabelVersion

* [RabbitMQQueueListInfo](https://cloud.tencent.com/document/api/1179/46089#RabbitMQQueueListInfo)

	* 新增成员：CreateTime, ModifyTime

* [RabbitMQVipInstance](https://cloud.tencent.com/document/api/1179/46089#RabbitMQVipInstance)

	* 新增成员：PublicAccessEndpoint, Vpcs

	* <font color="#dd0000">**修改成员**：</font>ExceptionInformation, ClusterStatus


### 第 101 次发布

发布时间：2024-01-12 01:24:10

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [ExportRocketMQMessageDetail](https://cloud.tencent.com/document/api/1179/103002)

### 第 100 次发布

发布时间：2023-12-21 02:11:13

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeNamespaceBundlesOpt](https://cloud.tencent.com/document/api/1179/59039)

	* <font color="#dd0000">**删除出参**：</font>BundleSet


<font color="#dd0000">**删除数据结构**：</font>

* BundleSetOpt

### 第 99 次发布

发布时间：2023-12-19 02:14:52

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeRocketMQTopics](https://cloud.tencent.com/document/api/1179/63418)

	* 新增入参：FilterGroup


修改数据结构：

* [RabbitMQClusterAccessInfo](https://cloud.tencent.com/document/api/1179/46089#RabbitMQClusterAccessInfo)

	* 新增成员：WebConsoleDomainEndpoint

	* <font color="#dd0000">**修改成员**：</font>PublicWebConsoleSwitchStatus, VpcWebConsoleSwitchStatus, PublicDataStreamStatus, PrometheusEndpointInfo


### 第 98 次发布

发布时间：2023-12-14 16:31:17

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeRocketMQConsumerConnectionDetail](https://cloud.tencent.com/document/api/1179/102490)

新增数据结构：

* [RocketMQConsumerTopic](https://cloud.tencent.com/document/api/1179/46089#RocketMQConsumerTopic)

### 第 97 次发布

发布时间：2023-12-13 02:31:49

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [PulsarNetworkAccessPointInfo](https://cloud.tencent.com/document/api/1179/46089#PulsarNetworkAccessPointInfo)

	* 新增成员：OperationType


### 第 96 次发布

发布时间：2023-12-11 01:28:43

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [PulsarProInstance](https://cloud.tencent.com/document/api/1179/46089#PulsarProInstance)

	* 新增成员：Tags, CreateTime


### 第 95 次发布

发布时间：2023-11-28 01:25:42

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DeleteProCluster](https://cloud.tencent.com/document/api/1179/101986)

修改接口：

* [CreateProCluster](https://cloud.tencent.com/document/api/1179/101433)

	* <font color="#dd0000">**修改入参**：</font>ZoneIds


### 第 94 次发布

发布时间：2023-11-24 01:24:16

本次发布包含了以下内容：

改善已有的文档。

<font color="#dd0000">**预下线接口**：</font>

* DeleteProClusters

### 第 93 次发布

发布时间：2023-11-22 06:38:54

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateProCluster](https://cloud.tencent.com/document/api/1179/101433)

	* 新增入参：Vpc

	* <font color="#dd0000">**删除入参**：</font>Vpcs


修改数据结构：

* [Cluster](https://cloud.tencent.com/document/api/1179/46089#Cluster)

	* 新增成员：ProjectId, ProjectName


### 第 92 次发布

发布时间：2023-11-21 01:35:04

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateProCluster](https://cloud.tencent.com/document/api/1179/101433)

	* <font color="#dd0000">**修改入参**：</font>Tags


### 第 91 次发布

发布时间：2023-11-17 01:25:23

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [RocketMQSubscription](https://cloud.tencent.com/document/api/1179/46089#RocketMQSubscription)

	* 新增成员：ClientProtocol

* [RocketMQVipInstance](https://cloud.tencent.com/document/api/1179/46089#RocketMQVipInstance)

	* 新增成员：AclEnabled, DestroyTime

	* <font color="#dd0000">**修改成员**：</font>MaxRetention, MinRetention, Retention


### 第 90 次发布

发布时间：2023-11-15 02:25:53

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DeleteProClusters](https://cloud.tencent.com/document/api/1179/101582)

### 第 89 次发布

发布时间：2023-11-09 01:25:09

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateProCluster](https://cloud.tencent.com/document/api/1179/101433)

### 第 88 次发布

发布时间：2023-11-08 02:14:24

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [RocketMQClusterConfig](https://cloud.tencent.com/document/api/1179/46089#RocketMQClusterConfig)

	* 新增成员：TopicDistribution

	* <font color="#dd0000">**修改成员**：</font>MaxTpsPerNamespace, MaxNamespaceNum, UsedNamespaceNum, MaxTopicNum, UsedTopicNum, MaxGroupNum, UsedGroupNum, MaxRetentionTime, MaxLatencyTime, MaxQueuesPerTopic

* [RocketMQClusterInfo](https://cloud.tencent.com/document/api/1179/46089#RocketMQClusterInfo)

	* 新增成员：AclEnabled, PublicClbId, Vip, VpcId, SupportMigration, InstanceStatus

	* <font color="#dd0000">**修改成员**：</font>ClusterId, ClusterName, Region, CreateTime, Remark, PublicEndPoint, VpcEndPoint, SupportNamespaceEndpoint, Vpcs, IsVip, RocketMQFlag, Status, IsolateTime, HttpPublicEndpoint, HttpVpcEndpoint, InternalEndpoint, HttpInternalEndpoint


### 第 87 次发布

发布时间：2023-11-06 00:20:48

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeMsgTrace](https://cloud.tencent.com/document/api/1179/101114)

新增数据结构：

* [ConsumerLog](https://cloud.tencent.com/document/api/1179/46089#ConsumerLog)
* [ConsumerLogs](https://cloud.tencent.com/document/api/1179/46089#ConsumerLogs)
* [ProducerLog](https://cloud.tencent.com/document/api/1179/46089#ProducerLog)
* [ServerLog](https://cloud.tencent.com/document/api/1179/46089#ServerLog)

### 第 86 次发布

发布时间：2023-11-03 01:22:53

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeTopicMsgs](https://cloud.tencent.com/document/api/1179/101086)

新增数据结构：

* [MsgLog](https://cloud.tencent.com/document/api/1179/46089#MsgLog)

### 第 85 次发布

发布时间：2023-11-02 02:24:43

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeRocketMQConsumeStats](https://cloud.tencent.com/document/api/1179/101060)
* [VerifyRocketMQConsume](https://cloud.tencent.com/document/api/1179/101061)

新增数据结构：

* [ConsumerStats](https://cloud.tencent.com/document/api/1179/46089#ConsumerStats)

### 第 84 次发布

发布时间：2023-11-01 01:22:25

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [RabbitMQClusterInfo](https://cloud.tencent.com/document/api/1179/46089#RabbitMQClusterInfo)

	* 新增成员：AutoRenewFlag, MirrorQueuePolicyFlag


### 第 83 次发布

发布时间：2023-10-31 02:29:08

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeRocketMQSubscriptions](https://cloud.tencent.com/document/api/1179/100975)

### 第 82 次发布

发布时间：2023-10-27 02:18:14

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeRabbitMQQueueDetail](https://cloud.tencent.com/document/api/1179/100810)
* [DescribeRabbitMQQueues](https://cloud.tencent.com/document/api/1179/100809)

新增数据结构：

* [RabbitMQQueueListConsumerDetailInfo](https://cloud.tencent.com/document/api/1179/46089#RabbitMQQueueListConsumerDetailInfo)
* [RabbitMQQueueListInfo](https://cloud.tencent.com/document/api/1179/46089#RabbitMQQueueListInfo)

### 第 81 次发布

发布时间：2023-10-19 16:17:03

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeRocketMQConsumerConnections](https://cloud.tencent.com/document/api/1179/100460)

新增数据结构：

* [RocketMQConsumerConnection](https://cloud.tencent.com/document/api/1179/46089#RocketMQConsumerConnection)

### 第 80 次发布

发布时间：2023-10-18 02:51:11

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeRocketMQMigratingTopicList](https://cloud.tencent.com/document/api/1179/100429)
* [DescribeRocketMQSmoothMigrationTask](https://cloud.tencent.com/document/api/1179/100424)
* [DescribeRocketMQSmoothMigrationTaskList](https://cloud.tencent.com/document/api/1179/100423)
* [DescribeRocketMQSourceClusterGroupList](https://cloud.tencent.com/document/api/1179/100428)
* [DescribeRocketMQSourceClusterTopicList](https://cloud.tencent.com/document/api/1179/100427)
* [ImportRocketMQConsumerGroups](https://cloud.tencent.com/document/api/1179/100426)
* [ImportRocketMQTopics](https://cloud.tencent.com/document/api/1179/100425)

新增数据结构：

* [MigrateTopic](https://cloud.tencent.com/document/api/1179/46089#MigrateTopic)
* [RocketMQGroupConfig](https://cloud.tencent.com/document/api/1179/46089#RocketMQGroupConfig)
* [RocketMQGroupConfigOutput](https://cloud.tencent.com/document/api/1179/46089#RocketMQGroupConfigOutput)
* [RocketMQMigrationTopicDistribution](https://cloud.tencent.com/document/api/1179/46089#RocketMQMigrationTopicDistribution)
* [RocketMQSmoothMigrationTaskItem](https://cloud.tencent.com/document/api/1179/46089#RocketMQSmoothMigrationTaskItem)
* [RocketMQTopicConfig](https://cloud.tencent.com/document/api/1179/46089#RocketMQTopicConfig)
* [RocketMQTopicConfigOutput](https://cloud.tencent.com/document/api/1179/46089#RocketMQTopicConfigOutput)

### 第 79 次发布

发布时间：2023-10-13 01:25:14

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [ResetMsgSubOffsetByTimestamp](https://cloud.tencent.com/document/api/1179/46083)

	* <font color="#dd0000">**修改入参**：</font>ClusterId


### 第 78 次发布

发布时间：2023-10-09 01:24:14

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeRocketMQTopicMsgs](https://cloud.tencent.com/document/api/1179/97761)

	* 新增入参：Tag, QueryDeadLetterMessage


新增数据结构：

* [RocketMQSubscription](https://cloud.tencent.com/document/api/1179/46089#RocketMQSubscription)

修改数据结构：

* [RocketMQTopic](https://cloud.tencent.com/document/api/1179/46089#RocketMQTopic)

	* 新增成员：LastUpdateTime, SubscriptionCount, SubscriptionData


### 第 77 次发布

发布时间：2023-09-19 01:26:21

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeRocketMQPublicAccessPoint](https://cloud.tencent.com/document/api/1179/98678)
* [ModifyPublicNetworkAccessPoint](https://cloud.tencent.com/document/api/1179/98676)
* [SetRocketMQPublicAccessPoint](https://cloud.tencent.com/document/api/1179/98677)

新增数据结构：

* [PublicAccessRule](https://cloud.tencent.com/document/api/1179/46089#PublicAccessRule)

### 第 76 次发布

发布时间：2023-09-05 07:38:20

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeRocketMQMsgTrace](https://cloud.tencent.com/document/api/1179/97760)
* [DescribeRocketMQTopicMsgs](https://cloud.tencent.com/document/api/1179/97761)

新增数据结构：

* [RocketMQMsgLog](https://cloud.tencent.com/document/api/1179/46089#RocketMQMsgLog)
* [TraceResult](https://cloud.tencent.com/document/api/1179/46089#TraceResult)

### 第 75 次发布

发布时间：2023-08-25 02:13:40

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateEnvironmentRole](https://cloud.tencent.com/document/api/1179/62402)

	* <font color="#dd0000">**修改入参**：</font>ClusterId

* [CreateSubscription](https://cloud.tencent.com/document/api/1179/46075)

	* <font color="#dd0000">**修改入参**：</font>ClusterId

* [CreateTopic](https://cloud.tencent.com/document/api/1179/46088)

	* <font color="#dd0000">**修改入参**：</font>ClusterId

* [DeleteEnvironmentRoles](https://cloud.tencent.com/document/api/1179/62400)

	* <font color="#dd0000">**修改入参**：</font>ClusterId

* [DeleteEnvironments](https://cloud.tencent.com/document/api/1179/46080)

	* <font color="#dd0000">**修改入参**：</font>ClusterId

* [DeleteRoles](https://cloud.tencent.com/document/api/1179/62403)

	* <font color="#dd0000">**修改入参**：</font>ClusterId

* [DeleteTopics](https://cloud.tencent.com/document/api/1179/46087)

	* <font color="#dd0000">**修改入参**：</font>ClusterId

* [DescribeEnvironmentAttributes](https://cloud.tencent.com/document/api/1179/46079)

	* <font color="#dd0000">**修改入参**：</font>ClusterId

* [DescribeEnvironments](https://cloud.tencent.com/document/api/1179/46078)

	* <font color="#dd0000">**修改入参**：</font>ClusterId

* [DescribeRoles](https://cloud.tencent.com/document/api/1179/62399)

	* <font color="#dd0000">**修改入参**：</font>ClusterId

* [DescribeSubscriptions](https://cloud.tencent.com/document/api/1179/46072)

	* <font color="#dd0000">**修改入参**：</font>ClusterId

* [ModifyEnvironmentAttributes](https://cloud.tencent.com/document/api/1179/46077)

	* <font color="#dd0000">**修改入参**：</font>ClusterId

* [ModifyEnvironmentRole](https://cloud.tencent.com/document/api/1179/62398)

	* <font color="#dd0000">**修改入参**：</font>ClusterId

* [ModifyRole](https://cloud.tencent.com/document/api/1179/62397)

	* 新增入参：EnvironmentRoleSets, UnbindAllEnvironment

	* <font color="#dd0000">**修改入参**：</font>ClusterId

* [ModifyTopic](https://cloud.tencent.com/document/api/1179/46085)

	* <font color="#dd0000">**修改入参**：</font>ClusterId


### 第 74 次发布

发布时间：2023-08-24 01:28:28

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateEnvironment](https://cloud.tencent.com/document/api/1179/46081)

	* <font color="#dd0000">**修改入参**：</font>ClusterId


### 第 73 次发布

发布时间：2023-08-22 01:20:21

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateTopic](https://cloud.tencent.com/document/api/1179/46088)

	* 新增入参：MsgTTL

* [ModifyTopic](https://cloud.tencent.com/document/api/1179/46085)

	* 新增入参：MsgTTL


修改数据结构：

* [Topic](https://cloud.tencent.com/document/api/1179/46089#Topic)

	* 新增成员：MsgTTL


### 第 72 次发布

发布时间：2023-08-09 01:50:17

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeRabbitMQVirtualHost](https://cloud.tencent.com/document/api/1179/93455)

	* 新增入参：SortElement, SortOrder


修改数据结构：

* [RabbitMQVirtualHostInfo](https://cloud.tencent.com/document/api/1179/46089#RabbitMQVirtualHostInfo)

	* 新增成员：Status, MessageHeapCount, MessageRateIn, MessageRateOut

	* <font color="#dd0000">**修改成员**：</font>InstanceId, VirtualHost, Description, Tags, CreateTime, ModifyTime, VirtualHostStatistics


### 第 71 次发布

发布时间：2023-08-02 01:22:40

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DeleteRocketMQVipInstance](https://cloud.tencent.com/document/api/1179/95802)

修改接口：

* [DescribeCmqSubscriptionDetail](https://cloud.tencent.com/document/api/1179/55908)

	* 新增入参：QueueName, QueryType

	* <font color="#dd0000">**修改入参**：</font>TopicName


修改数据结构：

* [CmqSubscription](https://cloud.tencent.com/document/api/1179/46089#CmqSubscription)

	* 新增成员：TopicName

* [CmqTopic](https://cloud.tencent.com/document/api/1179/46089#CmqTopic)

	* 新增成员：SubscriptionCount

	* <font color="#dd0000">**修改成员**：</font>TopicId, TopicName, MsgRetentionSeconds, MaxMsgSize, Qps, FilterType, CreateTime, LastModifyTime, MsgCount, CreateUin, Tags, Trace, TenantId, NamespaceName, Status, BrokerType


### 第 70 次发布

发布时间：2023-08-01 01:43:47

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateRocketMQVipInstance](https://cloud.tencent.com/document/api/1179/95721)

新增数据结构：

* [VpcInfo](https://cloud.tencent.com/document/api/1179/46089#VpcInfo)

### 第 69 次发布

发布时间：2023-07-26 01:38:18

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [RabbitMQClusterInfo](https://cloud.tencent.com/document/api/1179/46089#RabbitMQClusterInfo)

	* 新增成员：ZoneIds

	* <font color="#dd0000">**修改成员**：</font>ExceptionInformation, ClusterStatus


### 第 68 次发布

发布时间：2023-07-17 01:38:17

本次发布包含了以下内容：

改善已有的文档。

<font color="#dd0000">**删除接口**：</font>

* CreateAMQPCluster
* CreateAMQPExchange
* CreateAMQPQueue
* CreateAMQPRouteRelation
* CreateAMQPVHost
* DeleteAMQPCluster
* DeleteAMQPExchange
* DeleteAMQPQueue
* DeleteAMQPRouteRelation
* DeleteAMQPVHost
* DescribeAMQPCluster
* DescribeAMQPCreateQuota
* DescribeAMQPExchanges
* DescribeAMQPQueues
* DescribeAMQPRouteRelations
* DescribeAMQPVHosts
* ModifyAMQPExchange
* ModifyAMQPQueue

<font color="#dd0000">**删除数据结构**：</font>

* AMQPClusterRecentStats
* AMQPExchange
* AMQPQueueDetail
* AMQPRouteRelation
* AMQPVHost

### 第 67 次发布

发布时间：2023-07-13 01:38:37

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateRole](https://cloud.tencent.com/document/api/1179/62401)

	* 新增出参：EnvironmentRoleSets


新增数据结构：

* [EnvironmentRoleSet](https://cloud.tencent.com/document/api/1179/46089#EnvironmentRoleSet)

### 第 66 次发布

发布时间：2023-07-10 01:45:08

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DeleteRabbitMQVipInstance](https://cloud.tencent.com/document/api/1179/94833)

### 第 65 次发布

发布时间：2023-06-28 01:43:23

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [ModifyRocketMQCluster](https://cloud.tencent.com/document/api/1179/63417)

	* 新增入参：PublicAccessEnabled

* [ModifyRocketMQNamespace](https://cloud.tencent.com/document/api/1179/63415)

	* 新增入参：PublicAccessEnabled


### 第 64 次发布

发布时间：2023-06-20 01:51:18

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [SendRocketMQMessage](https://cloud.tencent.com/document/api/1179/94179)

### 第 63 次发布

发布时间：2023-06-14 01:42:52

本次发布包含了以下内容：

改善已有的文档。

<font color="#dd0000">**删除接口**：</font>

* ModifyAMQPVHost

### 第 62 次发布

发布时间：2023-06-13 01:41:55

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DeleteRabbitMQUser](https://cloud.tencent.com/document/api/1179/93458)
* [DeleteRabbitMQVirtualHost](https://cloud.tencent.com/document/api/1179/93457)
* [DescribeRabbitMQUser](https://cloud.tencent.com/document/api/1179/93456)
* [DescribeRabbitMQVirtualHost](https://cloud.tencent.com/document/api/1179/93455)
* [DescribeRabbitMQVirtualHostList](https://cloud.tencent.com/document/api/1179/93452)
* [ModifyRabbitMQUser](https://cloud.tencent.com/document/api/1179/93454)
* [ModifyRabbitMQVirtualHost](https://cloud.tencent.com/document/api/1179/93453)

新增数据结构：

* [RabbitMQPrivateVirtualHost](https://cloud.tencent.com/document/api/1179/46089#RabbitMQPrivateVirtualHost)
* [RabbitMQUser](https://cloud.tencent.com/document/api/1179/46089#RabbitMQUser)
* [RabbitMQVirtualHostInfo](https://cloud.tencent.com/document/api/1179/46089#RabbitMQVirtualHostInfo)
* [RabbitMQVirtualHostStatistics](https://cloud.tencent.com/document/api/1179/46089#RabbitMQVirtualHostStatistics)

### 第 61 次发布

发布时间：2023-06-08 01:59:37

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateEnvironment](https://cloud.tencent.com/document/api/1179/46081)

	* 新增入参：AutoSubscriptionCreation

* [ModifyEnvironmentAttributes](https://cloud.tencent.com/document/api/1179/46077)

	* 新增入参：AutoSubscriptionCreation


修改数据结构：

* [Environment](https://cloud.tencent.com/document/api/1179/46089#Environment)

	* 新增成员：AutoSubscriptionCreation


### 第 60 次发布

发布时间：2023-06-06 01:59:07

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeNamespaceBundlesOpt](https://cloud.tencent.com/document/api/1179/59039)

	* 新增入参：Bundle, OwnerBroker


### 第 59 次发布

发布时间：2023-05-30 01:35:56

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [PulsarProClusterInfo](https://cloud.tencent.com/document/api/1179/46089#PulsarProClusterInfo)

	* 新增成员：CanEditRoute

	* <font color="#dd0000">**修改成员**：</font>ClusterId, ClusterName, Remark, CreateTime, Status, Version, NodeDistribution, MaxStorage


### 第 58 次发布

发布时间：2023-05-16 02:15:18

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeRocketMQMsg](https://cloud.tencent.com/document/api/1179/91055)

新增数据结构：

* [RocketMQMessageTrack](https://cloud.tencent.com/document/api/1179/46089#RocketMQMessageTrack)

### 第 57 次发布

发布时间：2023-05-11 01:48:28

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeTopics](https://cloud.tencent.com/document/api/1179/46086)

	* <font color="#dd0000">**修改入参**：</font>ClusterId


### 第 56 次发布

发布时间：2023-05-09 01:43:02

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateRabbitMQUser](https://cloud.tencent.com/document/api/1179/90855)
* [CreateRabbitMQVirtualHost](https://cloud.tencent.com/document/api/1179/90854)

### 第 55 次发布

发布时间：2023-04-27 01:38:59

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateRocketMQNamespace](https://cloud.tencent.com/document/api/1179/63427)

	* <font color="#dd0000">**修改入参**：</font>Ttl, RetentionTime

* [ModifyRocketMQNamespace](https://cloud.tencent.com/document/api/1179/63415)

	* <font color="#dd0000">**修改入参**：</font>Ttl, RetentionTime


### 第 54 次发布

发布时间：2023-04-25 01:51:08

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [RabbitMQVipInstance](https://cloud.tencent.com/document/api/1179/46089#RabbitMQVipInstance)

	* 新增成员：ClusterStatus

* [RocketMQClusterInfo](https://cloud.tencent.com/document/api/1179/46089#RocketMQClusterInfo)

	* 新增成员：InternalEndpoint, HttpInternalEndpoint

* [RocketMQNamespace](https://cloud.tencent.com/document/api/1179/46089#RocketMQNamespace)

	* 新增成员：InternalEndpoint

* [RocketMQVipInstance](https://cloud.tencent.com/document/api/1179/46089#RocketMQVipInstance)

	* 新增成员：MaxRetention, MinRetention, Retention


### 第 53 次发布

发布时间：2023-04-24 01:40:56

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [ModifyRocketMQInstanceSpec](https://cloud.tencent.com/document/api/1179/90461)

### 第 52 次发布

发布时间：2023-04-21 01:42:37

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribePulsarProInstanceDetail](https://cloud.tencent.com/document/api/1179/90377)
* [DescribePulsarProInstances](https://cloud.tencent.com/document/api/1179/90376)

新增数据结构：

* [PulsarNetworkAccessPointInfo](https://cloud.tencent.com/document/api/1179/46089#PulsarNetworkAccessPointInfo)
* [PulsarProClusterInfo](https://cloud.tencent.com/document/api/1179/46089#PulsarProClusterInfo)
* [PulsarProClusterSpecInfo](https://cloud.tencent.com/document/api/1179/46089#PulsarProClusterSpecInfo)
* [PulsarProInstance](https://cloud.tencent.com/document/api/1179/46089#PulsarProInstance)

### 第 51 次发布

发布时间：2023-03-15 02:09:35

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeRabbitMQVipInstance](https://cloud.tencent.com/document/api/1179/88648)

新增数据结构：

* [ExchangeQuota](https://cloud.tencent.com/document/api/1179/46089#ExchangeQuota)
* [PrometheusEndpointInfo](https://cloud.tencent.com/document/api/1179/46089#PrometheusEndpointInfo)
* [QueueQuota](https://cloud.tencent.com/document/api/1179/46089#QueueQuota)
* [RabbitMQClusterAccessInfo](https://cloud.tencent.com/document/api/1179/46089#RabbitMQClusterAccessInfo)
* [RabbitMQClusterInfo](https://cloud.tencent.com/document/api/1179/46089#RabbitMQClusterInfo)
* [RabbitMQClusterSpecInfo](https://cloud.tencent.com/document/api/1179/46089#RabbitMQClusterSpecInfo)
* [RabbitMQClusterWhiteListInfo](https://cloud.tencent.com/document/api/1179/46089#RabbitMQClusterWhiteListInfo)
* [VirtualHostQuota](https://cloud.tencent.com/document/api/1179/46089#VirtualHostQuota)
* [VpcEndpointInfo](https://cloud.tencent.com/document/api/1179/46089#VpcEndpointInfo)

### 第 50 次发布

发布时间：2023-03-14 01:53:37

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [ModifyRabbitMQVipInstance](https://cloud.tencent.com/document/api/1179/88450)

### 第 49 次发布

发布时间：2023-03-13 02:05:39

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateRabbitMQVipInstance](https://cloud.tencent.com/document/api/1179/88134)

### 第 48 次发布

发布时间：2023-03-09 02:20:30

本次发布包含了以下内容：

改善已有的文档。

<font color="#dd0000">**预下线接口**：</font>

* CreateAMQPCluster
* CreateAMQPExchange
* CreateAMQPQueue
* CreateAMQPRouteRelation
* CreateAMQPVHost
* DeleteAMQPCluster
* DeleteAMQPExchange
* DeleteAMQPQueue
* DeleteAMQPRouteRelation
* DeleteAMQPVHost
* DescribeAMQPCluster
* DescribeAMQPCreateQuota
* DescribeAMQPExchanges
* DescribeAMQPQueues
* DescribeAMQPRouteRelations
* DescribeAMQPVHosts
* ModifyAMQPExchange
* ModifyAMQPQueue
* ModifyAMQPVHost

### 第 47 次发布

发布时间：2023-03-07 01:48:59

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [RocketMQInstanceConfig](https://cloud.tencent.com/document/api/1179/46089#RocketMQInstanceConfig)

	* 新增成员：MaxQueuesPerTopic

	* <font color="#dd0000">**修改成员**：</font>MaxTpsPerNamespace, MaxNamespaceNum, UsedNamespaceNum, MaxTopicNum, UsedTopicNum, MaxGroupNum, UsedGroupNum, ConfigDisplay, NodeCount, NodeDistribution, TopicDistribution


### 第 46 次发布

发布时间：2023-02-21 02:10:01

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeRocketMQVipInstanceDetail](https://cloud.tencent.com/document/api/1179/86725)

新增数据结构：

* [InstanceNodeDistribution](https://cloud.tencent.com/document/api/1179/46089#InstanceNodeDistribution)
* [RocketMQInstanceConfig](https://cloud.tencent.com/document/api/1179/46089#RocketMQInstanceConfig)
* [RocketMQTopicDistribution](https://cloud.tencent.com/document/api/1179/46089#RocketMQTopicDistribution)

### 第 45 次发布

发布时间：2023-02-10 02:03:51

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [InternalTenant](https://cloud.tencent.com/document/api/1179/46089#InternalTenant)

	* 新增成员：PublicAccessEnabled

* [RocketMQClusterConfig](https://cloud.tencent.com/document/api/1179/46089#RocketMQClusterConfig)

	* 新增成员：MaxQueuesPerTopic

	* <font color="#dd0000">**修改成员**：</font>MaxTpsPerNamespace, MaxNamespaceNum, UsedNamespaceNum, MaxTopicNum, UsedTopicNum, MaxGroupNum, UsedGroupNum, MaxRetentionTime, MaxLatencyTime


### 第 44 次发布

发布时间：2023-02-08 02:05:03

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeRabbitMQNodeList](https://cloud.tencent.com/document/api/1179/82204)

	* 新增入参：NodeName, Filters, SortElement, SortOrder


修改数据结构：

* [RabbitMQPrivateNode](https://cloud.tencent.com/document/api/1179/46089#RabbitMQPrivateNode)

	* 新增成员：NodeStatus, CPUUsage, Memory, DiskUsage, ProcessNumber

* [RabbitMQVipInstance](https://cloud.tencent.com/document/api/1179/46089#RabbitMQVipInstance)

	* 新增成员：ExceptionInformation


### 第 43 次发布

发布时间：2022-12-30 01:47:00

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [RocketMQTopic](https://cloud.tencent.com/document/api/1179/46089#RocketMQTopic)

	* 新增成员：Type, GroupNum


### 第 42 次发布

发布时间：2022-12-27 02:09:12

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateRocketMQGroup](https://cloud.tencent.com/document/api/1179/63428)

	* 新增入参：GroupType, RetryMaxTimes

* [DescribeRocketMQGroups](https://cloud.tencent.com/document/api/1179/63420)

	* 新增入参：Types

* [ModifyRocketMQGroup](https://cloud.tencent.com/document/api/1179/63416)

	* 新增入参：RetryMaxTimes


修改数据结构：

* [RocketMQClusterInfo](https://cloud.tencent.com/document/api/1179/46089#RocketMQClusterInfo)

	* 新增成员：Status, IsolateTime, HttpPublicEndpoint, HttpVpcEndpoint

	* <font color="#dd0000">**修改成员**：</font>ClusterId, ClusterName, Region, CreateTime, Remark, PublicEndPoint, VpcEndPoint, SupportNamespaceEndpoint, Vpcs, IsVip, RocketMQFlag

* [RocketMQGroup](https://cloud.tencent.com/document/api/1179/46089#RocketMQGroup)

	* 新增成员：GroupType, RetryMaxTimes

	* <font color="#dd0000">**修改成员**：</font>Name, ConsumerNum, TPS, TotalAccumulative, ConsumptionMode, ReadEnabled, RetryPartitionNum, CreateTime, UpdateTime, ClientProtocol, Remark, ConsumerType, BroadcastEnabled


### 第 41 次发布

发布时间：2022-11-25 07:03:54

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [RocketMQClusterInfo](https://cloud.tencent.com/document/api/1179/46089#RocketMQClusterInfo)

	* 新增成员：RocketMQFlag


### 第 40 次发布

发布时间：2022-11-15 06:41:43

本次发布包含了以下内容：

改善已有的文档。

新增数据结构：

* [VpcConfig](https://cloud.tencent.com/document/api/1179/46089#VpcConfig)

修改数据结构：

* [RocketMQClusterInfo](https://cloud.tencent.com/document/api/1179/46089#RocketMQClusterInfo)

	* 新增成员：Vpcs, IsVip


### 第 39 次发布

发布时间：2022-11-07 06:38:51

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [CmqTopic](https://cloud.tencent.com/document/api/1179/46089#CmqTopic)

	* 新增成员：BrokerType


### 第 38 次发布

发布时间：2022-11-01 06:46:31

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeRabbitMQNodeList](https://cloud.tencent.com/document/api/1179/82204)
* [DescribeRabbitMQVipInstances](https://cloud.tencent.com/document/api/1179/82205)

新增数据结构：

* [RabbitMQPrivateNode](https://cloud.tencent.com/document/api/1179/46089#RabbitMQPrivateNode)
* [RabbitMQVipInstance](https://cloud.tencent.com/document/api/1179/46089#RabbitMQVipInstance)

### 第 37 次发布

发布时间：2022-09-22 06:48:45

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeRocketMQVipInstances](https://cloud.tencent.com/document/api/1179/80903)

新增数据结构：

* [RocketMQVipInstance](https://cloud.tencent.com/document/api/1179/46089#RocketMQVipInstance)

### 第 36 次发布

发布时间：2022-06-29 06:13:55

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeTopics](https://cloud.tencent.com/document/api/1179/46086)

	* 新增入参：TopicCreator


### 第 35 次发布

发布时间：2022-06-28 06:17:03

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [ReceiveMessage](https://cloud.tencent.com/document/api/1179/57458)

	* 新增入参：MaxNumMessages, MaxNumBytes, Timeout

	* 新增出参：MessageIDList, MessagesPayload


### 第 34 次发布

发布时间：2022-04-13 07:16:01

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateCmqQueue](https://cloud.tencent.com/document/api/1179/55917)

	* 新增入参：RetentionSizeInMB

* [ModifyCmqQueueAttribute](https://cloud.tencent.com/document/api/1179/55905)

	* 新增入参：RetentionSizeInMB


### 第 33 次发布

发布时间：2022-04-11 06:18:16

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [AMQPQueueDetail](https://cloud.tencent.com/document/api/1179/46089#AMQPQueueDetail)

	* 新增成员：TopicName


### 第 32 次发布

发布时间：2022-04-08 06:13:51

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [CmqQueue](https://cloud.tencent.com/document/api/1179/46089#CmqQueue)

	* 新增成员：RetentionSizeInMB

* [CmqTopic](https://cloud.tencent.com/document/api/1179/46089#CmqTopic)

	* 新增成员：Status

* [RocketMQClusterInfo](https://cloud.tencent.com/document/api/1179/46089#RocketMQClusterInfo)

	* 新增成员：SupportNamespaceEndpoint

* [RocketMQNamespace](https://cloud.tencent.com/document/api/1179/46089#RocketMQNamespace)

	* 新增成员：PublicEndpoint, VpcEndpoint


### 第 31 次发布

发布时间：2022-03-24 20:46:23

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [ResetRocketMQConsumerOffSet](https://cloud.tencent.com/document/api/1179/71662)

### 第 30 次发布

发布时间：2022-03-03 08:12:23

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateAMQPExchange](https://cloud.tencent.com/document/api/1179/64672)

	* 新增入参：DelayedType

* [DescribeAMQPVHosts](https://cloud.tencent.com/document/api/1179/64658)

	* 新增入参：VHostIdList


修改数据结构：

* [AMQPClusterDetail](https://cloud.tencent.com/document/api/1179/46089#AMQPClusterDetail)

	* 新增成员：Status

* [AMQPExchange](https://cloud.tencent.com/document/api/1179/46089#AMQPExchange)

	* 新增成员：AlternateExchange, AlternateExchangeDeleteMark, DelayType

* [AMQPVHost](https://cloud.tencent.com/document/api/1179/46089#AMQPVHost)

	* 新增成员：Status


### 第 29 次发布

发布时间：2022-02-17 08:16:33

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateCmqQueue](https://cloud.tencent.com/document/api/1179/55917)

	* 新增入参：Tags

* [CreateCmqTopic](https://cloud.tencent.com/document/api/1179/55915)

	* 新增入参：Tags

* [CreateTopic](https://cloud.tencent.com/document/api/1179/46088)

	* 新增入参：PulsarTopicType

	* <font color="#dd0000">**修改入参**：</font>TopicType


修改数据结构：

* [Cluster](https://cloud.tencent.com/document/api/1179/46089#Cluster)

	* 新增成员：PayMode

* [Consumer](https://cloud.tencent.com/document/api/1179/46089#Consumer)

	* 新增成员：Partition

* [Subscription](https://cloud.tencent.com/document/api/1179/46089#Subscription)

	* 新增成员：SubType, BlockedSubscriptionOnUnackedMsgs, MaxUnackedMsgNum

* [Topic](https://cloud.tencent.com/document/api/1179/46089#Topic)

	* 新增成员：PulsarTopicType


### 第 28 次发布

发布时间：2022-01-21 08:17:48

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [CmqQueue](https://cloud.tencent.com/document/api/1179/46089#CmqQueue)

	* 新增成员：Status, MaxUnackedMsgNum, MaxMsgBacklogSize


### 第 27 次发布

发布时间：2021-12-29 08:13:22

本次发布包含了以下内容：

改善已有的文档。

<font color="#dd0000">**删除接口**：</font>

* DescribeProducers

<font color="#dd0000">**删除数据结构**：</font>

* Connection
* Producer

### 第 26 次发布

发布时间：2021-12-21 08:11:07

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribePublisherSummary](https://cloud.tencent.com/document/api/1179/66370)
* [DescribePublishers](https://cloud.tencent.com/document/api/1179/66369)

新增数据结构：

* [Publisher](https://cloud.tencent.com/document/api/1179/46089#Publisher)
* [Sort](https://cloud.tencent.com/document/api/1179/46089#Sort)

### 第 25 次发布

发布时间：2021-12-14 08:15:22

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateRocketMQTopic](https://cloud.tencent.com/document/api/1179/63426)

	* 新增入参：PartitionNum

* [ModifyRocketMQTopic](https://cloud.tencent.com/document/api/1179/63414)

	* 新增入参：PartitionNum


### 第 24 次发布

发布时间：2021-12-03 08:11:41

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeAllTenants](https://cloud.tencent.com/document/api/1179/65403)

新增数据结构：

* [InternalTenant](https://cloud.tencent.com/document/api/1179/46089#InternalTenant)

修改数据结构：

* [RocketMQClusterConfig](https://cloud.tencent.com/document/api/1179/46089#RocketMQClusterConfig)

	* 新增成员：MaxTpsPerNamespace, MaxNamespaceNum, UsedNamespaceNum, MaxTopicNum, UsedTopicNum, MaxGroupNum, UsedGroupNum, MaxRetentionTime, MaxLatencyTime

* [RocketMQClusterDetail](https://cloud.tencent.com/document/api/1179/46089#RocketMQClusterDetail)

	* 新增成员：Info, Config, Status

* [RocketMQClusterInfo](https://cloud.tencent.com/document/api/1179/46089#RocketMQClusterInfo)

	* 新增成员：ClusterId, ClusterName, Region, CreateTime, Remark, PublicEndPoint, VpcEndPoint

* [RocketMQClusterRecentStats](https://cloud.tencent.com/document/api/1179/46089#RocketMQClusterRecentStats)

	* 新增成员：TopicNum, ProducedMsgNum, ConsumedMsgNum, AccumulativeMsgNum

* [RocketMQGroup](https://cloud.tencent.com/document/api/1179/46089#RocketMQGroup)

	* 新增成员：Name, ConsumerNum, TPS, TotalAccumulative, ConsumptionMode, ReadEnabled, RetryPartitionNum, CreateTime, UpdateTime, ClientProtocol, Remark, ConsumerType, BroadcastEnabled

* [RocketMQNamespace](https://cloud.tencent.com/document/api/1179/46089#RocketMQNamespace)

	* 新增成员：NamespaceId, Ttl, RetentionTime, Remark

* [RocketMQTopic](https://cloud.tencent.com/document/api/1179/46089#RocketMQTopic)

	* 新增成员：Name, Remark, PartitionNum, CreateTime, UpdateTime


### 第 23 次发布

发布时间：2021-11-24 08:13:42

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateAMQPCluster](https://cloud.tencent.com/document/api/1179/64661)
* [CreateAMQPExchange](https://cloud.tencent.com/document/api/1179/64672)
* [CreateAMQPQueue](https://cloud.tencent.com/document/api/1179/64671)
* [CreateAMQPRouteRelation](https://cloud.tencent.com/document/api/1179/64670)
* [CreateAMQPVHost](https://cloud.tencent.com/document/api/1179/64660)
* [DeleteAMQPCluster](https://cloud.tencent.com/document/api/1179/64656)
* [DeleteAMQPExchange](https://cloud.tencent.com/document/api/1179/64669)
* [DeleteAMQPQueue](https://cloud.tencent.com/document/api/1179/64668)
* [DeleteAMQPRouteRelation](https://cloud.tencent.com/document/api/1179/64667)
* [DeleteAMQPVHost](https://cloud.tencent.com/document/api/1179/64659)
* [DescribeAMQPCluster](https://cloud.tencent.com/document/api/1179/64655)
* [DescribeAMQPClusters](https://cloud.tencent.com/document/api/1179/64654)
* [DescribeAMQPCreateQuota](https://cloud.tencent.com/document/api/1179/64653)
* [DescribeAMQPExchanges](https://cloud.tencent.com/document/api/1179/64666)
* [DescribeAMQPQueues](https://cloud.tencent.com/document/api/1179/64665)
* [DescribeAMQPRouteRelations](https://cloud.tencent.com/document/api/1179/64664)
* [DescribeAMQPVHosts](https://cloud.tencent.com/document/api/1179/64658)
* [ModifyAMQPCluster](https://cloud.tencent.com/document/api/1179/64652)
* [ModifyAMQPExchange](https://cloud.tencent.com/document/api/1179/64663)
* [ModifyAMQPQueue](https://cloud.tencent.com/document/api/1179/64662)
* [ModifyAMQPVHost](https://cloud.tencent.com/document/api/1179/64657)

新增数据结构：

* [AMQPClusterConfig](https://cloud.tencent.com/document/api/1179/46089#AMQPClusterConfig)
* [AMQPClusterDetail](https://cloud.tencent.com/document/api/1179/46089#AMQPClusterDetail)
* [AMQPClusterInfo](https://cloud.tencent.com/document/api/1179/46089#AMQPClusterInfo)
* [AMQPClusterRecentStats](https://cloud.tencent.com/document/api/1179/46089#AMQPClusterRecentStats)
* [AMQPExchange](https://cloud.tencent.com/document/api/1179/46089#AMQPExchange)
* [AMQPQueueDetail](https://cloud.tencent.com/document/api/1179/46089#AMQPQueueDetail)
* [AMQPRouteRelation](https://cloud.tencent.com/document/api/1179/46089#AMQPRouteRelation)
* [AMQPVHost](https://cloud.tencent.com/document/api/1179/46089#AMQPVHost)

### 第 22 次发布

发布时间：2021-10-27 20:52:54

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateRocketMQCluster](https://cloud.tencent.com/document/api/1179/63429)
* [CreateRocketMQGroup](https://cloud.tencent.com/document/api/1179/63428)
* [CreateRocketMQNamespace](https://cloud.tencent.com/document/api/1179/63427)
* [CreateRocketMQTopic](https://cloud.tencent.com/document/api/1179/63426)
* [DeleteRocketMQCluster](https://cloud.tencent.com/document/api/1179/63425)
* [DeleteRocketMQGroup](https://cloud.tencent.com/document/api/1179/63424)
* [DeleteRocketMQNamespace](https://cloud.tencent.com/document/api/1179/63412)
* [DeleteRocketMQTopic](https://cloud.tencent.com/document/api/1179/63423)
* [DescribeRocketMQCluster](https://cloud.tencent.com/document/api/1179/63422)
* [DescribeRocketMQClusters](https://cloud.tencent.com/document/api/1179/63421)
* [DescribeRocketMQGroups](https://cloud.tencent.com/document/api/1179/63420)
* [DescribeRocketMQNamespaces](https://cloud.tencent.com/document/api/1179/63419)
* [DescribeRocketMQTopics](https://cloud.tencent.com/document/api/1179/63418)
* [ModifyRocketMQCluster](https://cloud.tencent.com/document/api/1179/63417)
* [ModifyRocketMQGroup](https://cloud.tencent.com/document/api/1179/63416)
* [ModifyRocketMQNamespace](https://cloud.tencent.com/document/api/1179/63415)
* [ModifyRocketMQTopic](https://cloud.tencent.com/document/api/1179/63414)

新增数据结构：

* [RocketMQClusterConfig](https://cloud.tencent.com/document/api/1179/46089#RocketMQClusterConfig)
* [RocketMQClusterDetail](https://cloud.tencent.com/document/api/1179/46089#RocketMQClusterDetail)
* [RocketMQClusterInfo](https://cloud.tencent.com/document/api/1179/46089#RocketMQClusterInfo)
* [RocketMQClusterRecentStats](https://cloud.tencent.com/document/api/1179/46089#RocketMQClusterRecentStats)
* [RocketMQGroup](https://cloud.tencent.com/document/api/1179/46089#RocketMQGroup)
* [RocketMQNamespace](https://cloud.tencent.com/document/api/1179/46089#RocketMQNamespace)
* [RocketMQTopic](https://cloud.tencent.com/document/api/1179/46089#RocketMQTopic)

### 第 21 次发布

发布时间：2021-10-21 11:38:45

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateCluster](https://cloud.tencent.com/document/api/1179/52193)

	* 新增入参：PublicAccessEnabled

* [DescribeClusters](https://cloud.tencent.com/document/api/1179/52183)

	* 新增入参：IsTagFilter, Filters

* [DescribeCmqQueues](https://cloud.tencent.com/document/api/1179/55909)

	* 新增入参：Filters

* [DescribeCmqTopics](https://cloud.tencent.com/document/api/1179/55906)

	* 新增入参：Filters

* [ModifyCluster](https://cloud.tencent.com/document/api/1179/52189)

	* 新增入参：PublicAccessEnabled


修改数据结构：

* [Cluster](https://cloud.tencent.com/document/api/1179/46089#Cluster)

	* 新增成员：MaxPublishRateInMessages, MaxDispatchRateInMessages, MaxPublishRateInBytes, MaxDispatchRateInBytes, TopicNum, MaxMessageDelayInSeconds, PublicAccessEnabled, Tags


### 第 20 次发布

发布时间：2021-10-13 08:12:03

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [Environment](https://cloud.tencent.com/document/api/1179/46089#Environment)

	* 新增成员：RetentionPolicy


### 第 19 次发布

发布时间：2021-10-09 11:19:31

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateEnvironmentRole](https://cloud.tencent.com/document/api/1179/62402)
* [CreateRole](https://cloud.tencent.com/document/api/1179/62401)
* [DeleteEnvironmentRoles](https://cloud.tencent.com/document/api/1179/62400)
* [DeleteRoles](https://cloud.tencent.com/document/api/1179/62403)
* [DescribeRoles](https://cloud.tencent.com/document/api/1179/62399)
* [ModifyEnvironmentRole](https://cloud.tencent.com/document/api/1179/62398)
* [ModifyRole](https://cloud.tencent.com/document/api/1179/62397)

新增数据结构：

* [Role](https://cloud.tencent.com/document/api/1179/46089#Role)

### 第 18 次发布

发布时间：2021-09-17 08:13:22

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeCmqQueues](https://cloud.tencent.com/document/api/1179/55909)

	* 新增入参：QueueNameList, IsTagFilter

* [DescribeCmqTopics](https://cloud.tencent.com/document/api/1179/55906)

	* 新增入参：TopicNameList, IsTagFilter


### 第 17 次发布

发布时间：2021-09-02 08:09:49

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeClusters](https://cloud.tencent.com/document/api/1179/52183)

	* 新增入参：ClusterIdList


### 第 16 次发布

发布时间：2021-09-01 08:11:10

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [Cluster](https://cloud.tencent.com/document/api/1179/46089#Cluster)

	* 新增成员：UsedStorageBudget


### 第 15 次发布

发布时间：2021-08-19 08:11:36

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeEnvironmentRoles](https://cloud.tencent.com/document/api/1179/49051)

	* 新增入参：Filters


### 第 14 次发布

发布时间：2021-08-18 08:11:25

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateEnvironment](https://cloud.tencent.com/document/api/1179/46081)

	* 新增入参：RetentionPolicy

* [DeleteSubscriptions](https://cloud.tencent.com/document/api/1179/46074)

	* 新增入参：Force

* [DeleteTopics](https://cloud.tencent.com/document/api/1179/46087)

	* 新增入参：Force

* [ModifyEnvironmentAttributes](https://cloud.tencent.com/document/api/1179/46077)

	* 新增入参：RetentionPolicy


新增数据结构：

* [RetentionPolicy](https://cloud.tencent.com/document/api/1179/46089#RetentionPolicy)

### 第 13 次发布

发布时间：2021-07-29 08:12:13

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateSubscription](https://cloud.tencent.com/document/api/1179/46075)

	* 新增入参：PostFixPattern


### 第 12 次发布

发布时间：2021-07-22 08:11:34

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeNamespaceBundlesOpt](https://cloud.tencent.com/document/api/1179/59039)
* [DescribeNodeHealthOpt](https://cloud.tencent.com/document/api/1179/59038)

新增数据结构：

* [BundleSetOpt](https://cloud.tencent.com/document/api/1179/46089#BundleSetOpt)

### 第 11 次发布

发布时间：2021-07-21 08:11:28

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [Cluster](https://cloud.tencent.com/document/api/1179/46089#Cluster)

	* 新增成员：Version, PublicEndPoint, VpcEndPoint, NamespaceNum


### 第 10 次发布

发布时间：2021-07-13 08:15:04

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [Environment](https://cloud.tencent.com/document/api/1179/46089#Environment)

	* 新增成员：TopicNum


### 第 9 次发布

发布时间：2021-06-17 08:10:59

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [AcknowledgeMessage](https://cloud.tencent.com/document/api/1179/57459)
* [ReceiveMessage](https://cloud.tencent.com/document/api/1179/57458)

修改接口：

* [SendBatchMessages](https://cloud.tencent.com/document/api/1179/53441)

	* <font color="#dd0000">**修改入参**：</font>StringToken

* [SendMessages](https://cloud.tencent.com/document/api/1179/53440)

	* <font color="#dd0000">**修改入参**：</font>StringToken


### 第 8 次发布

发布时间：2021-06-07 08:10:21

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [SendMsg](https://cloud.tencent.com/document/api/1179/56772)

### 第 7 次发布

发布时间：2021-05-18 08:11:59

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [ClearCmqQueue](https://cloud.tencent.com/document/api/1179/55922)
* [ClearCmqSubscriptionFilterTags](https://cloud.tencent.com/document/api/1179/55921)
* [CreateCmqQueue](https://cloud.tencent.com/document/api/1179/55917)
* [CreateCmqSubscribe](https://cloud.tencent.com/document/api/1179/55916)
* [CreateCmqTopic](https://cloud.tencent.com/document/api/1179/55915)
* [DeleteCmqQueue](https://cloud.tencent.com/document/api/1179/55914)
* [DeleteCmqSubscribe](https://cloud.tencent.com/document/api/1179/55913)
* [DeleteCmqTopic](https://cloud.tencent.com/document/api/1179/55912)
* [DescribeCmqDeadLetterSourceQueues](https://cloud.tencent.com/document/api/1179/55911)
* [DescribeCmqQueueDetail](https://cloud.tencent.com/document/api/1179/55910)
* [DescribeCmqQueues](https://cloud.tencent.com/document/api/1179/55909)
* [DescribeCmqSubscriptionDetail](https://cloud.tencent.com/document/api/1179/55908)
* [DescribeCmqTopicDetail](https://cloud.tencent.com/document/api/1179/55907)
* [DescribeCmqTopics](https://cloud.tencent.com/document/api/1179/55906)
* [ModifyCmqQueueAttribute](https://cloud.tencent.com/document/api/1179/55905)
* [ModifyCmqSubscriptionAttribute](https://cloud.tencent.com/document/api/1179/55904)
* [ModifyCmqTopicAttribute](https://cloud.tencent.com/document/api/1179/55903)
* [PublishCmqMsg](https://cloud.tencent.com/document/api/1179/55920)
* [RewindCmqQueue](https://cloud.tencent.com/document/api/1179/55902)
* [SendCmqMsg](https://cloud.tencent.com/document/api/1179/55919)
* [UnbindCmqDeadLetter](https://cloud.tencent.com/document/api/1179/55901)

新增数据结构：

* [CmqDeadLetterPolicy](https://cloud.tencent.com/document/api/1179/46089#CmqDeadLetterPolicy)
* [CmqDeadLetterSource](https://cloud.tencent.com/document/api/1179/46089#CmqDeadLetterSource)
* [CmqQueue](https://cloud.tencent.com/document/api/1179/46089#CmqQueue)
* [CmqSubscription](https://cloud.tencent.com/document/api/1179/46089#CmqSubscription)
* [CmqTopic](https://cloud.tencent.com/document/api/1179/46089#CmqTopic)
* [CmqTransactionPolicy](https://cloud.tencent.com/document/api/1179/46089#CmqTransactionPolicy)

### 第 6 次发布

发布时间：2021-05-11 08:11:30

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeEnvironments](https://cloud.tencent.com/document/api/1179/46078)

	* 新增入参：Filters

* [DescribeTopics](https://cloud.tencent.com/document/api/1179/46086)

	* 新增入参：Filters


新增数据结构：

* [Filter](https://cloud.tencent.com/document/api/1179/46089#Filter)

修改数据结构：

* [FilterSubscription](https://cloud.tencent.com/document/api/1179/46089#FilterSubscription)

	* 新增成员：SubscriptionNames

* [Topic](https://cloud.tencent.com/document/api/1179/46089#Topic)

	* 新增成员：ProducerLimit, ConsumerLimit


### 第 5 次发布

发布时间：2021-03-09 08:11:08

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [SendBatchMessages](https://cloud.tencent.com/document/api/1179/53441)
* [SendMessages](https://cloud.tencent.com/document/api/1179/53440)

### 第 4 次发布

发布时间：2021-01-21 08:09:28

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeEnvironments](https://cloud.tencent.com/document/api/1179/46078)

	* 新增入参：ClusterId


### 第 3 次发布

发布时间：2021-01-19 15:48:57

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateCluster](https://cloud.tencent.com/document/api/1179/52193)
* [DeleteCluster](https://cloud.tencent.com/document/api/1179/52185)
* [DescribeBindClusters](https://cloud.tencent.com/document/api/1179/52191)
* [DescribeBindVpcs](https://cloud.tencent.com/document/api/1179/52187)
* [DescribeClusterDetail](https://cloud.tencent.com/document/api/1179/52184)
* [DescribeClusters](https://cloud.tencent.com/document/api/1179/52183)
* [ModifyCluster](https://cloud.tencent.com/document/api/1179/52189)

修改接口：

* [CreateEnvironment](https://cloud.tencent.com/document/api/1179/46081)

	* 新增入参：ClusterId

	* 新增出参：NamespaceId

* [CreateSubscription](https://cloud.tencent.com/document/api/1179/46075)

	* 新增入参：ClusterId, AutoCreatePolicyTopic

* [CreateTopic](https://cloud.tencent.com/document/api/1179/46088)

	* 新增入参：ClusterId

* [DeleteEnvironments](https://cloud.tencent.com/document/api/1179/46080)

	* 新增入参：ClusterId

* [DeleteSubscriptions](https://cloud.tencent.com/document/api/1179/46074)

	* 新增入参：ClusterId, EnvironmentId

* [DeleteTopics](https://cloud.tencent.com/document/api/1179/46087)

	* 新增入参：ClusterId, EnvironmentId

* [DescribeEnvironmentAttributes](https://cloud.tencent.com/document/api/1179/46079)

	* 新增入参：ClusterId

* [DescribeEnvironmentRoles](https://cloud.tencent.com/document/api/1179/49051)

	* 新增入参：ClusterId, RoleName

	* <font color="#dd0000">**修改入参**：</font>EnvironmentId

* [DescribeProducers](https://cloud.tencent.com/document/api/1179/46073)

	* 新增入参：ClusterId

* [DescribeSubscriptions](https://cloud.tencent.com/document/api/1179/46072)

	* 新增入参：ClusterId

* [DescribeTopics](https://cloud.tencent.com/document/api/1179/46086)

	* 新增入参：ClusterId

* [ModifyEnvironmentAttributes](https://cloud.tencent.com/document/api/1179/46077)

	* 新增入参：ClusterId

	* 新增出参：NamespaceId

* [ModifyTopic](https://cloud.tencent.com/document/api/1179/46085)

	* 新增入参：ClusterId

* [ResetMsgSubOffsetByTimestamp](https://cloud.tencent.com/document/api/1179/46083)

	* 新增入参：ClusterId


新增数据结构：

* [BindCluster](https://cloud.tencent.com/document/api/1179/46089#BindCluster)
* [Cluster](https://cloud.tencent.com/document/api/1179/46089#Cluster)
* [Tag](https://cloud.tencent.com/document/api/1179/46089#Tag)
* [VpcBindRecord](https://cloud.tencent.com/document/api/1179/46089#VpcBindRecord)

修改数据结构：

* [Environment](https://cloud.tencent.com/document/api/1179/46089#Environment)

	* 新增成员：NamespaceId, NamespaceName


### 第 2 次发布

发布时间：2020-10-13 08:08:58

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeEnvironmentRoles](https://cloud.tencent.com/document/api/1179/49051)

新增数据结构：

* [EnvironmentRole](https://cloud.tencent.com/document/api/1179/46089#EnvironmentRole)

### 第 1 次发布

发布时间：2020-07-08 10:59:58

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateEnvironment](https://cloud.tencent.com/document/api/1179/46081)
* [CreateSubscription](https://cloud.tencent.com/document/api/1179/46075)
* [CreateTopic](https://cloud.tencent.com/document/api/1179/46088)
* [DeleteEnvironments](https://cloud.tencent.com/document/api/1179/46080)
* [DeleteSubscriptions](https://cloud.tencent.com/document/api/1179/46074)
* [DeleteTopics](https://cloud.tencent.com/document/api/1179/46087)
* [DescribeEnvironmentAttributes](https://cloud.tencent.com/document/api/1179/46079)
* [DescribeEnvironments](https://cloud.tencent.com/document/api/1179/46078)
* [DescribeProducers](https://cloud.tencent.com/document/api/1179/46073)
* [DescribeSubscriptions](https://cloud.tencent.com/document/api/1179/46072)
* [DescribeTopics](https://cloud.tencent.com/document/api/1179/46086)
* [ModifyEnvironmentAttributes](https://cloud.tencent.com/document/api/1179/46077)
* [ModifyTopic](https://cloud.tencent.com/document/api/1179/46085)
* [ResetMsgSubOffsetByTimestamp](https://cloud.tencent.com/document/api/1179/46083)

新增数据结构：

* [Connection](https://cloud.tencent.com/document/api/1179/46089#Connection)
* [Consumer](https://cloud.tencent.com/document/api/1179/46089#Consumer)
* [ConsumersSchedule](https://cloud.tencent.com/document/api/1179/46089#ConsumersSchedule)
* [Environment](https://cloud.tencent.com/document/api/1179/46089#Environment)
* [FilterSubscription](https://cloud.tencent.com/document/api/1179/46089#FilterSubscription)
* [PartitionsTopic](https://cloud.tencent.com/document/api/1179/46089#PartitionsTopic)
* [Producer](https://cloud.tencent.com/document/api/1179/46089#Producer)
* [Subscription](https://cloud.tencent.com/document/api/1179/46089#Subscription)
* [SubscriptionTopic](https://cloud.tencent.com/document/api/1179/46089#SubscriptionTopic)
* [Topic](https://cloud.tencent.com/document/api/1179/46089#Topic)
* [TopicRecord](https://cloud.tencent.com/document/api/1179/46089#TopicRecord)




## 设备安全(tds) 版本：2022-08-01

### 第 3 次发布

发布时间：2023-11-15 02:26:59

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeFraudUltimate](https://cloud.tencent.com/document/api/1628/83695)

	* 新增出参：Unionid


### 第 2 次发布

发布时间：2022-12-06 07:10:10

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeFraudUltimate](https://cloud.tencent.com/document/api/1628/83695)

### 第 1 次发布

发布时间：2022-09-23 17:56:43

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeFraudBase](https://cloud.tencent.com/document/api/1628/81019)
* [DescribeFraudPremium](https://cloud.tencent.com/document/api/1628/81018)
* [DescribeTrustedID](https://cloud.tencent.com/document/api/1628/81017)

新增数据结构：

* [RiskInfo](https://cloud.tencent.com/document/api/1628/81020#RiskInfo)




## 弹性微服务(tem) 版本：2020-12-21

### 第 8 次发布

发布时间：2021-07-15 08:00:33

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DeployServiceV2](https://cloud.tencent.com/document/api/1371/55519)

	* 新增入参：PostStart, PreStop, DeployStrategyConf, Liveness, Readiness


新增数据结构：

* [DeployStrategyConf](https://cloud.tencent.com/document/api/1371/55421#DeployStrategyConf)
* [HealthCheckConfig](https://cloud.tencent.com/document/api/1371/55421#HealthCheckConfig)

修改数据结构：

* [RunVersionPod](https://cloud.tencent.com/document/api/1371/55421#RunVersionPod)

	* 新增成员：RestartCount


### 第 7 次发布

发布时间：2021-06-21 08:00:32

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [GenerateDownloadUrl](https://cloud.tencent.com/document/api/1371/57595)

修改接口：

* [CreateCosTokenV2](https://cloud.tencent.com/document/api/1371/55523)

	* 新增入参：TimeVersion

* [DeployServiceV2](https://cloud.tencent.com/document/api/1371/55519)

	* 新增入参：VersionId


### 第 6 次发布

发布时间：2021-06-14 08:00:23

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DeployServiceV2](https://cloud.tencent.com/document/api/1371/55519)

	* 新增入参：SettingConfs, EksService


新增数据结构：

* [EksService](https://cloud.tencent.com/document/api/1371/55421#EksService)
* [MountedSettingConf](https://cloud.tencent.com/document/api/1371/55421#MountedSettingConf)

### 第 5 次发布

发布时间：2021-06-04 08:00:25

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeRelatedIngresses](https://cloud.tencent.com/document/api/1371/56697)
* [ModifyServiceInfo](https://cloud.tencent.com/document/api/1371/56696)
* [RestartServiceRunPod](https://cloud.tencent.com/document/api/1371/56695)

修改接口：

* [CreateNamespace](https://cloud.tencent.com/document/api/1371/55417)

	* 新增入参：EnableTswTraceService

* [DeployServiceV2](https://cloud.tencent.com/document/api/1371/55519)

	* 新增入参：PortMappings, UseRegistryDefaultConfig

* [DescribeIngresses](https://cloud.tencent.com/document/api/1371/55520)

	* 新增入参：Names


新增数据结构：

* [PortMapping](https://cloud.tencent.com/document/api/1371/55421#PortMapping)

### 第 4 次发布

发布时间：2021-06-03 08:00:27

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [IngressInfo](https://cloud.tencent.com/document/api/1371/55421#IngressInfo)

	* 新增成员：CreateTime, Mixed

* [IngressRule](https://cloud.tencent.com/document/api/1371/55421#IngressRule)

	* 新增成员：Protocol

* [IngressTls](https://cloud.tencent.com/document/api/1371/55421#IngressTls)

	* 新增成员：CertificateId

* [RunVersionPod](https://cloud.tencent.com/document/api/1371/55421#RunVersionPod)

	* 新增成员：Zone, DeployVersion


### 第 3 次发布

发布时间：2021-05-12 08:00:07

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [LogOutputConf](https://cloud.tencent.com/document/api/1371/55421#LogOutputConf)

	* 新增成员：ClsLogsetId, ClsLogTopicName

* [TemNamespaceInfo](https://cloud.tencent.com/document/api/1371/55421#TemNamespaceInfo)

	* 新增成员：EnableTswTraceService


### 第 2 次发布

发布时间：2021-05-08 14:44:11

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateCosTokenV2](https://cloud.tencent.com/document/api/1371/55523)
* [CreateResource](https://cloud.tencent.com/document/api/1371/55514)
* [CreateServiceV2](https://cloud.tencent.com/document/api/1371/55516)
* [DeleteIngress](https://cloud.tencent.com/document/api/1371/55522)
* [DeployServiceV2](https://cloud.tencent.com/document/api/1371/55519)
* [DescribeIngress](https://cloud.tencent.com/document/api/1371/55521)
* [DescribeIngresses](https://cloud.tencent.com/document/api/1371/55520)
* [DescribeServiceRunPodListV2](https://cloud.tencent.com/document/api/1371/55518)

新增数据结构：

* [DescribeRunPodPage](https://cloud.tencent.com/document/api/1371/55421#DescribeRunPodPage)
* [EsInfo](https://cloud.tencent.com/document/api/1371/55421#EsInfo)
* [LogOutputConf](https://cloud.tencent.com/document/api/1371/55421#LogOutputConf)
* [Pair](https://cloud.tencent.com/document/api/1371/55421#Pair)
* [RunVersionPod](https://cloud.tencent.com/document/api/1371/55421#RunVersionPod)
* [StorageConf](https://cloud.tencent.com/document/api/1371/55421#StorageConf)
* [StorageMountConf](https://cloud.tencent.com/document/api/1371/55421#StorageMountConf)

### 第 1 次发布

发布时间：2021-05-03 08:00:04

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateCosToken](https://cloud.tencent.com/document/api/1371/55420)
* [CreateNamespace](https://cloud.tencent.com/document/api/1371/55417)
* [DescribeNamespaces](https://cloud.tencent.com/document/api/1371/55416)
* [ModifyIngress](https://cloud.tencent.com/document/api/1371/55419)
* [ModifyNamespace](https://cloud.tencent.com/document/api/1371/55415)

新增数据结构：

* [CosToken](https://cloud.tencent.com/document/api/1371/55421#CosToken)
* [IngressInfo](https://cloud.tencent.com/document/api/1371/55421#IngressInfo)
* [IngressRule](https://cloud.tencent.com/document/api/1371/55421#IngressRule)
* [IngressRuleBackend](https://cloud.tencent.com/document/api/1371/55421#IngressRuleBackend)
* [IngressRulePath](https://cloud.tencent.com/document/api/1371/55421#IngressRulePath)
* [IngressRuleValue](https://cloud.tencent.com/document/api/1371/55421#IngressRuleValue)
* [IngressTls](https://cloud.tencent.com/document/api/1371/55421#IngressTls)
* [NamespacePage](https://cloud.tencent.com/document/api/1371/55421#NamespacePage)
* [TemNamespaceInfo](https://cloud.tencent.com/document/api/1371/55421#TemNamespaceInfo)



## 弹性微服务(tem) 版本：2021-07-01

### 第 43 次发布

发布时间：2024-07-24 02:14:59

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DeployApplication](https://cloud.tencent.com/document/api/1371/60158)

	* 新增入参：PostStartEncoded, PreStopEncoded


### 第 42 次发布

发布时间：2024-06-25 01:23:38

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [UseDefaultRepoParameters](https://cloud.tencent.com/document/api/1371/60171#UseDefaultRepoParameters)

	* <font color="#dd0000">**修改成员**：</font>EnterpriseInstanceName, EnterpriseInstanceChargeType, EnterpriseInstanceType


### 第 41 次发布

发布时间：2023-04-20 01:41:18

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [RollingUpdateApplicationByVersion](https://cloud.tencent.com/document/api/1371/66371)

	* 新增入参：Force


### 第 40 次发布

发布时间：2023-02-24 01:23:28

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [EksService](https://cloud.tencent.com/document/api/1371/60171#EksService)

	* 新增成员：ExternalDomain

* [IngressInfo](https://cloud.tencent.com/document/api/1371/60171#IngressInfo)

	* 新增成员：Domain

* [ServicePortMapping](https://cloud.tencent.com/document/api/1371/60171#ServicePortMapping)

	* 新增成员：ExternalDomain


### 第 39 次发布

发布时间：2023-02-16 01:58:58

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [LogConfigExtractRule](https://cloud.tencent.com/document/api/1371/60171#LogConfigExtractRule)

	* 新增成员：Backtracking, Delimiter

* [ServiceVersionBrief](https://cloud.tencent.com/document/api/1371/60171#ServiceVersionBrief)

	* 新增成员：RegionId

* [TemEnvironmentStartingStatus](https://cloud.tencent.com/document/api/1371/60171#TemEnvironmentStartingStatus)

	* 新增成员：StartFailedApplicationNum

* [TemEnvironmentStoppingStatus](https://cloud.tencent.com/document/api/1371/60171#TemEnvironmentStoppingStatus)

	* 新增成员：StopFailedApplicationNum

* [TemServiceVersionInfo](https://cloud.tencent.com/document/api/1371/60171#TemServiceVersionInfo)

	* 新增成员：PreStopEncoded, PostStartEncoded


### 第 38 次发布

发布时间：2023-02-07 02:03:34

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateEnvironment](https://cloud.tencent.com/document/api/1371/60150)

	* 新增入参：SetupVpc, SetupPrometheus, PrometheusId, ApmId

	* <font color="#dd0000">**修改入参**：</font>Vpc, SubnetIds

* [CreateResource](https://cloud.tencent.com/document/api/1371/60146)

	* <font color="#dd0000">**修改入参**：</font>ResourceId


### 第 37 次发布

发布时间：2022-12-15 01:49:45

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeEnvironments](https://cloud.tencent.com/document/api/1371/60149)

	* 新增入参：EnvironmentId


### 第 36 次发布

发布时间：2022-12-09 02:04:15

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateEnvironment](https://cloud.tencent.com/document/api/1371/60150)

	* 新增入参：EnvType, CreateRegion

* [DescribeApplications](https://cloud.tencent.com/document/api/1371/78169)

	* 新增入参：SortInfo

* [DescribeEnvironments](https://cloud.tencent.com/document/api/1371/60149)

	* 新增入参：SortInfo

* [ModifyEnvironment](https://cloud.tencent.com/document/api/1371/60148)

	* 新增入参：EnvType


新增数据结构：

* [SortType](https://cloud.tencent.com/document/api/1371/60171#SortType)

修改数据结构：

* [NamespaceInfo](https://cloud.tencent.com/document/api/1371/60171#NamespaceInfo)

	* 新增成员：EnvType

* [TemNamespaceInfo](https://cloud.tencent.com/document/api/1371/60171#TemNamespaceInfo)

	* 新增成员：EnvType, RegionId


### 第 35 次发布

发布时间：2022-11-17 06:48:59

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [HorizontalAutoscaler](https://cloud.tencent.com/document/api/1371/60171#HorizontalAutoscaler)

	* 新增成员：DoubleThreshold


### 第 34 次发布

发布时间：2022-11-08 06:44:33

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [TemNamespaceInfo](https://cloud.tencent.com/document/api/1371/60171#TemNamespaceInfo)

	* 新增成员：HasAuthority

* [TemService](https://cloud.tencent.com/document/api/1371/60171#TemService)

	* 新增成员：HasAuthority


### 第 33 次发布

发布时间：2022-11-02 06:44:20

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateLogConfig](https://cloud.tencent.com/document/api/1371/78465)

	* 新增入参：ExtractRule


新增数据结构：

* [LogConfigExtractRule](https://cloud.tencent.com/document/api/1371/60171#LogConfigExtractRule)

修改数据结构：

* [LogConfig](https://cloud.tencent.com/document/api/1371/60171#LogConfig)

	* 新增成员：ExtractRule


### 第 32 次发布

发布时间：2022-10-25 07:01:06

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateApplication](https://cloud.tencent.com/document/api/1371/60162)

	* 新增入参：Tags

* [CreateEnvironment](https://cloud.tencent.com/document/api/1371/60150)

	* 新增入参：Tags

* [DescribeApplications](https://cloud.tencent.com/document/api/1371/78169)

	* 新增入参：Filters

* [DescribeEnvironments](https://cloud.tencent.com/document/api/1371/60149)

	* 新增入参：Filters

* [ModifyApplicationReplicas](https://cloud.tencent.com/document/api/1371/65772)

	* 新增出参：Result


新增数据结构：

* [QueryFilter](https://cloud.tencent.com/document/api/1371/60171#QueryFilter)

修改数据结构：

* [DeployServicePodDetail](https://cloud.tencent.com/document/api/1371/60171#DeployServicePodDetail)

	* 新增成员：Status

* [NamespaceInfo](https://cloud.tencent.com/document/api/1371/60171#NamespaceInfo)

	* 新增成员：Tags

* [RunVersionPod](https://cloud.tencent.com/document/api/1371/60171#RunVersionPod)

	* 新增成员：NodeInfo, StartTime, Unhealthy, UnhealthyWarningMsg, VersionId, ApplicationName

* [ServicePage](https://cloud.tencent.com/document/api/1371/60171#ServicePage)

	* 新增成员：Current

* [ServiceVersionBrief](https://cloud.tencent.com/document/api/1371/60171#ServiceVersionBrief)

	* 新增成员：BatchDeployStatus, Zones, NodeInfos, PodList, WorkloadInfo, CreateDate

* [TemService](https://cloud.tencent.com/document/api/1371/60171#TemService)

	* 新增成员：Tags

* [TemServiceVersionInfo](https://cloud.tencent.com/document/api/1371/60171#TemServiceVersionInfo)

	* 新增成员：AppId, SubAccountUin, Uin, Region, GroupId, EnableRegistry, AutoscalerList, Modifier, Creator, DeployStrategyConf, PodList, ConfEdited, Tags

* [WorkloadInfo](https://cloud.tencent.com/document/api/1371/60171#WorkloadInfo)

	* 新增成员：VersionName, ReadyReplicas, Replicas, UpdatedReplicas, UpdatedReadyReplicas, UpdateRevision, CurrentRevision


### 第 31 次发布

发布时间：2022-09-28 06:54:52

本次发布包含了以下内容：

改善已有的文档。

新增数据结构：

* [Tag](https://cloud.tencent.com/document/api/1371/60171#Tag)

修改数据结构：

* [NamespacePage](https://cloud.tencent.com/document/api/1371/60171#NamespacePage)

	* 新增成员：Current

* [TemNamespaceInfo](https://cloud.tencent.com/document/api/1371/60171#TemNamespaceInfo)

	* 新增成员：AppId, Uin, SubAccountUin, ClusterId, Tags


### 第 30 次发布

发布时间：2022-09-27 06:45:31

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateApplicationService](https://cloud.tencent.com/document/api/1371/81051)
* [DeleteApplicationService](https://cloud.tencent.com/document/api/1371/81050)
* [DescribeApplicationServiceList](https://cloud.tencent.com/document/api/1371/81049)
* [ModifyApplicationService](https://cloud.tencent.com/document/api/1371/81048)

### 第 29 次发布

发布时间：2022-09-07 06:51:54

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DeployApplication](https://cloud.tencent.com/document/api/1371/60158)

	* 新增入参：TcrInstanceId, RepoServer, RepoType


### 第 28 次发布

发布时间：2022-08-12 11:47:08

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DeployApplication](https://cloud.tencent.com/document/api/1371/60158)

	* 新增入参：EnableMetrics


### 第 27 次发布

发布时间：2022-08-11 15:11:54

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DisableApplicationAutoscaler](https://cloud.tencent.com/document/api/1371/78955)
* [EnableApplicationAutoscaler](https://cloud.tencent.com/document/api/1371/78954)

### 第 26 次发布

发布时间：2022-08-11 07:11:15

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [TemServiceVersionInfo](https://cloud.tencent.com/document/api/1371/60171#TemServiceVersionInfo)

	* 新增成员：EnableMetrics

	* <font color="#dd0000">**修改成员**：</font>ApplicationId, MinAliveInstances


### 第 25 次发布

发布时间：2022-08-10 16:02:58

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeEnvironment](https://cloud.tencent.com/document/api/1371/78842)

新增数据结构：

* [NamespaceInfo](https://cloud.tencent.com/document/api/1371/60171#NamespaceInfo)

### 第 24 次发布

发布时间：2022-08-04 06:55:33

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateLogConfig](https://cloud.tencent.com/document/api/1371/78465)
* [DescribeLogConfig](https://cloud.tencent.com/document/api/1371/78470)
* [DescribePagedLogConfigList](https://cloud.tencent.com/document/api/1371/78469)
* [DestroyLogConfig](https://cloud.tencent.com/document/api/1371/78468)
* [ModifyLogConfig](https://cloud.tencent.com/document/api/1371/78467)

新增数据结构：

* [LogConfig](https://cloud.tencent.com/document/api/1371/60171#LogConfig)
* [LogConfigListPage](https://cloud.tencent.com/document/api/1371/60171#LogConfigListPage)
* [ServicePortMapping](https://cloud.tencent.com/document/api/1371/60171#ServicePortMapping)
* [ServicePortMappingItem](https://cloud.tencent.com/document/api/1371/60171#ServicePortMappingItem)

修改数据结构：

* [EksService](https://cloud.tencent.com/document/api/1371/60171#EksService)

	* 新增成员：ServicePortMappingList, FlushAll, EnableRegistryNextDeploy, ApplicationId, AllIpDone


### 第 23 次发布

发布时间：2022-08-03 06:46:27

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateApplicationAutoscaler](https://cloud.tencent.com/document/api/1371/78341)
* [CreateConfigData](https://cloud.tencent.com/document/api/1371/78337)
* [DeleteApplicationAutoscaler](https://cloud.tencent.com/document/api/1371/78340)
* [DescribeApplicationAutoscalerList](https://cloud.tencent.com/document/api/1371/78339)
* [DescribeConfigData](https://cloud.tencent.com/document/api/1371/78336)
* [DescribeConfigDataList](https://cloud.tencent.com/document/api/1371/78335)
* [DestroyConfigData](https://cloud.tencent.com/document/api/1371/78334)
* [ModifyApplicationAutoscaler](https://cloud.tencent.com/document/api/1371/78338)
* [ModifyConfigData](https://cloud.tencent.com/document/api/1371/78333)

新增数据结构：

* [Autoscaler](https://cloud.tencent.com/document/api/1371/60171#Autoscaler)
* [ConfigData](https://cloud.tencent.com/document/api/1371/60171#ConfigData)
* [DescribeConfigDataListPage](https://cloud.tencent.com/document/api/1371/60171#DescribeConfigDataListPage)

### 第 22 次发布

发布时间：2022-08-02 06:33:46

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeApplicationInfo](https://cloud.tencent.com/document/api/1371/78239)

新增数据结构：

* [NodeInfo](https://cloud.tencent.com/document/api/1371/60171#NodeInfo)
* [TemServiceVersionInfo](https://cloud.tencent.com/document/api/1371/60171#TemServiceVersionInfo)
* [WorkloadInfo](https://cloud.tencent.com/document/api/1371/60171#WorkloadInfo)

### 第 21 次发布

发布时间：2022-08-01 11:54:48

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeApplications](https://cloud.tencent.com/document/api/1371/78169)
* [DescribeEnvironmentStatus](https://cloud.tencent.com/document/api/1371/78168)

新增数据结构：

* [NamespaceStatusInfo](https://cloud.tencent.com/document/api/1371/60171#NamespaceStatusInfo)
* [ServicePage](https://cloud.tencent.com/document/api/1371/60171#ServicePage)
* [TemEnvironmentStartingStatus](https://cloud.tencent.com/document/api/1371/60171#TemEnvironmentStartingStatus)
* [TemEnvironmentStoppingStatus](https://cloud.tencent.com/document/api/1371/60171#TemEnvironmentStoppingStatus)
* [TemService](https://cloud.tencent.com/document/api/1371/60171#TemService)

### 第 20 次发布

发布时间：2022-07-22 06:14:55

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DestroyEnvironment](https://cloud.tencent.com/document/api/1371/77632)

### 第 19 次发布

发布时间：2022-07-11 06:18:55

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [PortMapping](https://cloud.tencent.com/document/api/1371/60171#PortMapping)

	* 新增成员：ServiceName


### 第 18 次发布

发布时间：2022-06-20 06:14:36

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeApplicationsStatus](https://cloud.tencent.com/document/api/1371/75754)

新增数据结构：

* [ServiceVersionBrief](https://cloud.tencent.com/document/api/1371/60171#ServiceVersionBrief)

### 第 17 次发布

发布时间：2022-06-09 06:18:14

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DeployApplication](https://cloud.tencent.com/document/api/1371/60158)

	* 新增入参：EnableTracing


### 第 16 次发布

发布时间：2022-06-08 06:16:15

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [CronHorizontalAutoscaler](https://cloud.tencent.com/document/api/1371/60171#CronHorizontalAutoscaler)

	* <font color="#dd0000">**修改成员**：</font>Name, Period, Schedules, Enabled

* [HorizontalAutoscaler](https://cloud.tencent.com/document/api/1371/60171#HorizontalAutoscaler)

	* 新增成员：Enabled

	* <font color="#dd0000">**修改成员**：</font>MinReplicas, MaxReplicas, Metrics, Threshold


### 第 15 次发布

发布时间：2022-04-28 06:18:38

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateApplication](https://cloud.tencent.com/document/api/1371/60162)

	* 新增入参：UseDefaultImageServiceParameters


新增数据结构：

* [UseDefaultRepoParameters](https://cloud.tencent.com/document/api/1371/60171#UseDefaultRepoParameters)

### 第 14 次发布

发布时间：2022-03-30 06:12:59

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateResource](https://cloud.tencent.com/document/api/1371/60146)

	* 新增入参：ResourceFrom, ResourceConfig

* [DeployApplication](https://cloud.tencent.com/document/api/1371/60158)

	* 新增入参：EnablePrometheusConf


新增数据结构：

* [EnablePrometheusConf](https://cloud.tencent.com/document/api/1371/60171#EnablePrometheusConf)

修改数据结构：

* [IngressInfo](https://cloud.tencent.com/document/api/1371/60171#IngressInfo)

	* 新增成员：RewriteType

* [MountedSettingConf](https://cloud.tencent.com/document/api/1371/60171#MountedSettingConf)

	* 新增成员：SecretDataName

* [Pair](https://cloud.tencent.com/document/api/1371/60171#Pair)

	* 新增成员：Secret


### 第 13 次发布

发布时间：2022-03-09 08:17:24

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DeployApplication](https://cloud.tencent.com/document/api/1371/60158)

	* 新增入参：OsFlavour


### 第 12 次发布

发布时间：2022-03-01 08:13:25

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [DeployStrategyConf](https://cloud.tencent.com/document/api/1371/60171#DeployStrategyConf)

	* 新增成员：Force


### 第 11 次发布

发布时间：2022-01-21 08:18:01

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [RollingUpdateApplicationByVersion](https://cloud.tencent.com/document/api/1371/66371)

	* 新增入参：DeployStrategyType, TotalBatchCount, BatchInterval, BetaBatchNum, MinAvailable


修改数据结构：

* [TemNamespaceInfo](https://cloud.tencent.com/document/api/1371/60171#TemNamespaceInfo)

	* 新增成员：Locked


### 第 10 次发布

发布时间：2022-01-12 08:15:47

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DeployApplication](https://cloud.tencent.com/document/api/1371/60158)

	* 新增入参：ConfEdited, SpeedUp, StartupProbe


修改数据结构：

* [DeployStrategyConf](https://cloud.tencent.com/document/api/1371/60171#DeployStrategyConf)

	* 新增成员：MinAvailable

* [Pair](https://cloud.tencent.com/document/api/1371/60171#Pair)

	* 新增成员：Type, Config


### 第 9 次发布

发布时间：2021-12-23 08:16:03

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [RestartApplication](https://cloud.tencent.com/document/api/1371/66685)
* [StopApplication](https://cloud.tencent.com/document/api/1371/66684)

### 第 8 次发布

发布时间：2021-12-22 08:17:21

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DeleteApplication](https://cloud.tencent.com/document/api/1371/66645)

### 第 7 次发布

发布时间：2021-12-21 08:11:22

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [RollingUpdateApplicationByVersion](https://cloud.tencent.com/document/api/1371/66371)

### 第 6 次发布

发布时间：2021-12-09 08:11:43

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [ModifyApplicationReplicas](https://cloud.tencent.com/document/api/1371/65772)

### 第 5 次发布

发布时间：2021-10-29 08:10:14

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeDeployApplicationDetail](https://cloud.tencent.com/document/api/1371/60154)

	* 新增入参：VersionId


### 第 4 次发布

发布时间：2021-08-24 08:00:55

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DeployApplication](https://cloud.tencent.com/document/api/1371/60158)

	* 新增入参：LogEnable


### 第 3 次发布

发布时间：2021-08-17 08:00:44

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [DeployServiceBatchDetail](https://cloud.tencent.com/document/api/1371/60171#DeployServiceBatchDetail)

	* 新增成员：NextBatchStartTime

* [TemDeployApplicationDetailInfo](https://cloud.tencent.com/document/api/1371/60171#TemDeployApplicationDetailInfo)

	* 新增成员：NewDeployVersion, OldDeployVersion, NewVersionPackageInfo, NextBatchStartTime


### 第 2 次发布

发布时间：2021-08-12 08:00:39

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateApplication](https://cloud.tencent.com/document/api/1371/60162)
* [CreateCosToken](https://cloud.tencent.com/document/api/1371/60164)
* [CreateEnvironment](https://cloud.tencent.com/document/api/1371/60150)
* [CreateResource](https://cloud.tencent.com/document/api/1371/60146)
* [DeleteIngress](https://cloud.tencent.com/document/api/1371/60170)
* [DeployApplication](https://cloud.tencent.com/document/api/1371/60158)
* [DescribeApplicationPods](https://cloud.tencent.com/document/api/1371/60157)
* [DescribeEnvironments](https://cloud.tencent.com/document/api/1371/60149)
* [DescribeIngress](https://cloud.tencent.com/document/api/1371/60169)
* [DescribeIngresses](https://cloud.tencent.com/document/api/1371/60168)
* [DescribeRelatedIngresses](https://cloud.tencent.com/document/api/1371/60167)
* [GenerateApplicationPackageDownloadUrl](https://cloud.tencent.com/document/api/1371/60161)
* [ModifyApplicationInfo](https://cloud.tencent.com/document/api/1371/60160)
* [ModifyEnvironment](https://cloud.tencent.com/document/api/1371/60148)
* [ModifyIngress](https://cloud.tencent.com/document/api/1371/60166)
* [RestartApplicationPod](https://cloud.tencent.com/document/api/1371/60156)

新增数据结构：

* [CosToken](https://cloud.tencent.com/document/api/1371/60171#CosToken)
* [CronHorizontalAutoscaler](https://cloud.tencent.com/document/api/1371/60171#CronHorizontalAutoscaler)
* [CronHorizontalAutoscalerSchedule](https://cloud.tencent.com/document/api/1371/60171#CronHorizontalAutoscalerSchedule)
* [EksService](https://cloud.tencent.com/document/api/1371/60171#EksService)
* [EsInfo](https://cloud.tencent.com/document/api/1371/60171#EsInfo)
* [HealthCheckConfig](https://cloud.tencent.com/document/api/1371/60171#HealthCheckConfig)
* [HorizontalAutoscaler](https://cloud.tencent.com/document/api/1371/60171#HorizontalAutoscaler)
* [IngressInfo](https://cloud.tencent.com/document/api/1371/60171#IngressInfo)
* [IngressRule](https://cloud.tencent.com/document/api/1371/60171#IngressRule)
* [IngressRuleBackend](https://cloud.tencent.com/document/api/1371/60171#IngressRuleBackend)
* [IngressRulePath](https://cloud.tencent.com/document/api/1371/60171#IngressRulePath)
* [IngressRuleValue](https://cloud.tencent.com/document/api/1371/60171#IngressRuleValue)
* [IngressTls](https://cloud.tencent.com/document/api/1371/60171#IngressTls)
* [LogOutputConf](https://cloud.tencent.com/document/api/1371/60171#LogOutputConf)
* [MountedSettingConf](https://cloud.tencent.com/document/api/1371/60171#MountedSettingConf)
* [NamespacePage](https://cloud.tencent.com/document/api/1371/60171#NamespacePage)
* [Pair](https://cloud.tencent.com/document/api/1371/60171#Pair)
* [PortMapping](https://cloud.tencent.com/document/api/1371/60171#PortMapping)
* [StorageConf](https://cloud.tencent.com/document/api/1371/60171#StorageConf)
* [StorageMountConf](https://cloud.tencent.com/document/api/1371/60171#StorageMountConf)
* [TemNamespaceInfo](https://cloud.tencent.com/document/api/1371/60171#TemNamespaceInfo)

修改数据结构：

* [DeployServiceBatchDetail](https://cloud.tencent.com/document/api/1371/60171#DeployServiceBatchDetail)

	* 新增成员：OldPods, NewPods

* [DeployServicePodDetail](https://cloud.tencent.com/document/api/1371/60171#DeployServicePodDetail)

	* 新增成员：Webshell

* [RunVersionPod](https://cloud.tencent.com/document/api/1371/60171#RunVersionPod)

	* 新增成员：Ready, ContainerState


### 第 1 次发布

发布时间：2021-08-04 08:00:42

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeDeployApplicationDetail](https://cloud.tencent.com/document/api/1371/60154)
* [ResumeDeployApplication](https://cloud.tencent.com/document/api/1371/60153)
* [RevertDeployApplication](https://cloud.tencent.com/document/api/1371/60152)

新增数据结构：

* [DeployServiceBatchDetail](https://cloud.tencent.com/document/api/1371/60171#DeployServiceBatchDetail)
* [DeployServicePodDetail](https://cloud.tencent.com/document/api/1371/60171#DeployServicePodDetail)
* [DeployStrategyConf](https://cloud.tencent.com/document/api/1371/60171#DeployStrategyConf)
* [DescribeRunPodPage](https://cloud.tencent.com/document/api/1371/60171#DescribeRunPodPage)
* [RunVersionPod](https://cloud.tencent.com/document/api/1371/60171#RunVersionPod)
* [TemDeployApplicationDetailInfo](https://cloud.tencent.com/document/api/1371/60171#TemDeployApplicationDetailInfo)




## 边缘安全加速平台(teo) 版本：2022-01-06

### 第 28 次发布

发布时间：2023-04-14 01:56:30

本次发布包含了以下内容：

改善已有的文档。

<font color="#dd0000">**删除接口**：</font>

* CheckCertificate
* CreateApplicationProxy
* CreateApplicationProxyRule
* CreateApplicationProxyRules
* CreateCustomErrorPage
* CreateDnsRecord
* CreateLoadBalancing
* CreateOriginGroup
* CreatePlanForZone
* CreateRule
* CreateZone
* DeleteApplicationProxy
* DeleteApplicationProxyRule
* DeleteDnsRecords
* DeleteLoadBalancing
* DeleteOriginGroup
* DeleteRules
* DeleteZone
* DescribeApplicationProxy
* DescribeApplicationProxyDetail
* DescribeAvailablePlans
* DescribeBotLog
* DescribeBotManagedRules
* DescribeCnameStatus
* DescribeDDoSPolicy
* DescribeDDosAttackData
* DescribeDDosAttackEvent
* DescribeDDosAttackEventDetail
* DescribeDDosAttackSourceEvent
* DescribeDDosAttackTopData
* DescribeDDosMajorAttackEvent
* DescribeDefaultCertificates
* DescribeDnsData
* DescribeDnsRecords
* DescribeDnssec
* DescribeHostsCertificate
* DescribeHostsSetting
* DescribeIdentification
* DescribeLoadBalancing
* DescribeLoadBalancingDetail
* DescribeOriginGroup
* DescribeOriginGroupDetail
* DescribeOverviewL7Data
* DescribeRules
* DescribeRulesSetting
* DescribeSecurityPolicy
* DescribeSecurityPolicyList
* DescribeSecurityPolicyManagedRules
* DescribeSecurityPolicyManagedRulesId
* DescribeSecurityPolicyRegions
* DescribeSecurityPortraitRules
* DescribeTimingL4Data
* DescribeTimingL7AnalysisData
* DescribeTimingL7CacheData
* DescribeTopL7AnalysisData
* DescribeTopL7CacheData
* DescribeWebManagedRulesAttackEvents
* DescribeWebManagedRulesData
* DescribeWebManagedRulesLog
* DescribeWebManagedRulesTopData
* DescribeWebProtectionAttackEvents
* DescribeWebProtectionData
* DescribeWebProtectionLog
* DescribeZoneDDoSPolicy
* DescribeZoneDetails
* DescribeZoneSetting
* DownloadL7Logs
* IdentifyZone
* ImportDnsRecords
* ModifyApplicationProxy
* ModifyApplicationProxyRule
* ModifyApplicationProxyRuleStatus
* ModifyApplicationProxyStatus
* ModifyDDoSPolicy
* ModifyDDoSPolicyHost
* ModifyDefaultCertificate
* ModifyDnsRecord
* ModifyDnssec
* ModifyHostsCertificate
* ModifyLoadBalancing
* ModifyLoadBalancingStatus
* ModifyOriginGroup
* ModifyRule
* ModifyRulePriority
* ModifySecurityPolicy
* ModifyZone
* ModifyZoneCnameSpeedUp
* ModifyZoneSetting
* ModifyZoneStatus
* ReclaimZone
* ScanDnsRecords

<font color="#dd0000">**删除数据结构**：</font>

* ACLCondition
* ACLUserRule
* AclConfig
* AiRule
* ApplicationProxy
* ApplicationProxyRule
* BotConfig
* BotLog
* BotLogData
* BotManagedRule
* BotManagedRuleDetail
* BotPortraitRule
* CCInterceptEvent
* CCInterceptEventData
* CCLog
* CCLogData
* CacheConfig
* CacheConfigCache
* CacheConfigFollowOrigin
* CacheConfigNoCache
* CacheKey
* CachePrefresh
* CertFilter
* CertSort
* ClientIp
* CnameStatus
* Compression
* DDoSAcl
* DDoSAntiPly
* DDoSApplication
* DDoSConfig
* DDoSFeaturesFilter
* DDoSGeoIp
* DDoSStatusInfo
* DDoSUserAllowBlockIP
* DDosAttackEvent
* DDosAttackEventData
* DDosAttackEventDetailData
* DDosAttackSourceEvent
* DDosAttackSourceEventData
* DDosMajorAttackEvent
* DDosMajorAttackEventData
* DataItem
* DdosAcls
* DdosAllowBlock
* DdosPacketFilter
* DdosRule
* DdosSpeedLimit
* DefaultServerCertInfo
* DetailHost
* DnsDataFilter
* DnsRecord
* DnsRecordFilter
* DnssecInfo
* DropPageConfig
* DropPageDetail
* ExceptConfig
* ExceptUserRule
* ExceptUserRuleCondition
* ExceptUserRuleScope
* Filter
* ForceRedirect
* GeoIp
* HostCertSetting
* Hsts
* Https
* IntelligenceRule
* IntelligenceRuleItem
* IpTableConfig
* IpTableRule
* Ipv6Access
* L7OfflineLog
* LoadBalancing
* ManagedRule
* MaxAge
* OfflineCache
* Origin
* OriginCheckOriginStatus
* OriginFilter
* OriginGroup
* OriginRecord
* OriginRecordPrivateParameter
* PlanInfo
* PortraitManagedRuleDetail
* PostMaxSize
* QueryCondition
* QueryString
* Quic
* RateLimitConfig
* RateLimitIntelligence
* RateLimitTemplate
* RateLimitTemplateDetail
* RateLimitUserRule
* RuleAction
* RuleAndConditions
* RuleChoicePropertiesItem
* RuleCodeAction
* RuleCodeActionParams
* RuleCondition
* RuleExtraParameter
* RuleFilter
* RuleItem
* RuleNormalAction
* RuleNormalActionParams
* RuleRewriteAction
* RuleRewriteActionParams
* RuleSettingDetail
* RulesProperties
* RulesSettingAction
* SecEntry
* SecEntryValue
* SecRuleRelatedInfo
* SecurityConfig
* SecurityEntity
* ServerCertInfo
* ShieldArea
* SmartRouting
* SwitchConfig
* TimingDataItem
* TimingDataRecord
* TimingTypeValue
* TopDataRecord
* TopDetailData
* TopNEntry
* TopNEntryValue
* UpstreamHttp2
* VanityNameServers
* VanityNameServersIps
* WafConfig
* WafRule
* WebAttackEvent
* WebEventData
* WebLogData
* WebLogs
* WebSocket

### 第 27 次发布

发布时间：2023-03-13 02:06:54

本次发布包含了以下内容：

改善已有的文档。

<font color="#dd0000">**预下线接口**：</font>

* DescribeDDosMajorAttackEvent
* DescribeOverviewL7Data
* DescribeTimingL4Data
* DescribeWebManagedRulesTopData

### 第 26 次发布

发布时间：2022-09-14 06:37:50

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeOverviewL7Data](https://cloud.tencent.com/document/api/1552/75656)

	* 新增入参：Filters


### 第 25 次发布

发布时间：2022-09-12 06:43:25

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [ServerCertInfo](https://cloud.tencent.com/document/api/1552/73155#ServerCertInfo)

	* 新增成员：SignAlgo


### 第 24 次发布

发布时间：2022-09-05 06:51:57

本次发布包含了以下内容：

改善已有的文档。

新增数据结构：

* [DropPageConfig](https://cloud.tencent.com/document/api/1552/73155#DropPageConfig)
* [DropPageDetail](https://cloud.tencent.com/document/api/1552/73155#DropPageDetail)
* [ExceptConfig](https://cloud.tencent.com/document/api/1552/73155#ExceptConfig)
* [ExceptUserRule](https://cloud.tencent.com/document/api/1552/73155#ExceptUserRule)
* [ExceptUserRuleCondition](https://cloud.tencent.com/document/api/1552/73155#ExceptUserRuleCondition)
* [ExceptUserRuleScope](https://cloud.tencent.com/document/api/1552/73155#ExceptUserRuleScope)

修改数据结构：

* [BotPortraitRule](https://cloud.tencent.com/document/api/1552/73155#BotPortraitRule)

	* 新增成员：ManagedIds, TransManagedIds

* [SecurityConfig](https://cloud.tencent.com/document/api/1552/73155#SecurityConfig)

	* 新增成员：ExceptConfig, DropPageConfig


### 第 23 次发布

发布时间：2022-08-30 06:54:55

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeDDoSPolicy](https://cloud.tencent.com/document/api/1552/75110)

	* 新增出参：DdosRule


### 第 22 次发布

发布时间：2022-08-26 06:50:57

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreatePlanForZone](https://cloud.tencent.com/document/api/1552/79666)
* [CreateRule](https://cloud.tencent.com/document/api/1552/79672)
* [DeleteRules](https://cloud.tencent.com/document/api/1552/79671)
* [DescribeAvailablePlans](https://cloud.tencent.com/document/api/1552/79665)
* [DescribeRules](https://cloud.tencent.com/document/api/1552/79670)
* [DescribeRulesSetting](https://cloud.tencent.com/document/api/1552/79669)
* [ModifyRule](https://cloud.tencent.com/document/api/1552/79668)
* [ModifyRulePriority](https://cloud.tencent.com/document/api/1552/79667)

新增数据结构：

* [PlanInfo](https://cloud.tencent.com/document/api/1552/73155#PlanInfo)
* [RuleAction](https://cloud.tencent.com/document/api/1552/73155#RuleAction)
* [RuleAndConditions](https://cloud.tencent.com/document/api/1552/73155#RuleAndConditions)
* [RuleChoicePropertiesItem](https://cloud.tencent.com/document/api/1552/73155#RuleChoicePropertiesItem)
* [RuleCodeAction](https://cloud.tencent.com/document/api/1552/73155#RuleCodeAction)
* [RuleCodeActionParams](https://cloud.tencent.com/document/api/1552/73155#RuleCodeActionParams)
* [RuleCondition](https://cloud.tencent.com/document/api/1552/73155#RuleCondition)
* [RuleExtraParameter](https://cloud.tencent.com/document/api/1552/73155#RuleExtraParameter)
* [RuleFilter](https://cloud.tencent.com/document/api/1552/73155#RuleFilter)
* [RuleItem](https://cloud.tencent.com/document/api/1552/73155#RuleItem)
* [RuleNormalAction](https://cloud.tencent.com/document/api/1552/73155#RuleNormalAction)
* [RuleNormalActionParams](https://cloud.tencent.com/document/api/1552/73155#RuleNormalActionParams)
* [RuleRewriteAction](https://cloud.tencent.com/document/api/1552/73155#RuleRewriteAction)
* [RuleRewriteActionParams](https://cloud.tencent.com/document/api/1552/73155#RuleRewriteActionParams)
* [RuleSettingDetail](https://cloud.tencent.com/document/api/1552/73155#RuleSettingDetail)
* [RulesProperties](https://cloud.tencent.com/document/api/1552/73155#RulesProperties)
* [RulesSettingAction](https://cloud.tencent.com/document/api/1552/73155#RulesSettingAction)

### 第 21 次发布

发布时间：2022-08-23 06:54:06

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateApplicationProxy](https://cloud.tencent.com/document/api/1552/74833)

	* <font color="#dd0000">**修改入参**：</font>Rule


### 第 20 次发布

发布时间：2022-08-19 06:38:50

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeApplicationProxyDetail](https://cloud.tencent.com/document/api/1552/74827)

	* 新增出参：Area

* [DescribeBotLog](https://cloud.tencent.com/document/api/1552/75663)

	* 新增入参：Area

* [DescribeDDosAttackData](https://cloud.tencent.com/document/api/1552/75662)

	* 新增入参：Area

* [DescribeDDosAttackEvent](https://cloud.tencent.com/document/api/1552/75661)

	* 新增入参：Area

* [DescribeDDosAttackEventDetail](https://cloud.tencent.com/document/api/1552/75660)

	* 新增入参：Area

* [DescribeDDosAttackSourceEvent](https://cloud.tencent.com/document/api/1552/75659)

	* 新增入参：Area

* [DescribeDDosAttackTopData](https://cloud.tencent.com/document/api/1552/75658)

	* 新增入参：Area

* [DescribeDDosMajorAttackEvent](https://cloud.tencent.com/document/api/1552/75657)

	* 新增入参：Area

* [DescribeOverviewL7Data](https://cloud.tencent.com/document/api/1552/75656)

	* 新增入参：Area

* [DescribeTimingL4Data](https://cloud.tencent.com/document/api/1552/75655)

	* 新增入参：Area

* [DescribeTimingL7AnalysisData](https://cloud.tencent.com/document/api/1552/75654)

	* 新增入参：Area

* [DescribeTimingL7CacheData](https://cloud.tencent.com/document/api/1552/75726)

	* 新增入参：Area

* [DescribeTopL7AnalysisData](https://cloud.tencent.com/document/api/1552/75653)

	* 新增入参：Area

* [DescribeTopL7CacheData](https://cloud.tencent.com/document/api/1552/75725)

	* 新增入参：Area

* [DescribeWebManagedRulesData](https://cloud.tencent.com/document/api/1552/75651)

	* 新增入参：Area

* [DescribeWebManagedRulesLog](https://cloud.tencent.com/document/api/1552/75650)

	* 新增入参：Area

* [DescribeWebManagedRulesTopData](https://cloud.tencent.com/document/api/1552/75649)

	* 新增入参：Area

* [DescribeWebProtectionData](https://cloud.tencent.com/document/api/1552/75647)

	* 新增入参：Area

* [DescribeWebProtectionLog](https://cloud.tencent.com/document/api/1552/75646)

	* 新增入参：Area

* [DescribeZoneDetails](https://cloud.tencent.com/document/api/1552/74843)

	* 新增出参：Area

* [DescribeZoneSetting](https://cloud.tencent.com/document/api/1552/74820)

	* 新增出参：Area


修改数据结构：

* [ApplicationProxy](https://cloud.tencent.com/document/api/1552/73155#ApplicationProxy)

	* 新增成员：Area, BanStatus

* [L7OfflineLog](https://cloud.tencent.com/document/api/1552/73155#L7OfflineLog)

	* 新增成员：Area

* [Resource](https://cloud.tencent.com/document/api/1552/73155#Resource)

	* 新增成员：Area

* [Zone](https://cloud.tencent.com/document/api/1552/73155#Zone)

	* 新增成员：Area


### 第 19 次发布

发布时间：2022-08-17 06:41:13

本次发布包含了以下内容：

改善已有的文档。

新增数据结构：

* [DdosSpeedLimit](https://cloud.tencent.com/document/api/1552/73155#DdosSpeedLimit)

修改数据结构：

* [DdosRule](https://cloud.tencent.com/document/api/1552/73155#DdosRule)

	* 新增成员：DdosSpeedLimit


### 第 18 次发布

发布时间：2022-08-15 06:42:02

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateApplicationProxy](https://cloud.tencent.com/document/api/1552/74833)

	* 新增入参：Ipv6

* [DescribeApplicationProxy](https://cloud.tencent.com/document/api/1552/74828)

	* 新增入参：ProxyId

* [DescribeApplicationProxyDetail](https://cloud.tencent.com/document/api/1552/74827)

	* 新增出参：Ipv6

* [DescribeZoneSetting](https://cloud.tencent.com/document/api/1552/74820)

	* 新增出参：Ipv6

* [ModifyApplicationProxy](https://cloud.tencent.com/document/api/1552/74826)

	* 新增入参：Ipv6

* [ModifyZoneSetting](https://cloud.tencent.com/document/api/1552/74819)

	* 新增入参：Ipv6


新增数据结构：

* [Ipv6Access](https://cloud.tencent.com/document/api/1552/73155#Ipv6Access)

修改数据结构：

* [ApplicationProxy](https://cloud.tencent.com/document/api/1552/73155#ApplicationProxy)

	* 新增成员：Ipv6

* [Origin](https://cloud.tencent.com/document/api/1552/73155#Origin)

	* 新增成员：Origins, BackupOrigins, CosPrivateAccess


### 第 17 次发布

发布时间：2022-08-11 06:53:53

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeWebManagedRulesData](https://cloud.tencent.com/document/api/1552/75651)

	* 新增入参：QueryCondition

* [DescribeWebManagedRulesTopData](https://cloud.tencent.com/document/api/1552/75649)

	* 新增入参：Interval, QueryCondition

* [DescribeWebProtectionData](https://cloud.tencent.com/document/api/1552/75647)

	* 新增入参：QueryCondition

* [DescribeWebProtectionLog](https://cloud.tencent.com/document/api/1552/75646)

	* 新增入参：EntityType


新增数据结构：

* [SecRuleRelatedInfo](https://cloud.tencent.com/document/api/1552/73155#SecRuleRelatedInfo)

修改数据结构：

* [BotLog](https://cloud.tencent.com/document/api/1552/73155#BotLog)

	* 新增成员：RuleDetailList, Label

* [CCLog](https://cloud.tencent.com/document/api/1552/73155#CCLog)

	* 新增成员：Ua, RequestMethod, RuleDetailList

* [WebLogs](https://cloud.tencent.com/document/api/1552/73155#WebLogs)

	* 新增成员：RuleDetailList


### 第 16 次发布

发布时间：2022-08-04 06:55:59

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [Compression](https://cloud.tencent.com/document/api/1552/73155#Compression)

	* 新增成员：Algorithms


### 第 15 次发布

发布时间：2022-08-03 06:46:50

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [OriginRecord](https://cloud.tencent.com/document/api/1552/73155#OriginRecord)

	* 新增成员：Proto


### 第 14 次发布

发布时间：2022-07-28 06:23:18

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeZoneDetails](https://cloud.tencent.com/document/api/1552/74843)

	* 新增出参：Resources


新增数据结构：

* [Resource](https://cloud.tencent.com/document/api/1552/73155#Resource)
* [Sv](https://cloud.tencent.com/document/api/1552/73155#Sv)

修改数据结构：

* [Zone](https://cloud.tencent.com/document/api/1552/73155#Zone)

	* 新增成员：Resources, CnameSpeedUp


### 第 13 次发布

发布时间：2022-07-12 06:17:57

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateZone](https://cloud.tencent.com/document/api/1552/74851)

	* 新增入参：Tags

* [DescribeZoneDetails](https://cloud.tencent.com/document/api/1552/74843)

	* 新增出参：Tags


新增数据结构：

* [Tag](https://cloud.tencent.com/document/api/1552/73155#Tag)

修改数据结构：

* [Zone](https://cloud.tencent.com/document/api/1552/73155#Zone)

	* 新增成员：Tags


### 第 12 次发布

发布时间：2022-07-05 06:22:14

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeTimingL4Data](https://cloud.tencent.com/document/api/1552/75655)

	* 新增入参：Filters, ProxyIds


新增数据结构：

* [IntelligenceRule](https://cloud.tencent.com/document/api/1552/73155#IntelligenceRule)
* [IntelligenceRuleItem](https://cloud.tencent.com/document/api/1552/73155#IntelligenceRuleItem)
* [IpTableConfig](https://cloud.tencent.com/document/api/1552/73155#IpTableConfig)
* [IpTableRule](https://cloud.tencent.com/document/api/1552/73155#IpTableRule)
* [RateLimitIntelligence](https://cloud.tencent.com/document/api/1552/73155#RateLimitIntelligence)

修改数据结构：

* [BotConfig](https://cloud.tencent.com/document/api/1552/73155#BotConfig)

	* 新增成员：IntelligenceRule

	* <font color="#dd0000">**修改成员**：</font>Switch

* [DDoSAntiPly](https://cloud.tencent.com/document/api/1552/73155#DDoSAntiPly)

	* 新增成员：UdpShard

* [DdosRule](https://cloud.tencent.com/document/api/1552/73155#DdosRule)

	* 新增成员：UdpShardOpen

* [RateLimitConfig](https://cloud.tencent.com/document/api/1552/73155#RateLimitConfig)

	* 新增成员：Intelligence

* [SecurityConfig](https://cloud.tencent.com/document/api/1552/73155#SecurityConfig)

	* 新增成员：IpTableConfig


### 第 11 次发布

发布时间：2022-07-01 06:18:27

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeApplicationProxy](https://cloud.tencent.com/document/api/1552/74828)

	* 新增出参：IpCount, DomainCount

* [DescribeOriginGroupDetail](https://cloud.tencent.com/document/api/1552/75097)

	* 新增出参：LoadBalancingUsedType


新增数据结构：

* [OriginCheckOriginStatus](https://cloud.tencent.com/document/api/1552/73155#OriginCheckOriginStatus)

修改数据结构：

* [OriginGroup](https://cloud.tencent.com/document/api/1552/73155#OriginGroup)

	* 新增成员：Status, LoadBalancingUsedType


### 第 10 次发布

发布时间：2022-06-27 06:15:53

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeZoneSetting](https://cloud.tencent.com/document/api/1552/74820)

	* 新增出参：CachePrefresh

* [ModifyZoneSetting](https://cloud.tencent.com/document/api/1552/74819)

	* 新增入参：CachePrefresh


新增数据结构：

* [CachePrefresh](https://cloud.tencent.com/document/api/1552/73155#CachePrefresh)

### 第 9 次发布

发布时间：2022-06-17 06:14:37

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeTimingL7CacheData](https://cloud.tencent.com/document/api/1552/75726)
* [DescribeTopL7CacheData](https://cloud.tencent.com/document/api/1552/75725)

### 第 8 次发布

发布时间：2022-06-16 06:13:25

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeBotLog](https://cloud.tencent.com/document/api/1552/75663)
* [DescribeDDosAttackData](https://cloud.tencent.com/document/api/1552/75662)
* [DescribeDDosAttackEvent](https://cloud.tencent.com/document/api/1552/75661)
* [DescribeDDosAttackEventDetail](https://cloud.tencent.com/document/api/1552/75660)
* [DescribeDDosAttackSourceEvent](https://cloud.tencent.com/document/api/1552/75659)
* [DescribeDDosAttackTopData](https://cloud.tencent.com/document/api/1552/75658)
* [DescribeDDosMajorAttackEvent](https://cloud.tencent.com/document/api/1552/75657)
* [DescribeOverviewL7Data](https://cloud.tencent.com/document/api/1552/75656)
* [DescribeTimingL4Data](https://cloud.tencent.com/document/api/1552/75655)
* [DescribeTimingL7AnalysisData](https://cloud.tencent.com/document/api/1552/75654)
* [DescribeTopL7AnalysisData](https://cloud.tencent.com/document/api/1552/75653)
* [DescribeWebManagedRulesAttackEvents](https://cloud.tencent.com/document/api/1552/75652)
* [DescribeWebManagedRulesData](https://cloud.tencent.com/document/api/1552/75651)
* [DescribeWebManagedRulesLog](https://cloud.tencent.com/document/api/1552/75650)
* [DescribeWebManagedRulesTopData](https://cloud.tencent.com/document/api/1552/75649)
* [DescribeWebProtectionAttackEvents](https://cloud.tencent.com/document/api/1552/75648)
* [DescribeWebProtectionData](https://cloud.tencent.com/document/api/1552/75647)
* [DescribeWebProtectionLog](https://cloud.tencent.com/document/api/1552/75646)

修改接口：

* [DescribeSecurityPolicyManagedRulesId](https://cloud.tencent.com/document/api/1552/75106)

	* 新增出参：Count


新增数据结构：

* [BotLog](https://cloud.tencent.com/document/api/1552/73155#BotLog)
* [BotLogData](https://cloud.tencent.com/document/api/1552/73155#BotLogData)
* [CCInterceptEvent](https://cloud.tencent.com/document/api/1552/73155#CCInterceptEvent)
* [CCInterceptEventData](https://cloud.tencent.com/document/api/1552/73155#CCInterceptEventData)
* [CCLog](https://cloud.tencent.com/document/api/1552/73155#CCLog)
* [CCLogData](https://cloud.tencent.com/document/api/1552/73155#CCLogData)
* [DDosAttackEvent](https://cloud.tencent.com/document/api/1552/73155#DDosAttackEvent)
* [DDosAttackEventData](https://cloud.tencent.com/document/api/1552/73155#DDosAttackEventData)
* [DDosAttackEventDetailData](https://cloud.tencent.com/document/api/1552/73155#DDosAttackEventDetailData)
* [DDosAttackSourceEvent](https://cloud.tencent.com/document/api/1552/73155#DDosAttackSourceEvent)
* [DDosAttackSourceEventData](https://cloud.tencent.com/document/api/1552/73155#DDosAttackSourceEventData)
* [DDosMajorAttackEvent](https://cloud.tencent.com/document/api/1552/73155#DDosMajorAttackEvent)
* [DDosMajorAttackEventData](https://cloud.tencent.com/document/api/1552/73155#DDosMajorAttackEventData)
* [Filter](https://cloud.tencent.com/document/api/1552/73155#Filter)
* [QueryCondition](https://cloud.tencent.com/document/api/1552/73155#QueryCondition)
* [SecEntry](https://cloud.tencent.com/document/api/1552/73155#SecEntry)
* [SecEntryValue](https://cloud.tencent.com/document/api/1552/73155#SecEntryValue)
* [TimingDataItem](https://cloud.tencent.com/document/api/1552/73155#TimingDataItem)
* [TimingDataRecord](https://cloud.tencent.com/document/api/1552/73155#TimingDataRecord)
* [TimingTypeValue](https://cloud.tencent.com/document/api/1552/73155#TimingTypeValue)
* [TopDataRecord](https://cloud.tencent.com/document/api/1552/73155#TopDataRecord)
* [TopDetailData](https://cloud.tencent.com/document/api/1552/73155#TopDetailData)
* [TopNEntry](https://cloud.tencent.com/document/api/1552/73155#TopNEntry)
* [TopNEntryValue](https://cloud.tencent.com/document/api/1552/73155#TopNEntryValue)
* [WebAttackEvent](https://cloud.tencent.com/document/api/1552/73155#WebAttackEvent)
* [WebEventData](https://cloud.tencent.com/document/api/1552/73155#WebEventData)
* [WebLogData](https://cloud.tencent.com/document/api/1552/73155#WebLogData)
* [WebLogs](https://cloud.tencent.com/document/api/1552/73155#WebLogs)

### 第 7 次发布

发布时间：2022-06-14 06:18:08

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeSecurityPortraitRules](https://cloud.tencent.com/document/api/1552/75505)

新增数据结构：

* [PortraitManagedRuleDetail](https://cloud.tencent.com/document/api/1552/73155#PortraitManagedRuleDetail)

修改数据结构：

* [BotPortraitRule](https://cloud.tencent.com/document/api/1552/73155#BotPortraitRule)

	* 新增成员：Switch


### 第 6 次发布

发布时间：2022-06-08 06:16:20

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateCustomErrorPage](https://cloud.tencent.com/document/api/1552/75112)
* [CreateOriginGroup](https://cloud.tencent.com/document/api/1552/75113)
* [DeleteOriginGroup](https://cloud.tencent.com/document/api/1552/75099)
* [DescribeBotManagedRules](https://cloud.tencent.com/document/api/1552/75111)
* [DescribeDDoSPolicy](https://cloud.tencent.com/document/api/1552/75110)
* [DescribeOriginGroup](https://cloud.tencent.com/document/api/1552/75098)
* [DescribeOriginGroupDetail](https://cloud.tencent.com/document/api/1552/75097)
* [DescribeSecurityPolicy](https://cloud.tencent.com/document/api/1552/75109)
* [DescribeSecurityPolicyList](https://cloud.tencent.com/document/api/1552/75108)
* [DescribeSecurityPolicyManagedRules](https://cloud.tencent.com/document/api/1552/75107)
* [DescribeSecurityPolicyManagedRulesId](https://cloud.tencent.com/document/api/1552/75106)
* [DescribeSecurityPolicyRegions](https://cloud.tencent.com/document/api/1552/75105)
* [DescribeZoneDDoSPolicy](https://cloud.tencent.com/document/api/1552/75104)
* [ModifyDDoSPolicy](https://cloud.tencent.com/document/api/1552/75103)
* [ModifyDDoSPolicyHost](https://cloud.tencent.com/document/api/1552/75102)
* [ModifyOriginGroup](https://cloud.tencent.com/document/api/1552/75096)
* [ModifySecurityPolicy](https://cloud.tencent.com/document/api/1552/75101)

新增数据结构：

* [ACLCondition](https://cloud.tencent.com/document/api/1552/73155#ACLCondition)
* [ACLUserRule](https://cloud.tencent.com/document/api/1552/73155#ACLUserRule)
* [AclConfig](https://cloud.tencent.com/document/api/1552/73155#AclConfig)
* [AiRule](https://cloud.tencent.com/document/api/1552/73155#AiRule)
* [BotConfig](https://cloud.tencent.com/document/api/1552/73155#BotConfig)
* [BotManagedRule](https://cloud.tencent.com/document/api/1552/73155#BotManagedRule)
* [BotManagedRuleDetail](https://cloud.tencent.com/document/api/1552/73155#BotManagedRuleDetail)
* [BotPortraitRule](https://cloud.tencent.com/document/api/1552/73155#BotPortraitRule)
* [DDoSAcl](https://cloud.tencent.com/document/api/1552/73155#DDoSAcl)
* [DDoSAntiPly](https://cloud.tencent.com/document/api/1552/73155#DDoSAntiPly)
* [DDoSApplication](https://cloud.tencent.com/document/api/1552/73155#DDoSApplication)
* [DDoSConfig](https://cloud.tencent.com/document/api/1552/73155#DDoSConfig)
* [DDoSFeaturesFilter](https://cloud.tencent.com/document/api/1552/73155#DDoSFeaturesFilter)
* [DDoSGeoIp](https://cloud.tencent.com/document/api/1552/73155#DDoSGeoIp)
* [DDoSStatusInfo](https://cloud.tencent.com/document/api/1552/73155#DDoSStatusInfo)
* [DDoSUserAllowBlockIP](https://cloud.tencent.com/document/api/1552/73155#DDoSUserAllowBlockIP)
* [DdosAcls](https://cloud.tencent.com/document/api/1552/73155#DdosAcls)
* [DdosAllowBlock](https://cloud.tencent.com/document/api/1552/73155#DdosAllowBlock)
* [DdosPacketFilter](https://cloud.tencent.com/document/api/1552/73155#DdosPacketFilter)
* [DdosRule](https://cloud.tencent.com/document/api/1552/73155#DdosRule)
* [GeoIp](https://cloud.tencent.com/document/api/1552/73155#GeoIp)
* [ManagedRule](https://cloud.tencent.com/document/api/1552/73155#ManagedRule)
* [OriginFilter](https://cloud.tencent.com/document/api/1552/73155#OriginFilter)
* [RateLimitConfig](https://cloud.tencent.com/document/api/1552/73155#RateLimitConfig)
* [RateLimitTemplate](https://cloud.tencent.com/document/api/1552/73155#RateLimitTemplate)
* [RateLimitTemplateDetail](https://cloud.tencent.com/document/api/1552/73155#RateLimitTemplateDetail)
* [RateLimitUserRule](https://cloud.tencent.com/document/api/1552/73155#RateLimitUserRule)
* [SecurityConfig](https://cloud.tencent.com/document/api/1552/73155#SecurityConfig)
* [SecurityEntity](https://cloud.tencent.com/document/api/1552/73155#SecurityEntity)
* [ShieldArea](https://cloud.tencent.com/document/api/1552/73155#ShieldArea)
* [SwitchConfig](https://cloud.tencent.com/document/api/1552/73155#SwitchConfig)
* [WafConfig](https://cloud.tencent.com/document/api/1552/73155#WafConfig)
* [WafRule](https://cloud.tencent.com/document/api/1552/73155#WafRule)

### 第 5 次发布

发布时间：2022-06-02 06:14:38

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CheckCertificate](https://cloud.tencent.com/document/api/1552/74817)
* [CreateApplicationProxy](https://cloud.tencent.com/document/api/1552/74833)
* [CreateApplicationProxyRule](https://cloud.tencent.com/document/api/1552/74832)
* [CreateApplicationProxyRules](https://cloud.tencent.com/document/api/1552/74831)
* [CreateDnsRecord](https://cloud.tencent.com/document/api/1552/74852)
* [CreateLoadBalancing](https://cloud.tencent.com/document/api/1552/74811)
* [CreateZone](https://cloud.tencent.com/document/api/1552/74851)
* [DeleteApplicationProxy](https://cloud.tencent.com/document/api/1552/74830)
* [DeleteApplicationProxyRule](https://cloud.tencent.com/document/api/1552/74829)
* [DeleteDnsRecords](https://cloud.tencent.com/document/api/1552/74850)
* [DeleteLoadBalancing](https://cloud.tencent.com/document/api/1552/74810)
* [DeleteZone](https://cloud.tencent.com/document/api/1552/74849)
* [DescribeApplicationProxy](https://cloud.tencent.com/document/api/1552/74828)
* [DescribeApplicationProxyDetail](https://cloud.tencent.com/document/api/1552/74827)
* [DescribeCnameStatus](https://cloud.tencent.com/document/api/1552/74848)
* [DescribeDefaultCertificates](https://cloud.tencent.com/document/api/1552/74816)
* [DescribeDnsData](https://cloud.tencent.com/document/api/1552/74847)
* [DescribeDnsRecords](https://cloud.tencent.com/document/api/1552/74846)
* [DescribeDnssec](https://cloud.tencent.com/document/api/1552/74845)
* [DescribeHostsCertificate](https://cloud.tencent.com/document/api/1552/74815)
* [DescribeHostsSetting](https://cloud.tencent.com/document/api/1552/74821)
* [DescribeIdentification](https://cloud.tencent.com/document/api/1552/74844)
* [DescribeLoadBalancing](https://cloud.tencent.com/document/api/1552/74809)
* [DescribeLoadBalancingDetail](https://cloud.tencent.com/document/api/1552/74808)
* [DescribeZoneDetails](https://cloud.tencent.com/document/api/1552/74843)
* [DescribeZoneSetting](https://cloud.tencent.com/document/api/1552/74820)
* [IdentifyZone](https://cloud.tencent.com/document/api/1552/74842)
* [ImportDnsRecords](https://cloud.tencent.com/document/api/1552/74841)
* [ModifyApplicationProxy](https://cloud.tencent.com/document/api/1552/74826)
* [ModifyApplicationProxyRule](https://cloud.tencent.com/document/api/1552/74825)
* [ModifyApplicationProxyRuleStatus](https://cloud.tencent.com/document/api/1552/74824)
* [ModifyApplicationProxyStatus](https://cloud.tencent.com/document/api/1552/74823)
* [ModifyDefaultCertificate](https://cloud.tencent.com/document/api/1552/74814)
* [ModifyDnsRecord](https://cloud.tencent.com/document/api/1552/74840)
* [ModifyDnssec](https://cloud.tencent.com/document/api/1552/74839)
* [ModifyHostsCertificate](https://cloud.tencent.com/document/api/1552/74813)
* [ModifyLoadBalancing](https://cloud.tencent.com/document/api/1552/74807)
* [ModifyLoadBalancingStatus](https://cloud.tencent.com/document/api/1552/74806)
* [ModifyZone](https://cloud.tencent.com/document/api/1552/74838)
* [ModifyZoneCnameSpeedUp](https://cloud.tencent.com/document/api/1552/74837)
* [ModifyZoneSetting](https://cloud.tencent.com/document/api/1552/74819)
* [ModifyZoneStatus](https://cloud.tencent.com/document/api/1552/74836)
* [ReclaimZone](https://cloud.tencent.com/document/api/1552/74835)
* [ScanDnsRecords](https://cloud.tencent.com/document/api/1552/74834)

新增数据结构：

* [ApplicationProxy](https://cloud.tencent.com/document/api/1552/73155#ApplicationProxy)
* [ApplicationProxyRule](https://cloud.tencent.com/document/api/1552/73155#ApplicationProxyRule)
* [CacheConfig](https://cloud.tencent.com/document/api/1552/73155#CacheConfig)
* [CacheConfigCache](https://cloud.tencent.com/document/api/1552/73155#CacheConfigCache)
* [CacheConfigFollowOrigin](https://cloud.tencent.com/document/api/1552/73155#CacheConfigFollowOrigin)
* [CacheConfigNoCache](https://cloud.tencent.com/document/api/1552/73155#CacheConfigNoCache)
* [CacheKey](https://cloud.tencent.com/document/api/1552/73155#CacheKey)
* [CertFilter](https://cloud.tencent.com/document/api/1552/73155#CertFilter)
* [CertSort](https://cloud.tencent.com/document/api/1552/73155#CertSort)
* [ClientIp](https://cloud.tencent.com/document/api/1552/73155#ClientIp)
* [CnameStatus](https://cloud.tencent.com/document/api/1552/73155#CnameStatus)
* [Compression](https://cloud.tencent.com/document/api/1552/73155#Compression)
* [DataItem](https://cloud.tencent.com/document/api/1552/73155#DataItem)
* [DefaultServerCertInfo](https://cloud.tencent.com/document/api/1552/73155#DefaultServerCertInfo)
* [DetailHost](https://cloud.tencent.com/document/api/1552/73155#DetailHost)
* [DnsDataFilter](https://cloud.tencent.com/document/api/1552/73155#DnsDataFilter)
* [DnsRecord](https://cloud.tencent.com/document/api/1552/73155#DnsRecord)
* [DnsRecordFilter](https://cloud.tencent.com/document/api/1552/73155#DnsRecordFilter)
* [DnssecInfo](https://cloud.tencent.com/document/api/1552/73155#DnssecInfo)
* [ForceRedirect](https://cloud.tencent.com/document/api/1552/73155#ForceRedirect)
* [HostCertSetting](https://cloud.tencent.com/document/api/1552/73155#HostCertSetting)
* [Hsts](https://cloud.tencent.com/document/api/1552/73155#Hsts)
* [Https](https://cloud.tencent.com/document/api/1552/73155#Https)
* [LoadBalancing](https://cloud.tencent.com/document/api/1552/73155#LoadBalancing)
* [MaxAge](https://cloud.tencent.com/document/api/1552/73155#MaxAge)
* [OfflineCache](https://cloud.tencent.com/document/api/1552/73155#OfflineCache)
* [Origin](https://cloud.tencent.com/document/api/1552/73155#Origin)
* [OriginGroup](https://cloud.tencent.com/document/api/1552/73155#OriginGroup)
* [OriginRecord](https://cloud.tencent.com/document/api/1552/73155#OriginRecord)
* [OriginRecordPrivateParameter](https://cloud.tencent.com/document/api/1552/73155#OriginRecordPrivateParameter)
* [PostMaxSize](https://cloud.tencent.com/document/api/1552/73155#PostMaxSize)
* [QueryString](https://cloud.tencent.com/document/api/1552/73155#QueryString)
* [Quic](https://cloud.tencent.com/document/api/1552/73155#Quic)
* [ServerCertInfo](https://cloud.tencent.com/document/api/1552/73155#ServerCertInfo)
* [SmartRouting](https://cloud.tencent.com/document/api/1552/73155#SmartRouting)
* [UpstreamHttp2](https://cloud.tencent.com/document/api/1552/73155#UpstreamHttp2)
* [VanityNameServers](https://cloud.tencent.com/document/api/1552/73155#VanityNameServers)
* [VanityNameServersIps](https://cloud.tencent.com/document/api/1552/73155#VanityNameServersIps)
* [WebSocket](https://cloud.tencent.com/document/api/1552/73155#WebSocket)

修改数据结构：

* [Zone](https://cloud.tencent.com/document/api/1552/73155#Zone)

	* 新增成员：CnameStatus


### 第 4 次发布

发布时间：2022-05-18 06:18:03

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DownloadL7Logs](https://cloud.tencent.com/document/api/1552/73899)

新增数据结构：

* [L7OfflineLog](https://cloud.tencent.com/document/api/1552/73155#L7OfflineLog)

### 第 3 次发布

发布时间：2022-05-09 06:14:50

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreatePrefetchTask](https://cloud.tencent.com/document/api/1552/73476)
* [DescribePrefetchTasks](https://cloud.tencent.com/document/api/1552/73475)

新增数据结构：

* [Header](https://cloud.tencent.com/document/api/1552/73155#Header)

### 第 2 次发布

发布时间：2022-05-06 06:16:42

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeZones](https://cloud.tencent.com/document/api/1552/73423)

新增数据结构：

* [Zone](https://cloud.tencent.com/document/api/1552/73155#Zone)
* [ZoneFilter](https://cloud.tencent.com/document/api/1552/73155#ZoneFilter)

### 第 1 次发布

发布时间：2022-04-28 14:45:34

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreatePurgeTask](https://cloud.tencent.com/document/api/1552/73154)
* [DescribePurgeTasks](https://cloud.tencent.com/document/api/1552/73153)

新增数据结构：

* [FailReason](https://cloud.tencent.com/document/api/1552/73155#FailReason)
* [Task](https://cloud.tencent.com/document/api/1552/73155#Task)



## 边缘安全加速平台(teo) 版本：2022-09-01

### 第 83 次发布

发布时间：2024-07-03 01:25:21

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [ModifyHostsCertificate](https://cloud.tencent.com/document/api/1552/80764)

	* 新增入参：ClientCertInfo


新增数据结构：

* [MutualTLS](https://cloud.tencent.com/document/api/1552/80721#MutualTLS)

修改数据结构：

* [AccelerationDomainCertificate](https://cloud.tencent.com/document/api/1552/80721#AccelerationDomainCertificate)

	* 新增成员：ClientCertInfo

* [CertificateInfo](https://cloud.tencent.com/document/api/1552/80721#CertificateInfo)

	* <font color="#dd0000">**修改成员**：</font>Alias, Type, ExpireTime, DeployTime, SignAlgo, Status


### 第 82 次发布

发布时间：2024-06-07 12:08:08

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateCustomizeErrorPage](https://cloud.tencent.com/document/api/1552/107118)
* [DeleteCustomErrorPage](https://cloud.tencent.com/document/api/1552/107117)
* [DescribeCustomErrorPages](https://cloud.tencent.com/document/api/1552/107116)
* [ModifyCustomErrorPage](https://cloud.tencent.com/document/api/1552/107115)

新增数据结构：

* [CustomErrorPage](https://cloud.tencent.com/document/api/1552/80721#CustomErrorPage)
* [ErrorPageReference](https://cloud.tencent.com/document/api/1552/80721#ErrorPageReference)

### 第 81 次发布

发布时间：2024-05-29 19:42:22

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [Rule](https://cloud.tencent.com/document/api/1552/80721#Rule)

	* <font color="#dd0000">**修改成员**：</font>Actions


### 第 80 次发布

发布时间：2024-05-10 02:31:21

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreatePurgeTask](https://cloud.tencent.com/document/api/1552/80703)

	* 新增入参：CacheTag


新增数据结构：

* [CacheTag](https://cloud.tencent.com/document/api/1552/80721#CacheTag)

修改数据结构：

* [Task](https://cloud.tencent.com/document/api/1552/80721#Task)

	* 新增成员：Method


### 第 79 次发布

发布时间：2024-05-07 17:48:36

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeSecurityIPGroup](https://cloud.tencent.com/document/api/1552/105866)

### 第 78 次发布

发布时间：2024-04-29 16:57:36

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreatePlan](https://cloud.tencent.com/document/api/1552/105771)
* [DestroyPlan](https://cloud.tencent.com/document/api/1552/105770)
* [IncreasePlanQuota](https://cloud.tencent.com/document/api/1552/105769)
* [ModifyPlan](https://cloud.tencent.com/document/api/1552/105768)
* [RenewPlan](https://cloud.tencent.com/document/api/1552/105767)
* [UpgradePlan](https://cloud.tencent.com/document/api/1552/105766)

新增数据结构：

* [PrepaidPlanParam](https://cloud.tencent.com/document/api/1552/80721#PrepaidPlanParam)
* [RenewFlag](https://cloud.tencent.com/document/api/1552/80721#RenewFlag)

### 第 77 次发布

发布时间：2024-04-26 01:25:17

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateRealtimeLogDeliveryTask](https://cloud.tencent.com/document/api/1552/104112)

	* 新增入参：LogFormat

* [ModifyRealtimeLogDeliveryTask](https://cloud.tencent.com/document/api/1552/104109)

	* 新增入参：LogFormat


新增数据结构：

* [LogFormat](https://cloud.tencent.com/document/api/1552/80721#LogFormat)

修改数据结构：

* [RealtimeLogDeliveryTask](https://cloud.tencent.com/document/api/1552/80721#RealtimeLogDeliveryTask)

	* 新增成员：LogFormat


### 第 76 次发布

发布时间：2024-03-13 01:24:49

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeSecurityIPGroupInfo](https://cloud.tencent.com/document/api/1552/104305)

### 第 75 次发布

发布时间：2024-03-06 01:24:59

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateCLSIndex](https://cloud.tencent.com/document/api/1552/104113)
* [CreateRealtimeLogDeliveryTask](https://cloud.tencent.com/document/api/1552/104112)
* [DeleteRealtimeLogDeliveryTask](https://cloud.tencent.com/document/api/1552/104111)
* [DescribeRealtimeLogDeliveryTasks](https://cloud.tencent.com/document/api/1552/104110)
* [ModifyRealtimeLogDeliveryTask](https://cloud.tencent.com/document/api/1552/104109)

新增数据结构：

* [CLSTopic](https://cloud.tencent.com/document/api/1552/80721#CLSTopic)
* [CustomEndpoint](https://cloud.tencent.com/document/api/1552/80721#CustomEndpoint)
* [CustomField](https://cloud.tencent.com/document/api/1552/80721#CustomField)
* [DeliveryCondition](https://cloud.tencent.com/document/api/1552/80721#DeliveryCondition)
* [RealtimeLogDeliveryTask](https://cloud.tencent.com/document/api/1552/80721#RealtimeLogDeliveryTask)
* [S3](https://cloud.tencent.com/document/api/1552/80721#S3)

### 第 74 次发布

发布时间：2024-02-29 01:25:10

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [L4ProxyRule](https://cloud.tencent.com/document/api/1552/80721#L4ProxyRule)

	* 新增成员：BuId


### 第 73 次发布

发布时间：2024-01-30 01:24:01

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeApplicationProxies](https://cloud.tencent.com/document/api/1552/80690)

	* 新增入参：ZoneId


### 第 72 次发布

发布时间：2024-01-27 19:39:47

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeBillingData](https://cloud.tencent.com/document/api/1552/103562)

新增数据结构：

* [BillingData](https://cloud.tencent.com/document/api/1552/80721#BillingData)
* [BillingDataFilter](https://cloud.tencent.com/document/api/1552/80721#BillingDataFilter)

### 第 71 次发布

发布时间：2024-01-25 11:46:06

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateL4Proxy](https://cloud.tencent.com/document/api/1552/103417)
* [CreateL4ProxyRules](https://cloud.tencent.com/document/api/1552/103416)
* [DeleteL4Proxy](https://cloud.tencent.com/document/api/1552/103415)
* [DeleteL4ProxyRules](https://cloud.tencent.com/document/api/1552/103414)
* [DescribeL4Proxy](https://cloud.tencent.com/document/api/1552/103413)
* [DescribeL4ProxyRules](https://cloud.tencent.com/document/api/1552/103412)
* [ModifyL4Proxy](https://cloud.tencent.com/document/api/1552/103411)
* [ModifyL4ProxyRules](https://cloud.tencent.com/document/api/1552/103410)
* [ModifyL4ProxyRulesStatus](https://cloud.tencent.com/document/api/1552/103409)
* [ModifyL4ProxyStatus](https://cloud.tencent.com/document/api/1552/103408)

新增数据结构：

* [DDosProtectionConfig](https://cloud.tencent.com/document/api/1552/80721#DDosProtectionConfig)
* [L4Proxy](https://cloud.tencent.com/document/api/1552/80721#L4Proxy)
* [L4ProxyRule](https://cloud.tencent.com/document/api/1552/80721#L4ProxyRule)

### 第 70 次发布

发布时间：2024-01-19 01:22:03

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeDefaultCertificates](https://cloud.tencent.com/document/api/1552/80603)

	* 新增入参：ZoneId

	* <font color="#dd0000">**修改入参**：</font>Filters


### 第 69 次发布

发布时间：2024-01-08 00:19:23

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [RateLimitTemplateDetail](https://cloud.tencent.com/document/api/1552/80721#RateLimitTemplateDetail)

	* <font color="#dd0000">**修改成员**：</font>ID, Action, PunishTime, Threshold, Period


### 第 68 次发布

发布时间：2023-12-06 12:21:14

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeIPRegion](https://cloud.tencent.com/document/api/1552/102227)

新增数据结构：

* [IPRegionInfo](https://cloud.tencent.com/document/api/1552/80721#IPRegionInfo)

### 第 67 次发布

发布时间：2023-12-06 02:32:56

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [OriginDetail](https://cloud.tencent.com/document/api/1552/80721#OriginDetail)

	* 新增成员：VodeoSubAppId, VodeoDistributionRange, VodeoBucketId

* [OriginInfo](https://cloud.tencent.com/document/api/1552/80721#OriginInfo)

	* 新增成员：VodeoSubAppId, VodeoDistributionRange, VodeoBucketId

* [Resource](https://cloud.tencent.com/document/api/1552/80721#Resource)

	* 新增成员：Type


### 第 66 次发布

发布时间：2023-11-28 01:26:13

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [Identification](https://cloud.tencent.com/document/api/1552/80721#Identification)

	* <font color="#dd0000">**修改成员**：</font>Domain


### 第 65 次发布

发布时间：2023-11-23 17:11:36

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateConfigGroupVersion](https://cloud.tencent.com/document/api/1552/101867)
* [DeployConfigGroupVersion](https://cloud.tencent.com/document/api/1552/101866)
* [DescribeConfigGroupVersionDetail](https://cloud.tencent.com/document/api/1552/101865)
* [DescribeConfigGroupVersions](https://cloud.tencent.com/document/api/1552/101864)
* [DescribeDeployHistory](https://cloud.tencent.com/document/api/1552/101863)
* [DescribeEnvironments](https://cloud.tencent.com/document/api/1552/101862)

新增数据结构：

* [ConfigGroupVersionInfo](https://cloud.tencent.com/document/api/1552/80721#ConfigGroupVersionInfo)
* [DeployRecord](https://cloud.tencent.com/document/api/1552/80721#DeployRecord)
* [EnvInfo](https://cloud.tencent.com/document/api/1552/80721#EnvInfo)

### 第 64 次发布

发布时间：2023-11-22 06:42:38

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribePrefetchTasks](https://cloud.tencent.com/document/api/1552/80700)

	* 新增入参：ZoneId


### 第 63 次发布

发布时间：2023-11-07 16:01:35

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [BindSharedCNAME](https://cloud.tencent.com/document/api/1552/101363)
* [DeleteSharedCNAME](https://cloud.tencent.com/document/api/1552/101362)

新增数据结构：

* [BindSharedCNAMEMap](https://cloud.tencent.com/document/api/1552/80721#BindSharedCNAMEMap)

### 第 62 次发布

发布时间：2023-11-01 11:21:19

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [OriginGroup](https://cloud.tencent.com/document/api/1552/80721#OriginGroup)

	* 新增成员：HostHeader


### 第 61 次发布

发布时间：2023-10-27 10:26:11

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [BindSecurityTemplateToEntity](https://cloud.tencent.com/document/api/1552/100814)

### 第 60 次发布

发布时间：2023-10-27 02:20:11

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeSecurityTemplateBindings](https://cloud.tencent.com/document/api/1552/100811)

修改接口：

* [CreateOriginGroup](https://cloud.tencent.com/document/api/1552/80598)

	* 新增入参：HostHeader

* [ModifyOriginGroup](https://cloud.tencent.com/document/api/1552/80592)

	* 新增入参：HostHeader


新增数据结构：

* [EntityStatus](https://cloud.tencent.com/document/api/1552/80721#EntityStatus)
* [SecurityTemplateBinding](https://cloud.tencent.com/document/api/1552/80721#SecurityTemplateBinding)
* [TemplateScope](https://cloud.tencent.com/document/api/1552/80721#TemplateScope)

### 第 59 次发布

发布时间：2023-10-26 01:24:50

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateAccelerationDomain](https://cloud.tencent.com/document/api/1552/86338)

	* 新增入参：IPv6Status

* [ModifyAccelerationDomain](https://cloud.tencent.com/document/api/1552/86335)

	* 新增入参：IPv6Status

	* <font color="#dd0000">**修改入参**：</font>OriginInfo


### 第 58 次发布

发布时间：2023-10-25 15:06:46

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateOriginGroup](https://cloud.tencent.com/document/api/1552/80598)
* [DeleteOriginGroup](https://cloud.tencent.com/document/api/1552/80596)
* [ModifyOriginGroup](https://cloud.tencent.com/document/api/1552/80592)

修改接口：

* [CreateAccelerationDomain](https://cloud.tencent.com/document/api/1552/86338)

	* 新增入参：OriginProtocol, HttpOriginPort, HttpsOriginPort

* [DescribeOriginGroup](https://cloud.tencent.com/document/api/1552/80594)

	* 新增入参：ZoneId

	* <font color="#dd0000">**修改入参**：</font>Offset, Limit

* [ModifyAccelerationDomain](https://cloud.tencent.com/document/api/1552/86335)

	* 新增入参：OriginProtocol, HttpOriginPort, HttpsOriginPort


新增数据结构：

* [OriginGroupReference](https://cloud.tencent.com/document/api/1552/80721#OriginGroupReference)

修改数据结构：

* [AccelerationDomain](https://cloud.tencent.com/document/api/1552/80721#AccelerationDomain)

	* 新增成员：OriginProtocol, HttpOriginPort, HttpsOriginPort, IPv6Status

* [OriginGroup](https://cloud.tencent.com/document/api/1552/80721#OriginGroup)

	* 新增成员：GroupId, Name, Type, Records, References, CreateTime

	* <font color="#dd0000">**删除成员**：</font>ZoneId, ZoneName, OriginGroupId, OriginType, OriginGroupName, ConfigurationType, OriginRecords, HostHeader

	* <font color="#dd0000">**修改成员**：</font>UpdateTime

* [OriginRecord](https://cloud.tencent.com/document/api/1552/80721#OriginRecord)

	* 新增成员：Type

	* <font color="#dd0000">**删除成员**：</font>Port, Proto, Area


### 第 57 次发布

发布时间：2023-10-11 02:31:17

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [AclUserRule](https://cloud.tencent.com/document/api/1552/80721#AclUserRule)

	* 新增成员：CustomResponseId

* [BotUserRule](https://cloud.tencent.com/document/api/1552/80721#BotUserRule)

	* 新增成员：Name, CustomResponseId, ResponseCode, RedirectUrl

* [DropPageDetail](https://cloud.tencent.com/document/api/1552/80721#DropPageDetail)

	* 新增成员：CustomResponseId

* [RateLimitUserRule](https://cloud.tencent.com/document/api/1552/80721#RateLimitUserRule)

	* 新增成员：Name, CustomResponseId, ResponseCode, RedirectUrl


### 第 56 次发布

发布时间：2023-10-10 01:53:07

本次发布包含了以下内容：

改善已有的文档。

<font color="#dd0000">**删除接口**：</font>

* CreateOriginGroup
* DeleteOriginGroup
* ModifyOriginGroup

### 第 55 次发布

发布时间：2023-09-28 01:23:06

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [RuleCondition](https://cloud.tencent.com/document/api/1552/80721#RuleCondition)


### 第 54 次发布

发布时间：2023-09-27 12:55:42

本次发布包含了以下内容：

改善已有的文档。

新增数据结构：

* [AccelerationDomainCertificate](https://cloud.tencent.com/document/api/1552/80721#AccelerationDomainCertificate)
* [CertificateInfo](https://cloud.tencent.com/document/api/1552/80721#CertificateInfo)

修改数据结构：

* [AccelerationDomain](https://cloud.tencent.com/document/api/1552/80721#AccelerationDomain)

	* 新增成员：Certificate


### 第 53 次发布

发布时间：2023-09-27 01:25:45

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [VerifyOwnership](https://cloud.tencent.com/document/api/1552/98879)

### 第 52 次发布

发布时间：2023-09-26 01:32:17

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateAccelerationDomain](https://cloud.tencent.com/document/api/1552/86338)

	* 新增出参：OwnershipVerification

* [CreateZone](https://cloud.tencent.com/document/api/1552/80719)

	* 新增入参：Area, PlanId

	* 新增出参：OwnershipVerification

* [ModifyHostsCertificate](https://cloud.tencent.com/document/api/1552/80764)

	* 新增入参：Mode


新增数据结构：

* [DnsVerification](https://cloud.tencent.com/document/api/1552/80721#DnsVerification)
* [FileVerification](https://cloud.tencent.com/document/api/1552/80721#FileVerification)
* [NsVerification](https://cloud.tencent.com/document/api/1552/80721#NsVerification)
* [OwnershipVerification](https://cloud.tencent.com/document/api/1552/80721#OwnershipVerification)

修改数据结构：

* [AccelerationDomain](https://cloud.tencent.com/document/api/1552/80721#AccelerationDomain)

	* 新增成员：OwnershipVerification

	* <font color="#dd0000">**修改成员**：</font>ZoneId, DomainName, DomainStatus, OriginDetail, Cname, IdentificationStatus, CreatedOn, ModifiedOn

* [Zone](https://cloud.tencent.com/document/api/1552/80721#Zone)

	* 新增成员：OwnershipVerification

	* <font color="#dd0000">**修改成员**：</font>LockStatus


### 第 51 次发布

发布时间：2023-09-13 02:30:58

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [OriginDetail](https://cloud.tencent.com/document/api/1552/80721#OriginDetail)

	* <font color="#dd0000">**修改成员**：</font>OriginType, Origin, BackupOrigin, OriginGroupName, BackOriginGroupName, PrivateAccess, PrivateParameters


### 第 50 次发布

发布时间：2023-09-05 07:43:47

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateSharedCNAME](https://cloud.tencent.com/document/api/1552/97762)

### 第 49 次发布

发布时间：2023-08-16 01:45:46

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateApplicationProxyRule](https://cloud.tencent.com/document/api/1552/80693)

	* 新增入参：RuleTag


修改数据结构：

* [ApplicationProxyRule](https://cloud.tencent.com/document/api/1552/80721#ApplicationProxyRule)

	* 新增成员：RuleTag


### 第 48 次发布

发布时间：2023-08-15 01:40:49

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [ModifyApplicationProxyRule](https://cloud.tencent.com/document/api/1552/80688)

	* 新增入参：RuleTag


### 第 47 次发布

发布时间：2023-08-04 01:18:31

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [L4OfflineLog](https://cloud.tencent.com/document/api/1552/80721#L4OfflineLog)

	* 新增成员：LogStartTime, LogEndTime

* [L7OfflineLog](https://cloud.tencent.com/document/api/1552/80721#L7OfflineLog)

	* 新增成员：LogStartTime, LogEndTime

* [Resource](https://cloud.tencent.com/document/api/1552/80721#Resource)

	* <font color="#dd0000">**修改成员**：</font>Group, ZoneNumber


### 第 46 次发布

发布时间：2023-07-31 01:43:23

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [ApplicationProxy](https://cloud.tencent.com/document/api/1552/80721#ApplicationProxy)

	* <font color="#dd0000">**修改成员**：</font>ProxyId, AccelerateMainland


### 第 45 次发布

发布时间：2023-07-06 01:59:03

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [ModifyZoneSetting](https://cloud.tencent.com/document/api/1552/80614)

	* 新增入参：StandardDebug


新增数据结构：

* [StandardDebug](https://cloud.tencent.com/document/api/1552/80721#StandardDebug)

修改数据结构：

* [ZoneSetting](https://cloud.tencent.com/document/api/1552/80721#ZoneSetting)

	* 新增成员：StandardDebug

	* <font color="#dd0000">**修改成员**：</font>AccelerateMainland


### 第 44 次发布

发布时间：2023-07-05 11:45:45

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CheckCnameStatus](https://cloud.tencent.com/document/api/1552/94491)

<font color="#dd0000">**删除接口**：</font>

* CheckCertificate
* CreateCredential
* CreateReplayTask
* CreateSpeedTesting
* DescribeAddableEntityList
* DescribeClientRuleList
* DescribeDnsData
* DescribeLogSets
* DescribeLogTopicTasks
* DescribeSingleL7AnalysisData
* DescribeSpeedTestingDetails
* DescribeSpeedTestingMetricData
* DescribeSpeedTestingQuota
* DescribeTimingL7SourceData
* DescribeWebManagedRulesData
* DescribeWebManagedRulesHitRuleDetail
* DescribeWebManagedRulesLog
* DescribeWebProtectionClientIpList
* DescribeWebProtectionData
* DescribeWebProtectionHitRuleDetail
* DescribeWebProtectionTopData
* ModifyDefaultCertificate
* ModifyRulePriority
* ModifySecurityWafGroupPolicy
* ReclaimAliasDomain
* ReclaimZone
* UpdateOriginProtectionIPWhitelist

修改接口：

* [CreateApplicationProxyRule](https://cloud.tencent.com/document/api/1552/80693)

	* 新增入参：SessionPersistTime

* [CreatePurgeTask](https://cloud.tencent.com/document/api/1552/80703)

	* 新增入参：Method

* [CreateZone](https://cloud.tencent.com/document/api/1552/80719)

	* <font color="#dd0000">**修改入参**：</font>ZoneName

* [ModifyApplicationProxyRule](https://cloud.tencent.com/document/api/1552/80688)

	* 新增入参：SessionPersistTime

* [ModifyZone](https://cloud.tencent.com/document/api/1552/80709)

	* 新增入参：Area, ZoneName


新增数据结构：

* [CnameStatus](https://cloud.tencent.com/document/api/1552/80721#CnameStatus)

<font color="#dd0000">**删除数据结构**：</font>

* ClientRule
* ClsLogTopicInfo
* DistrictStatistics
* DnsData
* LogSetInfo
* OptimizeAction
* SecClientIp
* SecHitRuleInfo
* SecRuleRelatedInfo
* SingleDataRecord
* SingleTypeValue
* SpeedTestingConfig
* SpeedTestingDetailData
* SpeedTestingInfo
* SpeedTestingMetricData
* SpeedTestingQuota
* SpeedTestingStatistics
* SpeedTestingStatus
* WafGroup
* WebLogs

修改数据结构：

* [ApplicationProxyRule](https://cloud.tencent.com/document/api/1552/80721#ApplicationProxyRule)

	* 新增成员：SessionPersistTime

* [Cache](https://cloud.tencent.com/document/api/1552/80721#Cache)

* [Resource](https://cloud.tencent.com/document/api/1552/80721#Resource)

	* 新增成员：Group, ZoneNumber

* [Sv](https://cloud.tencent.com/document/api/1552/80721#Sv)

	* 新增成员：Pack, InstanceId, ProtectionSpecs


### 第 43 次发布

发布时间：2023-05-18 01:56:23

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [ApplicationProxy](https://cloud.tencent.com/document/api/1552/80721#ApplicationProxy)

	* 新增成员：AccelerateMainland


### 第 42 次发布

发布时间：2023-05-08 01:55:39

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [ZoneSetting](https://cloud.tencent.com/document/api/1552/80721#ZoneSetting)

	* 新增成员：AccelerateMainland


### 第 41 次发布

发布时间：2023-04-28 01:40:49

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [Zone](https://cloud.tencent.com/document/api/1552/80721#Zone)

	* 新增成员：LockStatus


### 第 40 次发布

发布时间：2023-04-26 01:54:26

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateApplicationProxy](https://cloud.tencent.com/document/api/1552/80694)

	* 新增入参：AccelerateMainland

* [ModifyApplicationProxy](https://cloud.tencent.com/document/api/1552/80689)

	* 新增入参：AccelerateMainland

* [ModifyZoneSetting](https://cloud.tencent.com/document/api/1552/80614)

	* 新增入参：ImageOptimize


新增数据结构：

* [AccelerateMainland](https://cloud.tencent.com/document/api/1552/80721#AccelerateMainland)

### 第 39 次发布

发布时间：2023-04-25 19:50:56

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateSecurityIPGroup](https://cloud.tencent.com/document/api/1552/90651)
* [DeleteSecurityIPGroup](https://cloud.tencent.com/document/api/1552/90650)
* [ModifySecurityIPGroup](https://cloud.tencent.com/document/api/1552/90649)

新增数据结构：

* [IPGroup](https://cloud.tencent.com/document/api/1552/80721#IPGroup)

### 第 38 次发布

发布时间：2023-04-05 01:58:24

本次发布包含了以下内容：

改善已有的文档。

新增数据结构：

* [AlgDetectJS](https://cloud.tencent.com/document/api/1552/80721#AlgDetectJS)
* [AlgDetectResult](https://cloud.tencent.com/document/api/1552/80721#AlgDetectResult)
* [AlgDetectRule](https://cloud.tencent.com/document/api/1552/80721#AlgDetectRule)
* [AlgDetectSession](https://cloud.tencent.com/document/api/1552/80721#AlgDetectSession)

修改数据结构：

* [BotConfig](https://cloud.tencent.com/document/api/1552/80721#BotConfig)

	* 新增成员：AlgDetectRule


### 第 37 次发布

发布时间：2023-03-23 02:39:19

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeDDoSAttackEvent](https://cloud.tencent.com/document/api/1552/80659)

新增数据结构：

* [DDoSAttackEvent](https://cloud.tencent.com/document/api/1552/80721#DDoSAttackEvent)
* [DDoSBlockData](https://cloud.tencent.com/document/api/1552/80721#DDoSBlockData)

### 第 36 次发布

发布时间：2023-03-20 02:00:54

本次发布包含了以下内容：

改善已有的文档。

新增数据结构：

* [ImageOptimize](https://cloud.tencent.com/document/api/1552/80721#ImageOptimize)

修改数据结构：

* [ZoneSetting](https://cloud.tencent.com/document/api/1552/80721#ZoneSetting)

	* 新增成员：ImageOptimize


### 第 35 次发布

发布时间：2023-03-15 02:11:56

本次发布包含了以下内容：

改善已有的文档。

新增数据结构：

* [BotExtendAction](https://cloud.tencent.com/document/api/1552/80721#BotExtendAction)
* [BotUserRule](https://cloud.tencent.com/document/api/1552/80721#BotUserRule)

修改数据结构：

* [BotConfig](https://cloud.tencent.com/document/api/1552/80721#BotConfig)

	* 新增成员：BotUserRules, Customizes


### 第 34 次发布

发布时间：2023-03-14 01:55:45

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [IdentifyZone](https://cloud.tencent.com/document/api/1552/80712)

	* 新增入参：Domain


修改数据结构：

* [AccelerationDomain](https://cloud.tencent.com/document/api/1552/80721#AccelerationDomain)

	* 新增成员：IdentificationStatus

* [Https](https://cloud.tencent.com/document/api/1552/80721#Https)

	* 新增成员：CipherSuite

* [Identification](https://cloud.tencent.com/document/api/1552/80721#Identification)

	* 新增成员：Domain


### 第 33 次发布

发布时间：2023-02-21 02:12:14

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeAddableEntityList](https://cloud.tencent.com/document/api/1552/80630)

	* 新增入参：Area


### 第 32 次发布

发布时间：2023-02-17 06:04:54

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [Zone](https://cloud.tencent.com/document/api/1552/80721#Zone)

	* 新增成员：IsFake


### 第 31 次发布

发布时间：2023-02-09 02:15:06

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateAccelerationDomain](https://cloud.tencent.com/document/api/1552/86338)
* [DeleteAccelerationDomains](https://cloud.tencent.com/document/api/1552/86337)
* [DescribeAccelerationDomains](https://cloud.tencent.com/document/api/1552/86336)
* [ModifyAccelerationDomain](https://cloud.tencent.com/document/api/1552/86335)
* [ModifyAccelerationDomainStatuses](https://cloud.tencent.com/document/api/1552/86334)

新增数据结构：

* [AccelerationDomain](https://cloud.tencent.com/document/api/1552/80721#AccelerationDomain)
* [OriginDetail](https://cloud.tencent.com/document/api/1552/80721#OriginDetail)
* [OriginInfo](https://cloud.tencent.com/document/api/1552/80721#OriginInfo)

### 第 30 次发布

发布时间：2023-02-08 02:07:28

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [WebLogs](https://cloud.tencent.com/document/api/1552/80721#WebLogs)

	* 新增成员：RealClientIp, RealClientIpCountryCode


### 第 29 次发布

发布时间：2023-02-07 02:04:55

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [OriginGroup](https://cloud.tencent.com/document/api/1552/80721#OriginGroup)

	* <font color="#dd0000">**修改成员**：</font>ZoneId, ZoneName, OriginGroupId, OriginType, OriginGroupName, ConfigurationType, OriginRecords, UpdateTime, HostHeader


### 第 28 次发布

发布时间：2023-01-19 01:54:45

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeTimingL7SourceData](https://cloud.tencent.com/document/api/1552/85910)

### 第 27 次发布

发布时间：2023-01-17 01:53:08

本次发布包含了以下内容：

改善已有的文档。

新增数据结构：

* [FirstPartConfig](https://cloud.tencent.com/document/api/1552/80721#FirstPartConfig)
* [SlowPostConfig](https://cloud.tencent.com/document/api/1552/80721#SlowPostConfig)
* [SlowRateConfig](https://cloud.tencent.com/document/api/1552/80721#SlowRateConfig)

修改数据结构：

* [AclConfig](https://cloud.tencent.com/document/api/1552/80721#AclConfig)

	* 新增成员：Customizes

* [RateLimitConfig](https://cloud.tencent.com/document/api/1552/80721#RateLimitConfig)

	* 新增成员：RateLimitCustomizes

* [SecurityConfig](https://cloud.tencent.com/document/api/1552/80721#SecurityConfig)

	* 新增成员：SlowPostConfig


### 第 26 次发布

发布时间：2023-01-16 02:10:35

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeOriginProtection](https://cloud.tencent.com/document/api/1552/84664)

	* <font color="#dd0000">**修改入参**：</font>Filters


### 第 25 次发布

发布时间：2023-01-10 01:48:46

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeDDoSAttackData](https://cloud.tencent.com/document/api/1552/80660)

### 第 24 次发布

发布时间：2023-01-06 01:46:38

本次发布包含了以下内容：

改善已有的文档。

<font color="#dd0000">**删除接口**：</font>

* CreateCustomErrorPage
* CreateIpTableList
* CreateLogSet
* CreateLogTopicTask
* CreateSecurityDropPage
* DeleteLogTopicTask
* DescribeBotClientIpList
* DescribeBotData
* DescribeBotHitRuleDetail
* DescribeBotLog
* DescribeBotManagedRules
* DescribeBotTopData
* DescribeDDoSAttackData
* DescribeDDoSAttackEvent
* DescribeDDoSAttackEventDetail
* DescribeDDoSAttackSourceEvent
* DescribeDDoSBlockList
* DescribeDDoSMajorAttackEvent
* DescribeDDoSPolicy
* DescribeDistributionL4AccessData
* DescribeDnssec
* DescribeLogTopicTaskDetail
* DescribeRateLimitIntelligenceRule
* DescribeSecurityGroupManagedRules
* DescribeSecurityPolicy
* DescribeSecurityPolicyList
* DescribeSecurityPolicyRegions
* DescribeSecurityPortraitRules
* DescribeSecurityRuleId
* DescribeTimingL4AccessData
* DescribeWebProtectionAttackEvents
* DescribeZoneDDoSPolicy
* ModifyAlarmConfig
* ModifyAlarmDefaultThreshold
* ModifyDDoSPolicy
* ModifyDDoSPolicyHost
* ModifyDnssec
* ModifyLogTopicTask
* ModifyZoneCnameSpeedUp
* SwitchLogTopicTask

<font color="#dd0000">**删除数据结构**：</font>

* BotLog
* BotManagedRuleDetail
* CCInterceptEvent
* DDoSAcl
* DDoSAclRule
* DDoSAllowBlock
* DDoSAllowBlockRule
* DDoSAntiPly
* DDoSAttackEvent
* DDoSAttackEventDetailData
* DDoSAttackSourceEvent
* DDoSBlockData
* DDoSFeaturesFilter
* DDoSGeoIp
* DDoSHost
* DDoSMajorAttackEvent
* DDoSPacketFilter
* DDoSRule
* DDoSSpeedLimit
* DDoSStatusInfo
* DnssecInfo
* GeoIp
* LogTopicDetailInfo
* PortraitManagedRuleDetail
* RateLimitIntelligenceRuleDetail
* SecurityEntity
* SecurityRule
* ShieldArea
* WafGroupDetail
* WafGroupInfo
* WafGroupRule

### 第 23 次发布

发布时间：2022-12-30 01:48:06

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeOriginProtection](https://cloud.tencent.com/document/api/1552/84664)
* [UpdateOriginProtectionIPWhitelist](https://cloud.tencent.com/document/api/1552/84663)

新增数据结构：

* [DiffIPWhitelist](https://cloud.tencent.com/document/api/1552/80721#DiffIPWhitelist)
* [IPWhitelist](https://cloud.tencent.com/document/api/1552/80721#IPWhitelist)
* [OriginProtectionInfo](https://cloud.tencent.com/document/api/1552/80721#OriginProtectionInfo)

### 第 22 次发布

发布时间：2022-12-27 02:10:56

本次发布包含了以下内容：

改善已有的文档。

<font color="#dd0000">**删除接口**：</font>

* CreateDnsRecord
* CreateLoadBalancing
* DeleteDnsRecords
* DeleteLoadBalancing
* DescribeDnsRecords
* DescribeLoadBalancing
* ModifyDnsRecord
* ModifyLoadBalancing

<font color="#dd0000">**删除数据结构**：</font>

* AdvancedOriginGroup
* DnsRecord
* LoadBalancing
* OriginGroupCondition

### 第 21 次发布

发布时间：2022-12-26 01:58:03

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeDistributionL4AccessData](https://cloud.tencent.com/document/api/1552/84489)
* [DescribeTimingL4AccessData](https://cloud.tencent.com/document/api/1552/84488)

### 第 20 次发布

发布时间：2022-12-23 02:00:21

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [ModifyZoneSetting](https://cloud.tencent.com/document/api/1552/80614)

	* 新增入参：Grpc


新增数据结构：

* [Grpc](https://cloud.tencent.com/document/api/1552/80721#Grpc)

修改数据结构：

* [ZoneSetting](https://cloud.tencent.com/document/api/1552/80721#ZoneSetting)

	* 新增成员：Grpc


### 第 19 次发布

发布时间：2022-12-22 02:07:02

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [FollowOrigin](https://cloud.tencent.com/document/api/1552/80721#FollowOrigin)

	* 新增成员：DefaultCacheStrategy


### 第 18 次发布

发布时间：2022-12-20 01:58:08

本次发布包含了以下内容：

改善已有的文档。

<font color="#dd0000">**删除接口**：</font>

* ModifyLoadBalancingStatus

### 第 17 次发布

发布时间：2022-12-09 02:05:01

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeSecurityRuleId](https://cloud.tencent.com/document/api/1552/80673)

	* 新增入参：Domains

	* <font color="#dd0000">**修改入参**：</font>RuleIdList

	* 新增出参：SecurityRules


新增数据结构：

* [SecurityRule](https://cloud.tencent.com/document/api/1552/80721#SecurityRule)

修改数据结构：

* [BotLog](https://cloud.tencent.com/document/api/1552/80721#BotLog)

	* 新增成员：Area

* [IpTableRule](https://cloud.tencent.com/document/api/1552/80721#IpTableRule)

	* 新增成员：Operator, RuleName

	* <font color="#dd0000">**修改成员**：</font>MatchContent

* [RateLimitIntelligence](https://cloud.tencent.com/document/api/1552/80721#RateLimitIntelligence)

	* 新增成员：RuleId

* [SecHitRuleInfo](https://cloud.tencent.com/document/api/1552/80721#SecHitRuleInfo)

	* 新增成员：ZoneId, RuleEnabled, AlarmEnabled, RuleDeleted

* [SecRuleRelatedInfo](https://cloud.tencent.com/document/api/1552/80721#SecRuleRelatedInfo)

	* 新增成员：RuleType, RuleEnabled, RuleDeleted, AlarmEnabled

* [WebLogs](https://cloud.tencent.com/document/api/1552/80721#WebLogs)

	* 新增成员：Area


### 第 16 次发布

发布时间：2022-11-29 07:26:41

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateSecurityDropPage](https://cloud.tencent.com/document/api/1552/80682)

	* 新增入参：TemplateId


### 第 15 次发布

发布时间：2022-11-24 06:59:55

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [RuleCondition](https://cloud.tencent.com/document/api/1552/80721#RuleCondition)

	* 新增成员：IgnoreNameCase


### 第 14 次发布

发布时间：2022-11-23 06:56:52

本次发布包含了以下内容：

改善已有的文档。

<font color="#dd0000">**删除接口**：</font>

* DescribeBillingData

<font color="#dd0000">**删除数据结构**：</font>

* BillingDataFilter

### 第 13 次发布

发布时间：2022-11-17 06:49:23

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [BindZoneToPlan](https://cloud.tencent.com/document/api/1552/83042)

修改接口：

* [CreateZone](https://cloud.tencent.com/document/api/1552/80719)

	* 新增入参：AliasZoneName

* [DescribeZones](https://cloud.tencent.com/document/api/1552/80713)

	* 新增入参：Order, Direction

* [ModifyZone](https://cloud.tencent.com/document/api/1552/80709)

	* 新增入参：AliasZoneName


修改数据结构：

* [Zone](https://cloud.tencent.com/document/api/1552/80721#Zone)

	* 新增成员：ActiveStatus, AliasZoneName


### 第 12 次发布

发布时间：2022-11-09 06:56:06

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeBotManagedRules](https://cloud.tencent.com/document/api/1552/80681)

	* 新增入参：TemplateId

	* <font color="#dd0000">**修改入参**：</font>ZoneId, Entity

* [DescribeSecurityGroupManagedRules](https://cloud.tencent.com/document/api/1552/80678)

	* 新增入参：TemplateId

	* <font color="#dd0000">**修改入参**：</font>ZoneId, Entity

* [DescribeSecurityPolicy](https://cloud.tencent.com/document/api/1552/80677)

	* 新增入参：TemplateId

	* <font color="#dd0000">**修改入参**：</font>ZoneId, Entity

* [DescribeSecurityPortraitRules](https://cloud.tencent.com/document/api/1552/80674)

	* 新增入参：TemplateId

	* <font color="#dd0000">**修改入参**：</font>ZoneId, Entity

* [ModifySecurityPolicy](https://cloud.tencent.com/document/api/1552/80669)

	* 新增入参：TemplateId

	* <font color="#dd0000">**修改入参**：</font>Entity

* [ModifySecurityWafGroupPolicy](https://cloud.tencent.com/document/api/1552/80668)

	* 新增入参：TemplateId

	* <font color="#dd0000">**修改入参**：</font>ZoneId, Entity


新增数据结构：

* [TemplateConfig](https://cloud.tencent.com/document/api/1552/80721#TemplateConfig)

修改数据结构：

* [IpTableRule](https://cloud.tencent.com/document/api/1552/80721#IpTableRule)

	* 新增成员：Status

* [RateLimitUserRule](https://cloud.tencent.com/document/api/1552/80721#RateLimitUserRule)

	* 新增成员：FreqScope

* [SecurityConfig](https://cloud.tencent.com/document/api/1552/80721#SecurityConfig)

	* 新增成员：TemplateConfig


### 第 11 次发布

发布时间：2022-11-07 06:39:45

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [SecHitRuleInfo](https://cloud.tencent.com/document/api/1552/80721#SecHitRuleInfo)

	* 新增成员：BotLabel

* [SecRuleRelatedInfo](https://cloud.tencent.com/document/api/1552/80721#SecRuleRelatedInfo)

	* 新增成员：AttackContent


### 第 10 次发布

发布时间：2022-11-04 06:41:03

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateAliasDomain](https://cloud.tencent.com/document/api/1552/81247)
* [DeleteAliasDomain](https://cloud.tencent.com/document/api/1552/81246)
* [DescribeAliasDomains](https://cloud.tencent.com/document/api/1552/81245)
* [ModifyAliasDomain](https://cloud.tencent.com/document/api/1552/81244)
* [ModifyAliasDomainStatus](https://cloud.tencent.com/document/api/1552/81243)

新增数据结构：

* [AliasDomain](https://cloud.tencent.com/document/api/1552/80721#AliasDomain)

### 第 9 次发布

发布时间：2022-11-01 06:48:56

本次发布包含了以下内容：

改善已有的文档。

<font color="#dd0000">**删除接口**：</font>

* CreateAliasDomain
* DeleteAliasDomain
* DescribeAliasDomains
* ModifyAliasDomain
* ModifyAliasDomainStatus

<font color="#dd0000">**删除数据结构**：</font>

* AliasDomain

### 第 8 次发布

发布时间：2022-10-31 06:54:04

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateApplicationProxyRule](https://cloud.tencent.com/document/api/1552/80693)

	* 新增入参：OriginPort

* [ModifyApplicationProxyRule](https://cloud.tencent.com/document/api/1552/80688)

	* 新增入参：OriginPort


修改数据结构：

* [ApplicationProxyRule](https://cloud.tencent.com/document/api/1552/80721#ApplicationProxyRule)

	* 新增成员：OriginPort


### 第 7 次发布

发布时间：2022-10-25 07:02:19

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [AliasDomain](https://cloud.tencent.com/document/api/1552/80721#AliasDomain)

	* 新增成员：ForbidMode, TargetForbid

* [Https](https://cloud.tencent.com/document/api/1552/80721#Https)

	* 新增成员：ApplyType

* [ServerCertInfo](https://cloud.tencent.com/document/api/1552/80721#ServerCertInfo)

	* 新增成员：CommonName


### 第 6 次发布

发布时间：2022-10-20 06:52:24

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateRule](https://cloud.tencent.com/document/api/1552/80622)

	* 新增入参：Tags

* [ModifyRule](https://cloud.tencent.com/document/api/1552/80616)

	* 新增入参：Tags


新增数据结构：

* [SubRule](https://cloud.tencent.com/document/api/1552/80721#SubRule)
* [SubRuleItem](https://cloud.tencent.com/document/api/1552/80721#SubRuleItem)

修改数据结构：

* [FollowOrigin](https://cloud.tencent.com/document/api/1552/80721#FollowOrigin)

	* 新增成员：DefaultCacheTime, DefaultCache

* [Rule](https://cloud.tencent.com/document/api/1552/80721#Rule)

	* 新增成员：SubRules

* [RuleItem](https://cloud.tencent.com/document/api/1552/80721#RuleItem)

	* 新增成员：Tags


### 第 5 次发布

发布时间：2022-10-11 06:58:18

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [RuleCondition](https://cloud.tencent.com/document/api/1552/80721#RuleCondition)

	* 新增成员：Name

	* <font color="#dd0000">**修改成员**：</font>Values


### 第 4 次发布

发布时间：2022-10-10 06:43:20

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateAliasDomain](https://cloud.tencent.com/document/api/1552/81247)
* [DeleteAliasDomain](https://cloud.tencent.com/document/api/1552/81246)
* [DescribeAliasDomains](https://cloud.tencent.com/document/api/1552/81245)
* [ModifyAliasDomain](https://cloud.tencent.com/document/api/1552/81244)
* [ModifyAliasDomainStatus](https://cloud.tencent.com/document/api/1552/81243)
* [ReclaimAliasDomain](https://cloud.tencent.com/document/api/1552/81242)

新增数据结构：

* [AliasDomain](https://cloud.tencent.com/document/api/1552/80721#AliasDomain)

修改数据结构：

* [RateLimitTemplate](https://cloud.tencent.com/document/api/1552/80721#RateLimitTemplate)

	* 新增成员：Action


### 第 3 次发布

发布时间：2022-09-30 06:58:07

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateZone](https://cloud.tencent.com/document/api/1552/80719)

	* 新增入参：AllowDuplicates

* [ModifyHostsCertificate](https://cloud.tencent.com/document/api/1552/80764)

	* 新增入参：ApplyType


修改数据结构：

* [RuleCondition](https://cloud.tencent.com/document/api/1552/80721#RuleCondition)

	* 新增成员：IgnoreCase


### 第 2 次发布

发布时间：2022-09-28 19:21:32

本次发布包含了以下内容：

改善已有的文档。

<font color="#dd0000">**删除接口**：</font>

* DescribeHostCertificates

修改接口：

* [CreateLoadBalancing](https://cloud.tencent.com/document/api/1552/80599)

	* 新增入参：OriginType, AdvancedOriginGroups

* [CreateOriginGroup](https://cloud.tencent.com/document/api/1552/80598)

	* 新增入参：HostHeader

* [DeleteLogTopicTask](https://cloud.tencent.com/document/api/1552/80631)

	* <font color="#dd0000">**修改入参**：</font>LogSetRegion

* [IdentifyZone](https://cloud.tencent.com/document/api/1552/80712)

	* 新增出参：FileAscription

* [ModifyLoadBalancing](https://cloud.tencent.com/document/api/1552/80763)

	* 新增入参：OriginType, AdvancedOriginGroups

* [ModifyOriginGroup](https://cloud.tencent.com/document/api/1552/80592)

	* 新增入参：HostHeader

* [ModifyZoneSetting](https://cloud.tencent.com/document/api/1552/80614)

	* 新增入参：ClientIpCountry


新增数据结构：

* [AdvancedOriginGroup](https://cloud.tencent.com/document/api/1552/80721#AdvancedOriginGroup)
* [ClientIpCountry](https://cloud.tencent.com/document/api/1552/80721#ClientIpCountry)
* [FileAscriptionInfo](https://cloud.tencent.com/document/api/1552/80721#FileAscriptionInfo)
* [OriginGroupCondition](https://cloud.tencent.com/document/api/1552/80721#OriginGroupCondition)
* [PartialModule](https://cloud.tencent.com/document/api/1552/80721#PartialModule)
* [SkipCondition](https://cloud.tencent.com/document/api/1552/80721#SkipCondition)

<font color="#dd0000">**删除数据结构**：</font>

* HostCertInfo
* HostsCertificate
* Sort

修改数据结构：

* [ClsLogTopicInfo](https://cloud.tencent.com/document/api/1552/80721#ClsLogTopicInfo)

	* 新增成员：LogSetType

* [DefaultServerCertInfo](https://cloud.tencent.com/document/api/1552/80721#DefaultServerCertInfo)

	* 新增成员：SignAlgo

* [DetailHost](https://cloud.tencent.com/document/api/1552/80721#DetailHost)

	* 新增成员：ClientIpCountry

* [ExceptUserRuleScope](https://cloud.tencent.com/document/api/1552/80721#ExceptUserRuleScope)

	* 新增成员：Type, PartialModules, SkipConditions

* [Identification](https://cloud.tencent.com/document/api/1552/80721#Identification)

	* 新增成员：FileAscription

* [LoadBalancing](https://cloud.tencent.com/document/api/1552/80721#LoadBalancing)

	* 新增成员：OriginType, AdvancedOriginGroups

* [OriginGroup](https://cloud.tencent.com/document/api/1552/80721#OriginGroup)

	* 新增成员：HostHeader

* [ZoneSetting](https://cloud.tencent.com/document/api/1552/80721#ZoneSetting)

	* 新增成员：ClientIpCountry


### 第 1 次发布

发布时间：2022-09-20 06:52:09

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CheckCertificate](https://cloud.tencent.com/document/api/1552/80604)
* [CreateApplicationProxy](https://cloud.tencent.com/document/api/1552/80694)
* [CreateApplicationProxyRule](https://cloud.tencent.com/document/api/1552/80693)
* [CreateCredential](https://cloud.tencent.com/document/api/1552/80623)
* [CreateCustomErrorPage](https://cloud.tencent.com/document/api/1552/80684)
* [CreateDnsRecord](https://cloud.tencent.com/document/api/1552/80720)
* [CreateIpTableList](https://cloud.tencent.com/document/api/1552/80683)
* [CreateLoadBalancing](https://cloud.tencent.com/document/api/1552/80599)
* [CreateLogSet](https://cloud.tencent.com/document/api/1552/80633)
* [CreateLogTopicTask](https://cloud.tencent.com/document/api/1552/80632)
* [CreateOriginGroup](https://cloud.tencent.com/document/api/1552/80598)
* [CreatePlanForZone](https://cloud.tencent.com/document/api/1552/80607)
* [CreatePrefetchTask](https://cloud.tencent.com/document/api/1552/80704)
* [CreatePurgeTask](https://cloud.tencent.com/document/api/1552/80703)
* [CreateReplayTask](https://cloud.tencent.com/document/api/1552/80702)
* [CreateRule](https://cloud.tencent.com/document/api/1552/80622)
* [CreateSecurityDropPage](https://cloud.tencent.com/document/api/1552/80682)
* [CreateSpeedTesting](https://cloud.tencent.com/document/api/1552/80612)
* [CreateZone](https://cloud.tencent.com/document/api/1552/80719)
* [DeleteApplicationProxy](https://cloud.tencent.com/document/api/1552/80692)
* [DeleteApplicationProxyRule](https://cloud.tencent.com/document/api/1552/80691)
* [DeleteDnsRecords](https://cloud.tencent.com/document/api/1552/80718)
* [DeleteLoadBalancing](https://cloud.tencent.com/document/api/1552/80597)
* [DeleteLogTopicTask](https://cloud.tencent.com/document/api/1552/80631)
* [DeleteOriginGroup](https://cloud.tencent.com/document/api/1552/80596)
* [DeleteRules](https://cloud.tencent.com/document/api/1552/80621)
* [DeleteZone](https://cloud.tencent.com/document/api/1552/80717)
* [DescribeAddableEntityList](https://cloud.tencent.com/document/api/1552/80630)
* [DescribeApplicationProxies](https://cloud.tencent.com/document/api/1552/80690)
* [DescribeAvailablePlans](https://cloud.tencent.com/document/api/1552/80606)
* [DescribeBillingData](https://cloud.tencent.com/document/api/1552/103562)
* [DescribeBotClientIpList](https://cloud.tencent.com/document/api/1552/80666)
* [DescribeBotData](https://cloud.tencent.com/document/api/1552/80665)
* [DescribeBotHitRuleDetail](https://cloud.tencent.com/document/api/1552/80664)
* [DescribeBotLog](https://cloud.tencent.com/document/api/1552/80663)
* [DescribeBotManagedRules](https://cloud.tencent.com/document/api/1552/80681)
* [DescribeBotTopData](https://cloud.tencent.com/document/api/1552/80662)
* [DescribeClientRuleList](https://cloud.tencent.com/document/api/1552/80661)
* [DescribeContentQuota](https://cloud.tencent.com/document/api/1552/80701)
* [DescribeDDoSAttackData](https://cloud.tencent.com/document/api/1552/80660)
* [DescribeDDoSAttackEvent](https://cloud.tencent.com/document/api/1552/80659)
* [DescribeDDoSAttackEventDetail](https://cloud.tencent.com/document/api/1552/80658)
* [DescribeDDoSAttackSourceEvent](https://cloud.tencent.com/document/api/1552/80657)
* [DescribeDDoSAttackTopData](https://cloud.tencent.com/document/api/1552/80656)
* [DescribeDDoSBlockList](https://cloud.tencent.com/document/api/1552/80655)
* [DescribeDDoSMajorAttackEvent](https://cloud.tencent.com/document/api/1552/80654)
* [DescribeDDoSPolicy](https://cloud.tencent.com/document/api/1552/80680)
* [DescribeDefaultCertificates](https://cloud.tencent.com/document/api/1552/80603)
* [DescribeDnsData](https://cloud.tencent.com/document/api/1552/80652)
* [DescribeDnsRecords](https://cloud.tencent.com/document/api/1552/80716)
* [DescribeDnssec](https://cloud.tencent.com/document/api/1552/80715)
* [DescribeHostCertificates](https://cloud.tencent.com/document/api/1552/80602)
* [DescribeHostsSetting](https://cloud.tencent.com/document/api/1552/80620)
* [DescribeIdentifications](https://cloud.tencent.com/document/api/1552/80714)
* [DescribeLoadBalancing](https://cloud.tencent.com/document/api/1552/80595)
* [DescribeLogSets](https://cloud.tencent.com/document/api/1552/80629)
* [DescribeLogTopicTaskDetail](https://cloud.tencent.com/document/api/1552/80628)
* [DescribeLogTopicTasks](https://cloud.tencent.com/document/api/1552/80627)
* [DescribeOriginGroup](https://cloud.tencent.com/document/api/1552/80594)
* [DescribeOverviewL7Data](https://cloud.tencent.com/document/api/1552/80651)
* [DescribePrefetchTasks](https://cloud.tencent.com/document/api/1552/80700)
* [DescribePurgeTasks](https://cloud.tencent.com/document/api/1552/80699)
* [DescribeRateLimitIntelligenceRule](https://cloud.tencent.com/document/api/1552/80679)
* [DescribeRules](https://cloud.tencent.com/document/api/1552/80619)
* [DescribeRulesSetting](https://cloud.tencent.com/document/api/1552/80618)
* [DescribeSecurityGroupManagedRules](https://cloud.tencent.com/document/api/1552/80678)
* [DescribeSecurityPolicy](https://cloud.tencent.com/document/api/1552/80677)
* [DescribeSecurityPolicyList](https://cloud.tencent.com/document/api/1552/80676)
* [DescribeSecurityPolicyRegions](https://cloud.tencent.com/document/api/1552/80675)
* [DescribeSecurityPortraitRules](https://cloud.tencent.com/document/api/1552/80674)
* [DescribeSecurityRuleId](https://cloud.tencent.com/document/api/1552/80673)
* [DescribeSingleL7AnalysisData](https://cloud.tencent.com/document/api/1552/80650)
* [DescribeSpeedTestingDetails](https://cloud.tencent.com/document/api/1552/80611)
* [DescribeSpeedTestingMetricData](https://cloud.tencent.com/document/api/1552/80610)
* [DescribeSpeedTestingQuota](https://cloud.tencent.com/document/api/1552/80609)
* [DescribeTimingL4Data](https://cloud.tencent.com/document/api/1552/80649)
* [DescribeTimingL7AnalysisData](https://cloud.tencent.com/document/api/1552/80648)
* [DescribeTimingL7CacheData](https://cloud.tencent.com/document/api/1552/80647)
* [DescribeTopL7AnalysisData](https://cloud.tencent.com/document/api/1552/80646)
* [DescribeTopL7CacheData](https://cloud.tencent.com/document/api/1552/80645)
* [DescribeWebManagedRulesData](https://cloud.tencent.com/document/api/1552/80644)
* [DescribeWebManagedRulesHitRuleDetail](https://cloud.tencent.com/document/api/1552/80643)
* [DescribeWebManagedRulesLog](https://cloud.tencent.com/document/api/1552/80642)
* [DescribeWebProtectionAttackEvents](https://cloud.tencent.com/document/api/1552/80641)
* [DescribeWebProtectionClientIpList](https://cloud.tencent.com/document/api/1552/80640)
* [DescribeWebProtectionData](https://cloud.tencent.com/document/api/1552/80639)
* [DescribeWebProtectionHitRuleDetail](https://cloud.tencent.com/document/api/1552/80638)
* [DescribeWebProtectionTopData](https://cloud.tencent.com/document/api/1552/80637)
* [DescribeZoneDDoSPolicy](https://cloud.tencent.com/document/api/1552/80672)
* [DescribeZoneSetting](https://cloud.tencent.com/document/api/1552/80617)
* [DescribeZones](https://cloud.tencent.com/document/api/1552/80713)
* [DownloadL4Logs](https://cloud.tencent.com/document/api/1552/80636)
* [DownloadL7Logs](https://cloud.tencent.com/document/api/1552/80635)
* [IdentifyZone](https://cloud.tencent.com/document/api/1552/80712)
* [ModifyAlarmConfig](https://cloud.tencent.com/document/api/1552/80697)
* [ModifyAlarmDefaultThreshold](https://cloud.tencent.com/document/api/1552/80696)
* [ModifyApplicationProxy](https://cloud.tencent.com/document/api/1552/80689)
* [ModifyApplicationProxyRule](https://cloud.tencent.com/document/api/1552/80688)
* [ModifyApplicationProxyRuleStatus](https://cloud.tencent.com/document/api/1552/80687)
* [ModifyApplicationProxyStatus](https://cloud.tencent.com/document/api/1552/80686)
* [ModifyDDoSPolicy](https://cloud.tencent.com/document/api/1552/80671)
* [ModifyDDoSPolicyHost](https://cloud.tencent.com/document/api/1552/80670)
* [ModifyDefaultCertificate](https://cloud.tencent.com/document/api/1552/80601)
* [ModifyDnsRecord](https://cloud.tencent.com/document/api/1552/80711)
* [ModifyDnssec](https://cloud.tencent.com/document/api/1552/80710)
* [ModifyHostsCertificate](https://cloud.tencent.com/document/api/1552/80764)
* [ModifyLoadBalancing](https://cloud.tencent.com/document/api/1552/80763)
* [ModifyLoadBalancingStatus](https://cloud.tencent.com/document/api/1552/80593)
* [ModifyLogTopicTask](https://cloud.tencent.com/document/api/1552/80626)
* [ModifyOriginGroup](https://cloud.tencent.com/document/api/1552/80592)
* [ModifyRule](https://cloud.tencent.com/document/api/1552/80616)
* [ModifyRulePriority](https://cloud.tencent.com/document/api/1552/80615)
* [ModifySecurityPolicy](https://cloud.tencent.com/document/api/1552/80669)
* [ModifySecurityWafGroupPolicy](https://cloud.tencent.com/document/api/1552/80668)
* [ModifyZone](https://cloud.tencent.com/document/api/1552/80709)
* [ModifyZoneCnameSpeedUp](https://cloud.tencent.com/document/api/1552/80708)
* [ModifyZoneSetting](https://cloud.tencent.com/document/api/1552/80614)
* [ModifyZoneStatus](https://cloud.tencent.com/document/api/1552/80707)
* [ReclaimZone](https://cloud.tencent.com/document/api/1552/80706)
* [SwitchLogTopicTask](https://cloud.tencent.com/document/api/1552/80625)

新增数据结构：

* [AccelerateType](https://cloud.tencent.com/document/api/1552/80721#AccelerateType)
* [AclCondition](https://cloud.tencent.com/document/api/1552/80721#AclCondition)
* [AclConfig](https://cloud.tencent.com/document/api/1552/80721#AclConfig)
* [AclUserRule](https://cloud.tencent.com/document/api/1552/80721#AclUserRule)
* [Action](https://cloud.tencent.com/document/api/1552/80721#Action)
* [AdvancedFilter](https://cloud.tencent.com/document/api/1552/80721#AdvancedFilter)
* [AiRule](https://cloud.tencent.com/document/api/1552/80721#AiRule)
* [ApplicationProxy](https://cloud.tencent.com/document/api/1552/80721#ApplicationProxy)
* [ApplicationProxyRule](https://cloud.tencent.com/document/api/1552/80721#ApplicationProxyRule)
* [AscriptionInfo](https://cloud.tencent.com/document/api/1552/80721#AscriptionInfo)
* [BillingDataFilter](https://cloud.tencent.com/document/api/1552/80721#BillingDataFilter)
* [BotConfig](https://cloud.tencent.com/document/api/1552/80721#BotConfig)
* [BotLog](https://cloud.tencent.com/document/api/1552/80721#BotLog)
* [BotManagedRule](https://cloud.tencent.com/document/api/1552/80721#BotManagedRule)
* [BotManagedRuleDetail](https://cloud.tencent.com/document/api/1552/80721#BotManagedRuleDetail)
* [BotPortraitRule](https://cloud.tencent.com/document/api/1552/80721#BotPortraitRule)
* [CC](https://cloud.tencent.com/document/api/1552/80721#CC)
* [CCInterceptEvent](https://cloud.tencent.com/document/api/1552/80721#CCInterceptEvent)
* [Cache](https://cloud.tencent.com/document/api/1552/80721#Cache)
* [CacheConfig](https://cloud.tencent.com/document/api/1552/80721#CacheConfig)
* [CacheKey](https://cloud.tencent.com/document/api/1552/80721#CacheKey)
* [CachePrefresh](https://cloud.tencent.com/document/api/1552/80721#CachePrefresh)
* [ClientIpHeader](https://cloud.tencent.com/document/api/1552/80721#ClientIpHeader)
* [ClientRule](https://cloud.tencent.com/document/api/1552/80721#ClientRule)
* [ClsLogTopicInfo](https://cloud.tencent.com/document/api/1552/80721#ClsLogTopicInfo)
* [CodeAction](https://cloud.tencent.com/document/api/1552/80721#CodeAction)
* [Compression](https://cloud.tencent.com/document/api/1552/80721#Compression)
* [DDoS](https://cloud.tencent.com/document/api/1552/80721#DDoS)
* [DDoSAcl](https://cloud.tencent.com/document/api/1552/80721#DDoSAcl)
* [DDoSAclRule](https://cloud.tencent.com/document/api/1552/80721#DDoSAclRule)
* [DDoSAllowBlock](https://cloud.tencent.com/document/api/1552/80721#DDoSAllowBlock)
* [DDoSAllowBlockRule](https://cloud.tencent.com/document/api/1552/80721#DDoSAllowBlockRule)
* [DDoSAntiPly](https://cloud.tencent.com/document/api/1552/80721#DDoSAntiPly)
* [DDoSAttackEvent](https://cloud.tencent.com/document/api/1552/80721#DDoSAttackEvent)
* [DDoSAttackEventDetailData](https://cloud.tencent.com/document/api/1552/80721#DDoSAttackEventDetailData)
* [DDoSAttackSourceEvent](https://cloud.tencent.com/document/api/1552/80721#DDoSAttackSourceEvent)
* [DDoSBlockData](https://cloud.tencent.com/document/api/1552/80721#DDoSBlockData)
* [DDoSFeaturesFilter](https://cloud.tencent.com/document/api/1552/80721#DDoSFeaturesFilter)
* [DDoSGeoIp](https://cloud.tencent.com/document/api/1552/80721#DDoSGeoIp)
* [DDoSHost](https://cloud.tencent.com/document/api/1552/80721#DDoSHost)
* [DDoSMajorAttackEvent](https://cloud.tencent.com/document/api/1552/80721#DDoSMajorAttackEvent)
* [DDoSPacketFilter](https://cloud.tencent.com/document/api/1552/80721#DDoSPacketFilter)
* [DDoSRule](https://cloud.tencent.com/document/api/1552/80721#DDoSRule)
* [DDoSSpeedLimit](https://cloud.tencent.com/document/api/1552/80721#DDoSSpeedLimit)
* [DDoSStatusInfo](https://cloud.tencent.com/document/api/1552/80721#DDoSStatusInfo)
* [DefaultServerCertInfo](https://cloud.tencent.com/document/api/1552/80721#DefaultServerCertInfo)
* [DetailHost](https://cloud.tencent.com/document/api/1552/80721#DetailHost)
* [DistrictStatistics](https://cloud.tencent.com/document/api/1552/80721#DistrictStatistics)
* [DnsData](https://cloud.tencent.com/document/api/1552/80721#DnsData)
* [DnsRecord](https://cloud.tencent.com/document/api/1552/80721#DnsRecord)
* [DnssecInfo](https://cloud.tencent.com/document/api/1552/80721#DnssecInfo)
* [DropPageConfig](https://cloud.tencent.com/document/api/1552/80721#DropPageConfig)
* [DropPageDetail](https://cloud.tencent.com/document/api/1552/80721#DropPageDetail)
* [ExceptConfig](https://cloud.tencent.com/document/api/1552/80721#ExceptConfig)
* [ExceptUserRule](https://cloud.tencent.com/document/api/1552/80721#ExceptUserRule)
* [ExceptUserRuleCondition](https://cloud.tencent.com/document/api/1552/80721#ExceptUserRuleCondition)
* [ExceptUserRuleScope](https://cloud.tencent.com/document/api/1552/80721#ExceptUserRuleScope)
* [FailReason](https://cloud.tencent.com/document/api/1552/80721#FailReason)
* [Filter](https://cloud.tencent.com/document/api/1552/80721#Filter)
* [FollowOrigin](https://cloud.tencent.com/document/api/1552/80721#FollowOrigin)
* [ForceRedirect](https://cloud.tencent.com/document/api/1552/80721#ForceRedirect)
* [GeoIp](https://cloud.tencent.com/document/api/1552/80721#GeoIp)
* [Header](https://cloud.tencent.com/document/api/1552/80721#Header)
* [HostCertInfo](https://cloud.tencent.com/document/api/1552/80721#HostCertInfo)
* [HostsCertificate](https://cloud.tencent.com/document/api/1552/80721#HostsCertificate)
* [Hsts](https://cloud.tencent.com/document/api/1552/80721#Hsts)
* [Https](https://cloud.tencent.com/document/api/1552/80721#Https)
* [Identification](https://cloud.tencent.com/document/api/1552/80721#Identification)
* [IntelligenceRule](https://cloud.tencent.com/document/api/1552/80721#IntelligenceRule)
* [IntelligenceRuleItem](https://cloud.tencent.com/document/api/1552/80721#IntelligenceRuleItem)
* [IpTableConfig](https://cloud.tencent.com/document/api/1552/80721#IpTableConfig)
* [IpTableRule](https://cloud.tencent.com/document/api/1552/80721#IpTableRule)
* [Ipv6](https://cloud.tencent.com/document/api/1552/80721#Ipv6)
* [L4OfflineLog](https://cloud.tencent.com/document/api/1552/80721#L4OfflineLog)
* [L7OfflineLog](https://cloud.tencent.com/document/api/1552/80721#L7OfflineLog)
* [LoadBalancing](https://cloud.tencent.com/document/api/1552/80721#LoadBalancing)
* [LogSetInfo](https://cloud.tencent.com/document/api/1552/80721#LogSetInfo)
* [LogTopicDetailInfo](https://cloud.tencent.com/document/api/1552/80721#LogTopicDetailInfo)
* [MaxAge](https://cloud.tencent.com/document/api/1552/80721#MaxAge)
* [NoCache](https://cloud.tencent.com/document/api/1552/80721#NoCache)
* [NormalAction](https://cloud.tencent.com/document/api/1552/80721#NormalAction)
* [OfflineCache](https://cloud.tencent.com/document/api/1552/80721#OfflineCache)
* [OptimizeAction](https://cloud.tencent.com/document/api/1552/80721#OptimizeAction)
* [Origin](https://cloud.tencent.com/document/api/1552/80721#Origin)
* [OriginGroup](https://cloud.tencent.com/document/api/1552/80721#OriginGroup)
* [OriginRecord](https://cloud.tencent.com/document/api/1552/80721#OriginRecord)
* [PlanInfo](https://cloud.tencent.com/document/api/1552/80721#PlanInfo)
* [PortraitManagedRuleDetail](https://cloud.tencent.com/document/api/1552/80721#PortraitManagedRuleDetail)
* [PostMaxSize](https://cloud.tencent.com/document/api/1552/80721#PostMaxSize)
* [PrivateParameter](https://cloud.tencent.com/document/api/1552/80721#PrivateParameter)
* [QueryCondition](https://cloud.tencent.com/document/api/1552/80721#QueryCondition)
* [QueryString](https://cloud.tencent.com/document/api/1552/80721#QueryString)
* [Quic](https://cloud.tencent.com/document/api/1552/80721#Quic)
* [Quota](https://cloud.tencent.com/document/api/1552/80721#Quota)
* [RateLimitConfig](https://cloud.tencent.com/document/api/1552/80721#RateLimitConfig)
* [RateLimitIntelligence](https://cloud.tencent.com/document/api/1552/80721#RateLimitIntelligence)
* [RateLimitIntelligenceRuleDetail](https://cloud.tencent.com/document/api/1552/80721#RateLimitIntelligenceRuleDetail)
* [RateLimitTemplate](https://cloud.tencent.com/document/api/1552/80721#RateLimitTemplate)
* [RateLimitTemplateDetail](https://cloud.tencent.com/document/api/1552/80721#RateLimitTemplateDetail)
* [RateLimitUserRule](https://cloud.tencent.com/document/api/1552/80721#RateLimitUserRule)
* [Resource](https://cloud.tencent.com/document/api/1552/80721#Resource)
* [RewriteAction](https://cloud.tencent.com/document/api/1552/80721#RewriteAction)
* [Rule](https://cloud.tencent.com/document/api/1552/80721#Rule)
* [RuleAndConditions](https://cloud.tencent.com/document/api/1552/80721#RuleAndConditions)
* [RuleChoicePropertiesItem](https://cloud.tencent.com/document/api/1552/80721#RuleChoicePropertiesItem)
* [RuleCodeActionParams](https://cloud.tencent.com/document/api/1552/80721#RuleCodeActionParams)
* [RuleCondition](https://cloud.tencent.com/document/api/1552/80721#RuleCondition)
* [RuleExtraParameter](https://cloud.tencent.com/document/api/1552/80721#RuleExtraParameter)
* [RuleItem](https://cloud.tencent.com/document/api/1552/80721#RuleItem)
* [RuleNormalActionParams](https://cloud.tencent.com/document/api/1552/80721#RuleNormalActionParams)
* [RuleRewriteActionParams](https://cloud.tencent.com/document/api/1552/80721#RuleRewriteActionParams)
* [RulesProperties](https://cloud.tencent.com/document/api/1552/80721#RulesProperties)
* [RulesSettingAction](https://cloud.tencent.com/document/api/1552/80721#RulesSettingAction)
* [SecClientIp](https://cloud.tencent.com/document/api/1552/80721#SecClientIp)
* [SecEntry](https://cloud.tencent.com/document/api/1552/80721#SecEntry)
* [SecEntryValue](https://cloud.tencent.com/document/api/1552/80721#SecEntryValue)
* [SecHitRuleInfo](https://cloud.tencent.com/document/api/1552/80721#SecHitRuleInfo)
* [SecRuleRelatedInfo](https://cloud.tencent.com/document/api/1552/80721#SecRuleRelatedInfo)
* [SecurityConfig](https://cloud.tencent.com/document/api/1552/80721#SecurityConfig)
* [SecurityEntity](https://cloud.tencent.com/document/api/1552/80721#SecurityEntity)
* [SecurityType](https://cloud.tencent.com/document/api/1552/80721#SecurityType)
* [ServerCertInfo](https://cloud.tencent.com/document/api/1552/80721#ServerCertInfo)
* [ShieldArea](https://cloud.tencent.com/document/api/1552/80721#ShieldArea)
* [SingleDataRecord](https://cloud.tencent.com/document/api/1552/80721#SingleDataRecord)
* [SingleTypeValue](https://cloud.tencent.com/document/api/1552/80721#SingleTypeValue)
* [SmartRouting](https://cloud.tencent.com/document/api/1552/80721#SmartRouting)
* [Sort](https://cloud.tencent.com/document/api/1552/80721#Sort)
* [SpeedTestingConfig](https://cloud.tencent.com/document/api/1552/80721#SpeedTestingConfig)
* [SpeedTestingDetailData](https://cloud.tencent.com/document/api/1552/80721#SpeedTestingDetailData)
* [SpeedTestingInfo](https://cloud.tencent.com/document/api/1552/80721#SpeedTestingInfo)
* [SpeedTestingMetricData](https://cloud.tencent.com/document/api/1552/80721#SpeedTestingMetricData)
* [SpeedTestingQuota](https://cloud.tencent.com/document/api/1552/80721#SpeedTestingQuota)
* [SpeedTestingStatistics](https://cloud.tencent.com/document/api/1552/80721#SpeedTestingStatistics)
* [SpeedTestingStatus](https://cloud.tencent.com/document/api/1552/80721#SpeedTestingStatus)
* [Sv](https://cloud.tencent.com/document/api/1552/80721#Sv)
* [SwitchConfig](https://cloud.tencent.com/document/api/1552/80721#SwitchConfig)
* [Tag](https://cloud.tencent.com/document/api/1552/80721#Tag)
* [Task](https://cloud.tencent.com/document/api/1552/80721#Task)
* [TimingDataItem](https://cloud.tencent.com/document/api/1552/80721#TimingDataItem)
* [TimingDataRecord](https://cloud.tencent.com/document/api/1552/80721#TimingDataRecord)
* [TimingTypeValue](https://cloud.tencent.com/document/api/1552/80721#TimingTypeValue)
* [TopDataRecord](https://cloud.tencent.com/document/api/1552/80721#TopDataRecord)
* [TopDetailData](https://cloud.tencent.com/document/api/1552/80721#TopDetailData)
* [TopEntry](https://cloud.tencent.com/document/api/1552/80721#TopEntry)
* [TopEntryValue](https://cloud.tencent.com/document/api/1552/80721#TopEntryValue)
* [UpstreamHttp2](https://cloud.tencent.com/document/api/1552/80721#UpstreamHttp2)
* [VanityNameServers](https://cloud.tencent.com/document/api/1552/80721#VanityNameServers)
* [VanityNameServersIps](https://cloud.tencent.com/document/api/1552/80721#VanityNameServersIps)
* [Waf](https://cloud.tencent.com/document/api/1552/80721#Waf)
* [WafConfig](https://cloud.tencent.com/document/api/1552/80721#WafConfig)
* [WafGroup](https://cloud.tencent.com/document/api/1552/80721#WafGroup)
* [WafGroupDetail](https://cloud.tencent.com/document/api/1552/80721#WafGroupDetail)
* [WafGroupInfo](https://cloud.tencent.com/document/api/1552/80721#WafGroupInfo)
* [WafGroupRule](https://cloud.tencent.com/document/api/1552/80721#WafGroupRule)
* [WafRule](https://cloud.tencent.com/document/api/1552/80721#WafRule)
* [WebLogs](https://cloud.tencent.com/document/api/1552/80721#WebLogs)
* [WebSocket](https://cloud.tencent.com/document/api/1552/80721#WebSocket)
* [Zone](https://cloud.tencent.com/document/api/1552/80721#Zone)
* [ZoneSetting](https://cloud.tencent.com/document/api/1552/80721#ZoneSetting)




## 高性能计算平台(thpc) 版本：2021-11-09

### 第 9 次发布

发布时间：2022-04-27 06:17:04

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [BindAutoScalingGroup](https://cloud.tencent.com/document/api/1527/66099)

	* 新增入参：QueueName


### 第 8 次发布

发布时间：2022-04-01 06:15:33

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateCluster](https://cloud.tencent.com/document/api/1527/64905)

	* 新增入参：LoginNode, LoginNodeCount, Tags


新增数据结构：

* [LoginNode](https://cloud.tencent.com/document/api/1527/64906#LoginNode)
* [Tag](https://cloud.tencent.com/document/api/1527/64906#Tag)

### 第 7 次发布

发布时间：2022-03-30 06:13:05

本次发布包含了以下内容：

改善已有的文档。

新增数据结构：

* [LoginNodeOverview](https://cloud.tencent.com/document/api/1527/64906#LoginNodeOverview)

修改数据结构：

* [ClusterOverview](https://cloud.tencent.com/document/api/1527/64906#ClusterOverview)

	* 新增成员：LoginNodeSet, LoginNodeCount


### 第 6 次发布

发布时间：2021-12-22 08:17:26

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeClusters](https://cloud.tencent.com/document/api/1527/66646)

新增数据结构：

* [ClusterOverview](https://cloud.tencent.com/document/api/1527/64906#ClusterOverview)
* [ComputeNodeOverview](https://cloud.tencent.com/document/api/1527/64906#ComputeNodeOverview)
* [ManagerNodeOverview](https://cloud.tencent.com/document/api/1527/64906#ManagerNodeOverview)

### 第 5 次发布

发布时间：2021-12-21 08:11:27

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [CFSOption](https://cloud.tencent.com/document/api/1527/64906#CFSOption)

	* <font color="#dd0000">**修改成员**：</font>Protocol, StorageType


### 第 4 次发布

发布时间：2021-12-16 08:15:07

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [BindAutoScalingGroup](https://cloud.tencent.com/document/api/1527/66099)

### 第 3 次发布

发布时间：2021-12-15 08:13:47

本次发布包含了以下内容：

改善已有的文档。

新增数据结构：

* [GooseFSOption](https://cloud.tencent.com/document/api/1527/64906#GooseFSOption)

修改数据结构：

* [StorageOption](https://cloud.tencent.com/document/api/1527/64906#StorageOption)

	* 新增成员：GooseFSOptions

	* <font color="#dd0000">**修改成员**：</font>CFSOptions


### 第 2 次发布

发布时间：2021-12-13 08:14:47

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateCluster](https://cloud.tencent.com/document/api/1527/64905)

	* 新增入参：StorageOption


新增数据结构：

* [CFSOption](https://cloud.tencent.com/document/api/1527/64906#CFSOption)
* [StorageOption](https://cloud.tencent.com/document/api/1527/64906#StorageOption)

### 第 1 次发布

发布时间：2021-11-29 12:09:18

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateCluster](https://cloud.tencent.com/document/api/1527/64905)
* [DeleteCluster](https://cloud.tencent.com/document/api/1527/64904)

新增数据结构：

* [ComputeNode](https://cloud.tencent.com/document/api/1527/64906#ComputeNode)
* [DataDisk](https://cloud.tencent.com/document/api/1527/64906#DataDisk)
* [InstanceChargePrepaid](https://cloud.tencent.com/document/api/1527/64906#InstanceChargePrepaid)
* [InternetAccessible](https://cloud.tencent.com/document/api/1527/64906#InternetAccessible)
* [LoginSettings](https://cloud.tencent.com/document/api/1527/64906#LoginSettings)
* [ManagerNode](https://cloud.tencent.com/document/api/1527/64906#ManagerNode)
* [Placement](https://cloud.tencent.com/document/api/1527/64906#Placement)
* [SystemDisk](https://cloud.tencent.com/document/api/1527/64906#SystemDisk)
* [VirtualPrivateCloud](https://cloud.tencent.com/document/api/1527/64906#VirtualPrivateCloud)



## 高性能计算平台(thpc) 版本：2022-04-01

### 第 12 次发布

发布时间：2023-02-27 01:46:46

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [AddQueue](https://cloud.tencent.com/document/api/1527/86911)
* [DeleteQueue](https://cloud.tencent.com/document/api/1527/86910)
* [DescribeNodes](https://cloud.tencent.com/document/api/1527/86912)
* [DescribeQueues](https://cloud.tencent.com/document/api/1527/86909)

新增数据结构：

* [Filter](https://cloud.tencent.com/document/api/1527/72108#Filter)
* [NodeOverview](https://cloud.tencent.com/document/api/1527/72108#NodeOverview)
* [QueueOverview](https://cloud.tencent.com/document/api/1527/72108#QueueOverview)

### 第 11 次发布

发布时间：2023-02-22 01:58:40

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [AddNodes](https://cloud.tencent.com/document/api/1527/72105)

	* 新增入参：NodeType


### 第 10 次发布

发布时间：2023-02-08 02:08:58

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [AddNodes](https://cloud.tencent.com/document/api/1527/72105)

	* <font color="#dd0000">**修改入参**：</font>ImageId


### 第 9 次发布

发布时间：2023-01-11 01:46:25

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeAutoScalingConfiguration](https://cloud.tencent.com/document/api/1527/85635)

新增数据结构：

* [ExpansionNodeConfigOverview](https://cloud.tencent.com/document/api/1527/72108#ExpansionNodeConfigOverview)
* [QueueConfigOverview](https://cloud.tencent.com/document/api/1527/72108#QueueConfigOverview)

### 第 8 次发布

发布时间：2023-01-10 01:50:30

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeClusterStorageOption](https://cloud.tencent.com/document/api/1527/84385)

	* 新增出参：StorageOption


新增数据结构：

* [CFSOptionOverview](https://cloud.tencent.com/document/api/1527/72108#CFSOptionOverview)
* [GooseFSOptionOverview](https://cloud.tencent.com/document/api/1527/72108#GooseFSOptionOverview)
* [StorageOptionOverview](https://cloud.tencent.com/document/api/1527/72108#StorageOptionOverview)

### 第 7 次发布

发布时间：2022-12-21 02:09:45

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [AddClusterStorageOption](https://cloud.tencent.com/document/api/1527/84387)
* [DeleteClusterStorageOption](https://cloud.tencent.com/document/api/1527/84386)
* [DescribeClusterStorageOption](https://cloud.tencent.com/document/api/1527/84385)

### 第 6 次发布

发布时间：2022-11-16 06:42:38

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeClusterActivities](https://cloud.tencent.com/document/api/1527/82937)

新增数据结构：

* [ClusterActivity](https://cloud.tencent.com/document/api/1527/72108#ClusterActivity)
* [NodeActivity](https://cloud.tencent.com/document/api/1527/72108#NodeActivity)

### 第 5 次发布

发布时间：2022-11-04 06:42:08

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateCluster](https://cloud.tencent.com/document/api/1527/72102)

	* 新增入参：AutoScalingType


### 第 4 次发布

发布时间：2022-10-27 07:00:42

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [ClusterOverview](https://cloud.tencent.com/document/api/1527/72108#ClusterOverview)

	* 新增成员：VpcId


### 第 3 次发布

发布时间：2022-10-21 06:49:31

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [SetAutoScalingConfiguration](https://cloud.tencent.com/document/api/1527/81796)

新增数据结构：

* [ExpansionNodeConfig](https://cloud.tencent.com/document/api/1527/72108#ExpansionNodeConfig)
* [QueueConfig](https://cloud.tencent.com/document/api/1527/72108#QueueConfig)

### 第 2 次发布

发布时间：2022-04-27 10:43:23

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [BindAutoScalingGroup](https://cloud.tencent.com/document/api/1527/72107)

	* 新增入参：QueueName


### 第 1 次发布

发布时间：2022-04-04 11:19:56

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [AddNodes](https://cloud.tencent.com/document/api/1527/72105)
* [BindAutoScalingGroup](https://cloud.tencent.com/document/api/1527/72107)
* [CreateCluster](https://cloud.tencent.com/document/api/1527/72102)
* [DeleteCluster](https://cloud.tencent.com/document/api/1527/72101)
* [DeleteNodes](https://cloud.tencent.com/document/api/1527/72104)
* [DescribeClusters](https://cloud.tencent.com/document/api/1527/72100)

新增数据结构：

* [CFSOption](https://cloud.tencent.com/document/api/1527/72108#CFSOption)
* [ClusterOverview](https://cloud.tencent.com/document/api/1527/72108#ClusterOverview)
* [ComputeNode](https://cloud.tencent.com/document/api/1527/72108#ComputeNode)
* [ComputeNodeOverview](https://cloud.tencent.com/document/api/1527/72108#ComputeNodeOverview)
* [DataDisk](https://cloud.tencent.com/document/api/1527/72108#DataDisk)
* [GooseFSOption](https://cloud.tencent.com/document/api/1527/72108#GooseFSOption)
* [InstanceChargePrepaid](https://cloud.tencent.com/document/api/1527/72108#InstanceChargePrepaid)
* [InternetAccessible](https://cloud.tencent.com/document/api/1527/72108#InternetAccessible)
* [LoginNode](https://cloud.tencent.com/document/api/1527/72108#LoginNode)
* [LoginNodeOverview](https://cloud.tencent.com/document/api/1527/72108#LoginNodeOverview)
* [LoginSettings](https://cloud.tencent.com/document/api/1527/72108#LoginSettings)
* [ManagerNode](https://cloud.tencent.com/document/api/1527/72108#ManagerNode)
* [ManagerNodeOverview](https://cloud.tencent.com/document/api/1527/72108#ManagerNodeOverview)
* [Placement](https://cloud.tencent.com/document/api/1527/72108#Placement)
* [StorageOption](https://cloud.tencent.com/document/api/1527/72108#StorageOption)
* [SystemDisk](https://cloud.tencent.com/document/api/1527/72108#SystemDisk)
* [Tag](https://cloud.tencent.com/document/api/1527/72108#Tag)
* [VirtualPrivateCloud](https://cloud.tencent.com/document/api/1527/72108#VirtualPrivateCloud)



## 高性能计算平台(thpc) 版本：2023-03-21

### 第 16 次发布

发布时间：2024-07-24 02:16:49

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [AttachNodes](https://cloud.tencent.com/document/api/1527/109158)
* [DetachNodes](https://cloud.tencent.com/document/api/1527/109157)

修改接口：

* [AddNodes](https://cloud.tencent.com/document/api/1527/89571)

	* 新增入参：ResourceType


修改数据结构：

* [ComputeNode](https://cloud.tencent.com/document/api/1527/89579#ComputeNode)

	* 新增成员：ResourceType

* [NodeOverview](https://cloud.tencent.com/document/api/1527/89579#NodeOverview)

	* 新增成员：NodeId

	* <font color="#dd0000">**修改成员**：</font>InstanceId, Zone, NodeState, ImageId, QueueName, NodeRole, NodeType


### 第 15 次发布

发布时间：2024-07-12 01:26:38

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [LoginSettings](https://cloud.tencent.com/document/api/1527/89579#LoginSettings)

	* 新增成员：KeyIds


### 第 14 次发布

发布时间：2024-06-27 01:21:12

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateCluster](https://cloud.tencent.com/document/api/1527/89563)

	* 新增入参：SchedulerVersion


修改数据结构：

* [ClusterOverview](https://cloud.tencent.com/document/api/1527/89579#ClusterOverview)

	* 新增成员：SchedulerVersion


### 第 13 次发布

发布时间：2023-11-06 00:21:33

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [ManagerNode](https://cloud.tencent.com/document/api/1527/89579#ManagerNode)

	* 新增成员：EnhancedService


### 第 12 次发布

发布时间：2023-09-21 06:17:00

本次发布包含了以下内容：

改善已有的文档。

新增数据结构：

* [EnhancedService](https://cloud.tencent.com/document/api/1527/89579#EnhancedService)
* [RunAutomationServiceEnabled](https://cloud.tencent.com/document/api/1527/89579#RunAutomationServiceEnabled)
* [RunMonitorServiceEnabled](https://cloud.tencent.com/document/api/1527/89579#RunMonitorServiceEnabled)
* [RunSecurityServiceEnabled](https://cloud.tencent.com/document/api/1527/89579#RunSecurityServiceEnabled)

修改数据结构：

* [QueueConfig](https://cloud.tencent.com/document/api/1527/89579#QueueConfig)

	* 新增成员：EnhancedService


### 第 11 次发布

发布时间：2023-09-14 02:31:21

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateCluster](https://cloud.tencent.com/document/api/1527/89563)

	* 新增入参：HpcClusterId


### 第 10 次发布

发布时间：2023-09-07 02:37:25

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [QueueConfig](https://cloud.tencent.com/document/api/1527/89579#QueueConfig)

	* 新增成员：ScaleUpMemRatio

* [QueueConfigOverview](https://cloud.tencent.com/document/api/1527/89579#QueueConfigOverview)

	* 新增成员：ScaleUpMemRatio


### 第 9 次发布

发布时间：2023-09-06 02:32:29

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [QueueConfigOverview](https://cloud.tencent.com/document/api/1527/89579#QueueConfigOverview)

	* <font color="#dd0000">**修改成员**：</font>QueueName, MinSize, MaxSize, EnableAutoExpansion, EnableAutoShrink, ExpansionNodeConfigs, DesiredIdleNodeCapacity, ScaleOutRatio, ScaleOutNodeThreshold, MaxNodesPerCycle


### 第 8 次发布

发布时间：2023-06-15 01:38:28

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [CFSOption](https://cloud.tencent.com/document/api/1527/89579#CFSOption)

	* 新增成员：MountOption

* [CFSOptionOverview](https://cloud.tencent.com/document/api/1527/89579#CFSOptionOverview)

	* 新增成员：MountOption


### 第 7 次发布

发布时间：2023-06-12 01:40:28

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [QueueConfig](https://cloud.tencent.com/document/api/1527/89579#QueueConfig)

	* 新增成员：MaxNodesPerCycle

* [QueueConfigOverview](https://cloud.tencent.com/document/api/1527/89579#QueueConfigOverview)

	* 新增成员：MaxNodesPerCycle


### 第 6 次发布

发布时间：2023-05-31 01:45:41

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [AddNodes](https://cloud.tencent.com/document/api/1527/89571)

	* 新增入参：ProjectId


修改数据结构：

* [ComputeNode](https://cloud.tencent.com/document/api/1527/89579#ComputeNode)

	* 新增成员：ProjectId

* [ExpansionNodeConfig](https://cloud.tencent.com/document/api/1527/89579#ExpansionNodeConfig)

	* 新增成员：ProjectId

* [LoginNode](https://cloud.tencent.com/document/api/1527/89579#LoginNode)

	* 新增成员：ProjectId

* [ManagerNode](https://cloud.tencent.com/document/api/1527/89579#ManagerNode)

	* 新增成员：ProjectId


### 第 5 次发布

发布时间：2023-05-29 15:05:43

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [ClusterOverview](https://cloud.tencent.com/document/api/1527/89579#ClusterOverview)

	* 新增成员：AutoScalingType


### 第 4 次发布

发布时间：2023-05-19 02:07:25

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [QueueConfig](https://cloud.tencent.com/document/api/1527/89579#QueueConfig)

	* 新增成员：ScaleOutRatio, ScaleOutNodeThreshold

* [QueueConfigOverview](https://cloud.tencent.com/document/api/1527/89579#QueueConfigOverview)

	* 新增成员：ScaleOutRatio, ScaleOutNodeThreshold


### 第 3 次发布

发布时间：2023-05-09 01:46:09

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeInitNodeScripts](https://cloud.tencent.com/document/api/1527/90856)

### 第 2 次发布

发布时间：2023-05-01 01:41:10

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [ModifyInitNodeScripts](https://cloud.tencent.com/document/api/1527/90753)

修改接口：

* [CreateCluster](https://cloud.tencent.com/document/api/1527/89563)

	* 新增入参：InitNodeScripts


新增数据结构：

* [NodeScript](https://cloud.tencent.com/document/api/1527/89579#NodeScript)

修改数据结构：

* [QueueConfig](https://cloud.tencent.com/document/api/1527/89579#QueueConfig)

	* 新增成员：DesiredIdleNodeCapacity

* [QueueConfigOverview](https://cloud.tencent.com/document/api/1527/89579#QueueConfigOverview)

	* 新增成员：DesiredIdleNodeCapacity


### 第 1 次发布

发布时间：2023-03-29 12:01:10

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [AddClusterStorageOption](https://cloud.tencent.com/document/api/1527/89578)
* [AddNodes](https://cloud.tencent.com/document/api/1527/89571)
* [AddQueue](https://cloud.tencent.com/document/api/1527/89567)
* [CreateCluster](https://cloud.tencent.com/document/api/1527/89563)
* [DeleteCluster](https://cloud.tencent.com/document/api/1527/89562)
* [DeleteClusterStorageOption](https://cloud.tencent.com/document/api/1527/89577)
* [DeleteNodes](https://cloud.tencent.com/document/api/1527/89570)
* [DeleteQueue](https://cloud.tencent.com/document/api/1527/89566)
* [DescribeAutoScalingConfiguration](https://cloud.tencent.com/document/api/1527/89574)
* [DescribeClusterActivities](https://cloud.tencent.com/document/api/1527/89561)
* [DescribeClusterStorageOption](https://cloud.tencent.com/document/api/1527/89576)
* [DescribeClusters](https://cloud.tencent.com/document/api/1527/89560)
* [DescribeNodes](https://cloud.tencent.com/document/api/1527/89569)
* [DescribeQueues](https://cloud.tencent.com/document/api/1527/89565)
* [SetAutoScalingConfiguration](https://cloud.tencent.com/document/api/1527/89573)

新增数据结构：

* [CFSOption](https://cloud.tencent.com/document/api/1527/89579#CFSOption)
* [CFSOptionOverview](https://cloud.tencent.com/document/api/1527/89579#CFSOptionOverview)
* [ClusterActivity](https://cloud.tencent.com/document/api/1527/89579#ClusterActivity)
* [ClusterOverview](https://cloud.tencent.com/document/api/1527/89579#ClusterOverview)
* [ComputeNode](https://cloud.tencent.com/document/api/1527/89579#ComputeNode)
* [ComputeNodeOverview](https://cloud.tencent.com/document/api/1527/89579#ComputeNodeOverview)
* [DataDisk](https://cloud.tencent.com/document/api/1527/89579#DataDisk)
* [ExpansionNodeConfig](https://cloud.tencent.com/document/api/1527/89579#ExpansionNodeConfig)
* [ExpansionNodeConfigOverview](https://cloud.tencent.com/document/api/1527/89579#ExpansionNodeConfigOverview)
* [Filter](https://cloud.tencent.com/document/api/1527/89579#Filter)
* [GooseFSOption](https://cloud.tencent.com/document/api/1527/89579#GooseFSOption)
* [GooseFSOptionOverview](https://cloud.tencent.com/document/api/1527/89579#GooseFSOptionOverview)
* [GooseFSxOption](https://cloud.tencent.com/document/api/1527/89579#GooseFSxOption)
* [GooseFSxOptionOverview](https://cloud.tencent.com/document/api/1527/89579#GooseFSxOptionOverview)
* [InstanceChargePrepaid](https://cloud.tencent.com/document/api/1527/89579#InstanceChargePrepaid)
* [InternetAccessible](https://cloud.tencent.com/document/api/1527/89579#InternetAccessible)
* [LoginNode](https://cloud.tencent.com/document/api/1527/89579#LoginNode)
* [LoginNodeOverview](https://cloud.tencent.com/document/api/1527/89579#LoginNodeOverview)
* [LoginSettings](https://cloud.tencent.com/document/api/1527/89579#LoginSettings)
* [ManagerNode](https://cloud.tencent.com/document/api/1527/89579#ManagerNode)
* [ManagerNodeOverview](https://cloud.tencent.com/document/api/1527/89579#ManagerNodeOverview)
* [NodeActivity](https://cloud.tencent.com/document/api/1527/89579#NodeActivity)
* [NodeOverview](https://cloud.tencent.com/document/api/1527/89579#NodeOverview)
* [Placement](https://cloud.tencent.com/document/api/1527/89579#Placement)
* [QueueConfig](https://cloud.tencent.com/document/api/1527/89579#QueueConfig)
* [QueueConfigOverview](https://cloud.tencent.com/document/api/1527/89579#QueueConfigOverview)
* [QueueOverview](https://cloud.tencent.com/document/api/1527/89579#QueueOverview)
* [StorageOption](https://cloud.tencent.com/document/api/1527/89579#StorageOption)
* [StorageOptionOverview](https://cloud.tencent.com/document/api/1527/89579#StorageOptionOverview)
* [SystemDisk](https://cloud.tencent.com/document/api/1527/89579#SystemDisk)
* [Tag](https://cloud.tencent.com/document/api/1527/89579#Tag)
* [VirtualPrivateCloud](https://cloud.tencent.com/document/api/1527/89579#VirtualPrivateCloud)




## 智能钛机器学习(tia) 版本：2018-02-26

### 第 3 次发布

发布时间：2019-02-22 16:44:16

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [Model](https://cloud.tencent.com/document/api/851/18316#Model)

	* 新增成员：Id, Uin, DelTime


### 第 2 次发布

发布时间：2018-09-20 10:55:41

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateJob](https://cloud.tencent.com/document/api/851/18308)

	* 新增入参：RuntimeConf

* [CreateModel](https://cloud.tencent.com/document/api/851/18315)

	* 新增入参：RuntimeConf

	* <font color="#dd0000">**修改入参**：</font>Cluster

* [DeleteModel](https://cloud.tencent.com/document/api/851/18314)

	* 新增入参：ServType

	* <font color="#dd0000">**修改入参**：</font>Cluster

* [DescribeModel](https://cloud.tencent.com/document/api/851/18313)

	* 新增入参：ServType

	* <font color="#dd0000">**修改入参**：</font>Cluster

* [ListModels](https://cloud.tencent.com/document/api/851/18312)

	* 新增入参：ServType

	* <font color="#dd0000">**修改入参**：</font>Cluster


修改数据结构：

* [Job](https://cloud.tencent.com/document/api/851/18316#Job)

	* 新增成员：RuntimeConf, Id


### 第 1 次发布

发布时间：2018-07-12 17:03:28

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateJob](https://cloud.tencent.com/document/api/851/18308)
* [CreateModel](https://cloud.tencent.com/document/api/851/18315)
* [DeleteJob](https://cloud.tencent.com/document/api/851/18307)
* [DeleteModel](https://cloud.tencent.com/document/api/851/18314)
* [DescribeJob](https://cloud.tencent.com/document/api/851/18306)
* [DescribeModel](https://cloud.tencent.com/document/api/851/18313)
* [InstallAgent](https://cloud.tencent.com/document/api/851/18303)
* [ListJobs](https://cloud.tencent.com/document/api/851/18305)
* [ListModels](https://cloud.tencent.com/document/api/851/18312)
* [QueryLogs](https://cloud.tencent.com/document/api/851/18310)

新增数据结构：

* [Job](https://cloud.tencent.com/document/api/851/18316#Job)
* [Log](https://cloud.tencent.com/document/api/851/18316#Log)
* [Model](https://cloud.tencent.com/document/api/851/18316#Model)




## 资源编排 TIC(tic) 版本：2020-11-17

### 第 1 次发布

发布时间：2020-12-02 15:48:30

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [ApplyStack](https://cloud.tencent.com/document/api/1213/50597)
* [CreateStack](https://cloud.tencent.com/document/api/1213/50586)
* [CreateStackVersion](https://cloud.tencent.com/document/api/1213/50591)
* [DeleteStack](https://cloud.tencent.com/document/api/1213/50585)
* [DeleteStackVersion](https://cloud.tencent.com/document/api/1213/50590)
* [DescribeStackEvent](https://cloud.tencent.com/document/api/1213/50596)
* [DescribeStackEvents](https://cloud.tencent.com/document/api/1213/50595)
* [DescribeStackVersions](https://cloud.tencent.com/document/api/1213/50589)
* [DescribeStacks](https://cloud.tencent.com/document/api/1213/50584)
* [DestroyStack](https://cloud.tencent.com/document/api/1213/50594)
* [PlanStack](https://cloud.tencent.com/document/api/1213/50593)
* [UpdateStack](https://cloud.tencent.com/document/api/1213/50583)
* [UpdateStackVersion](https://cloud.tencent.com/document/api/1213/50588)

新增数据结构：

* [EventInfo](https://cloud.tencent.com/document/api/1213/50598#EventInfo)
* [Filter](https://cloud.tencent.com/document/api/1213/50598#Filter)
* [StackInfo](https://cloud.tencent.com/document/api/1213/50598#StackInfo)
* [VersionInfo](https://cloud.tencent.com/document/api/1213/50598#VersionInfo)




## 智能鉴黄(ticm) 版本：2018-11-27

### 第 2 次发布

发布时间：2020-03-16 08:19:11

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeVideoTask](https://cloud.tencent.com/document/api/864/42308)
* [VideoModeration](https://cloud.tencent.com/document/api/864/42307)

新增数据结构：

* [VodAsrTextSegmentItem](https://cloud.tencent.com/document/api/864/34487#VodAsrTextSegmentItem)
* [VodAudioStreamItem](https://cloud.tencent.com/document/api/864/34487#VodAudioStreamItem)
* [VodMetaData](https://cloud.tencent.com/document/api/864/34487#VodMetaData)
* [VodOcrTextSegmentItem](https://cloud.tencent.com/document/api/864/34487#VodOcrTextSegmentItem)
* [VodPoliticalAsrReviewResult](https://cloud.tencent.com/document/api/864/34487#VodPoliticalAsrReviewResult)
* [VodPoliticalOcrReviewResult](https://cloud.tencent.com/document/api/864/34487#VodPoliticalOcrReviewResult)
* [VodPoliticalReviewResult](https://cloud.tencent.com/document/api/864/34487#VodPoliticalReviewResult)
* [VodPoliticalReviewSegmentItem](https://cloud.tencent.com/document/api/864/34487#VodPoliticalReviewSegmentItem)
* [VodPornAsrReviewResult](https://cloud.tencent.com/document/api/864/34487#VodPornAsrReviewResult)
* [VodPornOcrResult](https://cloud.tencent.com/document/api/864/34487#VodPornOcrResult)
* [VodPornReviewResult](https://cloud.tencent.com/document/api/864/34487#VodPornReviewResult)
* [VodPornReviewSegmentItem](https://cloud.tencent.com/document/api/864/34487#VodPornReviewSegmentItem)
* [VodTerrorismReviewResult](https://cloud.tencent.com/document/api/864/34487#VodTerrorismReviewResult)
* [VodVideoStreamItem](https://cloud.tencent.com/document/api/864/34487#VodVideoStreamItem)

### 第 1 次发布

发布时间：2019-04-26 14:53:40

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [ImageModeration](https://cloud.tencent.com/document/api/864/34486)

新增数据结构：

* [Candidate](https://cloud.tencent.com/document/api/864/34487#Candidate)
* [DisgustResult](https://cloud.tencent.com/document/api/864/34487#DisgustResult)
* [FaceRect](https://cloud.tencent.com/document/api/864/34487#FaceRect)
* [FaceResult](https://cloud.tencent.com/document/api/864/34487#FaceResult)
* [PoliticsResult](https://cloud.tencent.com/document/api/864/34487#PoliticsResult)
* [PornResult](https://cloud.tencent.com/document/api/864/34487#PornResult)
* [TerrorismResult](https://cloud.tencent.com/document/api/864/34487#TerrorismResult)




## 威胁情报云查服务(tics) 版本：2018-11-15

### 第 1 次发布

发布时间：2018-12-19 10:03:28

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeDomainInfo](https://cloud.tencent.com/document/api/1013/31749)
* [DescribeFileInfo](https://cloud.tencent.com/document/api/1013/31748)
* [DescribeIpInfo](https://cloud.tencent.com/document/api/1013/31747)
* [DescribeThreatInfo](https://cloud.tencent.com/document/api/1013/31746)

新增数据结构：

* [FileInfoType](https://cloud.tencent.com/document/api/1013/31750#FileInfoType)
* [IntelligenceType](https://cloud.tencent.com/document/api/1013/31750#IntelligenceType)
* [TagType](https://cloud.tencent.com/document/api/1013/31750#TagType)




## 智能钛弹性模型服务TI-EMS(tiems) 版本：2019-04-16

### 第 7 次发布

发布时间：2020-04-01 08:39:10

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateJob](https://cloud.tencent.com/document/api/1120/39242)

	* 新增入参：LogTopicId

* [CreateRsgAsGroup](https://cloud.tencent.com/document/api/1120/40695)

	* 新增入参：InstanceType, DesiredSize

* [CreateService](https://cloud.tencent.com/document/api/1120/37560)

	* 新增入参：LogTopicId

* [UpdateRsgAsGroup](https://cloud.tencent.com/document/api/1120/40686)

	* 新增入参：DesiredSize

* [UpdateService](https://cloud.tencent.com/document/api/1120/37557)

	* 新增入参：LogTopicId


### 第 6 次发布

发布时间：2020-03-30 08:45:21

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [RsgAsGroup](https://cloud.tencent.com/document/api/1120/37561#RsgAsGroup)

	* 新增成员：DesiredSize


### 第 5 次发布

发布时间：2020-03-16 08:19:19

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [UpdateRsgAsGroup](https://cloud.tencent.com/document/api/1120/40686)

	* 新增入参：MaxSize, MinSize


修改数据结构：

* [Job](https://cloud.tencent.com/document/api/1120/37561#Job)

	* 新增成员：LogTopicId

* [JobStatus](https://cloud.tencent.com/document/api/1120/37561#JobStatus)

	* 新增成员：ReplicaInfos

* [ModelService](https://cloud.tencent.com/document/api/1120/37561#ModelService)

	* 新增成员：LogTopicId


### 第 4 次发布

发布时间：2020-01-02 17:10:55

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateRsgAsGroup](https://cloud.tencent.com/document/api/1120/40695)
* [DeleteInstance](https://cloud.tencent.com/document/api/1120/40694)
* [DeleteResourceGroup](https://cloud.tencent.com/document/api/1120/40693)
* [DeleteRsgAsGroup](https://cloud.tencent.com/document/api/1120/40692)
* [DescribeResourceGroups](https://cloud.tencent.com/document/api/1120/40691)
* [DescribeRsgAsGroupActivities](https://cloud.tencent.com/document/api/1120/40690)
* [DescribeRsgAsGroups](https://cloud.tencent.com/document/api/1120/40689)
* [DisableRsgAsGroup](https://cloud.tencent.com/document/api/1120/40688)
* [EnableRsgAsGroup](https://cloud.tencent.com/document/api/1120/40687)
* [UpdateRsgAsGroup](https://cloud.tencent.com/document/api/1120/40686)

修改接口：

* [CreateJob](https://cloud.tencent.com/document/api/1120/39242)

	* 新增入参：QuantizationInput

	* <font color="#dd0000">**修改入参**：</font>ResourceGroupId, WorkerCount, ConfigId

* [CreateService](https://cloud.tencent.com/document/api/1120/37560)

	* <font color="#dd0000">**修改入参**：</font>ResourceGroupId

* [UpdateService](https://cloud.tencent.com/document/api/1120/37557)

	* 新增入参：Cpu, Memory, Gpu


新增数据结构：

* [QuantizationInput](https://cloud.tencent.com/document/api/1120/37561#QuantizationInput)
* [ReplicaInfo](https://cloud.tencent.com/document/api/1120/37561#ReplicaInfo)
* [ResourceGroup](https://cloud.tencent.com/document/api/1120/37561#ResourceGroup)
* [RsgAsActivityRelatedInstance](https://cloud.tencent.com/document/api/1120/37561#RsgAsActivityRelatedInstance)
* [RsgAsGroup](https://cloud.tencent.com/document/api/1120/37561#RsgAsGroup)
* [RsgAsGroupActivity](https://cloud.tencent.com/document/api/1120/37561#RsgAsGroupActivity)

修改数据结构：

* [ExposeInfo](https://cloud.tencent.com/document/api/1120/37561#ExposeInfo)

	* 新增成员：GateWayServiceId, GateWayAPIId, GateWayDomain

* [Instance](https://cloud.tencent.com/document/api/1120/37561#Instance)

	* 新增成员：RsgAsGroupId

* [Job](https://cloud.tencent.com/document/api/1120/37561#Job)

	* 新增成员：JobType, QuantizationInput

* [ServiceStatus](https://cloud.tencent.com/document/api/1120/37561#ServiceStatus)

	* 新增成员：ReplicaInfos


### 第 3 次发布

发布时间：2019-11-15 17:20:20

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [ExposeService](https://cloud.tencent.com/document/api/1120/39263)

新增数据结构：

* [ExposeInfo](https://cloud.tencent.com/document/api/1120/37561#ExposeInfo)

<font color="#dd0000">**删除数据结构**：</font>

* Expose

修改数据结构：

* [ModelService](https://cloud.tencent.com/document/api/1120/37561#ModelService)

	* <font color="#dd0000">**修改成员**：</font>Exposes


### 第 2 次发布

发布时间：2019-11-14 21:54:14

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateJob](https://cloud.tencent.com/document/api/1120/39242)
* [CreateRuntime](https://cloud.tencent.com/document/api/1120/39238)
* [DeleteJob](https://cloud.tencent.com/document/api/1120/39241)
* [DeleteRuntime](https://cloud.tencent.com/document/api/1120/39237)
* [DescribeInstances](https://cloud.tencent.com/document/api/1120/39234)
* [UpdateJob](https://cloud.tencent.com/document/api/1120/39240)

修改接口：

* [CreateService](https://cloud.tencent.com/document/api/1120/37560)

	* 新增入参：Cpu, Memory, ResourceGroupId, Authentication, Gpu, GpuMemory, Description, GpuType

	* <font color="#dd0000">**修改入参**：</font>ServiceConfigId

	* <font color="#dd0000">**修改出参**：</font>Service

* [CreateServiceConfig](https://cloud.tencent.com/document/api/1120/37555)

	* 新增入参：Description

	* <font color="#dd0000">**删除入参**：</font>Cpu, Memory, TflopUnits, GpuMemory

	* <font color="#dd0000">**修改出参**：</font>ServiceConfig

* [DeleteService](https://cloud.tencent.com/document/api/1120/37559)

	* <font color="#dd0000">**修改入参**：</font>ServiceId

* [DeleteServiceConfig](https://cloud.tencent.com/document/api/1120/37554)

	* <font color="#dd0000">**修改入参**：</font>ServiceConfigId

* [DescribeServiceConfigs](https://cloud.tencent.com/document/api/1120/37552)

	* 新增入参：PageByName

	* <font color="#dd0000">**修改出参**：</font>ServiceConfigs

* [DescribeServices](https://cloud.tencent.com/document/api/1120/37558)

	* <font color="#dd0000">**修改出参**：</font>Services

* [UpdateService](https://cloud.tencent.com/document/api/1120/37557)

	* 新增入参：Description, GpuType

	* <font color="#dd0000">**修改入参**：</font>ServiceId, ServiceConfigId

	* <font color="#dd0000">**修改出参**：</font>Service


新增数据结构：

* [Config](https://cloud.tencent.com/document/api/1120/37561#Config)
* [Expose](https://cloud.tencent.com/document/api/1120/37561#Expose)
* [Instance](https://cloud.tencent.com/document/api/1120/37561#Instance)
* [Job](https://cloud.tencent.com/document/api/1120/37561#Job)
* [JobStatus](https://cloud.tencent.com/document/api/1120/37561#JobStatus)
* [ModelService](https://cloud.tencent.com/document/api/1120/37561#ModelService)
* [PredictInput](https://cloud.tencent.com/document/api/1120/37561#PredictInput)

<font color="#dd0000">**删除数据结构**：</font>

* Service
* ServiceConfig

修改数据结构：

* [ServiceStatus](https://cloud.tencent.com/document/api/1120/37561#ServiceStatus)

	* 新增成员：Message


### 第 1 次发布

发布时间：2019-08-27 16:02:42

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateService](https://cloud.tencent.com/document/api/1120/37560)
* [CreateServiceConfig](https://cloud.tencent.com/document/api/1120/37555)
* [DeleteService](https://cloud.tencent.com/document/api/1120/37559)
* [DeleteServiceConfig](https://cloud.tencent.com/document/api/1120/37554)
* [DescribeRuntimes](https://cloud.tencent.com/document/api/1120/37553)
* [DescribeServiceConfigs](https://cloud.tencent.com/document/api/1120/37552)
* [DescribeServices](https://cloud.tencent.com/document/api/1120/37558)
* [UpdateService](https://cloud.tencent.com/document/api/1120/37557)

新增数据结构：

* [Conditions](https://cloud.tencent.com/document/api/1120/37561#Conditions)
* [Filter](https://cloud.tencent.com/document/api/1120/37561#Filter)
* [Option](https://cloud.tencent.com/document/api/1120/37561#Option)
* [Runtime](https://cloud.tencent.com/document/api/1120/37561#Runtime)
* [Scaler](https://cloud.tencent.com/document/api/1120/37561#Scaler)
* [Service](https://cloud.tencent.com/document/api/1120/37561#Service)
* [ServiceConfig](https://cloud.tencent.com/document/api/1120/37561#ServiceConfig)
* [ServiceStatus](https://cloud.tencent.com/document/api/1120/37561#ServiceStatus)




## 图像分析(tiia) 版本：2019-05-29

### 第 32 次发布

发布时间：2024-07-05 01:19:00

本次发布包含了以下内容：

改善已有的文档。

<font color="#dd0000">**预下线接口**：</font>

* DetectProductBeta

### 第 31 次发布

发布时间：2023-01-13 01:55:53

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [UpdateImage](https://cloud.tencent.com/document/api/865/85724)

### 第 30 次发布

发布时间：2022-11-22 07:01:36

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DetectChefDress](https://cloud.tencent.com/document/api/865/83188)
* [DetectSecurity](https://cloud.tencent.com/document/api/865/83187)

新增数据结构：

* [AttributesForBody](https://cloud.tencent.com/document/api/865/35474#AttributesForBody)
* [BodyAttributes](https://cloud.tencent.com/document/api/865/35474#BodyAttributes)

### 第 29 次发布

发布时间：2022-11-09 06:57:46

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DetectPet](https://cloud.tencent.com/document/api/865/82589)

新增数据结构：

* [Pet](https://cloud.tencent.com/document/api/865/35474#Pet)

### 第 28 次发布

发布时间：2022-08-31 06:53:49

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [CarPlateContent](https://cloud.tencent.com/document/api/865/35474#CarPlateContent)

	* 新增成员：PlateStatus, PlateStatusConfidence, PlateAngle

* [CarTagItem](https://cloud.tencent.com/document/api/865/35474#CarTagItem)

	* 新增成员：Orientation, OrientationConfidence


### 第 27 次发布

发布时间：2022-08-16 06:45:30

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [Box](https://cloud.tencent.com/document/api/865/35474#Box)

	* 新增成员：CategoryId


### 第 26 次发布

发布时间：2022-07-29 06:16:27

本次发布包含了以下内容：

改善已有的文档。

<font color="#dd0000">**删除接口**：</font>

* DetectCelebrity

<font color="#dd0000">**删除数据结构**：</font>

* Face
* Labels
* Threshold

### 第 25 次发布

发布时间：2022-07-21 06:19:01

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [CarTagItem](https://cloud.tencent.com/document/api/865/35474#CarTagItem)

	* 新增成员：PlateConfidence, TypeConfidence, ColorConfidence


### 第 24 次发布

发布时间：2022-07-07 06:17:32

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [ObjectInfo](https://cloud.tencent.com/document/api/865/35474#ObjectInfo)

	* 新增成员：AllBox


### 第 23 次发布

发布时间：2022-06-15 06:15:49

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DetectEnvelope](https://cloud.tencent.com/document/api/865/75554)

新增数据结构：

* [ImageTag](https://cloud.tencent.com/document/api/865/35474#ImageTag)

### 第 22 次发布

发布时间：2022-06-09 06:18:37

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DetectLabelPro](https://cloud.tencent.com/document/api/865/75196)

### 第 21 次发布

发布时间：2022-06-03 06:14:26

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateImage](https://cloud.tencent.com/document/api/865/63487)

	* 新增入参：EnableDetect, CategoryId, ImageRect

	* 新增出参：Object

* [SearchImage](https://cloud.tencent.com/document/api/865/63483)

	* 新增入参：EnableDetect, CategoryId

	* 新增出参：Object


新增数据结构：

* [Attribute](https://cloud.tencent.com/document/api/865/35474#Attribute)
* [Box](https://cloud.tencent.com/document/api/865/35474#Box)
* [ColorInfo](https://cloud.tencent.com/document/api/865/35474#ColorInfo)
* [ObjectInfo](https://cloud.tencent.com/document/api/865/35474#ObjectInfo)
* [Rect](https://cloud.tencent.com/document/api/865/35474#Rect)

### 第 20 次发布

发布时间：2022-04-14 06:18:37

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [RecognizeCarPro](https://cloud.tencent.com/document/api/865/72553)

### 第 19 次发布

发布时间：2021-12-16 08:15:16

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [SearchImage](https://cloud.tencent.com/document/api/865/63483)

	* 新增入参：ImageRect


新增数据结构：

* [ImageRect](https://cloud.tencent.com/document/api/865/35474#ImageRect)

### 第 18 次发布

发布时间：2021-11-10 08:11:42

本次发布包含了以下内容：

改善已有的文档。

新增数据结构：

* [LemmaInfo](https://cloud.tencent.com/document/api/865/35474#LemmaInfo)

修改数据结构：

* [ProductInfo](https://cloud.tencent.com/document/api/865/35474#ProductInfo)

	* 新增成员：LemmaInfoList


### 第 17 次发布

发布时间：2021-11-09 08:16:08

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DetectProductBeta](https://cloud.tencent.com/document/api/865/43354)

	* 新增入参：NeedLemma


### 第 16 次发布

发布时间：2021-10-29 08:10:24

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateGroup](https://cloud.tencent.com/document/api/865/63488)
* [CreateImage](https://cloud.tencent.com/document/api/865/63487)
* [DeleteImages](https://cloud.tencent.com/document/api/865/63486)
* [DescribeGroups](https://cloud.tencent.com/document/api/865/63485)
* [DescribeImages](https://cloud.tencent.com/document/api/865/63484)
* [SearchImage](https://cloud.tencent.com/document/api/865/63483)

新增数据结构：

* [GroupInfo](https://cloud.tencent.com/document/api/865/35474#GroupInfo)
* [ImageInfo](https://cloud.tencent.com/document/api/865/35474#ImageInfo)

### 第 15 次发布

发布时间：2021-09-24 10:12:47

本次发布包含了以下内容：

改善已有的文档。

新增数据结构：

* [CarPlateContent](https://cloud.tencent.com/document/api/865/35474#CarPlateContent)

修改数据结构：

* [CarTagItem](https://cloud.tencent.com/document/api/865/35474#CarTagItem)

	* 新增成员：PlateContent


### 第 14 次发布

发布时间：2021-07-01 08:08:11

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DetectLabelBeta](https://cloud.tencent.com/document/api/865/58067)

### 第 13 次发布

发布时间：2021-06-22 08:09:18

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DetectProductBeta](https://cloud.tencent.com/document/api/865/43354)

	* 新增出参：ProductInfoList


### 第 12 次发布

发布时间：2020-06-01 08:17:59

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DetectLabel](https://cloud.tencent.com/document/api/865/35471)

	* 新增出参：NewsLabels


### 第 11 次发布

发布时间：2020-04-23 08:16:03

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DetectCelebrity](https://cloud.tencent.com/document/api/865/36900)

	* 新增出参：Threshold


新增数据结构：

* [Threshold](https://cloud.tencent.com/document/api/865/35474#Threshold)

### 第 10 次发布

发布时间：2020-04-10 08:15:09

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DetectProductBeta](https://cloud.tencent.com/document/api/865/43354)

新增数据结构：

* [Location](https://cloud.tencent.com/document/api/865/35474#Location)
* [ProductInfo](https://cloud.tencent.com/document/api/865/35474#ProductInfo)
* [RegionDetected](https://cloud.tencent.com/document/api/865/35474#RegionDetected)

### 第 9 次发布

发布时间：2020-03-31 08:13:35

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [Face](https://cloud.tencent.com/document/api/865/35474#Face)

	* 新增成员：ID


### 第 8 次发布

发布时间：2020-02-18 14:48:02

本次发布包含了以下内容：

改善已有的文档。

<font color="#dd0000">**删除接口**：</font>

* ImageModeration

<font color="#dd0000">**删除数据结构**：</font>

* Candidate
* DisgustResult
* FaceRect
* FaceResult
* PoliticsResult
* PornResult
* TerrorismResult
* TextResult

### 第 7 次发布

发布时间：2020-01-10 10:15:14

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [CarTagItem](https://cloud.tencent.com/document/api/865/35474#CarTagItem)

	* 新增成员：CarLocation


### 第 6 次发布

发布时间：2019-11-08 10:05:10

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DetectLabel](https://cloud.tencent.com/document/api/865/35471)

	* 新增入参：Scenes

	* 新增出参：CameraLabels, AlbumLabels


修改数据结构：

* [DetectLabelItem](https://cloud.tencent.com/document/api/865/35474#DetectLabelItem)

	* 新增成员：FirstCategory, SecondCategory


### 第 5 次发布

发布时间：2019-11-01 11:34:51

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CropImage](https://cloud.tencent.com/document/api/865/38899)
* [DetectDisgust](https://cloud.tencent.com/document/api/865/38897)
* [DetectMisbehavior](https://cloud.tencent.com/document/api/865/38898)

### 第 4 次发布

发布时间：2019-09-19 20:10:56

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [ImageModeration](https://cloud.tencent.com/document/api/865/35473)

	* 新增出参：TextResult


新增数据结构：

* [TextResult](https://cloud.tencent.com/document/api/865/35474#TextResult)

### 第 3 次发布

发布时间：2019-08-08 22:35:55

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [AssessQuality](https://cloud.tencent.com/document/api/865/36899)
* [DetectCelebrity](https://cloud.tencent.com/document/api/865/36900)
* [EnhanceImage](https://cloud.tencent.com/document/api/865/36902)

新增数据结构：

* [Face](https://cloud.tencent.com/document/api/865/35474#Face)
* [Labels](https://cloud.tencent.com/document/api/865/35474#Labels)

### 第 2 次发布

发布时间：2019-07-25 20:32:11

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DetectProduct](https://cloud.tencent.com/document/api/865/36457)
* [RecognizeCar](https://cloud.tencent.com/document/api/865/36456)

新增数据结构：

* [CarTagItem](https://cloud.tencent.com/document/api/865/35474#CarTagItem)
* [Coord](https://cloud.tencent.com/document/api/865/35474#Coord)
* [Product](https://cloud.tencent.com/document/api/865/35474#Product)

### 第 1 次发布

发布时间：2019-06-13 15:41:10

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DetectLabel](https://cloud.tencent.com/document/api/865/35471)
* [ImageModeration](https://cloud.tencent.com/document/api/865/35473)

新增数据结构：

* [Candidate](https://cloud.tencent.com/document/api/865/35474#Candidate)
* [DetectLabelItem](https://cloud.tencent.com/document/api/865/35474#DetectLabelItem)
* [DisgustResult](https://cloud.tencent.com/document/api/865/35474#DisgustResult)
* [FaceRect](https://cloud.tencent.com/document/api/865/35474#FaceRect)
* [FaceResult](https://cloud.tencent.com/document/api/865/35474#FaceResult)
* [PoliticsResult](https://cloud.tencent.com/document/api/865/35474#PoliticsResult)
* [PornResult](https://cloud.tencent.com/document/api/865/35474#PornResult)
* [TerrorismResult](https://cloud.tencent.com/document/api/865/35474#TerrorismResult)




## TI-ONE 训练平台(tione) 版本：2019-10-22

### 第 13 次发布

发布时间：2024-05-14 02:40:07

本次发布包含了以下内容：

改善已有的文档。

<font color="#dd0000">**删除接口**：</font>

* UpdateNotebookLifecycleScript

### 第 12 次发布

发布时间：2020-08-14 08:02:11

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateTrainingJob](https://cloud.tencent.com/document/api/#/#)

	* 新增入参：RetryWhenResourceInsufficient


修改数据结构：

* [StoppingCondition](https://cloud.tencent.com/document/api/851/42528#StoppingCondition)

	* 新增成员：MaxWaitTimeInSeconds


### 第 11 次发布

发布时间：2020-08-06 08:02:02

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateNotebookInstance](https://cloud.tencent.com/document/api/#/#)

	* 新增入参：ClsConfig

* [DescribeNotebookInstance](https://cloud.tencent.com/document/api/#/#)

	* 新增出参：ClsConfig

* [UpdateNotebookInstance](https://cloud.tencent.com/document/api/#/#)

	* 新增入参：ClsConfig


新增数据结构：

* [ClsConfig](https://cloud.tencent.com/document/api/851/42528#ClsConfig)

### 第 10 次发布

发布时间：2020-07-22 08:01:55

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateTrainingJob](https://cloud.tencent.com/document/api/#/#)

	* <font color="#dd0000">**修改入参**：</font>InputDataConfig


### 第 9 次发布

发布时间：2020-07-03 08:01:35

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [OutputDataConfig](https://cloud.tencent.com/document/api/851/42528#OutputDataConfig)

	* 新增成员：FileSystemDataSource


### 第 8 次发布

发布时间：2020-07-02 08:01:32

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeTrainingJobs](https://cloud.tencent.com/document/api/#/#)

修改接口：

* [DescribeTrainingJob](https://cloud.tencent.com/document/api/#/#)

	* 新增出参：LogUrl, InstanceId


新增数据结构：

* [TrainingJobSummary](https://cloud.tencent.com/document/api/851/42528#TrainingJobSummary)

### 第 7 次发布

发布时间：2020-06-16 08:02:57

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [NotebookInstanceSummary](https://cloud.tencent.com/document/api/851/42528#NotebookInstanceSummary)

	* 新增成员：RuntimeInSeconds, RemainTimeInSeconds


### 第 6 次发布

发布时间：2020-06-15 08:01:29

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeNotebookSummary](https://cloud.tencent.com/document/api/#/#)

修改接口：

* [CreateNotebookInstance](https://cloud.tencent.com/document/api/#/#)

	* 新增入参：StoppingCondition, AutoStopping

* [DescribeNotebookInstance](https://cloud.tencent.com/document/api/#/#)

	* 新增出参：Prepay, Deadline, StoppingCondition

* [StartNotebookInstance](https://cloud.tencent.com/document/api/#/#)

	* 新增入参：AutoStopping, StoppingCondition

* [UpdateNotebookInstance](https://cloud.tencent.com/document/api/#/#)

	* 新增入参：AutoStopping, StoppingCondition


新增数据结构：

* [BillingLabel](https://cloud.tencent.com/document/api/851/42528#BillingLabel)

修改数据结构：

* [NotebookInstanceSummary](https://cloud.tencent.com/document/api/851/42528#NotebookInstanceSummary)

	* 新增成员：StartupTime, Deadline, StoppingCondition, Prepay, BillingLabel


### 第 5 次发布

发布时间：2020-05-15 08:01:29

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateNotebookInstance](https://cloud.tencent.com/document/api/#/#)

	* 新增入参：ClsAccess

* [DescribeNotebookInstance](https://cloud.tencent.com/document/api/#/#)

	* 新增出参：ClsAccess

* [UpdateNotebookInstance](https://cloud.tencent.com/document/api/#/#)

	* 新增入参：ClsAccess


### 第 4 次发布

发布时间：2020-04-02 08:00:31

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateNotebookInstance](https://cloud.tencent.com/document/api/#/#)

	* 新增入参：LifecycleScriptsName, DefaultCodeRepository, AdditionalCodeRepositories

	* <font color="#dd0000">**删除入参**：</font>RoleArn, SecurityGroupIds, Tags

	* <font color="#dd0000">**修改入参**：</font>NotebookInstanceName, InstanceType, VolumeSizeInGB

* [DescribeNotebookInstance](https://cloud.tencent.com/document/api/#/#)

	* 新增出参：LifecycleScriptsName, DefaultCodeRepository, AdditionalCodeRepositories

	* <font color="#dd0000">**删除出参**：</font>SecurityGroupIds, Url, NetworkInterfaceId

* [UpdateNotebookInstance](https://cloud.tencent.com/document/api/#/#)

	* 新增入参：LifecycleScriptsName, DisassociateLifecycleScript, DefaultCodeRepository, AdditionalCodeRepositories, DisassociateDefaultCodeRepository, DisassociateAdditionalCodeRepositories


<font color="#dd0000">**删除数据结构**：</font>

* Tag

修改数据结构：

* [GitSecret](https://cloud.tencent.com/document/api/851/42528#GitSecret)

	* 新增成员：NoSecret

	* <font color="#dd0000">**删除成员**：</font>None


### 第 3 次发布

发布时间：2020-04-01 08:01:02

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateCodeRepository](https://cloud.tencent.com/document/api/#/#)
* [CreateNotebookLifecycleScript](https://cloud.tencent.com/document/api/#/#)
* [DeleteCodeRepository](https://cloud.tencent.com/document/api/#/#)
* [DeleteNotebookLifecycleScript](https://cloud.tencent.com/document/api/#/#)
* [DescribeCodeRepositories](https://cloud.tencent.com/document/api/#/#)
* [DescribeCodeRepository](https://cloud.tencent.com/document/api/#/#)
* [DescribeNotebookLifecycleScript](https://cloud.tencent.com/document/api/#/#)
* [DescribeNotebookLifecycleScripts](https://cloud.tencent.com/document/api/#/#)
* [UpdateCodeRepository](https://cloud.tencent.com/document/api/#/#)
* [UpdateNotebookLifecycleScript](https://cloud.tencent.com/document/api/#/#)

修改接口：

* [DescribeNotebookInstances](https://cloud.tencent.com/document/api/#/#)

	* 新增入参：Filters

	* <font color="#dd0000">**删除入参**：</font>CreationTimeAfter, CreationTimeBefore, LastModifiedTimeAfter, LastModifiedTimeBefore, NameContains, StatusEquals, MaxResults


新增数据结构：

* [CodeRepoSummary](https://cloud.tencent.com/document/api/851/42528#CodeRepoSummary)
* [Filter](https://cloud.tencent.com/document/api/851/42528#Filter)
* [GitConfig](https://cloud.tencent.com/document/api/851/42528#GitConfig)
* [GitSecret](https://cloud.tencent.com/document/api/851/42528#GitSecret)
* [NotebookLifecycleScriptsSummary](https://cloud.tencent.com/document/api/851/42528#NotebookLifecycleScriptsSummary)

### 第 2 次发布

发布时间：2020-03-31 08:00:28

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateTrainingJob](https://cloud.tencent.com/document/api/#/#)

	* <font color="#dd0000">**修改入参**：</font>AlgorithmSpecification, InputDataConfig, OutputDataConfig, ResourceConfig


### 第 1 次发布

发布时间：2020-03-18 14:38:04

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateNotebookInstance](https://cloud.tencent.com/document/api/#/#)
* [CreatePresignedNotebookInstanceUrl](https://cloud.tencent.com/document/api/#/#)
* [CreateTrainingJob](https://cloud.tencent.com/document/api/#/#)
* [DeleteNotebookInstance](https://cloud.tencent.com/document/api/#/#)
* [DescribeNotebookInstance](https://cloud.tencent.com/document/api/#/#)
* [DescribeNotebookInstances](https://cloud.tencent.com/document/api/#/#)
* [DescribeTrainingJob](https://cloud.tencent.com/document/api/#/#)
* [StartNotebookInstance](https://cloud.tencent.com/document/api/#/#)
* [StopNotebookInstance](https://cloud.tencent.com/document/api/#/#)
* [StopTrainingJob](https://cloud.tencent.com/document/api/#/#)
* [UpdateNotebookInstance](https://cloud.tencent.com/document/api/#/#)

新增数据结构：

* [AlgorithmSpecification](https://cloud.tencent.com/document/api/851/42528#AlgorithmSpecification)
* [CosDataSource](https://cloud.tencent.com/document/api/851/42528#CosDataSource)
* [DataSource](https://cloud.tencent.com/document/api/851/42528#DataSource)
* [EnvConfig](https://cloud.tencent.com/document/api/851/42528#EnvConfig)
* [FileSystemDataSource](https://cloud.tencent.com/document/api/851/42528#FileSystemDataSource)
* [InputDataConfig](https://cloud.tencent.com/document/api/851/42528#InputDataConfig)
* [ModelArtifacts](https://cloud.tencent.com/document/api/851/42528#ModelArtifacts)
* [NotebookInstanceSummary](https://cloud.tencent.com/document/api/851/42528#NotebookInstanceSummary)
* [OutputDataConfig](https://cloud.tencent.com/document/api/851/42528#OutputDataConfig)
* [ResourceConfig](https://cloud.tencent.com/document/api/851/42528#ResourceConfig)
* [SecondaryStatusTransition](https://cloud.tencent.com/document/api/851/42528#SecondaryStatusTransition)
* [StoppingCondition](https://cloud.tencent.com/document/api/851/42528#StoppingCondition)
* [Tag](https://cloud.tencent.com/document/api/851/42528#Tag)
* [VpcConfig](https://cloud.tencent.com/document/api/851/42528#VpcConfig)



## TI-ONE 训练平台(tione) 版本：2021-11-11

### 第 63 次发布

发布时间：2024-06-07 02:37:51

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeModelServiceCallInfo](https://cloud.tencent.com/document/api/851/82286)

	* 新增出参：ServiceCallInfoV2


新增数据结构：

* [ServiceCallInfoV2](https://cloud.tencent.com/document/api/851/75051#ServiceCallInfoV2)

修改数据结构：

* [IntranetCallInfo](https://cloud.tencent.com/document/api/851/75051#IntranetCallInfo)

	* 新增成员：PrivateLinkInfosV2


### 第 62 次发布

发布时间：2024-05-27 02:17:11

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [GooseFS](https://cloud.tencent.com/document/api/851/75051#GooseFS)

	* 新增成员：NameSpace


### 第 61 次发布

发布时间：2024-05-23 02:16:47

本次发布包含了以下内容：

改善已有的文档。

<font color="#dd0000">**删除接口**：</font>

* CreateBatchModelAccTasks
* CreateBatchTask
* CreateNotebookImage
* CreateOptimizedModel
* CreateTrainingTask
* DeleteBatchTask
* DeleteModelAccelerateTask
* DeleteNotebookImageRecord
* DeleteTrainingTask
* DescribeAPIConfigs
* DescribeBatchTask
* DescribeBatchTaskInstances
* DescribeBatchTasks
* DescribeBillingSpecs
* DescribeBillingSpecsPrice
* DescribeDatasetDetailStructured
* DescribeDatasetDetailUnstructured
* DescribeEvents
* DescribeLatestTrainingMetrics
* DescribeLogs
* DescribeModelAccEngineVersions
* DescribeModelAccelerateTasks
* DescribeModelServiceHistory
* DescribeModelServices
* DescribeNotebookImageKernels
* DescribeNotebookImageRecords
* DescribeTrainingFrameworks
* DescribeTrainingMetrics
* DescribeTrainingModels
* ModifyModelServicePartialConfig
* ModifyNotebook
* ModifyNotebookTags
* ModifyServiceGroupWeights
* RestartModelAccelerateTask
* StartTrainingTask
* StopBatchTask
* StopCreatingImage
* StopTrainingTask

<font color="#dd0000">**删除数据结构**：</font>

* APIConfigDetail
* BatchModelAccTask
* BatchTaskDetail
* BatchTaskInstance
* BatchTaskSetItem
* CronInfo
* CustomTrainingData
* CustomTrainingMetric
* CustomTrainingPoint
* DetectionLabelInfo
* EncodedStartCmdInfo
* EngineVersion
* Event
* FilterLabelInfo
* FrameworkInfo
* FrameworkVersion
* LogIdentity
* ModelAccEngineVersion
* NotebookImageRecord
* OcrLabelInfo
* PointInfo
* PreTrainModel
* RowItem
* RowValue
* SegmentationInfo
* ServiceHistory
* Spec
* SpecPrice
* SpecUnit
* TextLabelDistributionDetailInfoFifthClass
* TextLabelDistributionDetailInfoFirstClass
* TextLabelDistributionDetailInfoFourthClass
* TextLabelDistributionDetailInfoSecondClass
* TextLabelDistributionDetailInfoThirdClass
* TextLabelDistributionInfo
* TrainingDataPoint
* TrainingMetric
* TrainingModelDTO
* WeightEntry

修改数据结构：

* [LocalDisk](https://cloud.tencent.com/document/api/851/75051#LocalDisk)

	* 新增成员：LocalPath


### 第 60 次发布

发布时间：2024-05-22 02:16:53

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateModelService](https://cloud.tencent.com/document/api/851/82291)

	* 新增入参：ServicePort

* [ModifyModelService](https://cloud.tencent.com/document/api/851/83228)

	* 新增入参：ServicePort


新增数据结构：

* [ImageSecret](https://cloud.tencent.com/document/api/851/75051#ImageSecret)

修改数据结构：

* [ImageInfo](https://cloud.tencent.com/document/api/851/75051#ImageInfo)

	* 新增成员：ImageSecret

* [ServiceInfo](https://cloud.tencent.com/document/api/851/75051#ServiceInfo)

	* 新增成员：ServicePort


### 第 59 次发布

发布时间：2024-05-14 02:40:26

本次发布包含了以下内容：

改善已有的文档。

新增数据结构：

* [CBSConfig](https://cloud.tencent.com/document/api/851/75051#CBSConfig)

修改数据结构：

* [DataConfig](https://cloud.tencent.com/document/api/851/75051#DataConfig)

	* 新增成员：CBSSource


### 第 58 次发布

发布时间：2024-04-25 01:25:56

本次发布包含了以下内容：

改善已有的文档。

新增数据结构：

* [LocalDisk](https://cloud.tencent.com/document/api/851/75051#LocalDisk)

修改数据结构：

* [DataConfig](https://cloud.tencent.com/document/api/851/75051#DataConfig)

	* 新增成员：LocalDiskSource


### 第 57 次发布

发布时间：2024-04-12 01:25:11

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateTrainingTask](https://cloud.tencent.com/document/api/#/#)

	* 新增入参：EncodedStartCmdInfo


新增数据结构：

* [EncodedStartCmdInfo](https://cloud.tencent.com/document/api/851/75051#EncodedStartCmdInfo)

### 第 56 次发布

发布时间：2024-04-10 01:24:24

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateBatchTask](https://cloud.tencent.com/document/api/#/#)

	* 新增入参：StartCmdBase64

* [CreateModelService](https://cloud.tencent.com/document/api/851/82291)

	* 新增入参：CommandBase64

* [ModifyModelService](https://cloud.tencent.com/document/api/851/83228)

	* 新增入参：CommandBase64


### 第 55 次发布

发布时间：2024-03-29 01:28:05

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeBuildInImages](https://cloud.tencent.com/document/api/851/104325)

	* 新增入参：ImageFilters


新增数据结构：

* [ImageFIlter](https://cloud.tencent.com/document/api/851/75051#ImageFIlter)

修改数据结构：

* [Instance](https://cloud.tencent.com/document/api/851/75051#Instance)

	* 新增成员：ErrCode, ErrMsg


### 第 54 次发布

发布时间：2024-03-28 01:27:54

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [ImageInfo](https://cloud.tencent.com/document/api/851/75051#ImageInfo)

	* 新增成员：SupportDataPipeline


### 第 53 次发布

发布时间：2024-03-14 01:25:59

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeBuildInImages](https://cloud.tencent.com/document/api/851/104325)

### 第 52 次发布

发布时间：2024-03-13 01:25:17

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreatePresignedNotebookUrl](https://cloud.tencent.com/document/api/851/104306)

### 第 51 次发布

发布时间：2024-02-02 01:23:26

本次发布包含了以下内容：

改善已有的文档。

新增数据结构：

* [DefaultInnerCallInfo](https://cloud.tencent.com/document/api/851/75051#DefaultInnerCallInfo)
* [PrivateLinkInfo](https://cloud.tencent.com/document/api/851/75051#PrivateLinkInfo)

修改数据结构：

* [InferCodeInfo](https://cloud.tencent.com/document/api/851/75051#InferCodeInfo)

	* <font color="#dd0000">**修改成员**：</font>CosPathInfo

* [IngressPrivateLinkInfo](https://cloud.tencent.com/document/api/851/75051#IngressPrivateLinkInfo)

	* 新增成员：State

* [IntranetCallInfo](https://cloud.tencent.com/document/api/851/75051#IntranetCallInfo)

	* 新增成员：PrivateLinkInfos, DefaultInnerCallInfos

* [Service](https://cloud.tencent.com/document/api/851/75051#Service)

	* 新增成员：ResourceGroupSWType

* [ServiceCallInfo](https://cloud.tencent.com/document/api/851/75051#ServiceCallInfo)

	* 新增成员：AuthorizationEnable

* [ServiceGroup](https://cloud.tencent.com/document/api/851/75051#ServiceGroup)

	* 新增成员：ReplicasCount, AvailableReplicasCount

* [ServiceInfo](https://cloud.tencent.com/document/api/851/75051#ServiceInfo)

	* <font color="#dd0000">**修改成员**：</font>PodList


### 第 50 次发布

发布时间：2024-01-24 16:03:05

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateBatchTask](https://cloud.tencent.com/document/api/#/#)


修改数据结构：

* [BatchTaskDetail](https://cloud.tencent.com/document/api/851/75051#BatchTaskDetail)

	* <font color="#dd0000">**修改成员**：</font>PodList, ModelInferenceCodeInfo


### 第 49 次发布

发布时间：2024-01-09 01:26:40

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateNotebook](https://cloud.tencent.com/document/api/851/95658)

	* 新增入参：VolumeSourceGooseFS


修改数据结构：

* [GooseFS](https://cloud.tencent.com/document/api/851/75051#GooseFS)

	* 新增成员：Type, Path

* [NotebookDetail](https://cloud.tencent.com/document/api/851/75051#NotebookDetail)

	* 新增成员：SSHConfig, VolumeSourceGooseFS

	* <font color="#dd0000">**修改成员**：</font>ImageInfo, ImageType

* [NotebookImageRecord](https://cloud.tencent.com/document/api/851/75051#NotebookImageRecord)

	* <font color="#dd0000">**修改成员**：</font>RecordId, ImageUrl, Status, CreateTime, Message, InstanceId, Kernels

* [NotebookSetItem](https://cloud.tencent.com/document/api/851/75051#NotebookSetItem)

	* 新增成员：VolumeSourceGooseFS

* [ServiceLimit](https://cloud.tencent.com/document/api/851/75051#ServiceLimit)

	* 新增成员：EnableInstanceReqLimit, InstanceReqLimit

* [TrainingDataPoint](https://cloud.tencent.com/document/api/851/75051#TrainingDataPoint)

	* 新增成员：Timestamp, Value


### 第 48 次发布

发布时间：2023-12-21 02:14:50

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeBillingResourceGroups](https://cloud.tencent.com/document/api/851/75065)

	* <font color="#dd0000">**修改入参**：</font>Type

* [DescribeBillingSpecs](https://cloud.tencent.com/document/api/#/#)

	* <font color="#dd0000">**修改入参**：</font>TaskType


### 第 47 次发布

发布时间：2023-12-20 02:15:59

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeModelAccelerateVersions](https://cloud.tencent.com/document/api/851/102555)

新增数据结构：

* [ModelAccelerateVersion](https://cloud.tencent.com/document/api/851/75051#ModelAccelerateVersion)
* [ModelSource](https://cloud.tencent.com/document/api/851/75051#ModelSource)

### 第 46 次发布

发布时间：2023-12-19 02:18:26

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [ModelInfo](https://cloud.tencent.com/document/api/851/75051#ModelInfo)

	* 新增成员：IsPrivateModel


### 第 45 次发布

发布时间：2023-11-27 00:20:30

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeBillingResourceGroup](https://cloud.tencent.com/document/api/851/101969)

### 第 44 次发布

发布时间：2023-11-24 01:25:14

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [Instance](https://cloud.tencent.com/document/api/851/75051#Instance)

	* 新增成员：CvmInstanceId


### 第 43 次发布

发布时间：2023-11-17 01:26:29

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateTrainingTask](https://cloud.tencent.com/document/api/#/#)

	* 新增入参：PreTrainModel


新增数据结构：

* [PreTrainModel](https://cloud.tencent.com/document/api/851/75051#PreTrainModel)

### 第 42 次发布

发布时间：2023-11-16 01:32:39

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeEvents](https://cloud.tencent.com/document/api/#/#)

修改接口：

* [DescribeLogs](https://cloud.tencent.com/document/api/#/#)

	* 新增入参：ServiceId


新增数据结构：

* [Event](https://cloud.tencent.com/document/api/851/75051#Event)

### 第 41 次发布

发布时间：2023-11-07 02:22:04

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeTrainingTaskPods](https://cloud.tencent.com/document/api/851/75088)

	* <font color="#dd0000">**修改出参**：</font>PodInfoList


### 第 40 次发布

发布时间：2023-11-03 01:24:08

本次发布包含了以下内容：

改善已有的文档。

新增数据结构：

* [CrossTenantENIInfo](https://cloud.tencent.com/document/api/851/75051#CrossTenantENIInfo)

修改数据结构：

* [Container](https://cloud.tencent.com/document/api/851/75051#Container)

	* <font color="#dd0000">**修改成员**：</font>Name, ContainerId, Image, Status

* [ContainerStatus](https://cloud.tencent.com/document/api/851/75051#ContainerStatus)

	* <font color="#dd0000">**修改成员**：</font>RestartCount, State, Ready, Reason, Message

* [Pod](https://cloud.tencent.com/document/api/851/75051#Pod)

	* 新增成员：CrossTenantENIInfo


### 第 39 次发布

发布时间：2023-11-01 01:23:17

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeBillingResourceInstanceRunningJobs](https://cloud.tencent.com/document/api/851/101008)

新增数据结构：

* [ResourceInstanceRunningJobInfo](https://cloud.tencent.com/document/api/851/75051#ResourceInstanceRunningJobInfo)

### 第 38 次发布

发布时间：2023-09-22 02:38:16

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [Instance](https://cloud.tencent.com/document/api/851/75051#Instance)

	* 新增成员：SpecFeatures


### 第 37 次发布

发布时间：2023-09-06 02:33:35

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateModelService](https://cloud.tencent.com/document/api/851/82291)

	* 新增入参：ServiceEIP

* [ModifyModelService](https://cloud.tencent.com/document/api/851/83228)

	* 新增入参：ServiceEIP


修改数据结构：

* [PodInfo](https://cloud.tencent.com/document/api/851/75051#PodInfo)

	* 新增成员：StartTime, EndTime, ResourceConfigInfo

* [Spec](https://cloud.tencent.com/document/api/851/75051#Spec)

	* 新增成员：SpecFeatures, SpecType, GpuType, CategoryId


### 第 36 次发布

发布时间：2023-09-01 01:23:56

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateTrainingModel](https://cloud.tencent.com/document/api/851/75074)

	* <font color="#dd0000">**修改入参**：</font>TrainingModelCosPath

* [DeleteModelService](https://cloud.tencent.com/document/api/851/82290)

	* 新增入参：ServiceCategory

* [DescribeLogs](https://cloud.tencent.com/document/api/#/#)

	* <font color="#dd0000">**修改入参**：</font>PodName

* [DescribeModelService](https://cloud.tencent.com/document/api/851/82287)

	* 新增入参：ServiceCategory

* [DescribeModelServiceCallInfo](https://cloud.tencent.com/document/api/851/82286)

	* 新增入参：ServiceCategory

	* 新增出参：TJCallInfo, IntranetCallInfo

* [DescribeModelServiceGroup](https://cloud.tencent.com/document/api/851/82285)

	* 新增入参：ServiceCategory

* [DescribeModelServiceGroups](https://cloud.tencent.com/document/api/851/82284)

	* 新增入参：ServiceCategory


新增数据结构：

* [IngressPrivateLinkInfo](https://cloud.tencent.com/document/api/851/75051#IngressPrivateLinkInfo)
* [IntranetCallInfo](https://cloud.tencent.com/document/api/851/75051#IntranetCallInfo)
* [ServiceEIP](https://cloud.tencent.com/document/api/851/75051#ServiceEIP)
* [ServiceEIPInfo](https://cloud.tencent.com/document/api/851/75051#ServiceEIPInfo)
* [TJCallInfo](https://cloud.tencent.com/document/api/851/75051#TJCallInfo)

修改数据结构：

* [ServiceInfo](https://cloud.tencent.com/document/api/851/75051#ServiceInfo)

	* 新增成员：ServiceEIP

* [TrainingModelDTO](https://cloud.tencent.com/document/api/851/75051#TrainingModelDTO)

	* <font color="#dd0000">**修改成员**：</font>TrainingModelVersions

* [TrainingModelVersionDTO](https://cloud.tencent.com/document/api/851/75051#TrainingModelVersionDTO)

	* <font color="#dd0000">**修改成员**：</font>ReasoningEnvironmentId, TrainingJobVersion, TrainingPreference, AutoMLTaskId, IsQAT


### 第 35 次发布

发布时间：2023-08-28 02:39:57

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateModelService](https://cloud.tencent.com/document/api/851/82291)

	* 新增入参：Command

* [ModifyModelService](https://cloud.tencent.com/document/api/851/83228)

	* 新增入参：Command


新增数据结构：

* [InferCodeInfo](https://cloud.tencent.com/document/api/851/75051#InferCodeInfo)

修改数据结构：

* [ServiceInfo](https://cloud.tencent.com/document/api/851/75051#ServiceInfo)

	* 新增成员：VolumeMount, InferCodeInfo, Command

* [StatefulSetCondition](https://cloud.tencent.com/document/api/851/75051#StatefulSetCondition)

	* 新增成员：LastUpdateTime

* [WorkloadStatus](https://cloud.tencent.com/document/api/851/75051#WorkloadStatus)


### 第 34 次发布

发布时间：2023-08-23 01:45:33

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateNotebook](https://cloud.tencent.com/document/api/851/95658)

	* 新增入参：SSHConfig

* [CreateTrainingTask](https://cloud.tencent.com/document/api/#/#)

	* <font color="#dd0000">**修改入参**：</font>CodePackagePath, TrainingMode, Output, LogEnable

* [ModifyNotebook](https://cloud.tencent.com/document/api/#/#)

	* 新增入参：SSHConfig


新增数据结构：

* [SSHConfig](https://cloud.tencent.com/document/api/851/75051#SSHConfig)

修改数据结构：

* [NotebookSetItem](https://cloud.tencent.com/document/api/851/75051#NotebookSetItem)

	* 新增成员：SSHConfig

	* <font color="#dd0000">**修改成员**：</font>UserTypes

* [PodInfo](https://cloud.tencent.com/document/api/851/75051#PodInfo)

	* 新增成员：Status

	* <font color="#dd0000">**修改成员**：</font>Name, IP


### 第 33 次发布

发布时间：2023-08-22 01:21:13

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateNotebookImage](https://cloud.tencent.com/document/api/#/#)

	* <font color="#dd0000">**修改入参**：</font>Kernels


修改数据结构：

* [ImageInfo](https://cloud.tencent.com/document/api/851/75051#ImageInfo)

	* 新增成员：AllowSaveAllContent, ImageName


### 第 32 次发布

发布时间：2023-08-14 21:50:46

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [SendChatMessage](https://cloud.tencent.com/document/api/851/96176)

### 第 31 次发布

发布时间：2023-08-08 22:45:41

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [ChatCompletion](https://cloud.tencent.com/document/api/851/96102)

新增数据结构：

* [Choice](https://cloud.tencent.com/document/api/851/75051#Choice)
* [Message](https://cloud.tencent.com/document/api/851/75051#Message)
* [Usage](https://cloud.tencent.com/document/api/851/75051#Usage)

### 第 30 次发布

发布时间：2023-07-28 15:36:37

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DeleteNotebook](https://cloud.tencent.com/document/api/851/95663)
* [DescribeNotebook](https://cloud.tencent.com/document/api/851/95662)
* [StopCreatingImage](https://cloud.tencent.com/document/api/#/#)
* [StopNotebook](https://cloud.tencent.com/document/api/851/95660)

新增数据结构：

* [NotebookDetail](https://cloud.tencent.com/document/api/851/75051#NotebookDetail)

### 第 29 次发布

发布时间：2023-07-28 15:25:51

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateNotebook](https://cloud.tencent.com/document/api/851/95658)
* [CreateNotebookImage](https://cloud.tencent.com/document/api/#/#)
* [DeleteNotebookImageRecord](https://cloud.tencent.com/document/api/#/#)
* [DescribeNotebookImageKernels](https://cloud.tencent.com/document/api/#/#)
* [DescribeNotebookImageRecords](https://cloud.tencent.com/document/api/#/#)
* [DescribeNotebooks](https://cloud.tencent.com/document/api/851/95653)
* [ModifyNotebook](https://cloud.tencent.com/document/api/#/#)
* [ModifyNotebookTags](https://cloud.tencent.com/document/api/#/#)
* [StartNotebook](https://cloud.tencent.com/document/api/851/95650)

新增数据结构：

* [NotebookImageRecord](https://cloud.tencent.com/document/api/851/75051#NotebookImageRecord)
* [NotebookSetItem](https://cloud.tencent.com/document/api/851/75051#NotebookSetItem)
* [ResourceConf](https://cloud.tencent.com/document/api/851/75051#ResourceConf)

### 第 28 次发布

发布时间：2023-07-17 01:40:19

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateModelService](https://cloud.tencent.com/document/api/851/82291)

	* 新增入参：ModelTurboEnable, ServiceCategory

* [DescribeModelServiceHotUpdated](https://cloud.tencent.com/document/api/851/82282)

	* 新增出参：ModelTurboFlag

* [ModifyModelService](https://cloud.tencent.com/document/api/851/83228)

	* 新增入参：ModelTurboEnable


修改数据结构：

* [GpuDetail](https://cloud.tencent.com/document/api/851/75051#GpuDetail)

	* <font color="#dd0000">**修改成员**：</font>Name, Value

* [HyperParameter](https://cloud.tencent.com/document/api/851/75051#HyperParameter)

	* 新增成员：LoraScale

* [ModelInfo](https://cloud.tencent.com/document/api/851/75051#ModelInfo)

	* 新增成员：ModelFormat

* [ServiceInfo](https://cloud.tencent.com/document/api/851/75051#ServiceInfo)

	* 新增成员：ModelTurboEnable

* [WorkloadStatus](https://cloud.tencent.com/document/api/851/75051#WorkloadStatus)

	* 新增成员：Reason


### 第 27 次发布

发布时间：2023-06-26 01:57:45

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [CFSConfig](https://cloud.tencent.com/document/api/851/75051#CFSConfig)

	* 新增成员：MountType, Protocol


### 第 26 次发布

发布时间：2023-06-08 02:02:11

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeTrainingTaskPods](https://cloud.tencent.com/document/api/851/75088)

	* 新增出参：PodInfoList


新增数据结构：

* [PodInfo](https://cloud.tencent.com/document/api/851/75051#PodInfo)

### 第 25 次发布

发布时间：2023-05-29 15:06:20

本次发布包含了以下内容：

改善已有的文档。

新增数据结构：

* [CFSTurbo](https://cloud.tencent.com/document/api/851/75051#CFSTurbo)

修改数据结构：

* [DataConfig](https://cloud.tencent.com/document/api/851/75051#DataConfig)

	* 新增成员：CFSTurboSource


### 第 24 次发布

发布时间：2023-05-16 02:19:20

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [HyperParameter](https://cloud.tencent.com/document/api/851/75051#HyperParameter)

	* 新增成员：PipelineArgs


### 第 23 次发布

发布时间：2023-05-15 02:05:29

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [BatchTaskDetail](https://cloud.tencent.com/document/api/851/75051#BatchTaskDetail)

	* 新增成员：ModelInferenceCodeInfo


### 第 22 次发布

发布时间：2023-05-08 01:57:36

本次发布包含了以下内容：

改善已有的文档。

新增数据结构：

* [GooseFS](https://cloud.tencent.com/document/api/851/75051#GooseFS)
* [RDMAConfig](https://cloud.tencent.com/document/api/851/75051#RDMAConfig)

修改数据结构：

* [DataConfig](https://cloud.tencent.com/document/api/851/75051#DataConfig)

	* 新增成员：GooseFSSource

* [ResourceConfigInfo](https://cloud.tencent.com/document/api/851/75051#ResourceConfigInfo)

	* 新增成员：RDMAConfig


### 第 21 次发布

发布时间：2023-04-25 01:54:53

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateModelService](https://cloud.tencent.com/document/api/851/82291)

	* <font color="#dd0000">**修改入参**：</font>ImageInfo


修改数据结构：

* [ServiceInfo](https://cloud.tencent.com/document/api/851/75051#ServiceInfo)

	* 新增成员：ScaleStrategy, CronScaleJobs, ScaleMode, ServiceLimit, ScheduledAction


### 第 20 次发布

发布时间：2023-04-07 02:48:14

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeTrainingModels](https://cloud.tencent.com/document/api/#/#)

	* 新增入参：WithModelVersions

* [RestartModelAccelerateTask](https://cloud.tencent.com/document/api/#/#)

	* 新增入参：FrameworkVersion


修改数据结构：

* [BatchModelAccTask](https://cloud.tencent.com/document/api/851/75051#BatchModelAccTask)

	* 新增成员：FrameworkVersion

* [EngineVersion](https://cloud.tencent.com/document/api/851/75051#EngineVersion)

	* 新增成员：FrameworkVersion

* [ModelAccelerateTask](https://cloud.tencent.com/document/api/851/75051#ModelAccelerateTask)

	* 新增成员：FrameworkVersion

* [Pod](https://cloud.tencent.com/document/api/851/75051#Pod)

	* 新增成员：ContainerInfos

* [ServiceInfo](https://cloud.tencent.com/document/api/851/75051#ServiceInfo)

	* 新增成员：PodInfos

* [TrainingModelDTO](https://cloud.tencent.com/document/api/851/75051#TrainingModelDTO)

	* 新增成员：TrainingModelVersions


### 第 19 次发布

发布时间：2023-02-22 01:59:34

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeModelServiceCallInfo](https://cloud.tencent.com/document/api/851/82286)

	* 新增出参：DefaultNginxGatewayCallInfo


新增数据结构：

* [Container](https://cloud.tencent.com/document/api/851/75051#Container)
* [ContainerStatus](https://cloud.tencent.com/document/api/851/75051#ContainerStatus)
* [DefaultNginxGatewayCallInfo](https://cloud.tencent.com/document/api/851/75051#DefaultNginxGatewayCallInfo)
* [Pod](https://cloud.tencent.com/document/api/851/75051#Pod)

修改数据结构：

* [BatchTaskDetail](https://cloud.tencent.com/document/api/851/75051#BatchTaskDetail)

	* 新增成员：PodList

* [DataConfig](https://cloud.tencent.com/document/api/851/75051#DataConfig)

	* <font color="#dd0000">**修改成员**：</font>MappingPath, DataSourceType, DataSetSource, COSSource, CFSSource, HDFSSource

* [ServiceInfo](https://cloud.tencent.com/document/api/851/75051#ServiceInfo)

	* 新增成员：Pods

* [TrainingModelVersionDTO](https://cloud.tencent.com/document/api/851/75051#TrainingModelVersionDTO)

	* 新增成员：ReasoningEnvironmentId, TrainingJobVersion, TrainingPreference, AutoMLTaskId, IsQAT


### 第 18 次发布

发布时间：2023-02-15 02:04:48

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [DatasetGroup](https://cloud.tencent.com/document/api/851/75051#DatasetGroup)

	* 新增成员：OcrScene, AnnotationKeyStatus, ContentType

* [DatasetInfo](https://cloud.tencent.com/document/api/851/75051#DatasetInfo)

	* 新增成员：OcrScene, AnnotationKeyStatus

* [SpecPrice](https://cloud.tencent.com/document/api/851/75051#SpecPrice)

	* 新增成员：SpecCount


### 第 17 次发布

发布时间：2023-02-14 01:56:09

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [EngineVersion](https://cloud.tencent.com/document/api/851/75051#EngineVersion)

	* 新增成员：IsSupportIntEightQuantization


### 第 16 次发布

发布时间：2023-01-06 01:48:47

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [Spec](https://cloud.tencent.com/document/api/851/75051#Spec)

	* 新增成员：Available, AvailableRegion


### 第 15 次发布

发布时间：2023-01-02 01:47:18

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateTrainingModel](https://cloud.tencent.com/document/api/851/75074)

	* 新增入参：IsQAT


修改数据结构：

* [ModelAccelerateTask](https://cloud.tencent.com/document/api/851/75051#ModelAccelerateTask)

	* 新增成员：QATModel


### 第 14 次发布

发布时间：2022-12-19 02:08:29

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateBatchTask](https://cloud.tencent.com/document/api/#/#)

	* 新增入参：CallbackUrl

* [CreateTrainingTask](https://cloud.tencent.com/document/api/#/#)

	* 新增入参：CallbackUrl


修改数据结构：

* [TrainingTaskDetail](https://cloud.tencent.com/document/api/851/75051#TrainingTaskDetail)

	* 新增成员：CallbackUrl

* [TrainingTaskSetItem](https://cloud.tencent.com/document/api/851/75051#TrainingTaskSetItem)

	* 新增成员：CallbackUrl


### 第 13 次发布

发布时间：2022-12-16 01:46:34

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateModelService](https://cloud.tencent.com/document/api/851/82291)

	* 新增入参：CallbackUrl


### 第 12 次发布

发布时间：2022-12-08 01:49:46

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [Service](https://cloud.tencent.com/document/api/851/75051#Service)

	* 新增成员：CreateFailedReason, ResourceGroupName, Tags


### 第 11 次发布

发布时间：2022-11-29 07:29:47

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [WorkloadStatus](https://cloud.tencent.com/document/api/851/75051#WorkloadStatus)

	* 新增成员：Conditions


### 第 10 次发布

发布时间：2022-11-23 06:59:03

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [ModifyModelService](https://cloud.tencent.com/document/api/851/83228)

### 第 9 次发布

发布时间：2022-11-18 06:53:56

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [ModifyModelServicePartialConfig](https://cloud.tencent.com/document/api/#/#)

### 第 8 次发布

发布时间：2022-11-10 06:57:12

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateBatchModelAccTasks](https://cloud.tencent.com/document/api/#/#)
* [CreateOptimizedModel](https://cloud.tencent.com/document/api/#/#)
* [DeleteModelAccelerateTask](https://cloud.tencent.com/document/api/#/#)
* [DescribeModelAccEngineVersions](https://cloud.tencent.com/document/api/#/#)
* [DescribeModelAccelerateTask](https://cloud.tencent.com/document/api/851/82606)
* [DescribeModelAccelerateTasks](https://cloud.tencent.com/document/api/#/#)
* [RestartModelAccelerateTask](https://cloud.tencent.com/document/api/#/#)
* [StopModelAccelerateTask](https://cloud.tencent.com/document/api/851/82603)

新增数据结构：

* [BatchModelAccTask](https://cloud.tencent.com/document/api/851/75051#BatchModelAccTask)
* [EngineVersion](https://cloud.tencent.com/document/api/851/75051#EngineVersion)
* [HyperParameter](https://cloud.tencent.com/document/api/851/75051#HyperParameter)
* [ModelAccEngineVersion](https://cloud.tencent.com/document/api/851/75051#ModelAccEngineVersion)
* [ModelAccelerateTask](https://cloud.tencent.com/document/api/851/75051#ModelAccelerateTask)
* [ModelInputInfo](https://cloud.tencent.com/document/api/851/75051#ModelInputInfo)

### 第 7 次发布

发布时间：2022-11-02 06:46:06

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateModelService](https://cloud.tencent.com/document/api/851/82291)
* [DeleteModelService](https://cloud.tencent.com/document/api/851/82290)
* [DeleteModelServiceGroup](https://cloud.tencent.com/document/api/851/82289)
* [DescribeAPIConfigs](https://cloud.tencent.com/document/api/#/#)
* [DescribeModelService](https://cloud.tencent.com/document/api/851/82287)
* [DescribeModelServiceCallInfo](https://cloud.tencent.com/document/api/851/82286)
* [DescribeModelServiceGroup](https://cloud.tencent.com/document/api/851/82285)
* [DescribeModelServiceGroups](https://cloud.tencent.com/document/api/851/82284)
* [DescribeModelServiceHistory](https://cloud.tencent.com/document/api/#/#)
* [DescribeModelServiceHotUpdated](https://cloud.tencent.com/document/api/851/82282)
* [DescribeModelServices](https://cloud.tencent.com/document/api/#/#)
* [ModifyServiceGroupWeights](https://cloud.tencent.com/document/api/#/#)

修改接口：

* [CreateTrainingTask](https://cloud.tencent.com/document/api/#/#)

	* 新增入参：FrameworkEnvironment


新增数据结构：

* [APIConfigDetail](https://cloud.tencent.com/document/api/851/75051#APIConfigDetail)
* [CronScaleJob](https://cloud.tencent.com/document/api/851/75051#CronScaleJob)
* [EnvVar](https://cloud.tencent.com/document/api/851/75051#EnvVar)
* [HorizontalPodAutoscaler](https://cloud.tencent.com/document/api/851/75051#HorizontalPodAutoscaler)
* [InferGatewayCallInfo](https://cloud.tencent.com/document/api/851/75051#InferGatewayCallInfo)
* [Option](https://cloud.tencent.com/document/api/851/75051#Option)
* [ScheduledAction](https://cloud.tencent.com/document/api/851/75051#ScheduledAction)
* [Service](https://cloud.tencent.com/document/api/851/75051#Service)
* [ServiceCallInfo](https://cloud.tencent.com/document/api/851/75051#ServiceCallInfo)
* [ServiceGroup](https://cloud.tencent.com/document/api/851/75051#ServiceGroup)
* [ServiceHistory](https://cloud.tencent.com/document/api/851/75051#ServiceHistory)
* [ServiceInfo](https://cloud.tencent.com/document/api/851/75051#ServiceInfo)
* [ServiceLimit](https://cloud.tencent.com/document/api/851/75051#ServiceLimit)
* [StatefulSetCondition](https://cloud.tencent.com/document/api/851/75051#StatefulSetCondition)
* [VolumeMount](https://cloud.tencent.com/document/api/851/75051#VolumeMount)
* [WeightEntry](https://cloud.tencent.com/document/api/851/75051#WeightEntry)
* [WorkloadStatus](https://cloud.tencent.com/document/api/851/75051#WorkloadStatus)

修改数据结构：

* [FrameworkVersion](https://cloud.tencent.com/document/api/851/75051#FrameworkVersion)

	* 新增成员：Environment

* [ResourceInfo](https://cloud.tencent.com/document/api/851/75051#ResourceInfo)

	* 新增成员：RealGpuDetailSet

* [TrainingTaskDetail](https://cloud.tencent.com/document/api/851/75051#TrainingTaskDetail)

	* 新增成员：FrameworkEnvironment

* [TrainingTaskSetItem](https://cloud.tencent.com/document/api/851/75051#TrainingTaskSetItem)

	* 新增成员：FrameworkEnvironment


### 第 6 次发布

发布时间：2022-09-30 07:00:21

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateDataset](https://cloud.tencent.com/document/api/851/75050)

	* 新增入参：ContentType

* [DescribeDatasetDetailUnstructured](https://cloud.tencent.com/document/api/#/#)

	* 新增入参：TextClassificationLabels

	* 新增出参：RowTexts


新增数据结构：

* [TextLabelDistributionDetailInfoFifthClass](https://cloud.tencent.com/document/api/851/75051#TextLabelDistributionDetailInfoFifthClass)
* [TextLabelDistributionDetailInfoFirstClass](https://cloud.tencent.com/document/api/851/75051#TextLabelDistributionDetailInfoFirstClass)
* [TextLabelDistributionDetailInfoFourthClass](https://cloud.tencent.com/document/api/851/75051#TextLabelDistributionDetailInfoFourthClass)
* [TextLabelDistributionDetailInfoSecondClass](https://cloud.tencent.com/document/api/851/75051#TextLabelDistributionDetailInfoSecondClass)
* [TextLabelDistributionDetailInfoThirdClass](https://cloud.tencent.com/document/api/851/75051#TextLabelDistributionDetailInfoThirdClass)
* [TextLabelDistributionInfo](https://cloud.tencent.com/document/api/851/75051#TextLabelDistributionInfo)

修改数据结构：

* [FilterLabelInfo](https://cloud.tencent.com/document/api/851/75051#FilterLabelInfo)

	* 新增成员：OcrLabelInfo, TextClassificationLabelList, RowText, ContentOmit


### 第 5 次发布

发布时间：2022-09-06 13:11:30

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateBatchTask](https://cloud.tencent.com/document/api/#/#)
* [DeleteBatchTask](https://cloud.tencent.com/document/api/#/#)
* [DescribeBatchTask](https://cloud.tencent.com/document/api/#/#)
* [DescribeBatchTaskInstances](https://cloud.tencent.com/document/api/#/#)
* [DescribeBatchTasks](https://cloud.tencent.com/document/api/#/#)
* [DescribeBillingSpecs](https://cloud.tencent.com/document/api/#/#)
* [StopBatchTask](https://cloud.tencent.com/document/api/#/#)

修改接口：

* [CreateTrainingModel](https://cloud.tencent.com/document/api/851/75074)

	* 新增入参：AutoClean, MaxReservedModels, ModelCleanPeriod


新增数据结构：

* [BatchTaskDetail](https://cloud.tencent.com/document/api/851/75051#BatchTaskDetail)
* [BatchTaskInstance](https://cloud.tencent.com/document/api/851/75051#BatchTaskInstance)
* [BatchTaskSetItem](https://cloud.tencent.com/document/api/851/75051#BatchTaskSetItem)
* [CronInfo](https://cloud.tencent.com/document/api/851/75051#CronInfo)
* [ModelInfo](https://cloud.tencent.com/document/api/851/75051#ModelInfo)
* [Spec](https://cloud.tencent.com/document/api/851/75051#Spec)

修改数据结构：

* [TrainingModelVersionDTO](https://cloud.tencent.com/document/api/851/75051#TrainingModelVersionDTO)

	* 新增成员：VersionType, GPUType, AutoClean, ModelCleanPeriod, MaxReservedModels, ModelHotUpdatePath


### 第 4 次发布

发布时间：2022-08-09 12:28:40

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateTrainingModel](https://cloud.tencent.com/document/api/851/75074)

	* 新增入参：ReasoningEnvironmentId

* [DeleteTrainingModel](https://cloud.tencent.com/document/api/851/75073)

	* 新增入参：ModelVersionType


修改数据结构：

* [TrainingTaskDetail](https://cloud.tencent.com/document/api/851/75051#TrainingTaskDetail)

	* 新增成员：Message

* [TrainingTaskSetItem](https://cloud.tencent.com/document/api/851/75051#TrainingTaskSetItem)

	* 新增成员：Message


### 第 3 次发布

发布时间：2022-07-18 06:17:59

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DeleteTrainingModel](https://cloud.tencent.com/document/api/851/75073)

	* 新增入参：EnableDeleteCos

* [DeleteTrainingModelVersion](https://cloud.tencent.com/document/api/851/75072)

	* 新增入参：EnableDeleteCos


### 第 2 次发布

发布时间：2022-06-07 21:53:13

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateTrainingModel](https://cloud.tencent.com/document/api/851/75074)
* [CreateTrainingTask](https://cloud.tencent.com/document/api/#/#)
* [DeleteDataset](https://cloud.tencent.com/document/api/851/75080)
* [DeleteTrainingModel](https://cloud.tencent.com/document/api/851/75073)
* [DeleteTrainingModelVersion](https://cloud.tencent.com/document/api/851/75072)
* [DeleteTrainingTask](https://cloud.tencent.com/document/api/#/#)
* [DescribeBillingResourceGroups](https://cloud.tencent.com/document/api/851/75065)
* [DescribeBillingSpecsPrice](https://cloud.tencent.com/document/api/#/#)
* [DescribeDatasetDetailStructured](https://cloud.tencent.com/document/api/#/#)
* [DescribeDatasetDetailUnstructured](https://cloud.tencent.com/document/api/#/#)
* [DescribeDatasets](https://cloud.tencent.com/document/api/851/75077)
* [DescribeInferTemplates](https://cloud.tencent.com/document/api/851/75082)
* [DescribeLatestTrainingMetrics](https://cloud.tencent.com/document/api/#/#)
* [DescribeLogs](https://cloud.tencent.com/document/api/#/#)
* [DescribeTrainingFrameworks](https://cloud.tencent.com/document/api/#/#)
* [DescribeTrainingMetrics](https://cloud.tencent.com/document/api/#/#)
* [DescribeTrainingModelVersion](https://cloud.tencent.com/document/api/851/75071)
* [DescribeTrainingModelVersions](https://cloud.tencent.com/document/api/851/75070)
* [DescribeTrainingModels](https://cloud.tencent.com/document/api/#/#)
* [DescribeTrainingTask](https://cloud.tencent.com/document/api/851/75089)
* [DescribeTrainingTaskPods](https://cloud.tencent.com/document/api/851/75088)
* [DescribeTrainingTasks](https://cloud.tencent.com/document/api/851/75087)
* [PushTrainingMetrics](https://cloud.tencent.com/document/api/851/75086)
* [StartTrainingTask](https://cloud.tencent.com/document/api/#/#)
* [StopTrainingTask](https://cloud.tencent.com/document/api/#/#)

新增数据结构：

* [CFSConfig](https://cloud.tencent.com/document/api/851/75051#CFSConfig)
* [CustomTrainingData](https://cloud.tencent.com/document/api/851/75051#CustomTrainingData)
* [CustomTrainingMetric](https://cloud.tencent.com/document/api/851/75051#CustomTrainingMetric)
* [CustomTrainingPoint](https://cloud.tencent.com/document/api/851/75051#CustomTrainingPoint)
* [DataConfig](https://cloud.tencent.com/document/api/851/75051#DataConfig)
* [DataPoint](https://cloud.tencent.com/document/api/851/75051#DataPoint)
* [DataSetConfig](https://cloud.tencent.com/document/api/851/75051#DataSetConfig)
* [DatasetGroup](https://cloud.tencent.com/document/api/851/75051#DatasetGroup)
* [DatasetInfo](https://cloud.tencent.com/document/api/851/75051#DatasetInfo)
* [DetectionLabelInfo](https://cloud.tencent.com/document/api/851/75051#DetectionLabelInfo)
* [Filter](https://cloud.tencent.com/document/api/851/75051#Filter)
* [FilterLabelInfo](https://cloud.tencent.com/document/api/851/75051#FilterLabelInfo)
* [FrameworkInfo](https://cloud.tencent.com/document/api/851/75051#FrameworkInfo)
* [FrameworkVersion](https://cloud.tencent.com/document/api/851/75051#FrameworkVersion)
* [GpuDetail](https://cloud.tencent.com/document/api/851/75051#GpuDetail)
* [GroupResource](https://cloud.tencent.com/document/api/851/75051#GroupResource)
* [HDFSConfig](https://cloud.tencent.com/document/api/851/75051#HDFSConfig)
* [ImageInfo](https://cloud.tencent.com/document/api/851/75051#ImageInfo)
* [InferTemplate](https://cloud.tencent.com/document/api/851/75051#InferTemplate)
* [InferTemplateGroup](https://cloud.tencent.com/document/api/851/75051#InferTemplateGroup)
* [Instance](https://cloud.tencent.com/document/api/851/75051#Instance)
* [LogConfig](https://cloud.tencent.com/document/api/851/75051#LogConfig)
* [LogIdentity](https://cloud.tencent.com/document/api/851/75051#LogIdentity)
* [MetricData](https://cloud.tencent.com/document/api/851/75051#MetricData)
* [OcrLabelInfo](https://cloud.tencent.com/document/api/851/75051#OcrLabelInfo)
* [PointInfo](https://cloud.tencent.com/document/api/851/75051#PointInfo)
* [ResourceConfigInfo](https://cloud.tencent.com/document/api/851/75051#ResourceConfigInfo)
* [ResourceGroup](https://cloud.tencent.com/document/api/851/75051#ResourceGroup)
* [ResourceInfo](https://cloud.tencent.com/document/api/851/75051#ResourceInfo)
* [RowItem](https://cloud.tencent.com/document/api/851/75051#RowItem)
* [RowValue](https://cloud.tencent.com/document/api/851/75051#RowValue)
* [SegmentationInfo](https://cloud.tencent.com/document/api/851/75051#SegmentationInfo)
* [SpecPrice](https://cloud.tencent.com/document/api/851/75051#SpecPrice)
* [SpecUnit](https://cloud.tencent.com/document/api/851/75051#SpecUnit)
* [StartCmdInfo](https://cloud.tencent.com/document/api/851/75051#StartCmdInfo)
* [TagFilter](https://cloud.tencent.com/document/api/851/75051#TagFilter)
* [TrainingDataPoint](https://cloud.tencent.com/document/api/851/75051#TrainingDataPoint)
* [TrainingMetric](https://cloud.tencent.com/document/api/851/75051#TrainingMetric)
* [TrainingModelDTO](https://cloud.tencent.com/document/api/851/75051#TrainingModelDTO)
* [TrainingModelVersionDTO](https://cloud.tencent.com/document/api/851/75051#TrainingModelVersionDTO)
* [TrainingTaskDetail](https://cloud.tencent.com/document/api/851/75051#TrainingTaskDetail)
* [TrainingTaskSetItem](https://cloud.tencent.com/document/api/851/75051#TrainingTaskSetItem)

### 第 1 次发布

发布时间：2022-06-07 20:01:24

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateDataset](https://cloud.tencent.com/document/api/851/75050)

新增数据结构：

* [CosPathInfo](https://cloud.tencent.com/document/api/851/75051#CosPathInfo)
* [SchemaInfo](https://cloud.tencent.com/document/api/851/75051#SchemaInfo)
* [Tag](https://cloud.tencent.com/document/api/851/75051#Tag)




## 互动白板(tiw) 版本：2019-09-19

### 第 38 次发布

发布时间：2023-12-29 01:26:38

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreatePPTCheckTask](https://cloud.tencent.com/document/api/1137/90054)

	* 新增入参：AutoHandleUnsupportedElementTypes

* [CreateTranscode](https://cloud.tencent.com/document/api/1137/40060)

	* 新增入参：AutoHandleUnsupportedElementTypes


### 第 37 次发布

发布时间：2023-12-01 01:26:06

本次发布包含了以下内容：

改善已有的文档。

<font color="#dd0000">**删除接口**：</font>

* CreateOfflineRecord
* DescribeOfflineRecord
* DescribeOfflineRecordCallback
* SetOfflineRecordCallback

修改接口：

* [CreateTranscode](https://cloud.tencent.com/document/api/1137/40060)

	* 新增入参：ExcelParam


新增数据结构：

* [ExcelParam](https://cloud.tencent.com/document/api/1137/40068#ExcelParam)

### 第 36 次发布

发布时间：2023-11-01 01:23:35

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribePPTCheck](https://cloud.tencent.com/document/api/1137/90053)

	* 新增出参：Errs


修改数据结构：

* [PPTErr](https://cloud.tencent.com/document/api/1137/40068#PPTErr)

	* <font color="#dd0000">**修改成员**：</font>Name, Type, Detail


### 第 35 次发布

发布时间：2023-10-31 02:34:57

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [StartOnlineRecord](https://cloud.tencent.com/document/api/1137/40063)

	* 新增入参：TRTCRoomId, TRTCRoomIdStr

* [StartWhiteboardPush](https://cloud.tencent.com/document/api/1137/52081)

	* 新增入参：GroupId


### 第 34 次发布

发布时间：2023-09-01 01:24:40

本次发布包含了以下内容：

改善已有的文档。

<font color="#dd0000">**预下线接口**：</font>

* CreateOfflineRecord
* DescribeOfflineRecord
* DescribeOfflineRecordCallback
* SetOfflineRecordCallback

### 第 33 次发布

发布时间：2023-07-24 01:52:09

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeTranscodeByUrl](https://cloud.tencent.com/document/api/1137/95412)

### 第 32 次发布

发布时间：2023-07-21 01:44:39

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeTranscode](https://cloud.tencent.com/document/api/1137/40059)

	* 新增出参：CreateTime, AssignTime, FinishedTime


### 第 31 次发布

发布时间：2023-04-11 01:42:49

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreatePPTCheckTask](https://cloud.tencent.com/document/api/1137/90054)
* [DescribePPTCheck](https://cloud.tencent.com/document/api/1137/90053)
* [DescribePPTCheckCallback](https://cloud.tencent.com/document/api/1137/90052)
* [DescribeRunningTasks](https://cloud.tencent.com/document/api/1137/90049)
* [DescribeWarningCallback](https://cloud.tencent.com/document/api/1137/90057)
* [SetPPTCheckCallback](https://cloud.tencent.com/document/api/1137/90051)
* [SetPPTCheckCallbackKey](https://cloud.tencent.com/document/api/1137/90050)
* [SetWarningCallback](https://cloud.tencent.com/document/api/1137/90056)

新增数据结构：

* [PPTErr](https://cloud.tencent.com/document/api/1137/40068#PPTErr)
* [PPTErrSlide](https://cloud.tencent.com/document/api/1137/40068#PPTErrSlide)
* [RunningTaskItem](https://cloud.tencent.com/document/api/1137/40068#RunningTaskItem)

### 第 30 次发布

发布时间：2023-03-29 04:22:17

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeRecordSearch](https://cloud.tencent.com/document/api/1137/89543)

新增数据结构：

* [RecordTaskResult](https://cloud.tencent.com/document/api/1137/40068#RecordTaskResult)
* [RecordTaskSearchResult](https://cloud.tencent.com/document/api/1137/40068#RecordTaskSearchResult)

### 第 29 次发布

发布时间：2023-03-27 02:48:49

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [ApplyTiwTrial](https://cloud.tencent.com/document/api/1137/89418)
* [CreateApplication](https://cloud.tencent.com/document/api/1137/89417)
* [CreateOfflineRecord](https://cloud.tencent.com/document/api/1137/89396)
* [DescribeAPIService](https://cloud.tencent.com/document/api/1137/89416)
* [DescribeApplicationInfos](https://cloud.tencent.com/document/api/1137/89415)
* [DescribeApplicationUsage](https://cloud.tencent.com/document/api/1137/89414)
* [DescribeBoardSDKLog](https://cloud.tencent.com/document/api/1137/89413)
* [DescribeIMApplications](https://cloud.tencent.com/document/api/1137/89412)
* [DescribeOfflineRecord](https://cloud.tencent.com/document/api/1137/89395)
* [DescribeOfflineRecordCallback](https://cloud.tencent.com/document/api/1137/89394)
* [DescribePostpaidUsage](https://cloud.tencent.com/document/api/1137/89411)
* [DescribeRoomList](https://cloud.tencent.com/document/api/1137/89410)
* [DescribeTranscodeSearch](https://cloud.tencent.com/document/api/1137/89398)
* [DescribeUsageSummary](https://cloud.tencent.com/document/api/1137/89409)
* [DescribeUserList](https://cloud.tencent.com/document/api/1137/89408)
* [DescribeUserResources](https://cloud.tencent.com/document/api/1137/89407)
* [DescribeUserStatus](https://cloud.tencent.com/document/api/1137/89406)
* [DescribeWhiteboardApplicationConfig](https://cloud.tencent.com/document/api/1137/89405)
* [DescribeWhiteboardBucketConfig](https://cloud.tencent.com/document/api/1137/89404)
* [DescribeWhiteboardPushSearch](https://cloud.tencent.com/document/api/1137/89397)
* [ModifyApplication](https://cloud.tencent.com/document/api/1137/89403)
* [ModifyAutoRenewFlag](https://cloud.tencent.com/document/api/1137/89402)
* [ModifyWhiteboardApplicationConfig](https://cloud.tencent.com/document/api/1137/89401)
* [ModifyWhiteboardBucketConfig](https://cloud.tencent.com/document/api/1137/89400)
* [SetOfflineRecordCallback](https://cloud.tencent.com/document/api/1137/89393)

新增数据结构：

* [ApplicationItem](https://cloud.tencent.com/document/api/1137/40068#ApplicationItem)
* [DataItem](https://cloud.tencent.com/document/api/1137/40068#DataItem)
* [Detail](https://cloud.tencent.com/document/api/1137/40068#Detail)
* [RoomListItem](https://cloud.tencent.com/document/api/1137/40068#RoomListItem)
* [Tag](https://cloud.tencent.com/document/api/1137/40068#Tag)
* [TranscodeTaskResult](https://cloud.tencent.com/document/api/1137/40068#TranscodeTaskResult)
* [TranscodeTaskSearchResult](https://cloud.tencent.com/document/api/1137/40068#TranscodeTaskSearchResult)
* [UserListItem](https://cloud.tencent.com/document/api/1137/40068#UserListItem)
* [WhiteboardApplicationConfig](https://cloud.tencent.com/document/api/1137/40068#WhiteboardApplicationConfig)
* [WhiteboardPushResult](https://cloud.tencent.com/document/api/1137/40068#WhiteboardPushResult)
* [WhiteboardPushTaskSearchResult](https://cloud.tencent.com/document/api/1137/40068#WhiteboardPushTaskSearchResult)

### 第 28 次发布

发布时间：2023-01-16 02:13:33

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeTranscode](https://cloud.tencent.com/document/api/1137/40059)

	* 新增出参：ResourceListUrl, Ext

* [StartWhiteboardPush](https://cloud.tencent.com/document/api/1137/52081)

	* 新增入参：TRTCEnterRoomMode


### 第 27 次发布

发布时间：2022-12-12 01:52:52

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateTranscode](https://cloud.tencent.com/document/api/1137/40060)

	* 新增入参：AutoHandleUnsupportedElement


### 第 26 次发布

发布时间：2022-12-07 07:09:41

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeTIWRoomDailyUsage](https://cloud.tencent.com/document/api/1137/83732)

新增数据结构：

* [RoomUsageDataItem](https://cloud.tencent.com/document/api/1137/40068#RoomUsageDataItem)

### 第 25 次发布

发布时间：2022-05-17 06:17:19

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [StartWhiteboardPush](https://cloud.tencent.com/document/api/1137/52081)

	* 新增入参：IMAuthParam, TRTCAuthParam


新增数据结构：

* [AuthParam](https://cloud.tencent.com/document/api/1137/40068#AuthParam)

### 第 24 次发布

发布时间：2021-12-27 08:11:32

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateSnapshotTask](https://cloud.tencent.com/document/api/1137/59004)

	* 新增入参：SnapshotMode


### 第 23 次发布

发布时间：2021-11-19 08:15:40

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [StartWhiteboardPush](https://cloud.tencent.com/document/api/1137/52081)

	* 新增入参：TRTCRoomId, TRTCRoomIdStr


### 第 22 次发布

发布时间：2021-10-29 08:10:34

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeTIWDailyUsage](https://cloud.tencent.com/document/api/1137/63489)

新增数据结构：

* [UsageDataItem](https://cloud.tencent.com/document/api/1137/40068#UsageDataItem)

### 第 21 次发布

发布时间：2021-09-07 08:10:23

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateTranscode](https://cloud.tencent.com/document/api/1137/40060)

	* 新增入参：MinScaleResolution


### 第 20 次发布

发布时间：2021-07-21 08:10:28

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateSnapshotTask](https://cloud.tencent.com/document/api/1137/59004)
* [DescribeSnapshotTask](https://cloud.tencent.com/document/api/1137/59003)

新增数据结构：

* [SnapshotCOS](https://cloud.tencent.com/document/api/1137/40068#SnapshotCOS)
* [SnapshotResult](https://cloud.tencent.com/document/api/1137/40068#SnapshotResult)
* [SnapshotWhiteboard](https://cloud.tencent.com/document/api/1137/40068#SnapshotWhiteboard)

### 第 19 次发布

发布时间：2021-07-12 08:10:18

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeOnlineRecord](https://cloud.tencent.com/document/api/1137/40067)

	* 新增出参：Interrupts


新增数据结构：

* [Interrupt](https://cloud.tencent.com/document/api/1137/40068#Interrupt)

### 第 18 次发布

发布时间：2021-06-29 08:16:06

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateTranscode](https://cloud.tencent.com/document/api/1137/40060)

	* 新增入参：Priority


### 第 17 次发布

发布时间：2021-04-23 08:09:10

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeQualityMetrics](https://cloud.tencent.com/document/api/1137/55001)

新增数据结构：

* [TimeValue](https://cloud.tencent.com/document/api/1137/40068#TimeValue)

### 第 16 次发布

发布时间：2021-03-22 08:09:35

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [StartWhiteboardPush](https://cloud.tencent.com/document/api/1137/52081)

	* 新增入参：VideoFPS, VideoBitrate, UserDefinedRecordId, AutoPublish, UserDefinedStreamId


### 第 15 次发布

发布时间：2021-02-25 08:08:57

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [StartWhiteboardPush](https://cloud.tencent.com/document/api/1137/52081)

	* 新增入参：PrivateMapKey


### 第 14 次发布

发布时间：2021-01-29 08:09:39

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [StartOnlineRecord](https://cloud.tencent.com/document/api/1137/40063)

	* 新增入参：AutoStopTimeout


### 第 13 次发布

发布时间：2021-01-21 08:08:33

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeWhiteboardPush](https://cloud.tencent.com/document/api/1137/52300)
* [DescribeWhiteboardPushCallback](https://cloud.tencent.com/document/api/1137/52299)
* [SetWhiteboardPushCallback](https://cloud.tencent.com/document/api/1137/52298)
* [SetWhiteboardPushCallbackKey](https://cloud.tencent.com/document/api/1137/52297)

修改接口：

* [CreateTranscode](https://cloud.tencent.com/document/api/1137/40060)

	* 新增入参：ExtraData

* [CreateVideoGenerationTask](https://cloud.tencent.com/document/api/1137/48571)

	* 新增入参：ExtraData

* [StartOnlineRecord](https://cloud.tencent.com/document/api/1137/40063)

	* 新增入参：ExtraData


### 第 12 次发布

发布时间：2021-01-15 08:08:46

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [StartWhiteboardPush](https://cloud.tencent.com/document/api/1137/52081)
* [StopWhiteboardPush](https://cloud.tencent.com/document/api/1137/52080)

新增数据结构：

* [WhiteboardPushBackupParam](https://cloud.tencent.com/document/api/1137/40068#WhiteboardPushBackupParam)

### 第 11 次发布

发布时间：2020-11-04 08:07:50

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateTranscode](https://cloud.tencent.com/document/api/1137/40060)

	* 新增出参：TaskId

* [DescribeOnlineRecordCallback](https://cloud.tencent.com/document/api/1137/40624)

	* 新增出参：Callback, CallbackKey

* [DescribeTranscode](https://cloud.tencent.com/document/api/1137/40059)

	* 新增出参：Pages, Progress, Resolution, ResultUrl, Status, TaskId, Title, ThumbnailUrl, ThumbnailResolution, CompressFileUrl

* [DescribeTranscodeCallback](https://cloud.tencent.com/document/api/1137/40623)

	* 新增出参：Callback, CallbackKey


### 第 10 次发布

发布时间：2020-11-03 08:09:01

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateTranscode](https://cloud.tencent.com/document/api/1137/40060)

	* <font color="#dd0000">**删除出参**：</font>TaskId

* [DescribeOnlineRecordCallback](https://cloud.tencent.com/document/api/1137/40624)

	* <font color="#dd0000">**删除出参**：</font>Callback, CallbackKey

* [DescribeTranscode](https://cloud.tencent.com/document/api/1137/40059)

	* <font color="#dd0000">**删除出参**：</font>Pages, Progress, Resolution, ResultUrl, Status, TaskId, Title, ThumbnailUrl, ThumbnailResolution, CompressFileUrl

* [DescribeTranscodeCallback](https://cloud.tencent.com/document/api/1137/40623)

	* <font color="#dd0000">**删除出参**：</font>Callback, CallbackKey


### 第 9 次发布

发布时间：2020-09-25 08:08:01

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeVideoGenerationTask](https://cloud.tencent.com/document/api/1137/48570)

	* 新增出参：VideoInfoList


### 第 8 次发布

发布时间：2020-09-22 08:08:51

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateVideoGenerationTask](https://cloud.tencent.com/document/api/1137/48571)
* [DescribeVideoGenerationTask](https://cloud.tencent.com/document/api/1137/48570)
* [DescribeVideoGenerationTaskCallback](https://cloud.tencent.com/document/api/1137/48569)
* [SetVideoGenerationTaskCallback](https://cloud.tencent.com/document/api/1137/48568)
* [SetVideoGenerationTaskCallbackKey](https://cloud.tencent.com/document/api/1137/48567)

### 第 7 次发布

发布时间：2020-09-14 08:06:39

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeOnlineRecord](https://cloud.tencent.com/document/api/1137/40067)

	* 新增出参：ReplayUrl

* [StartOnlineRecord](https://cloud.tencent.com/document/api/1137/40063)

	* 新增入参：RecordMode, ChatGroupId


### 第 6 次发布

发布时间：2020-08-21 08:24:00

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [StartOnlineRecord](https://cloud.tencent.com/document/api/1137/40063)

	* 新增入参：RecordControl


新增数据结构：

* [RecordControl](https://cloud.tencent.com/document/api/1137/40068#RecordControl)
* [StreamControl](https://cloud.tencent.com/document/api/1137/40068#StreamControl)

修改数据结构：

* [StreamLayout](https://cloud.tencent.com/document/api/1137/40068#StreamLayout)

	* 新增成员：FillMode


### 第 5 次发布

发布时间：2020-08-18 08:25:38

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [VideoInfo](https://cloud.tencent.com/document/api/1137/40068#VideoInfo)

	* 新增成员：Width, Height


### 第 4 次发布

发布时间：2020-06-01 08:21:16

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [SetOnlineRecordCallbackKey](https://cloud.tencent.com/document/api/1137/45042)
* [SetTranscodeCallbackKey](https://cloud.tencent.com/document/api/1137/45041)

### 第 3 次发布

发布时间：2020-05-12 08:19:24

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeOnlineRecordCallback](https://cloud.tencent.com/document/api/1137/40624)

	* 新增出参：CallbackKey

* [DescribeTranscodeCallback](https://cloud.tencent.com/document/api/1137/40623)

	* 新增出参：CallbackKey


### 第 2 次发布

发布时间：2020-01-02 14:51:05

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeOnlineRecordCallback](https://cloud.tencent.com/document/api/1137/40624)
* [DescribeTranscodeCallback](https://cloud.tencent.com/document/api/1137/40623)

修改数据结构：

* [CustomLayout](https://cloud.tencent.com/document/api/1137/40068#CustomLayout)

	* <font color="#dd0000">**修改成员**：</font>InputStreamList


### 第 1 次发布

发布时间：2019-12-05 16:48:15

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateTranscode](https://cloud.tencent.com/document/api/1137/40060)
* [DescribeOnlineRecord](https://cloud.tencent.com/document/api/1137/40067)
* [DescribeTranscode](https://cloud.tencent.com/document/api/1137/40059)
* [PauseOnlineRecord](https://cloud.tencent.com/document/api/1137/40066)
* [ResumeOnlineRecord](https://cloud.tencent.com/document/api/1137/40065)
* [SetOnlineRecordCallback](https://cloud.tencent.com/document/api/1137/40064)
* [SetTranscodeCallback](https://cloud.tencent.com/document/api/1137/40058)
* [StartOnlineRecord](https://cloud.tencent.com/document/api/1137/40063)
* [StopOnlineRecord](https://cloud.tencent.com/document/api/1137/40062)

新增数据结构：

* [Canvas](https://cloud.tencent.com/document/api/1137/40068#Canvas)
* [Concat](https://cloud.tencent.com/document/api/1137/40068#Concat)
* [CustomLayout](https://cloud.tencent.com/document/api/1137/40068#CustomLayout)
* [LayoutParams](https://cloud.tencent.com/document/api/1137/40068#LayoutParams)
* [MixStream](https://cloud.tencent.com/document/api/1137/40068#MixStream)
* [OmittedDuration](https://cloud.tencent.com/document/api/1137/40068#OmittedDuration)
* [StreamLayout](https://cloud.tencent.com/document/api/1137/40068#StreamLayout)
* [VideoInfo](https://cloud.tencent.com/document/api/1137/40068#VideoInfo)
* [Whiteboard](https://cloud.tencent.com/document/api/1137/40068#Whiteboard)




## 容器服务(tke) 版本：2018-05-25

### 第 176 次发布

发布时间：2024-07-26 02:19:58

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeReservedInstanceUtilizationRate](https://cloud.tencent.com/document/api/457/109337)

新增数据结构：

* [ReservedInstanceUtilizationRate](https://cloud.tencent.com/document/api/457/31866#ReservedInstanceUtilizationRate)

### 第 175 次发布

发布时间：2024-06-27 01:21:28

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreatePrometheusConfig](https://cloud.tencent.com/document/api/457/76241)

	* 新增入参：Probes

* [DeletePrometheusClusterAgent](https://cloud.tencent.com/document/api/457/76246)

	* 新增入参：Force

* [DeletePrometheusConfig](https://cloud.tencent.com/document/api/457/76239)

	* 新增入参：Probes

* [DescribePrometheusConfig](https://cloud.tencent.com/document/api/457/76237)

	* 新增出参：Probes

* [ModifyPrometheusConfig](https://cloud.tencent.com/document/api/457/76236)

	* 新增入参：Probes


### 第 174 次发布

发布时间：2024-06-26 01:25:37

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [PrometheusAgentInfo](https://cloud.tencent.com/document/api/457/31866#PrometheusAgentInfo)

	* 新增成员：Region


### 第 173 次发布

发布时间：2024-06-20 02:22:36

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribePodChargeInfo](https://cloud.tencent.com/document/api/457/107507)

修改接口：

* [DescribeIPAMD](https://cloud.tencent.com/document/api/457/101765)

	* 新增出参：EnableTrunkingENI


新增数据结构：

* [PodChargeInfo](https://cloud.tencent.com/document/api/457/31866#PodChargeInfo)

修改数据结构：

* [ContainerState](https://cloud.tencent.com/document/api/457/31866#ContainerState)

	* <font color="#dd0000">**修改成员**：</font>StartTime, State, FinishTime, ExitCode, Reason, Message, RestartCount


### 第 172 次发布

发布时间：2024-06-17 02:22:05

本次发布包含了以下内容：

改善已有的文档。

<font color="#dd0000">**预下线接口**：</font>

* DescribeExternalClusterSpec

### 第 171 次发布

发布时间：2024-04-17 01:24:26

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [NodePool](https://cloud.tencent.com/document/api/457/31866#NodePool)

	* 新增成员：RuntimeConfig


### 第 170 次发布

发布时间：2024-04-16 01:21:55

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeSupportedRuntime](https://cloud.tencent.com/document/api/457/105241)
* [ModifyClusterRuntimeConfig](https://cloud.tencent.com/document/api/457/105240)

新增数据结构：

* [NodePoolRuntime](https://cloud.tencent.com/document/api/457/31866#NodePoolRuntime)
* [OptionalRuntimes](https://cloud.tencent.com/document/api/457/31866#OptionalRuntimes)
* [RuntimeConfig](https://cloud.tencent.com/document/api/457/31866#RuntimeConfig)

### 第 169 次发布

发布时间：2024-03-20 01:27:36

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [PodLimitsByType](https://cloud.tencent.com/document/api/457/31866#PodLimitsByType)

	* 新增成员：TKESubENI


### 第 168 次发布

发布时间：2024-03-13 01:25:40

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [GetClusterLevelPrice](https://cloud.tencent.com/document/api/457/72004)

	* 新增出参：Policy


### 第 167 次发布

发布时间：2023-12-26 01:27:04

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateClusterNodePool](https://cloud.tencent.com/document/api/457/49436)

	* 新增入参：Annotations

* [ModifyClusterNodePool](https://cloud.tencent.com/document/api/457/49431)

	* 新增入参：Annotations


新增数据结构：

* [AnnotationValue](https://cloud.tencent.com/document/api/457/31866#AnnotationValue)

修改数据结构：

* [NodePool](https://cloud.tencent.com/document/api/457/31866#NodePool)

	* 新增成员：Annotations


### 第 166 次发布

发布时间：2023-12-12 02:39:11

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateCLSLogConfig](https://cloud.tencent.com/document/api/457/102410)
* [CreateEksLogConfig](https://cloud.tencent.com/document/api/457/102409)

### 第 165 次发布

发布时间：2023-12-08 02:37:20

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [ResourceDeleteOption](https://cloud.tencent.com/document/api/457/31866#ResourceDeleteOption)

	* 新增成员：SkipDeletionProtection


### 第 164 次发布

发布时间：2023-11-30 06:52:41

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeLogSwitches](https://cloud.tencent.com/document/api/457/102050)

新增数据结构：

* [Switch](https://cloud.tencent.com/document/api/457/31866#Switch)
* [SwitchInfo](https://cloud.tencent.com/document/api/457/31866#SwitchInfo)

### 第 163 次发布

发布时间：2023-11-22 06:54:10

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeIPAMD](https://cloud.tencent.com/document/api/457/101765)

	* 新增出参：ClaimExpiredDuration


### 第 162 次发布

发布时间：2023-11-21 01:37:07

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeClusterExtraArgs](https://cloud.tencent.com/document/api/457/101764)
* [DescribeExternalNodeSupportConfig](https://cloud.tencent.com/document/api/457/101767)
* [DescribeIPAMD](https://cloud.tencent.com/document/api/457/101765)

修改接口：

* [DescribeClusterEndpoints](https://cloud.tencent.com/document/api/457/78051)

	* 新增出参：ClusterIntranetSubnetId


新增数据结构：

* [Step](https://cloud.tencent.com/document/api/457/31866#Step)

### 第 161 次发布

发布时间：2023-09-27 22:00:52

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateReservedInstances](https://cloud.tencent.com/document/api/457/99167)
* [DeleteReservedInstances](https://cloud.tencent.com/document/api/457/99166)
* [DescribePodDeductionRate](https://cloud.tencent.com/document/api/457/99165)
* [DescribePodsBySpec](https://cloud.tencent.com/document/api/457/99164)
* [DescribePostNodeResources](https://cloud.tencent.com/document/api/457/99168)
* [DescribeRIUtilizationDetail](https://cloud.tencent.com/document/api/457/99163)
* [DescribeReservedInstances](https://cloud.tencent.com/document/api/457/99162)
* [ModifyReservedInstanceScope](https://cloud.tencent.com/document/api/457/99161)
* [RenewReservedInstances](https://cloud.tencent.com/document/api/457/99158)

修改接口：

* [ModifyClusterNodePool](https://cloud.tencent.com/document/api/457/49431)

	* 新增入参：PreStartUserScript


新增数据结构：

* [InstanceChargePrepaid](https://cloud.tencent.com/document/api/457/31866#InstanceChargePrepaid)
* [PodDeductionRate](https://cloud.tencent.com/document/api/457/31866#PodDeductionRate)
* [PodNodeInfo](https://cloud.tencent.com/document/api/457/31866#PodNodeInfo)
* [RIUtilizationDetail](https://cloud.tencent.com/document/api/457/31866#RIUtilizationDetail)
* [ReservedInstance](https://cloud.tencent.com/document/api/457/31866#ReservedInstance)
* [ReservedInstanceScope](https://cloud.tencent.com/document/api/457/31866#ReservedInstanceScope)
* [ReservedInstanceSpec](https://cloud.tencent.com/document/api/457/31866#ReservedInstanceSpec)
* [SuperNodeResource](https://cloud.tencent.com/document/api/457/31866#SuperNodeResource)

修改数据结构：

* [NodePool](https://cloud.tencent.com/document/api/457/31866#NodePool)

	* 新增成员：ExtraArgs, GPUArgs, DockerGraphPath, DataDisks, Unschedulable, PreStartUserScript


### 第 160 次发布

发布时间：2023-08-07 01:18:30

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [ModifyClusterAttribute](https://cloud.tencent.com/document/api/457/42938)

	* 新增入参：ClusterProperty

	* 新增出参：ClusterProperty


新增数据结构：

* [ClusterProperty](https://cloud.tencent.com/document/api/457/31866#ClusterProperty)

### 第 159 次发布

发布时间：2023-07-14 01:40:32

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [DataDisk](https://cloud.tencent.com/document/api/457/31866#DataDisk)

	* <font color="#dd0000">**修改成员**：</font>MountTarget


### 第 158 次发布

发布时间：2023-07-12 01:46:09

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [ClusterAsGroupOption](https://cloud.tencent.com/document/api/457/31866#ClusterAsGroupOption)

	* <font color="#dd0000">**修改成员**：</font>IsScaleDownEnabled, Expander, MaxEmptyBulkDelete, ScaleDownDelay, ScaleDownUnneededTime, ScaleDownUtilizationThreshold, SkipNodesWithLocalStorage, SkipNodesWithSystemPods, IgnoreDaemonSetsUtilization, OkTotalUnreadyCount, MaxTotalUnreadyPercentage, ScaleDownUnreadyTime, UnregisteredNodeRemovalTime


### 第 157 次发布

发布时间：2023-07-11 01:47:07

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [ClusterAsGroupOption](https://cloud.tencent.com/document/api/457/31866#ClusterAsGroupOption)

	* <font color="#dd0000">**修改成员**：</font>IsScaleDownEnabled, Expander, MaxEmptyBulkDelete, ScaleDownDelay, ScaleDownUnneededTime, ScaleDownUtilizationThreshold, SkipNodesWithLocalStorage, SkipNodesWithSystemPods, IgnoreDaemonSetsUtilization


### 第 156 次发布

发布时间：2023-07-07 01:54:52

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeResourceUsage](https://cloud.tencent.com/document/api/457/72005)

	* 新增出参：RSUsage

* [ModifyClusterVirtualNodePool](https://cloud.tencent.com/document/api/457/85348)

	* 新增入参：SecurityGroupIds


修改数据结构：

* [ClusterLevelAttribute](https://cloud.tencent.com/document/api/457/31866#ClusterLevelAttribute)

	* 新增成员：RSCount


### 第 155 次发布

发布时间：2023-06-30 01:49:36

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [KMSConfiguration](https://cloud.tencent.com/document/api/457/31866#KMSConfiguration)

	* 新增成员：KeyId, KmsRegion


### 第 154 次发布

发布时间：2023-06-29 01:44:18

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeEncryptionStatus](https://cloud.tencent.com/document/api/457/94085)

	* 新增入参：ClusterId

	* 新增出参：Status, ErrorMsg

* [DisableEncryptionProtection](https://cloud.tencent.com/document/api/457/94084)

	* 新增入参：ClusterId

* [EnableEncryptionProtection](https://cloud.tencent.com/document/api/457/94083)

	* 新增入参：ClusterId, KMSConfiguration


新增数据结构：

* [KMSConfiguration](https://cloud.tencent.com/document/api/457/31866#KMSConfiguration)

### 第 153 次发布

发布时间：2023-06-20 01:53:31

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DeleteAddon](https://cloud.tencent.com/document/api/457/94184)
* [DescribeAddon](https://cloud.tencent.com/document/api/457/94183)
* [DescribeAddonValues](https://cloud.tencent.com/document/api/457/94182)
* [InstallAddon](https://cloud.tencent.com/document/api/457/94181)
* [UpdateAddon](https://cloud.tencent.com/document/api/457/94180)

新增数据结构：

* [Addon](https://cloud.tencent.com/document/api/457/31866#Addon)

### 第 152 次发布

发布时间：2023-06-16 01:44:43

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeEncryptionStatus](https://cloud.tencent.com/document/api/457/94085)
* [DisableEncryptionProtection](https://cloud.tencent.com/document/api/457/94084)
* [EnableEncryptionProtection](https://cloud.tencent.com/document/api/457/94083)

### 第 151 次发布

发布时间：2023-06-09 01:45:39

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [ClusterLevelChangeRecord](https://cloud.tencent.com/document/api/457/31866#ClusterLevelChangeRecord)

	* 新增成员：CreatedAt


### 第 150 次发布

发布时间：2023-05-16 02:20:16

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeClusterInspectionResultsOverview](https://cloud.tencent.com/document/api/457/91059)
* [ListClusterInspectionResults](https://cloud.tencent.com/document/api/457/91058)
* [ListClusterInspectionResultsItems](https://cloud.tencent.com/document/api/457/91057)

新增数据结构：

* [KubeJarvisStateCatalogue](https://cloud.tencent.com/document/api/457/31866#KubeJarvisStateCatalogue)
* [KubeJarvisStateDiagnostic](https://cloud.tencent.com/document/api/457/31866#KubeJarvisStateDiagnostic)
* [KubeJarvisStateDiagnosticOverview](https://cloud.tencent.com/document/api/457/31866#KubeJarvisStateDiagnosticOverview)
* [KubeJarvisStateInspectionOverview](https://cloud.tencent.com/document/api/457/31866#KubeJarvisStateInspectionOverview)
* [KubeJarvisStateInspectionResult](https://cloud.tencent.com/document/api/457/31866#KubeJarvisStateInspectionResult)
* [KubeJarvisStateInspectionResultsItem](https://cloud.tencent.com/document/api/457/31866#KubeJarvisStateInspectionResultsItem)
* [KubeJarvisStateResultObjInfo](https://cloud.tencent.com/document/api/457/31866#KubeJarvisStateResultObjInfo)
* [KubeJarvisStateResultsItem](https://cloud.tencent.com/document/api/457/31866#KubeJarvisStateResultsItem)
* [KubeJarvisStateStatistic](https://cloud.tencent.com/document/api/457/31866#KubeJarvisStateStatistic)

### 第 149 次发布

发布时间：2023-05-10 01:54:36

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [EdgeCluster](https://cloud.tencent.com/document/api/457/31866#EdgeCluster)

	* 新增成员：TagSpecification


### 第 148 次发布

发布时间：2023-04-26 01:57:54

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateTKEEdgeCluster](https://cloud.tencent.com/document/api/457/74868)

	* 新增入参：TagSpecification

* [DescribeTKEEdgeClusterCredential](https://cloud.tencent.com/document/api/457/74859)

	* 新增出参：UnitCluster


### 第 147 次发布

发布时间：2023-04-21 01:46:03

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateBackupStorageLocation](https://cloud.tencent.com/document/api/457/90380)
* [DeleteBackupStorageLocation](https://cloud.tencent.com/document/api/457/90379)
* [DescribeBackupStorageLocations](https://cloud.tencent.com/document/api/457/90378)

修改接口：

* [EnableVpcCniNetworkType](https://cloud.tencent.com/document/api/457/55757)

	* 新增入参：SkipAddingNonMasqueradeCIDRs


新增数据结构：

* [BackupStorageLocation](https://cloud.tencent.com/document/api/457/31866#BackupStorageLocation)

修改数据结构：

* [EdgeCluster](https://cloud.tencent.com/document/api/457/31866#EdgeCluster)

	* 新增成员：EdgeVersion


### 第 146 次发布

发布时间：2023-04-20 01:46:09

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [VirtualNodeSpec](https://cloud.tencent.com/document/api/457/31866#VirtualNodeSpec)

	* 新增成员：Tags


### 第 145 次发布

发布时间：2023-04-19 01:55:58

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [UpdateClusterKubeconfig](https://cloud.tencent.com/document/api/457/90300)

### 第 144 次发布

发布时间：2023-04-07 02:49:45

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [Cluster](https://cloud.tencent.com/document/api/457/31866#Cluster)

	* 新增成员：ClusterEtcdNodeNum

* [ClusterNetworkSettings](https://cloud.tencent.com/document/api/457/31866#ClusterNetworkSettings)

	* 新增成员：CiliumMode


### 第 143 次发布

发布时间：2023-04-05 02:04:02

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeClusterReleases](https://cloud.tencent.com/document/api/457/83755)

	* 新增入参：ClusterType


### 第 142 次发布

发布时间：2023-04-04 01:48:42

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [ServiceAccountAuthenticationOptions](https://cloud.tencent.com/document/api/457/31866#ServiceAccountAuthenticationOptions)

	* 新增成员：UseTKEDefault


### 第 141 次发布

发布时间：2023-03-21 02:24:11

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [AddVpcCniSubnets](https://cloud.tencent.com/document/api/457/56371)

	* 新增入参：SkipAddingNonMasqueradeCIDRs


### 第 140 次发布

发布时间：2023-03-01 01:55:40

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [EdgeCluster](https://cloud.tencent.com/document/api/457/31866#EdgeCluster)

	* 新增成员：AutoUpgradeClusterLevel, ChargeType


### 第 139 次发布

发布时间：2023-02-21 02:15:28

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CheckInstancesUpgradeAble](https://cloud.tencent.com/document/api/457/50366)

	* 新增出参：UnavailableVersionReason


新增数据结构：

* [UnavailableReason](https://cloud.tencent.com/document/api/457/31866#UnavailableReason)

修改数据结构：

* [UpgradeAbleInstancesItem](https://cloud.tencent.com/document/api/457/31866#UpgradeAbleInstancesItem)

	* 新增成员：RuntimeVersion, RuntimeLatestVersion


### 第 138 次发布

发布时间：2023-02-16 02:02:16

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [EnableClusterAudit](https://cloud.tencent.com/document/api/457/73900)

	* 新增入参：TopicRegion

* [EnableEventPersistence](https://cloud.tencent.com/document/api/457/73904)

	* 新增入参：TopicRegion


### 第 137 次发布

发布时间：2023-01-13 01:57:09

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateClusterVirtualNodePool](https://cloud.tencent.com/document/api/457/85354)

	* 新增入参：SecurityGroupIds

* [UpgradeClusterInstances](https://cloud.tencent.com/document/api/457/50365)

	* 新增入参：UpgradeRunTime


### 第 136 次发布

发布时间：2023-01-09 01:50:43

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateClusterVirtualNode](https://cloud.tencent.com/document/api/457/85355)
* [CreateClusterVirtualNodePool](https://cloud.tencent.com/document/api/457/85354)
* [DeleteClusterVirtualNode](https://cloud.tencent.com/document/api/457/85353)
* [DeleteClusterVirtualNodePool](https://cloud.tencent.com/document/api/457/85352)
* [DescribeClusterVirtualNode](https://cloud.tencent.com/document/api/457/85351)
* [DescribeClusterVirtualNodePools](https://cloud.tencent.com/document/api/457/85350)
* [DrainClusterVirtualNode](https://cloud.tencent.com/document/api/457/85349)
* [ModifyClusterVirtualNodePool](https://cloud.tencent.com/document/api/457/85348)

新增数据结构：

* [VirtualNode](https://cloud.tencent.com/document/api/457/31866#VirtualNode)
* [VirtualNodePool](https://cloud.tencent.com/document/api/457/31866#VirtualNodePool)
* [VirtualNodeSpec](https://cloud.tencent.com/document/api/457/31866#VirtualNodeSpec)

### 第 135 次发布

发布时间：2022-12-14 01:52:28

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateImageCache](https://cloud.tencent.com/document/api/457/70861)

	* 新增入参：RegistrySkipVerifyList, RegistryHttpEndPointList, ResolveConfig


### 第 134 次发布

发布时间：2022-12-13 10:57:15

本次发布包含了以下内容：

改善已有的文档。

<font color="#dd0000">**删除接口**：</font>

* CreateClusterNodePoolFromExistingAsg

### 第 133 次发布

发布时间：2022-12-08 01:50:31

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CancelClusterRelease](https://cloud.tencent.com/document/api/457/83759)
* [DescribeClusterPendingReleases](https://cloud.tencent.com/document/api/457/83758)
* [DescribeClusterReleaseDetails](https://cloud.tencent.com/document/api/457/83757)
* [DescribeClusterReleaseHistory](https://cloud.tencent.com/document/api/457/83756)
* [DescribeClusterReleases](https://cloud.tencent.com/document/api/457/83755)
* [RollbackClusterRelease](https://cloud.tencent.com/document/api/457/83754)
* [UninstallClusterRelease](https://cloud.tencent.com/document/api/457/83753)
* [UpgradeClusterRelease](https://cloud.tencent.com/document/api/457/83752)

修改接口：

* [UpdateImageCache](https://cloud.tencent.com/document/api/457/70857)

	* 新增入参：ImageRegistryCredentials, Images, ImageCacheSize, RetentionDays, SecurityGroupIds


新增数据结构：

* [Release](https://cloud.tencent.com/document/api/457/31866#Release)
* [ReleaseDetails](https://cloud.tencent.com/document/api/457/31866#ReleaseDetails)
* [ReleaseHistory](https://cloud.tencent.com/document/api/457/31866#ReleaseHistory)

### 第 132 次发布

发布时间：2022-12-07 07:10:03

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateClusterRelease](https://cloud.tencent.com/document/api/457/83554)

	* 新增入参：ClusterType


### 第 131 次发布

发布时间：2022-12-02 07:08:12

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateClusterRelease](https://cloud.tencent.com/document/api/457/83554)

新增数据结构：

* [PendingRelease](https://cloud.tencent.com/document/api/457/31866#PendingRelease)
* [ReleaseValues](https://cloud.tencent.com/document/api/457/31866#ReleaseValues)

### 第 130 次发布

发布时间：2022-11-22 07:03:00

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [SubnetInfos](https://cloud.tencent.com/document/api/457/31866#SubnetInfos)

	* 新增成员：Os, Arch


### 第 129 次发布

发布时间：2022-11-21 06:55:04

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [ModifyClusterNodePool](https://cloud.tencent.com/document/api/457/49431)

	* 新增入参：GPUArgs, UserScript, IgnoreExistedNode, DockerGraphPath


### 第 128 次发布

发布时间：2022-11-16 06:43:39

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DisableClusterAudit](https://cloud.tencent.com/document/api/457/73901)

	* 新增入参：DeleteLogSetAndTopic

* [DisableEventPersistence](https://cloud.tencent.com/document/api/457/73905)

	* 新增入参：DeleteLogSetAndTopic


### 第 127 次发布

发布时间：2022-10-21 06:50:37

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [EdgeCluster](https://cloud.tencent.com/document/api/457/31866#EdgeCluster)

	* 新增成员：Level

* [PrometheusAgentOverview](https://cloud.tencent.com/document/api/457/31866#PrometheusAgentOverview)

	* 新增成员：Region, VpcId, FailedReason


### 第 126 次发布

发布时间：2022-10-20 06:54:45

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribePrometheusInstanceInitStatus](https://cloud.tencent.com/document/api/457/76244)

	* 新增入参：InstanceId

	* 新增出参：Status, Steps, EksClusterId

* [RunPrometheusInstance](https://cloud.tencent.com/document/api/457/76242)

	* 新增入参：InstanceId, SubnetId


### 第 125 次发布

发布时间：2022-10-18 06:55:58

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeClusterAuthenticationOptions](https://cloud.tencent.com/document/api/457/62278)

	* 新增出参：OIDCConfig

* [ModifyClusterAuthenticationOptions](https://cloud.tencent.com/document/api/457/62277)

	* 新增入参：OIDCConfig


新增数据结构：

* [OIDCConfigAuthenticationOptions](https://cloud.tencent.com/document/api/457/31866#OIDCConfigAuthenticationOptions)

### 第 124 次发布

发布时间：2022-10-10 06:45:41

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeEdgeClusterUpgradeInfo](https://cloud.tencent.com/document/api/457/81249)
* [UpdateEdgeClusterVersion](https://cloud.tencent.com/document/api/457/81248)

### 第 123 次发布

发布时间：2022-09-28 06:56:37

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateTKEEdgeCluster](https://cloud.tencent.com/document/api/457/74868)

	* 新增入参：EdgeVersion, RegistryPrefix

* [DescribeAvailableTKEEdgeVersion](https://cloud.tencent.com/document/api/457/74863)

	* 新增入参：ClusterId

	* 新增出参：EdgeVersionLatest, EdgeVersionCurrent


### 第 122 次发布

发布时间：2022-09-15 06:43:33

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [UpdateTKEEdgeCluster](https://cloud.tencent.com/document/api/457/74855)

	* 新增入参：ClusterLevel


### 第 121 次发布

发布时间：2022-09-08 06:45:00

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [UpdateTKEEdgeCluster](https://cloud.tencent.com/document/api/457/74855)

	* 新增入参：AutoUpgradeClusterLevel


### 第 120 次发布

发布时间：2022-09-01 06:53:50

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [Cluster](https://cloud.tencent.com/document/api/457/31866#Cluster)

	* 新增成员：RuntimeVersion


### 第 119 次发布

发布时间：2022-08-30 06:57:14

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeClusterEndpoints](https://cloud.tencent.com/document/api/457/78051)

	* 新增出参：ClusterExternalDomain, ClusterIntranetDomain, SecurityGroup

* [ModifyClusterEndpointSP](https://cloud.tencent.com/document/api/457/39408)

	* 新增入参：SecurityGroup


新增数据结构：

* [CUDNN](https://cloud.tencent.com/document/api/457/31866#CUDNN)
* [CustomDriver](https://cloud.tencent.com/document/api/457/31866#CustomDriver)
* [DriverVersion](https://cloud.tencent.com/document/api/457/31866#DriverVersion)
* [GPUArgs](https://cloud.tencent.com/document/api/457/31866#GPUArgs)

修改数据结构：

* [InstanceAdvancedSettings](https://cloud.tencent.com/document/api/457/31866#InstanceAdvancedSettings)

	* 新增成员：GPUArgs

* [SubnetInfos](https://cloud.tencent.com/document/api/457/31866#SubnetInfos)

	* 新增成员：SecurityGroups


### 第 118 次发布

发布时间：2022-08-23 06:56:25

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DeletePrometheusClusterAgent](https://cloud.tencent.com/document/api/457/76246)

	* 新增入参：Agents, InstanceId


新增数据结构：

* [PrometheusAgentInfo](https://cloud.tencent.com/document/api/457/31866#PrometheusAgentInfo)

### 第 117 次发布

发布时间：2022-08-18 06:44:32

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateTKEEdgeCluster](https://cloud.tencent.com/document/api/457/74868)

	* 新增入参：ClusterLevel, AutoUpgradeClusterLevel, ChargeType


### 第 116 次发布

发布时间：2022-08-17 06:42:44

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateEdgeCVMInstances](https://cloud.tencent.com/document/api/457/79153)

### 第 115 次发布

发布时间：2022-08-10 06:54:09

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [EdgeCluster](https://cloud.tencent.com/document/api/457/31866#EdgeCluster)

	* 新增成员：ClusterAdvancedSettings


### 第 114 次发布

发布时间：2022-08-02 06:35:11

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeTKEEdgeScript](https://cloud.tencent.com/document/api/457/70732)

	* 新增入参：ScriptVersion

	* 新增出参：ScriptVersion


修改数据结构：

* [EdgeClusterAdvancedSettings](https://cloud.tencent.com/document/api/457/31866#EdgeClusterAdvancedSettings)

	* 新增成员：Runtime, ProxyMode


### 第 113 次发布

发布时间：2022-07-29 06:16:41

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeEdgeLogSwitches](https://cloud.tencent.com/document/api/457/78054)

### 第 112 次发布

发布时间：2022-07-26 06:23:55

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateEdgeLogConfig](https://cloud.tencent.com/document/api/457/78055)
* [DescribeClusterEndpoints](https://cloud.tencent.com/document/api/457/78051)
* [InstallEdgeLogAgent](https://cloud.tencent.com/document/api/457/78053)
* [UninstallEdgeLogAgent](https://cloud.tencent.com/document/api/457/78052)

### 第 111 次发布

发布时间：2022-07-13 06:18:17

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [ExistedInstance](https://cloud.tencent.com/document/api/457/31866#ExistedInstance)

	* 新增成员：IPv6Addresses


### 第 110 次发布

发布时间：2022-07-07 06:17:44

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateClusterNodePool](https://cloud.tencent.com/document/api/457/49436)

	* 新增入参：DeletionProtection

* [ModifyClusterAttribute](https://cloud.tencent.com/document/api/457/42938)

	* 新增入参：QGPUShareEnable

	* 新增出参：QGPUShareEnable

* [ModifyClusterNodePool](https://cloud.tencent.com/document/api/457/49431)

	* 新增入参：DeletionProtection


修改数据结构：

* [Cluster](https://cloud.tencent.com/document/api/457/31866#Cluster)

	* 新增成员：QGPUShareEnable

* [ClusterAdvancedSettings](https://cloud.tencent.com/document/api/457/31866#ClusterAdvancedSettings)

	* 新增成员：QGPUShareEnable

* [ClusterNetworkSettings](https://cloud.tencent.com/document/api/457/31866#ClusterNetworkSettings)

	* 新增成员：IsDualStack, Ipv6ServiceCIDR

* [NodePool](https://cloud.tencent.com/document/api/457/31866#NodePool)

	* 新增成员：DeletionProtection


### 第 109 次发布

发布时间：2022-07-06 06:20:07

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeTKEEdgeScript](https://cloud.tencent.com/document/api/457/70732)

	* 新增出参：Link, Token, Command


### 第 108 次发布

发布时间：2022-07-04 06:17:50

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreatePrometheusClusterAgent](https://cloud.tencent.com/document/api/457/76247)

	* 新增入参：InstanceId, Agents


新增数据结构：

* [PrometheusClusterAgentBasic](https://cloud.tencent.com/document/api/457/31866#PrometheusClusterAgentBasic)
* [PrometheusClusterAgentPodConfig](https://cloud.tencent.com/document/api/457/31866#PrometheusClusterAgentPodConfig)
* [Toleration](https://cloud.tencent.com/document/api/457/31866#Toleration)

### 第 107 次发布

发布时间：2022-07-01 06:19:07

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [ClusterAdvancedSettings](https://cloud.tencent.com/document/api/457/31866#ClusterAdvancedSettings)

	* 新增成员：IsDualStack


### 第 106 次发布

发布时间：2022-06-30 06:14:07

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreatePrometheusClusterAgent](https://cloud.tencent.com/document/api/457/76247)
* [CreatePrometheusConfig](https://cloud.tencent.com/document/api/457/76241)
* [CreatePrometheusRecordRuleYaml](https://cloud.tencent.com/document/api/457/76240)
* [DeletePrometheusClusterAgent](https://cloud.tencent.com/document/api/457/76246)
* [DeletePrometheusConfig](https://cloud.tencent.com/document/api/457/76239)
* [DeletePrometheusRecordRuleYaml](https://cloud.tencent.com/document/api/457/76238)
* [DescribePrometheusConfig](https://cloud.tencent.com/document/api/457/76237)
* [DescribePrometheusGlobalConfig](https://cloud.tencent.com/document/api/457/76245)
* [DescribePrometheusInstanceInitStatus](https://cloud.tencent.com/document/api/457/76244)
* [ModifyPrometheusAgentExternalLabels](https://cloud.tencent.com/document/api/457/76243)
* [ModifyPrometheusConfig](https://cloud.tencent.com/document/api/457/76236)
* [ModifyPrometheusRecordRuleYaml](https://cloud.tencent.com/document/api/457/76235)
* [RunPrometheusInstance](https://cloud.tencent.com/document/api/457/76242)

### 第 105 次发布

发布时间：2022-06-27 06:16:26

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [ForwardTKEEdgeApplicationRequestV3](https://cloud.tencent.com/document/api/457/76042)

### 第 104 次发布

发布时间：2022-06-09 06:18:50

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateEKSCluster](https://cloud.tencent.com/document/api/457/52353)

	* 新增入参：SubnetInfos


新增数据结构：

* [SubnetInfos](https://cloud.tencent.com/document/api/457/31866#SubnetInfos)

### 第 103 次发布

发布时间：2022-06-03 06:14:39

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [ClusterCIDRSettings](https://cloud.tencent.com/document/api/457/31866#ClusterCIDRSettings)

	* 新增成员：IgnoreServiceCIDRConflict

* [ClusterNetworkSettings](https://cloud.tencent.com/document/api/457/31866#ClusterNetworkSettings)

	* 新增成员：IgnoreServiceCIDRConflict


### 第 102 次发布

发布时间：2022-06-02 06:15:27

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CheckEdgeClusterCIDR](https://cloud.tencent.com/document/api/457/74870)
* [CreateECMInstances](https://cloud.tencent.com/document/api/457/74869)
* [CreateTKEEdgeCluster](https://cloud.tencent.com/document/api/457/74868)
* [DeleteECMInstances](https://cloud.tencent.com/document/api/457/74867)
* [DeleteEdgeCVMInstances](https://cloud.tencent.com/document/api/457/74866)
* [DeleteEdgeClusterInstances](https://cloud.tencent.com/document/api/457/74865)
* [DeleteTKEEdgeCluster](https://cloud.tencent.com/document/api/457/74864)
* [DescribeAvailableTKEEdgeVersion](https://cloud.tencent.com/document/api/457/74863)
* [DescribeECMInstances](https://cloud.tencent.com/document/api/457/74862)
* [DescribeEdgeAvailableExtraArgs](https://cloud.tencent.com/document/api/457/74854)
* [DescribeEdgeCVMInstances](https://cloud.tencent.com/document/api/457/74861)
* [DescribeEdgeClusterExtraArgs](https://cloud.tencent.com/document/api/457/74853)
* [DescribeEdgeClusterInstances](https://cloud.tencent.com/document/api/457/74860)
* [DescribeTKEEdgeClusterCredential](https://cloud.tencent.com/document/api/457/74859)
* [DescribeTKEEdgeClusterStatus](https://cloud.tencent.com/document/api/457/74858)
* [DescribeTKEEdgeClusters](https://cloud.tencent.com/document/api/457/74857)
* [DescribeTKEEdgeExternalKubeconfig](https://cloud.tencent.com/document/api/457/74856)
* [UpdateTKEEdgeCluster](https://cloud.tencent.com/document/api/457/74855)

修改接口：

* [AddExistedInstances](https://cloud.tencent.com/document/api/457/31865)

	* 新增入参：ImageId

* [CreateClusterNodePool](https://cloud.tencent.com/document/api/457/49436)

	* 新增入参：ContainerRuntime, RuntimeVersion


新增数据结构：

* [ClusterCondition](https://cloud.tencent.com/document/api/457/31866#ClusterCondition)
* [ECMEnhancedService](https://cloud.tencent.com/document/api/457/31866#ECMEnhancedService)
* [ECMRunMonitorServiceEnabled](https://cloud.tencent.com/document/api/457/31866#ECMRunMonitorServiceEnabled)
* [ECMRunSecurityServiceEnabled](https://cloud.tencent.com/document/api/457/31866#ECMRunSecurityServiceEnabled)
* [ECMZoneInstanceCountISP](https://cloud.tencent.com/document/api/457/31866#ECMZoneInstanceCountISP)
* [EdgeArgsFlag](https://cloud.tencent.com/document/api/457/31866#EdgeArgsFlag)
* [EdgeAvailableExtraArgs](https://cloud.tencent.com/document/api/457/31866#EdgeAvailableExtraArgs)
* [EdgeCluster](https://cloud.tencent.com/document/api/457/31866#EdgeCluster)
* [EdgeClusterAdvancedSettings](https://cloud.tencent.com/document/api/457/31866#EdgeClusterAdvancedSettings)
* [EdgeClusterExtraArgs](https://cloud.tencent.com/document/api/457/31866#EdgeClusterExtraArgs)
* [EdgeClusterInternalLB](https://cloud.tencent.com/document/api/457/31866#EdgeClusterInternalLB)
* [EdgeClusterPublicLB](https://cloud.tencent.com/document/api/457/31866#EdgeClusterPublicLB)

修改数据结构：

* [InstanceAdvancedSettings](https://cloud.tencent.com/document/api/457/31866#InstanceAdvancedSettings)

	* 新增成员：Taints


### 第 101 次发布

发布时间：2022-05-20 06:19:18

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreatePrometheusGlobalNotification](https://cloud.tencent.com/document/api/457/74076)
* [DescribePrometheusGlobalNotification](https://cloud.tencent.com/document/api/457/74075)
* [ModifyPrometheusGlobalNotification](https://cloud.tencent.com/document/api/457/74074)

修改接口：

* [CreatePrometheusAlertPolicy](https://cloud.tencent.com/document/api/457/73918)

	* 新增入参：InstanceId, AlertRule

	* 新增出参：Id

* [CreatePrometheusTemp](https://cloud.tencent.com/document/api/457/73917)

	* 新增入参：Template

	* 新增出参：TemplateId

* [DeletePrometheusAlertPolicy](https://cloud.tencent.com/document/api/457/73916)

	* 新增入参：InstanceId, AlertIds, Names

* [DeletePrometheusTemp](https://cloud.tencent.com/document/api/457/73915)

	* 新增入参：TemplateId

* [DeletePrometheusTempSync](https://cloud.tencent.com/document/api/457/73914)

	* 新增入参：TemplateId, Targets

* [DescribePrometheusAlertPolicy](https://cloud.tencent.com/document/api/457/73913)

	* 新增入参：InstanceId, Offset, Limit, Filters

	* 新增出参：AlertRules, Total

* [DescribePrometheusClusterAgents](https://cloud.tencent.com/document/api/457/73912)

	* 新增入参：InstanceId, Offset, Limit

	* 新增出参：Agents, Total

* [DescribePrometheusInstancesOverview](https://cloud.tencent.com/document/api/457/73911)

	* 新增入参：Offset, Limit, Filters

	* 新增出参：Instances, Total

* [DescribePrometheusRecordRules](https://cloud.tencent.com/document/api/457/73910)

	* 新增入参：InstanceId, Offset, Limit, Filters

	* 新增出参：Records, Total

* [DescribePrometheusTemp](https://cloud.tencent.com/document/api/457/73909)

	* 新增入参：Filters, Offset, Limit

	* 新增出参：Templates, Total

* [DescribePrometheusTempSync](https://cloud.tencent.com/document/api/457/73908)

	* 新增入参：TemplateId

	* 新增出参：Targets

* [ModifyPrometheusAlertPolicy](https://cloud.tencent.com/document/api/457/73907)

	* 新增入参：InstanceId, AlertRule

* [ModifyPrometheusTemp](https://cloud.tencent.com/document/api/457/74013)

	* 新增入参：TemplateId, Template

* [SyncPrometheusTemp](https://cloud.tencent.com/document/api/457/73906)

	* 新增入参：TemplateId, Targets


新增数据结构：

* [PrometheusAlertManagerConfig](https://cloud.tencent.com/document/api/457/31866#PrometheusAlertManagerConfig)
* [PrometheusAlertPolicyItem](https://cloud.tencent.com/document/api/457/31866#PrometheusAlertPolicyItem)
* [PrometheusInstancesOverview](https://cloud.tencent.com/document/api/457/31866#PrometheusInstancesOverview)
* [PrometheusNotificationItem](https://cloud.tencent.com/document/api/457/31866#PrometheusNotificationItem)
* [PrometheusRecordRuleYamlItem](https://cloud.tencent.com/document/api/457/31866#PrometheusRecordRuleYamlItem)
* [PrometheusTemp](https://cloud.tencent.com/document/api/457/31866#PrometheusTemp)
* [PrometheusTempModify](https://cloud.tencent.com/document/api/457/31866#PrometheusTempModify)

### 第 100 次发布

发布时间：2022-05-19 06:19:17

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [ModifyPrometheusTemp](https://cloud.tencent.com/document/api/457/74013)

### 第 99 次发布

发布时间：2022-05-18 06:18:26

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreatePrometheusAlertPolicy](https://cloud.tencent.com/document/api/457/73918)
* [CreatePrometheusTemp](https://cloud.tencent.com/document/api/457/73917)
* [DeletePrometheusAlertPolicy](https://cloud.tencent.com/document/api/457/73916)
* [DeletePrometheusTemp](https://cloud.tencent.com/document/api/457/73915)
* [DeletePrometheusTempSync](https://cloud.tencent.com/document/api/457/73914)
* [DescribePrometheusAlertPolicy](https://cloud.tencent.com/document/api/457/73913)
* [DescribePrometheusClusterAgents](https://cloud.tencent.com/document/api/457/73912)
* [DescribePrometheusInstancesOverview](https://cloud.tencent.com/document/api/457/73911)
* [DescribePrometheusRecordRules](https://cloud.tencent.com/document/api/457/73910)
* [DescribePrometheusTemp](https://cloud.tencent.com/document/api/457/73909)
* [DescribePrometheusTempSync](https://cloud.tencent.com/document/api/457/73908)
* [DisableClusterAudit](https://cloud.tencent.com/document/api/457/73901)
* [DisableEventPersistence](https://cloud.tencent.com/document/api/457/73905)
* [EnableClusterAudit](https://cloud.tencent.com/document/api/457/73900)
* [EnableEventPersistence](https://cloud.tencent.com/document/api/457/73904)
* [InstallLogAgent](https://cloud.tencent.com/document/api/457/73903)
* [ModifyPrometheusAlertPolicy](https://cloud.tencent.com/document/api/457/73907)
* [SyncPrometheusTemp](https://cloud.tencent.com/document/api/457/73906)
* [UninstallLogAgent](https://cloud.tencent.com/document/api/457/73902)

### 第 98 次发布

发布时间：2022-05-12 06:17:58

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateClusterEndpoint](https://cloud.tencent.com/document/api/457/39414)

	* 新增入参：Domain, SecurityGroup, ExtensiveParameters


### 第 97 次发布

发布时间：2022-05-09 06:15:13

本次发布包含了以下内容：

改善已有的文档。

<font color="#dd0000">**删除接口**：</font>

* CreateClusterAsGroup

### 第 96 次发布

发布时间：2022-04-06 17:49:55

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [Cluster](https://cloud.tencent.com/document/api/457/31866#Cluster)

	* 新增成员：ClusterLevel, AutoUpgradeClusterLevel


### 第 95 次发布

发布时间：2022-04-01 20:14:58

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeClusterLevelAttribute](https://cloud.tencent.com/document/api/457/72007)
* [DescribeClusterLevelChangeRecords](https://cloud.tencent.com/document/api/457/72006)
* [DescribeResourceUsage](https://cloud.tencent.com/document/api/457/72005)
* [GetClusterLevelPrice](https://cloud.tencent.com/document/api/457/72004)

新增数据结构：

* [ClusterLevelAttribute](https://cloud.tencent.com/document/api/457/31866#ClusterLevelAttribute)
* [ClusterLevelChangeRecord](https://cloud.tencent.com/document/api/457/31866#ClusterLevelChangeRecord)
* [ResourceUsage](https://cloud.tencent.com/document/api/457/31866#ResourceUsage)
* [ResourceUsageDetail](https://cloud.tencent.com/document/api/457/31866#ResourceUsageDetail)

### 第 94 次发布

发布时间：2022-03-22 08:16:05

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeEKSClusterCredential](https://cloud.tencent.com/document/api/457/52351)

	* 新增出参：Kubeconfig


### 第 93 次发布

发布时间：2022-03-21 08:17:26

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [ModifyClusterAttribute](https://cloud.tencent.com/document/api/457/42938)

	* 新增入参：ClusterLevel, AutoUpgradeClusterLevel

	* 新增出参：ClusterLevel, AutoUpgradeClusterLevel


新增数据结构：

* [AutoUpgradeClusterLevel](https://cloud.tencent.com/document/api/457/31866#AutoUpgradeClusterLevel)

修改数据结构：

* [ClusterBasicSettings](https://cloud.tencent.com/document/api/457/31866#ClusterBasicSettings)

	* 新增成员：ClusterLevel, AutoUpgradeClusterLevel


### 第 92 次发布

发布时间：2022-03-16 08:15:43

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [Container](https://cloud.tencent.com/document/api/457/31866#Container)

	* 新增成员：SecurityContext


### 第 91 次发布

发布时间：2022-03-10 08:16:16

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateImageCache](https://cloud.tencent.com/document/api/457/70861)
* [DeleteImageCaches](https://cloud.tencent.com/document/api/457/70860)
* [DescribeImageCaches](https://cloud.tencent.com/document/api/457/70859)
* [GetMostSuitableImageCache](https://cloud.tencent.com/document/api/457/70858)
* [UpdateImageCache](https://cloud.tencent.com/document/api/457/70857)

新增数据结构：

* [ImageCache](https://cloud.tencent.com/document/api/457/31866#ImageCache)
* [ImageCacheEvent](https://cloud.tencent.com/document/api/457/31866#ImageCacheEvent)

### 第 90 次发布

发布时间：2022-03-07 08:14:19

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeTKEEdgeScript](https://cloud.tencent.com/document/api/457/70732)

### 第 89 次发布

发布时间：2022-02-11 08:13:17

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeClusterNodePools](https://cloud.tencent.com/document/api/457/49432)

	* 新增入参：Filters


### 第 88 次发布

发布时间：2022-01-24 08:16:10

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeClusterStatus](https://cloud.tencent.com/document/api/457/68727)

新增数据结构：

* [ClusterStatus](https://cloud.tencent.com/document/api/457/31866#ClusterStatus)

### 第 87 次发布

发布时间：2022-01-18 08:16:47

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [ModifyClusterNodePool](https://cloud.tencent.com/document/api/457/49431)

	* 新增入参：Unschedulable


### 第 86 次发布

发布时间：2022-01-14 08:16:57

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [UpdateEKSCluster](https://cloud.tencent.com/document/api/457/52349)

	* 新增入参：ExtraParam


### 第 85 次发布

发布时间：2022-01-07 08:14:40

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [PrometheusAgentOverview](https://cloud.tencent.com/document/api/457/31866#PrometheusAgentOverview)

	* 新增成员：ExternalLabels

* [PrometheusAlertRule](https://cloud.tencent.com/document/api/457/31866#PrometheusAlertRule)

	* 新增成员：RuleState


### 第 84 次发布

发布时间：2022-01-05 08:14:55

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateClusterNodePool](https://cloud.tencent.com/document/api/457/49436)

	* 新增入参：Tags

* [ModifyClusterNodePool](https://cloud.tencent.com/document/api/457/49431)

	* 新增入参：Tags


修改数据结构：

* [NodePool](https://cloud.tencent.com/document/api/457/31866#NodePool)

	* 新增成员：Tags


### 第 83 次发布

发布时间：2021-12-24 08:16:08

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeEKSClusterCredential](https://cloud.tencent.com/document/api/457/52351)

	* 新增出参：ProxyLB

* [UpdateEKSCluster](https://cloud.tencent.com/document/api/457/52349)

	* 新增入参：ProxyLB


修改数据结构：

* [ClusterPublicLB](https://cloud.tencent.com/document/api/457/31866#ClusterPublicLB)

	* 新增成员：SecurityGroup


### 第 82 次发布

发布时间：2021-12-17 08:17:44

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [ClusterBasicSettings](https://cloud.tencent.com/document/api/457/31866#ClusterBasicSettings)

	* 新增成员：SubnetId


### 第 81 次发布

发布时间：2021-12-09 08:12:05

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [EksCi](https://cloud.tencent.com/document/api/457/31866#EksCi)

	* 新增成员：PersistStatus


### 第 80 次发布

发布时间：2021-11-30 08:12:44

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [ForwardApplicationRequestV3](https://cloud.tencent.com/document/api/457/64978)
* [GetTkeAppChartList](https://cloud.tencent.com/document/api/457/64977)

新增数据结构：

* [AppChart](https://cloud.tencent.com/document/api/457/31866#AppChart)

### 第 79 次发布

发布时间：2021-11-29 08:13:39

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DisableClusterDeletionProtection](https://cloud.tencent.com/document/api/457/64876)
* [EnableClusterDeletionProtection](https://cloud.tencent.com/document/api/457/64875)

### 第 78 次发布

发布时间：2021-11-25 08:15:58

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [ScaleInClusterMaster](https://cloud.tencent.com/document/api/457/64792)
* [ScaleOutClusterMaster](https://cloud.tencent.com/document/api/457/64791)

新增数据结构：

* [ScaleInMaster](https://cloud.tencent.com/document/api/457/31866#ScaleInMaster)

### 第 77 次发布

发布时间：2021-11-02 08:12:02

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [ModifyClusterEndpointSP](https://cloud.tencent.com/document/api/457/39408)

	* <font color="#dd0000">**修改入参**：</font>SecurityPolicies


### 第 76 次发布

发布时间：2021-10-01 21:29:42

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeClusterAuthenticationOptions](https://cloud.tencent.com/document/api/457/62278)
* [ModifyClusterAuthenticationOptions](https://cloud.tencent.com/document/api/457/62277)

新增数据结构：

* [ServiceAccountAuthenticationOptions](https://cloud.tencent.com/document/api/457/31866#ServiceAccountAuthenticationOptions)

### 第 75 次发布

发布时间：2021-09-29 08:10:54

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [ModifyClusterNodePool](https://cloud.tencent.com/document/api/457/49431)

	* 新增入参：ExtraArgs


### 第 74 次发布

发布时间：2021-09-27 08:17:09

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeClusterKubeconfig](https://cloud.tencent.com/document/api/457/48149)

	* 新增入参：IsExtranet


### 第 73 次发布

发布时间：2021-09-24 10:12:59

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeExternalClusterSpec](https://cloud.tencent.com/document/api/457/61850)

修改接口：

* [DescribeClusters](https://cloud.tencent.com/document/api/457/31862)

	* 新增入参：ClusterType


### 第 72 次发布

发布时间：2021-09-17 08:13:49

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateEKSContainerInstances](https://cloud.tencent.com/document/api/457/61665)
* [DeleteEKSContainerInstances](https://cloud.tencent.com/document/api/457/61664)
* [DescribeEKSContainerInstanceEvent](https://cloud.tencent.com/document/api/457/61663)
* [DescribeEKSContainerInstances](https://cloud.tencent.com/document/api/457/61662)
* [DescribeEksContainerInstanceLog](https://cloud.tencent.com/document/api/457/61661)
* [RestartEKSContainerInstances](https://cloud.tencent.com/document/api/457/61660)
* [UpdateEKSContainerInstance](https://cloud.tencent.com/document/api/457/61659)

新增数据结构：

* [Capabilities](https://cloud.tencent.com/document/api/457/31866#Capabilities)
* [CbsVolume](https://cloud.tencent.com/document/api/457/31866#CbsVolume)
* [Container](https://cloud.tencent.com/document/api/457/31866#Container)
* [ContainerState](https://cloud.tencent.com/document/api/457/31866#ContainerState)
* [DNSConfig](https://cloud.tencent.com/document/api/457/31866#DNSConfig)
* [DNSConfigOption](https://cloud.tencent.com/document/api/457/31866#DNSConfigOption)
* [EipAttribute](https://cloud.tencent.com/document/api/457/31866#EipAttribute)
* [EksCi](https://cloud.tencent.com/document/api/457/31866#EksCi)
* [EksCiVolume](https://cloud.tencent.com/document/api/457/31866#EksCiVolume)
* [EnvironmentVariable](https://cloud.tencent.com/document/api/457/31866#EnvironmentVariable)
* [Event](https://cloud.tencent.com/document/api/457/31866#Event)
* [Exec](https://cloud.tencent.com/document/api/457/31866#Exec)
* [HttpGet](https://cloud.tencent.com/document/api/457/31866#HttpGet)
* [ImageRegistryCredential](https://cloud.tencent.com/document/api/457/31866#ImageRegistryCredential)
* [LivenessOrReadinessProbe](https://cloud.tencent.com/document/api/457/31866#LivenessOrReadinessProbe)
* [NfsVolume](https://cloud.tencent.com/document/api/457/31866#NfsVolume)
* [Probe](https://cloud.tencent.com/document/api/457/31866#Probe)
* [SecurityContext](https://cloud.tencent.com/document/api/457/31866#SecurityContext)
* [TcpSocket](https://cloud.tencent.com/document/api/457/31866#TcpSocket)
* [VolumeMount](https://cloud.tencent.com/document/api/457/31866#VolumeMount)

### 第 71 次发布

发布时间：2021-09-13 08:08:39

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeEKSContainerInstanceRegions](https://cloud.tencent.com/document/api/457/61419)

新增数据结构：

* [EksCiRegionInfo](https://cloud.tencent.com/document/api/457/31866#EksCiRegionInfo)

### 第 70 次发布

发布时间：2021-08-25 08:08:51

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [InstanceAdvancedSettings](https://cloud.tencent.com/document/api/457/31866#InstanceAdvancedSettings)

	* 新增成员：PreStartUserScript

* [RunAutomationServiceEnabled](https://cloud.tencent.com/document/api/457/31866#RunAutomationServiceEnabled)

	* 新增成员：Enabled


### 第 69 次发布

发布时间：2021-08-23 17:09:11

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [ModifyNodePoolInstanceTypes](https://cloud.tencent.com/document/api/457/60598)

### 第 68 次发布

发布时间：2021-08-18 08:08:49

本次发布包含了以下内容：

改善已有的文档。

新增数据结构：

* [RunAutomationServiceEnabled](https://cloud.tencent.com/document/api/457/31866#RunAutomationServiceEnabled)

修改数据结构：

* [EnhancedService](https://cloud.tencent.com/document/api/457/31866#EnhancedService)

	* 新增成员：AutomationService


### 第 67 次发布

发布时间：2021-08-05 08:08:52

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeVersions](https://cloud.tencent.com/document/api/457/59513)

新增数据结构：

* [VersionInstance](https://cloud.tencent.com/document/api/457/31866#VersionInstance)

### 第 66 次发布

发布时间：2021-08-04 08:08:49

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeClusterInstances](https://cloud.tencent.com/document/api/457/31863)

	* 新增入参：Filters


### 第 65 次发布

发布时间：2021-07-30 08:09:14

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreatePrometheusAlertRule](https://cloud.tencent.com/document/api/457/59328)
* [DeletePrometheusAlertRule](https://cloud.tencent.com/document/api/457/59327)
* [DescribePrometheusInstance](https://cloud.tencent.com/document/api/457/59326)
* [ModifyPrometheusAlertRule](https://cloud.tencent.com/document/api/457/59325)

新增数据结构：

* [PrometheusGrafanaInfo](https://cloud.tencent.com/document/api/457/31866#PrometheusGrafanaInfo)

### 第 64 次发布

发布时间：2021-07-29 08:09:25

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeVpcCniPodLimits](https://cloud.tencent.com/document/api/457/59275)

新增数据结构：

* [PodLimitsByType](https://cloud.tencent.com/document/api/457/31866#PodLimitsByType)
* [PodLimitsInstance](https://cloud.tencent.com/document/api/457/31866#PodLimitsInstance)

### 第 63 次发布

发布时间：2021-07-22 08:08:46

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [AddClusterCIDR](https://cloud.tencent.com/document/api/457/59036)
* [DisableVpcCniNetworkType](https://cloud.tencent.com/document/api/457/59035)

### 第 62 次发布

发布时间：2021-06-28 08:08:32

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [DataDisk](https://cloud.tencent.com/document/api/457/31866#DataDisk)

	* 新增成员：DiskPartition


### 第 61 次发布

发布时间：2021-06-23 11:36:42

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeClusterControllers](https://cloud.tencent.com/document/api/457/57744)

新增数据结构：

* [ControllerStatus](https://cloud.tencent.com/document/api/457/31866#ControllerStatus)

### 第 60 次发布

发布时间：2021-06-22 08:09:27

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [PrometheusAlertRule](https://cloud.tencent.com/document/api/457/31866#PrometheusAlertRule)

	* 新增成员：Annotations


### 第 59 次发布

发布时间：2021-06-18 08:08:14

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [ClusterAdvancedSettings](https://cloud.tencent.com/document/api/457/31866#ClusterAdvancedSettings)

	* 新增成员：CiliumMode

* [PrometheusInstanceOverview](https://cloud.tencent.com/document/api/457/31866#PrometheusInstanceOverview)

	* 新增成员：GrafanaURL, BoundTotal, BoundNormal


### 第 58 次发布

发布时间：2021-06-17 08:08:22

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [Cluster](https://cloud.tencent.com/document/api/457/31866#Cluster)

	* 新增成员：EnableExternalNode


### 第 57 次发布

发布时间：2021-05-28 08:08:07

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [AddVpcCniSubnets](https://cloud.tencent.com/document/api/457/56371)

修改数据结构：

* [ClusterNetworkSettings](https://cloud.tencent.com/document/api/457/31866#ClusterNetworkSettings)

	* 新增成员：KubeProxyMode, ServiceCIDR, Subnets


### 第 56 次发布

发布时间：2021-05-27 08:08:13

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [ClusterPublicLB](https://cloud.tencent.com/document/api/457/31866#ClusterPublicLB)

	* 新增成员：ExtraParam


### 第 55 次发布

发布时间：2021-05-21 08:08:09

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [AddExistedInstances](https://cloud.tencent.com/document/api/457/31865)

	* 新增入参：InstanceAdvancedSettingsOverrides


修改数据结构：

* [ExistedInstancesForNode](https://cloud.tencent.com/document/api/457/31866#ExistedInstancesForNode)

	* 新增成员：DesiredPodNumbers


### 第 54 次发布

发布时间：2021-05-20 08:08:13

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [InstanceAdvancedSettings](https://cloud.tencent.com/document/api/457/31866#InstanceAdvancedSettings)

	* 新增成员：DesiredPodNumber


### 第 53 次发布

发布时间：2021-05-18 08:08:57

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [EnableVpcCniNetworkType](https://cloud.tencent.com/document/api/457/55757)

	* 新增入参：ExpiredSeconds


### 第 52 次发布

发布时间：2021-05-17 08:08:15

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [SetNodePoolNodeProtection](https://cloud.tencent.com/document/api/457/53705)

	* 新增入参：ClusterId, NodePoolId, InstanceIds, ProtectedFromScaleIn

	* 新增出参：SucceedInstanceIds, FailedInstanceIds


### 第 51 次发布

发布时间：2021-05-14 08:08:14

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeEnableVpcCniProgress](https://cloud.tencent.com/document/api/457/55758)
* [EnableVpcCniNetworkType](https://cloud.tencent.com/document/api/457/55757)

### 第 50 次发布

发布时间：2021-05-13 08:07:42

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeClusterCommonNames](https://cloud.tencent.com/document/api/457/55721)

新增数据结构：

* [CommonName](https://cloud.tencent.com/document/api/457/31866#CommonName)

### 第 49 次发布

发布时间：2021-04-25 10:17:37

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeClusterEndpointStatus](https://cloud.tencent.com/document/api/457/39410)

	* 新增出参：ErrorMsg


### 第 48 次发布

发布时间：2021-04-13 08:08:32

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [UpdateClusterVersion](https://cloud.tencent.com/document/api/457/52133)

	* 新增入参：ExtraArgs


### 第 47 次发布

发布时间：2021-04-07 08:07:35

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [NodePool](https://cloud.tencent.com/document/api/457/31866#NodePool)

	* 新增成员：DesiredPodNum, UserScript


### 第 46 次发布

发布时间：2021-03-17 08:08:21

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [SetNodePoolNodeProtection](https://cloud.tencent.com/document/api/457/53705)

### 第 45 次发布

发布时间：2021-03-16 08:09:01

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeExistedInstances](https://cloud.tencent.com/document/api/457/36706)

	* 新增入参：IpAddresses


修改数据结构：

* [PrometheusAlertHistoryItem](https://cloud.tencent.com/document/api/457/31866#PrometheusAlertHistoryItem)

	* 新增成员：State, RuleItem, TopicId, TopicName


### 第 44 次发布

发布时间：2021-03-01 08:07:46

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [ClusterExtraArgs](https://cloud.tencent.com/document/api/457/31866#ClusterExtraArgs)

	* 新增成员：Etcd


### 第 43 次发布

发布时间：2021-02-26 08:07:42

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribePrometheusAlertHistory](https://cloud.tencent.com/document/api/457/53194)

新增数据结构：

* [PrometheusAlertHistoryItem](https://cloud.tencent.com/document/api/457/31866#PrometheusAlertHistoryItem)

### 第 42 次发布

发布时间：2021-02-25 08:07:36

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [ClusterAdvancedSettings](https://cloud.tencent.com/document/api/457/31866#ClusterAdvancedSettings)

	* 新增成员：EnableCustomizedPodCIDR, BasePodNumber


### 第 41 次发布

发布时间：2021-01-29 08:07:55

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateEKSCluster](https://cloud.tencent.com/document/api/457/52353)

	* 新增入参：TagSpecification


修改数据结构：

* [EksCluster](https://cloud.tencent.com/document/api/457/31866#EksCluster)

	* 新增成员：TagSpecification


### 第 40 次发布

发布时间：2021-01-26 08:08:22

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateClusterNodePool](https://cloud.tencent.com/document/api/457/49436)

	* 新增入参：NodePoolOs, OsCustomizeType


### 第 39 次发布

发布时间：2021-01-22 08:06:57

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateEKSCluster](https://cloud.tencent.com/document/api/457/52353)
* [DeleteEKSCluster](https://cloud.tencent.com/document/api/457/52352)
* [DescribeEKSClusterCredential](https://cloud.tencent.com/document/api/457/52351)
* [DescribeEKSClusters](https://cloud.tencent.com/document/api/457/52350)
* [UpdateEKSCluster](https://cloud.tencent.com/document/api/457/52349)

新增数据结构：

* [ClusterCredential](https://cloud.tencent.com/document/api/457/31866#ClusterCredential)
* [ClusterInternalLB](https://cloud.tencent.com/document/api/457/31866#ClusterInternalLB)
* [ClusterPublicLB](https://cloud.tencent.com/document/api/457/31866#ClusterPublicLB)
* [DnsServerConf](https://cloud.tencent.com/document/api/457/31866#DnsServerConf)
* [EksCluster](https://cloud.tencent.com/document/api/457/31866#EksCluster)
* [IPAddress](https://cloud.tencent.com/document/api/457/31866#IPAddress)

### 第 38 次发布

发布时间：2021-01-21 08:07:05

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [AddExistedInstances](https://cloud.tencent.com/document/api/457/31865)

	* 新增入参：SkipValidateOptions

* [CreateClusterInstances](https://cloud.tencent.com/document/api/457/36707)

	* 新增入参：SkipValidateOptions


修改数据结构：

* [PrometheusAlertRuleDetail](https://cloud.tencent.com/document/api/457/31866#PrometheusAlertRuleDetail)

	* 新增成员：Interval


### 第 37 次发布

发布时间：2021-01-18 08:07:11

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeAvailableClusterVersion](https://cloud.tencent.com/document/api/457/52135)
* [GetUpgradeInstanceProgress](https://cloud.tencent.com/document/api/457/52134)
* [UpdateClusterVersion](https://cloud.tencent.com/document/api/457/52133)

新增数据结构：

* [ClusterVersion](https://cloud.tencent.com/document/api/457/31866#ClusterVersion)
* [InstanceUpgradeClusterStatus](https://cloud.tencent.com/document/api/457/31866#InstanceUpgradeClusterStatus)
* [InstanceUpgradePreCheckResult](https://cloud.tencent.com/document/api/457/31866#InstanceUpgradePreCheckResult)
* [InstanceUpgradePreCheckResultItem](https://cloud.tencent.com/document/api/457/31866#InstanceUpgradePreCheckResultItem)
* [InstanceUpgradeProgressItem](https://cloud.tencent.com/document/api/457/31866#InstanceUpgradeProgressItem)
* [TaskStepInfo](https://cloud.tencent.com/document/api/457/31866#TaskStepInfo)

### 第 36 次发布

发布时间：2020-12-28 08:07:04

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [NodePool](https://cloud.tencent.com/document/api/457/31866#NodePool)

	* 新增成员：NodePoolOs, OsCustomizeType, ImageId


### 第 35 次发布

发布时间：2020-12-22 08:08:25

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [ModifyClusterAsGroupOptionAttribute](https://cloud.tencent.com/document/api/457/51289)

修改接口：

* [AddExistedInstances](https://cloud.tencent.com/document/api/457/31865)

	* 新增入参：NodePool

* [ModifyClusterNodePool](https://cloud.tencent.com/document/api/457/49431)

	* 新增入参：OsName, OsCustomizeType


新增数据结构：

* [NodePoolOption](https://cloud.tencent.com/document/api/457/31866#NodePoolOption)

### 第 34 次发布

发布时间：2020-12-16 08:07:33

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreatePrometheusTemplate](https://cloud.tencent.com/document/api/457/51024)
* [DeletePrometheusTemplate](https://cloud.tencent.com/document/api/457/51023)
* [DeletePrometheusTemplateSync](https://cloud.tencent.com/document/api/457/51022)
* [DescribePrometheusAgents](https://cloud.tencent.com/document/api/457/51021)
* [DescribePrometheusAlertRule](https://cloud.tencent.com/document/api/457/51020)
* [DescribePrometheusOverviews](https://cloud.tencent.com/document/api/457/51019)
* [DescribePrometheusTargets](https://cloud.tencent.com/document/api/457/51018)
* [DescribePrometheusTemplateSync](https://cloud.tencent.com/document/api/457/51017)
* [DescribePrometheusTemplates](https://cloud.tencent.com/document/api/457/51016)
* [ModifyNodePoolDesiredCapacityAboutAsg](https://cloud.tencent.com/document/api/457/51013)
* [ModifyPrometheusTemplate](https://cloud.tencent.com/document/api/457/51015)
* [SyncPrometheusTemplate](https://cloud.tencent.com/document/api/457/51014)

新增数据结构：

* [PrometheusAgentOverview](https://cloud.tencent.com/document/api/457/31866#PrometheusAgentOverview)
* [PrometheusAlertRule](https://cloud.tencent.com/document/api/457/31866#PrometheusAlertRule)
* [PrometheusAlertRuleDetail](https://cloud.tencent.com/document/api/457/31866#PrometheusAlertRuleDetail)
* [PrometheusConfigItem](https://cloud.tencent.com/document/api/457/31866#PrometheusConfigItem)
* [PrometheusInstanceOverview](https://cloud.tencent.com/document/api/457/31866#PrometheusInstanceOverview)
* [PrometheusJobTargets](https://cloud.tencent.com/document/api/457/31866#PrometheusJobTargets)
* [PrometheusNotification](https://cloud.tencent.com/document/api/457/31866#PrometheusNotification)
* [PrometheusTarget](https://cloud.tencent.com/document/api/457/31866#PrometheusTarget)
* [PrometheusTemplate](https://cloud.tencent.com/document/api/457/31866#PrometheusTemplate)
* [PrometheusTemplateModify](https://cloud.tencent.com/document/api/457/31866#PrometheusTemplateModify)
* [PrometheusTemplateSyncTarget](https://cloud.tencent.com/document/api/457/31866#PrometheusTemplateSyncTarget)

### 第 33 次发布

发布时间：2020-11-27 08:06:41

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CheckInstancesUpgradeAble](https://cloud.tencent.com/document/api/457/50366)
* [UpgradeClusterInstances](https://cloud.tencent.com/document/api/457/50365)

新增数据结构：

* [UpgradeAbleInstancesItem](https://cloud.tencent.com/document/api/457/31866#UpgradeAbleInstancesItem)
* [UpgradeNodeResetParam](https://cloud.tencent.com/document/api/457/31866#UpgradeNodeResetParam)

### 第 32 次发布

发布时间：2020-11-17 08:07:51

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [ClusterAdvancedSettings](https://cloud.tencent.com/document/api/457/31866#ClusterAdvancedSettings)

	* 新增成员：RuntimeVersion


### 第 31 次发布

发布时间：2020-10-28 08:06:19

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeClusterNodePoolDetail](https://cloud.tencent.com/document/api/457/49433)

	* 新增出参：NodePool

* [DescribeClusterNodePools](https://cloud.tencent.com/document/api/457/49432)

	* 新增出参：NodePoolSet, TotalCount


新增数据结构：

* [AutoscalingAdded](https://cloud.tencent.com/document/api/457/31866#AutoscalingAdded)
* [ManuallyAdded](https://cloud.tencent.com/document/api/457/31866#ManuallyAdded)
* [NodeCountSummary](https://cloud.tencent.com/document/api/457/31866#NodeCountSummary)
* [NodePool](https://cloud.tencent.com/document/api/457/31866#NodePool)

### 第 30 次发布

发布时间：2020-10-27 08:07:29

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [AddNodeToNodePool](https://cloud.tencent.com/document/api/457/49437)
* [CreateClusterNodePool](https://cloud.tencent.com/document/api/457/49436)
* [CreateClusterNodePoolFromExistingAsg](https://cloud.tencent.com/document/api/#/#)
* [DeleteClusterNodePool](https://cloud.tencent.com/document/api/457/49434)
* [DescribeClusterNodePoolDetail](https://cloud.tencent.com/document/api/457/49433)
* [DescribeClusterNodePools](https://cloud.tencent.com/document/api/457/49432)
* [ModifyClusterNodePool](https://cloud.tencent.com/document/api/457/49431)
* [RemoveNodeFromNodePool](https://cloud.tencent.com/document/api/457/49430)

新增数据结构：

* [Taint](https://cloud.tencent.com/document/api/457/31866#Taint)

### 第 29 次发布

发布时间：2020-10-26 08:06:11

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [AddExistedInstances](https://cloud.tencent.com/document/api/457/31865)

	* 新增出参：FailedReasons


### 第 28 次发布

发布时间：2020-10-21 08:06:43

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreatePrometheusDashboard](https://cloud.tencent.com/document/api/457/49282)
* [DescribePrometheusAgentInstances](https://cloud.tencent.com/document/api/457/49281)

修改数据结构：

* [ClusterAdvancedSettings](https://cloud.tencent.com/document/api/457/31866#ClusterAdvancedSettings)

	* 新增成员：VpcCniType


### 第 27 次发布

发布时间：2020-10-12 08:06:24

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [AcquireClusterAdminRole](https://cloud.tencent.com/document/api/457/49014)

### 第 26 次发布

发布时间：2020-09-08 08:08:07

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeClusterKubeconfig](https://cloud.tencent.com/document/api/457/48149)

### 第 25 次发布

发布时间：2020-09-01 08:06:22

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateCluster](https://cloud.tencent.com/document/api/457/34527)

	* 新增入参：ExtensionAddons


新增数据结构：

* [ExtensionAddon](https://cloud.tencent.com/document/api/457/31866#ExtensionAddon)

### 第 24 次发布

发布时间：2020-08-19 08:19:45

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [ClusterAdvancedSettings](https://cloud.tencent.com/document/api/457/31866#ClusterAdvancedSettings)

	* 新增成员：AuditEnabled, AuditLogsetId, AuditLogTopicId


### 第 23 次发布

发布时间：2020-08-06 08:19:06

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeClusterRoutes](https://cloud.tencent.com/document/api/457/37181)

	* 新增入参：Filters


### 第 22 次发布

发布时间：2020-06-17 08:17:52

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [ClusterAdvancedSettings](https://cloud.tencent.com/document/api/457/31866#ClusterAdvancedSettings)

	* 新增成员：KubeProxyMode


### 第 21 次发布

发布时间：2020-06-08 08:17:06

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [Cluster](https://cloud.tencent.com/document/api/457/31866#Cluster)

	* 新增成员：DeletionProtection


### 第 20 次发布

发布时间：2020-05-13 08:16:48

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DeleteClusterInstances](https://cloud.tencent.com/document/api/457/31864)

	* 新增出参：SuccInstanceIds, FailedInstanceIds, NotFoundInstanceIds

* [DescribeClusterAsGroups](https://cloud.tencent.com/document/api/457/40471)

	* <font color="#dd0000">**修改出参**：</font>ClusterAsGroupSet

* [DescribeClusterSecurity](https://cloud.tencent.com/document/api/457/36703)

	* 新增出参：JnsGwEndpoint


修改数据结构：

* [ClusterAsGroup](https://cloud.tencent.com/document/api/457/31866#ClusterAsGroup)

	* 新增成员：CreatedTime

* [ClusterAsGroupOption](https://cloud.tencent.com/document/api/457/31866#ClusterAsGroupOption)

	* 新增成员：OkTotalUnreadyCount, MaxTotalUnreadyPercentage, ScaleDownUnreadyTime, UnregisteredNodeRemovalTime

* [ExistedInstance](https://cloud.tencent.com/document/api/457/31866#ExistedInstance)

	* 新增成员：AutoscalingGroupId

	* <font color="#dd0000">**修改成员**：</font>CreatedTime

* [Instance](https://cloud.tencent.com/document/api/457/31866#Instance)

	* 新增成员：NodePoolId, AutoscalingGroupId


### 第 19 次发布

发布时间：2020-05-08 08:17:32

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [ClusterAdvancedSettings](https://cloud.tencent.com/document/api/457/31866#ClusterAdvancedSettings)

	* 新增成员：DeletionProtection


### 第 18 次发布

发布时间：2020-04-29 08:17:45

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DeleteCluster](https://cloud.tencent.com/document/api/457/36704)

	* 新增入参：ResourceDeleteOptions

* [DescribeClusterSecurity](https://cloud.tencent.com/document/api/457/36703)

	* 新增出参：Kubeconfig


新增数据结构：

* [ResourceDeleteOption](https://cloud.tencent.com/document/api/457/31866#ResourceDeleteOption)

### 第 17 次发布

发布时间：2020-04-13 08:15:58

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [Instance](https://cloud.tencent.com/document/api/457/31866#Instance)

	* 新增成员：LanIP


### 第 16 次发布

发布时间：2020-03-27 08:14:10

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeImages](https://cloud.tencent.com/document/api/457/42941)
* [DescribeRegions](https://cloud.tencent.com/document/api/457/42940)
* [ModifyClusterAttribute](https://cloud.tencent.com/document/api/457/42938)

新增数据结构：

* [ImageInstance](https://cloud.tencent.com/document/api/457/31866#ImageInstance)
* [RegionInstance](https://cloud.tencent.com/document/api/457/31866#RegionInstance)

### 第 15 次发布

发布时间：2020-03-10 00:50:32

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [Cluster](https://cloud.tencent.com/document/api/457/31866#Cluster)

	* 新增成员：ClusterMaterNodeNum, ImageId, OsCustomizeType, ContainerRuntime, CreatedTime

* [Instance](https://cloud.tencent.com/document/api/457/31866#Instance)

	* 新增成员：DrainStatus, InstanceAdvancedSettings, CreatedTime


### 第 14 次发布

发布时间：2020-02-27 14:24:28

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [ClusterAdvancedSettings](https://cloud.tencent.com/document/api/457/31866#ClusterAdvancedSettings)

	* 新增成员：NetworkType, IsNonStaticIpMode

* [ClusterCIDRSettings](https://cloud.tencent.com/document/api/457/31866#ClusterCIDRSettings)

	* 新增成员：ServiceCIDR, EniSubnetIds, ClaimExpiredSeconds

	* <font color="#dd0000">**修改成员**：</font>ClusterCIDR


### 第 13 次发布

发布时间：2020-01-09 11:33:18

本次发布包含了以下内容：

改善已有的文档。

新增数据结构：

* [ClusterExtraArgs](https://cloud.tencent.com/document/api/457/31866#ClusterExtraArgs)
* [InstanceExtraArgs](https://cloud.tencent.com/document/api/457/31866#InstanceExtraArgs)

修改数据结构：

* [ClusterAdvancedSettings](https://cloud.tencent.com/document/api/457/31866#ClusterAdvancedSettings)

	* 新增成员：ExtraArgs

* [ExistedInstancesForNode](https://cloud.tencent.com/document/api/457/31866#ExistedInstancesForNode)

	* 新增成员：InstanceAdvancedSettingsOverride

* [InstanceAdvancedSettings](https://cloud.tencent.com/document/api/457/31866#InstanceAdvancedSettings)

	* 新增成员：ExtraArgs

* [RunInstancesForNode](https://cloud.tencent.com/document/api/457/31866#RunInstancesForNode)

	* 新增成员：InstanceAdvancedSettingsOverrides


### 第 12 次发布

发布时间：2019-12-26 15:43:50

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeClusterAsGroupOption](https://cloud.tencent.com/document/api/457/40472)
* [DescribeClusterAsGroups](https://cloud.tencent.com/document/api/457/40471)
* [ModifyClusterAsGroupAttribute](https://cloud.tencent.com/document/api/457/40470)

修改接口：

* [CreateCluster](https://cloud.tencent.com/document/api/457/34527)

	* 新增入参：InstanceDataDiskMountSettings


新增数据结构：

* [AutoScalingGroupRange](https://cloud.tencent.com/document/api/457/31866#AutoScalingGroupRange)
* [ClusterAsGroup](https://cloud.tencent.com/document/api/457/31866#ClusterAsGroup)
* [ClusterAsGroupAttribute](https://cloud.tencent.com/document/api/457/31866#ClusterAsGroupAttribute)
* [ClusterAsGroupOption](https://cloud.tencent.com/document/api/457/31866#ClusterAsGroupOption)
* [InstanceDataDiskMountSetting](https://cloud.tencent.com/document/api/457/31866#InstanceDataDiskMountSetting)

修改数据结构：

* [DataDisk](https://cloud.tencent.com/document/api/457/31866#DataDisk)

	* 新增成员：AutoFormatAndMount

	* <font color="#dd0000">**删除成员**：</font>AutuFormatAndMount, DiskId

	* <font color="#dd0000">**修改成员**：</font>MountTarget


### 第 11 次发布

发布时间：2019-11-28 19:48:22

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [AddExistedInstances](https://cloud.tencent.com/document/api/457/31865)

	* 新增入参：HostName


新增数据结构：

* [DataDisk](https://cloud.tencent.com/document/api/457/31866#DataDisk)

修改数据结构：

* [Cluster](https://cloud.tencent.com/document/api/457/31866#Cluster)

	* 新增成员：Property

* [InstanceAdvancedSettings](https://cloud.tencent.com/document/api/457/31866#InstanceAdvancedSettings)

	* 新增成员：DataDisks


### 第 10 次发布

发布时间：2019-11-21 17:45:03

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateClusterEndpoint](https://cloud.tencent.com/document/api/457/39414)
* [CreateClusterEndpointVip](https://cloud.tencent.com/document/api/457/39413)
* [DeleteClusterEndpoint](https://cloud.tencent.com/document/api/457/39412)
* [DeleteClusterEndpointVip](https://cloud.tencent.com/document/api/457/39411)
* [DescribeClusterEndpointStatus](https://cloud.tencent.com/document/api/457/39410)
* [DescribeClusterEndpointVipStatus](https://cloud.tencent.com/document/api/457/39409)
* [ModifyClusterEndpointSP](https://cloud.tencent.com/document/api/457/39408)

修改数据结构：

* [ClusterAdvancedSettings](https://cloud.tencent.com/document/api/457/31866#ClusterAdvancedSettings)

	* 新增成员：NodeNameType

* [ExistedInstancesPara](https://cloud.tencent.com/document/api/457/31866#ExistedInstancesPara)

	* 新增成员：HostName


### 第 9 次发布

发布时间：2019-10-18 11:14:24

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DeleteClusterInstances](https://cloud.tencent.com/document/api/457/31864)

	* 新增入参：ForceDelete


修改数据结构：

* [Cluster](https://cloud.tencent.com/document/api/457/31866#Cluster)

	* 新增成员：ClusterStatus

* [ClusterBasicSettings](https://cloud.tencent.com/document/api/457/31866#ClusterBasicSettings)

	* 新增成员：NeedWorkSecurityGroup

* [InstanceAdvancedSettings](https://cloud.tencent.com/document/api/457/31866#InstanceAdvancedSettings)

	* 新增成员：Labels


### 第 8 次发布

发布时间：2019-09-12 16:45:51

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DeleteClusterAsGroups](https://cloud.tencent.com/document/api/457/37978)

新增数据结构：

* [Tag](https://cloud.tencent.com/document/api/457/31866#Tag)
* [TagSpecification](https://cloud.tencent.com/document/api/457/31866#TagSpecification)

修改数据结构：

* [Cluster](https://cloud.tencent.com/document/api/457/31866#Cluster)

	* 新增成员：TagSpecification

* [ClusterBasicSettings](https://cloud.tencent.com/document/api/457/31866#ClusterBasicSettings)

	* 新增成员：TagSpecification, OsCustomizeType


### 第 7 次发布

发布时间：2019-08-27 15:24:46

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateClusterAsGroup](https://cloud.tencent.com/document/api/#/#)

新增数据结构：

* [Label](https://cloud.tencent.com/document/api/457/31866#Label)

### 第 6 次发布

发布时间：2019-08-22 19:25:55

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeClusterInstances](https://cloud.tencent.com/document/api/457/31863)

	* 新增入参：InstanceRole


### 第 5 次发布

发布时间：2019-08-15 20:55:54

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateClusterRoute](https://cloud.tencent.com/document/api/457/37186)
* [CreateClusterRouteTable](https://cloud.tencent.com/document/api/457/37185)
* [DeleteClusterRoute](https://cloud.tencent.com/document/api/457/37184)
* [DeleteClusterRouteTable](https://cloud.tencent.com/document/api/457/37183)
* [DescribeClusterRouteTables](https://cloud.tencent.com/document/api/457/37182)
* [DescribeClusterRoutes](https://cloud.tencent.com/document/api/457/37181)
* [DescribeRouteTableConflicts](https://cloud.tencent.com/document/api/457/37180)

修改接口：

* [DescribeExistedInstances](https://cloud.tencent.com/document/api/457/36706)

	* <font color="#dd0000">**修改入参**：</font>Filters


新增数据结构：

* [RouteInfo](https://cloud.tencent.com/document/api/457/31866#RouteInfo)
* [RouteTableConflict](https://cloud.tencent.com/document/api/457/31866#RouteTableConflict)
* [RouteTableInfo](https://cloud.tencent.com/document/api/457/31866#RouteTableInfo)

### 第 4 次发布

发布时间：2019-08-01 15:08:30

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateClusterInstances](https://cloud.tencent.com/document/api/457/36707)
* [DeleteCluster](https://cloud.tencent.com/document/api/457/36704)
* [DescribeClusterSecurity](https://cloud.tencent.com/document/api/457/36703)
* [DescribeExistedInstances](https://cloud.tencent.com/document/api/457/36706)

修改接口：

* [AddExistedInstances](https://cloud.tencent.com/document/api/457/31865)

	* 新增出参：FailedInstanceIds, SuccInstanceIds, TimeoutInstanceIds


新增数据结构：

* [ExistedInstance](https://cloud.tencent.com/document/api/457/31866#ExistedInstance)

修改数据结构：

* [ClusterAdvancedSettings](https://cloud.tencent.com/document/api/457/31866#ClusterAdvancedSettings)

	* 新增成员：ContainerRuntime

* [ClusterNetworkSettings](https://cloud.tencent.com/document/api/457/31866#ClusterNetworkSettings)

	* 新增成员：Cni

* [Instance](https://cloud.tencent.com/document/api/457/31866#Instance)

	* <font color="#dd0000">**删除成员**：</font>InstanceAdvanceSettings


### 第 3 次发布

发布时间：2019-04-28 15:37:22

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateCluster](https://cloud.tencent.com/document/api/457/34527)

修改接口：

* [DescribeClusterInstances](https://cloud.tencent.com/document/api/457/31863)

	* <font color="#dd0000">**修改入参**：</font>InstanceIds


新增数据结构：

* [ClusterAdvancedSettings](https://cloud.tencent.com/document/api/457/31866#ClusterAdvancedSettings)
* [ClusterBasicSettings](https://cloud.tencent.com/document/api/457/31866#ClusterBasicSettings)
* [ClusterCIDRSettings](https://cloud.tencent.com/document/api/457/31866#ClusterCIDRSettings)
* [ExistedInstancesForNode](https://cloud.tencent.com/document/api/457/31866#ExistedInstancesForNode)
* [ExistedInstancesPara](https://cloud.tencent.com/document/api/457/31866#ExistedInstancesPara)
* [RunInstancesForNode](https://cloud.tencent.com/document/api/457/31866#RunInstancesForNode)

修改数据结构：

* [Cluster](https://cloud.tencent.com/document/api/457/31866#Cluster)

	* 新增成员：ProjectId


### 第 2 次发布

发布时间：2019-02-22 15:16:39

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeClusters](https://cloud.tencent.com/document/api/457/31862)

	* 新增入参：Filters


新增数据结构：

* [Filter](https://cloud.tencent.com/document/api/457/31866#Filter)

修改数据结构：

* [Cluster](https://cloud.tencent.com/document/api/457/31866#Cluster)

	* 新增成员：ClusterNodeNum

	* <font color="#dd0000">**修改成员**：</font>ClusterDescription

* [ClusterNetworkSettings](https://cloud.tencent.com/document/api/457/31866#ClusterNetworkSettings)

	* 新增成员：Ipvs

	* <font color="#dd0000">**删除成员**：</font>IPVS


### 第 1 次发布

发布时间：2018-12-24 17:32:12

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [AddExistedInstances](https://cloud.tencent.com/document/api/457/31865)
* [DeleteClusterInstances](https://cloud.tencent.com/document/api/457/31864)
* [DescribeClusterInstances](https://cloud.tencent.com/document/api/457/31863)
* [DescribeClusters](https://cloud.tencent.com/document/api/457/31862)

新增数据结构：

* [Cluster](https://cloud.tencent.com/document/api/457/31866#Cluster)
* [ClusterNetworkSettings](https://cloud.tencent.com/document/api/457/31866#ClusterNetworkSettings)
* [EnhancedService](https://cloud.tencent.com/document/api/457/31866#EnhancedService)
* [Instance](https://cloud.tencent.com/document/api/457/31866#Instance)
* [InstanceAdvancedSettings](https://cloud.tencent.com/document/api/457/31866#InstanceAdvancedSettings)
* [LoginSettings](https://cloud.tencent.com/document/api/457/31866#LoginSettings)
* [RunMonitorServiceEnabled](https://cloud.tencent.com/document/api/457/31866#RunMonitorServiceEnabled)
* [RunSecurityServiceEnabled](https://cloud.tencent.com/document/api/457/31866#RunSecurityServiceEnabled)



## 容器服务(tke) 版本：2022-05-01

### 第 3 次发布

发布时间：2024-07-24 02:19:34

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [NativeNodePoolInfo](https://cloud.tencent.com/document/api/457/103206#NativeNodePoolInfo)

	* 新增成员：ReadyReplicas


### 第 2 次发布

发布时间：2024-05-13 01:30:09

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateNodePool](https://cloud.tencent.com/document/api/457/106086)
* [DeleteNodePool](https://cloud.tencent.com/document/api/457/106085)
* [ModifyNodePool](https://cloud.tencent.com/document/api/457/106084)

新增数据结构：

* [AutoUpgradeOptions](https://cloud.tencent.com/document/api/457/103206#AutoUpgradeOptions)
* [CreateNativeNodePoolParam](https://cloud.tencent.com/document/api/457/103206#CreateNativeNodePoolParam)
* [DataDisk](https://cloud.tencent.com/document/api/457/103206#DataDisk)
* [Disk](https://cloud.tencent.com/document/api/457/103206#Disk)
* [InstanceChargePrepaid](https://cloud.tencent.com/document/api/457/103206#InstanceChargePrepaid)
* [IntOrString](https://cloud.tencent.com/document/api/457/103206#IntOrString)
* [LifecycleConfig](https://cloud.tencent.com/document/api/457/103206#LifecycleConfig)
* [MachineSetScaling](https://cloud.tencent.com/document/api/457/103206#MachineSetScaling)
* [MachineUpgradeSettings](https://cloud.tencent.com/document/api/457/103206#MachineUpgradeSettings)
* [ManagementConfig](https://cloud.tencent.com/document/api/457/103206#ManagementConfig)
* [Tag](https://cloud.tencent.com/document/api/457/103206#Tag)
* [TagSpecification](https://cloud.tencent.com/document/api/457/103206#TagSpecification)
* [UpdateNativeNodePoolParam](https://cloud.tencent.com/document/api/457/103206#UpdateNativeNodePoolParam)

修改数据结构：

* [NativeNodePoolInfo](https://cloud.tencent.com/document/api/457/103206#NativeNodePoolInfo)

	* 新增成员：Scaling, UpgradeSettings, AutoRepair, InstanceChargeType, InstanceChargePrepaid, SystemDisk, KeyIds, Management, HealthCheckPolicyName, HostNamePattern, KubeletArgs, Lifecycle, RuntimeRootDir, EnableAutoscaling, InstanceTypes, Replicas, InternetAccessible, DataDisks

* [NodePool](https://cloud.tencent.com/document/api/457/103206#NodePool)

	* 新增成员：Tags, Unschedulable


### 第 1 次发布

发布时间：2024-01-22 11:36:09

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeClusterInstances](https://cloud.tencent.com/document/api/457/103203)
* [DescribeNodePools](https://cloud.tencent.com/document/api/457/103205)

新增数据结构：

* [Annotation](https://cloud.tencent.com/document/api/457/103206#Annotation)
* [AutoscalingAdded](https://cloud.tencent.com/document/api/457/103206#AutoscalingAdded)
* [ExternalNodeInfo](https://cloud.tencent.com/document/api/457/103206#ExternalNodeInfo)
* [ExternalNodePoolInfo](https://cloud.tencent.com/document/api/457/103206#ExternalNodePoolInfo)
* [Filter](https://cloud.tencent.com/document/api/457/103206#Filter)
* [Instance](https://cloud.tencent.com/document/api/457/103206#Instance)
* [InstanceAdvancedSettings](https://cloud.tencent.com/document/api/457/103206#InstanceAdvancedSettings)
* [InstanceExtraArgs](https://cloud.tencent.com/document/api/457/103206#InstanceExtraArgs)
* [InternetAccessible](https://cloud.tencent.com/document/api/457/103206#InternetAccessible)
* [Label](https://cloud.tencent.com/document/api/457/103206#Label)
* [ManuallyAdded](https://cloud.tencent.com/document/api/457/103206#ManuallyAdded)
* [NativeNodeInfo](https://cloud.tencent.com/document/api/457/103206#NativeNodeInfo)
* [NativeNodePoolInfo](https://cloud.tencent.com/document/api/457/103206#NativeNodePoolInfo)
* [NodeCountSummary](https://cloud.tencent.com/document/api/457/103206#NodeCountSummary)
* [NodePool](https://cloud.tencent.com/document/api/457/103206#NodePool)
* [RegularNodeInfo](https://cloud.tencent.com/document/api/457/103206#RegularNodeInfo)
* [RegularNodePoolInfo](https://cloud.tencent.com/document/api/457/103206#RegularNodePoolInfo)
* [RuntimeConfig](https://cloud.tencent.com/document/api/457/103206#RuntimeConfig)
* [SortBy](https://cloud.tencent.com/document/api/457/103206#SortBy)
* [SuperNodeInfo](https://cloud.tencent.com/document/api/457/103206#SuperNodeInfo)
* [SuperNodePoolInfo](https://cloud.tencent.com/document/api/457/103206#SuperNodePoolInfo)
* [Taint](https://cloud.tencent.com/document/api/457/103206#Taint)




## (tkgdq) 版本：2019-04-11

### 第 1 次发布

发布时间：2019-08-05 15:10:15

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeEntity](https://cloud.tencent.com/document/api/1072/36799)
* [DescribeRelation](https://cloud.tencent.com/document/api/1072/36798)
* [DescribeTriple](https://cloud.tencent.com/document/api/1072/36797)

新增数据结构：

* [EntityRelationContent](https://cloud.tencent.com/document/api/1072/36800#EntityRelationContent)
* [EntityRelationObject](https://cloud.tencent.com/document/api/1072/36800#EntityRelationObject)
* [EntityRelationSubject](https://cloud.tencent.com/document/api/1072/36800#EntityRelationSubject)
* [TripleContent](https://cloud.tencent.com/document/api/1072/36800#TripleContent)




## 文本内容安全(tms) 版本：2020-07-13

### 第 4 次发布

发布时间：2020-12-18 15:20:34

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [TextModeration](https://cloud.tencent.com/document/api/1124/46976)

	* 新增出参：DataId


### 第 3 次发布

发布时间：2020-12-16 08:00:58

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeTextLib](https://cloud.tencent.com/document/api/1124/51004)
* [DescribeTextStat](https://cloud.tencent.com/document/api/1124/51003)

新增数据结构：

* [EvilCount](https://cloud.tencent.com/document/api/1124/46977#EvilCount)
* [Filters](https://cloud.tencent.com/document/api/1124/46977#Filters)
* [Overview](https://cloud.tencent.com/document/api/1124/46977#Overview)
* [TextLib](https://cloud.tencent.com/document/api/1124/46977#TextLib)
* [TrendCount](https://cloud.tencent.com/document/api/1124/46977#TrendCount)

### 第 2 次发布

发布时间：2020-08-21 08:00:22

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [AccountTipoffAccess](https://cloud.tencent.com/document/api/1124/47690)

新增数据结构：

* [TipoffResponse](https://cloud.tencent.com/document/api/1124/46977#TipoffResponse)

### 第 1 次发布

发布时间：2020-07-29 11:02:07

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [TextModeration](https://cloud.tencent.com/document/api/1124/46976)

新增数据结构：

* [DetailResults](https://cloud.tencent.com/document/api/1124/46977#DetailResults)
* [Device](https://cloud.tencent.com/document/api/1124/46977#Device)
* [RiskDetails](https://cloud.tencent.com/document/api/1124/46977#RiskDetails)
* [User](https://cloud.tencent.com/document/api/1124/46977#User)



## 文本内容安全(tms) 版本：2020-12-29

### 第 10 次发布

发布时间：2024-04-29 01:26:41

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [AnswerQuestion](https://cloud.tencent.com/document/api/1124/105753)

### 第 9 次发布

发布时间：2023-12-29 16:06:34

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [ModerateText](https://cloud.tencent.com/document/api/1124/102791)

新增数据结构：

* [LabelGrade](https://cloud.tencent.com/document/api/1124/51861#LabelGrade)
* [LibCheckResult](https://cloud.tencent.com/document/api/1124/51861#LibCheckResult)
* [ModelResult](https://cloud.tencent.com/document/api/1124/51861#ModelResult)
* [ModerationDetail](https://cloud.tencent.com/document/api/1124/51861#ModerationDetail)

### 第 8 次发布

发布时间：2023-11-28 01:28:13

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [TextModeration](https://cloud.tencent.com/document/api/1124/51860)

	* 新增出参：SentimentAnalysis


新增数据结构：

* [SentimentAnalysis](https://cloud.tencent.com/document/api/1124/51861#SentimentAnalysis)
* [SentimentDetail](https://cloud.tencent.com/document/api/1124/51861#SentimentDetail)

### 第 7 次发布

发布时间：2023-10-25 01:27:42

本次发布包含了以下内容：

改善已有的文档。

新增数据结构：

* [HitInfo](https://cloud.tencent.com/document/api/1124/51861#HitInfo)
* [Positions](https://cloud.tencent.com/document/api/1124/51861#Positions)

修改数据结构：

* [DetailResults](https://cloud.tencent.com/document/api/1124/51861#DetailResults)

	* 新增成员：HitInfos


### 第 6 次发布

发布时间：2022-11-18 06:55:59

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [User](https://cloud.tencent.com/document/api/1124/51861#User)

	* 新增成员：RoomId, ReceiverId, SendTime


### 第 5 次发布

发布时间：2022-11-16 06:44:41

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [TextModeration](https://cloud.tencent.com/document/api/1124/51860)

	* 新增出参：ContextText


### 第 4 次发布

发布时间：2022-11-15 06:45:50

本次发布包含了以下内容：

改善已有的文档。

新增数据结构：

* [Tag](https://cloud.tencent.com/document/api/1124/51861#Tag)

修改数据结构：

* [DetailResults](https://cloud.tencent.com/document/api/1124/51861#DetailResults)

	* 新增成员：Tags


### 第 3 次发布

发布时间：2021-12-20 08:14:04

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [TextModeration](https://cloud.tencent.com/document/api/1124/51860)

	* 新增出参：SubLabel


修改数据结构：

* [DetailResults](https://cloud.tencent.com/document/api/1124/51861#DetailResults)

	* 新增成员：SubLabel


### 第 2 次发布

发布时间：2021-08-03 08:01:39

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [User](https://cloud.tencent.com/document/api/1124/51861#User)

	* 新增成员：HeadUrl, Desc


### 第 1 次发布

发布时间：2021-01-12 08:00:29

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [TextModeration](https://cloud.tencent.com/document/api/1124/51860)

新增数据结构：

* [DetailResults](https://cloud.tencent.com/document/api/1124/51861#DetailResults)
* [Device](https://cloud.tencent.com/document/api/1124/51861#Device)
* [RiskDetails](https://cloud.tencent.com/document/api/1124/51861#RiskDetails)
* [User](https://cloud.tencent.com/document/api/1124/51861#User)




## 机器翻译(tmt) 版本：2018-03-21

### 第 10 次发布

发布时间：2024-07-04 01:25:30

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [TextTranslate](https://cloud.tencent.com/document/api/551/15619)

	* 新增入参：TermRepoIDList, SentRepoIDList

* [TextTranslateBatch](https://cloud.tencent.com/document/api/551/40566)

	* 新增入参：TermRepoIDList, SentRepoIDList


### 第 9 次发布

发布时间：2024-05-21 02:20:14

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [SpeechTranslate](https://cloud.tencent.com/document/api/551/16611)


### 第 8 次发布

发布时间：2022-08-31 06:55:53

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [GetFileTranslateData](https://cloud.tencent.com/document/api/551/17233#GetFileTranslateData)

	* 新增成员：Progress


### 第 7 次发布

发布时间：2022-05-18 06:19:05

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [FileTranslate](https://cloud.tencent.com/document/api/551/73920)
* [GetFileTranslate](https://cloud.tencent.com/document/api/551/73919)

新增数据结构：

* [GetFileTranslateData](https://cloud.tencent.com/document/api/551/17233#GetFileTranslateData)
* [Task](https://cloud.tencent.com/document/api/551/17233#Task)

### 第 6 次发布

发布时间：2020-07-21 08:18:31

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [SpeechTranslate](https://cloud.tencent.com/document/api/551/16611)

	* 新增入参：TransType


### 第 5 次发布

发布时间：2019-12-30 16:14:13

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [TextTranslateBatch](https://cloud.tencent.com/document/api/551/40566)

### 第 4 次发布

发布时间：2019-10-17 17:13:05

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [TextTranslate](https://cloud.tencent.com/document/api/551/15619)

	* 新增入参：UntranslatedText


### 第 3 次发布

发布时间：2019-03-14 16:08:56

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [SpeechTranslate](https://cloud.tencent.com/document/api/551/16611)

	* 新增入参：Mode

	* 新增出参：VadSeq


### 第 2 次发布

发布时间：2018-05-17 16:52:41

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [ImageTranslate](https://cloud.tencent.com/document/api/551/17232)

修改接口：

* [SpeechTranslate](https://cloud.tencent.com/document/api/551/16611)

	* 新增入参：ProjectId

	* 新增出参：SessionUuid, RecognizeStatus, SourceText, TargetText, Seq, Source, Target


新增数据结构：

* [ImageRecord](https://cloud.tencent.com/document/api/551/17233#ImageRecord)
* [ItemValue](https://cloud.tencent.com/document/api/551/17233#ItemValue)

### 第 1 次发布

发布时间：2018-04-24

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [LanguageDetect](https://cloud.tencent.com/document/api/551/15620)
* [SpeechTranslate](https://cloud.tencent.com/document/api/551/16611)
* [TextTranslate](https://cloud.tencent.com/document/api/551/15619)




## 文旅客情大数据(tourism) 版本：2023-02-15

### 第 1 次发布

发布时间：2023-04-07 10:20:53

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeDrawResourceList](https://cloud.tencent.com/document/api/1684/89961)

新增数据结构：

* [ResourceDrawListType](https://cloud.tencent.com/document/api/1684/89962#ResourceDrawListType)




## 流量风险决策平台(trdp) 版本：2022-07-26

### 第 1 次发布

发布时间：2022-12-05 10:34:47

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [EvaluateUserRisk](https://cloud.tencent.com/document/api/1604/83624)

新增数据结构：

* [AccountInfo](https://cloud.tencent.com/document/api/1604/83625#AccountInfo)
* [DeviceDetailInfo](https://cloud.tencent.com/document/api/1604/83625#DeviceDetailInfo)
* [DeviceFingerprintInfo](https://cloud.tencent.com/document/api/1604/83625#DeviceFingerprintInfo)
* [EvaluationResult](https://cloud.tencent.com/document/api/1604/83625#EvaluationResult)
* [MarketingInfo](https://cloud.tencent.com/document/api/1604/83625#MarketingInfo)
* [UniversalAccountInfo](https://cloud.tencent.com/document/api/1604/83625#UniversalAccountInfo)
* [UserInfo](https://cloud.tencent.com/document/api/1604/83625#UserInfo)




## 消息队列 RocketMQ 版(trocket) 版本：2023-03-08

### 第 17 次发布

发布时间：2024-07-05 01:19:38

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeInstanceList](https://cloud.tencent.com/document/api/1493/96028)

	* <font color="#dd0000">**修改入参**：</font>Offset, Limit


修改数据结构：

* [InstanceItem](https://cloud.tencent.com/document/api/1493/96031#InstanceItem)

	* 新增成员：RenewFlag

	* <font color="#dd0000">**修改成员**：</font>InstanceId, InstanceName, Version, InstanceType, InstanceStatus, TopicNumLimit, GroupNumLimit, PayMode, ExpiryTime, Remark, TopicNum, GroupNum, TagList, SkuCode, TpsLimit, ScaledTpsLimit, MessageRetention, MaxMessageDelay


### 第 16 次发布

发布时间：2024-06-25 01:24:46

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeProductSKUs](https://cloud.tencent.com/document/api/1493/107676)

新增数据结构：

* [PriceTag](https://cloud.tencent.com/document/api/1493/96031#PriceTag)
* [ProductSKU](https://cloud.tencent.com/document/api/1493/96031#ProductSKU)

### 第 15 次发布

发布时间：2024-06-03 02:23:52

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeFusionInstanceList](https://cloud.tencent.com/document/api/1493/106745)

新增数据结构：

* [FusionInstanceItem](https://cloud.tencent.com/document/api/1493/96031#FusionInstanceItem)
* [InstanceItemExtraInfo](https://cloud.tencent.com/document/api/1493/96031#InstanceItemExtraInfo)

### 第 14 次发布

发布时间：2024-04-22 01:28:17

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeMQTTClient](https://cloud.tencent.com/document/api/1493/103135)

	* 新增出参：Inbound, OutBound, CleanSession

* [DescribeMQTTInsPublicEndpoints](https://cloud.tencent.com/document/api/1493/103134)

	* 新增出参：Status


新增数据结构：

* [PacketStatistics](https://cloud.tencent.com/document/api/1493/96031#PacketStatistics)
* [StatisticsReport](https://cloud.tencent.com/document/api/1493/96031#StatisticsReport)

修改数据结构：

* [MQTTEndpointItem](https://cloud.tencent.com/document/api/1493/96031#MQTTEndpointItem)

	* 新增成员：Ip


### 第 13 次发布

发布时间：2024-04-18 01:31:47

本次发布包含了以下内容：

改善已有的文档。

<font color="#dd0000">**删除接口**：</font>

* DescribeTopicStatsOp

### 第 12 次发布

发布时间：2024-04-04 01:25:24

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [ModifyTopic](https://cloud.tencent.com/document/api/1493/97944)

	* 新增入参：MsgTTL


### 第 11 次发布

发布时间：2024-03-07 01:26:39

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateInstance](https://cloud.tencent.com/document/api/1493/97868)

	* 新增入参：PayMode, RenewFlag, TimeSpan, MaxTopicNum

* [CreateTopic](https://cloud.tencent.com/document/api/1493/97947)

	* 新增入参：MsgTTL

* [DescribeTopic](https://cloud.tencent.com/document/api/1493/97945)

	* <font color="#dd0000">**修改入参**：</font>Offset, Limit

	* 新增出参：MsgTTL

* [DescribeTopicList](https://cloud.tencent.com/document/api/1493/96030)

	* <font color="#dd0000">**修改入参**：</font>Offset, Limit

* [ModifyInstance](https://cloud.tencent.com/document/api/1493/97865)

	* 新增入参：MaxTopicNum


修改数据结构：

* [SubscriptionData](https://cloud.tencent.com/document/api/1493/96031#SubscriptionData)

	* 新增成员：MessageModel

	* <font color="#dd0000">**修改成员**：</font>InstanceId, Topic, TopicType, TopicQueueNum, ConsumerGroup, IsOnline, ConsumeType, SubString, ExpressionType, Consistency, ConsumerLag, LastUpdateTime, MaxRetryTimes, ConsumeMessageOrderly

* [TopicItem](https://cloud.tencent.com/document/api/1493/96031#TopicItem)

	* 新增成员：ClusterIdV4, NamespaceV4, TopicV4, FullNamespaceV4, MsgTTL


### 第 10 次发布

发布时间：2024-03-06 01:26:32

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeInstance](https://cloud.tencent.com/document/api/1493/97866)

	* 新增出参：ScaledTpsEnabled, RenewFlag, ExpiryTime, RoleNumLimit, AclEnabled, TopicNumLowerLimit, TopicNumUpperLimit


修改数据结构：

* [Endpoint](https://cloud.tencent.com/document/api/1493/96031#Endpoint)

	* <font color="#dd0000">**修改成员**：</font>Type, Status, PayMode, EndpointUrl, VpcId, SubnetId, Bandwidth, IpRules


### 第 9 次发布

发布时间：2024-01-23 01:30:19

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateMQTTInsPublicEndpoint](https://cloud.tencent.com/document/api/1493/103140)

	* <font color="#dd0000">**修改入参**：</font>Rules


### 第 8 次发布

发布时间：2024-01-22 01:23:11

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateMQTTInsPublicEndpoint](https://cloud.tencent.com/document/api/1493/103140)
* [CreateMQTTTopic](https://cloud.tencent.com/document/api/1493/103139)
* [CreateMQTTUser](https://cloud.tencent.com/document/api/1493/103121)
* [DeleteMQTTInsPublicEndpoint](https://cloud.tencent.com/document/api/1493/103138)
* [DeleteMQTTInstance](https://cloud.tencent.com/document/api/1493/103137)
* [DeleteMQTTTopic](https://cloud.tencent.com/document/api/1493/103136)
* [DeleteMQTTUser](https://cloud.tencent.com/document/api/1493/103120)
* [DescribeMQTTClient](https://cloud.tencent.com/document/api/1493/103135)
* [DescribeMQTTInsPublicEndpoints](https://cloud.tencent.com/document/api/1493/103134)
* [DescribeMQTTInsVPCEndpoints](https://cloud.tencent.com/document/api/1493/103133)
* [DescribeMQTTInstance](https://cloud.tencent.com/document/api/1493/103132)
* [DescribeMQTTInstanceCert](https://cloud.tencent.com/document/api/1493/103131)
* [DescribeMQTTMessage](https://cloud.tencent.com/document/api/1493/103123)
* [DescribeMQTTMessageList](https://cloud.tencent.com/document/api/1493/103130)
* [DescribeMQTTTopic](https://cloud.tencent.com/document/api/1493/103129)
* [DescribeMQTTTopicList](https://cloud.tencent.com/document/api/1493/103128)
* [DescribeMQTTUserList](https://cloud.tencent.com/document/api/1493/103119)
* [ModifyMQTTInsPublicEndpoint](https://cloud.tencent.com/document/api/1493/103127)
* [ModifyMQTTInstance](https://cloud.tencent.com/document/api/1493/103126)
* [ModifyMQTTInstanceCertBinding](https://cloud.tencent.com/document/api/1493/103125)
* [ModifyMQTTTopic](https://cloud.tencent.com/document/api/1493/103124)
* [ModifyMQTTUser](https://cloud.tencent.com/document/api/1493/103118)

新增数据结构：

* [CustomMapEntry](https://cloud.tencent.com/document/api/1493/96031#CustomMapEntry)
* [MQTTClientSubscription](https://cloud.tencent.com/document/api/1493/96031#MQTTClientSubscription)
* [MQTTEndpointItem](https://cloud.tencent.com/document/api/1493/96031#MQTTEndpointItem)
* [MQTTMessageItem](https://cloud.tencent.com/document/api/1493/96031#MQTTMessageItem)
* [MQTTTopicItem](https://cloud.tencent.com/document/api/1493/96031#MQTTTopicItem)
* [MQTTUserItem](https://cloud.tencent.com/document/api/1493/96031#MQTTUserItem)
* [PublicAccessRule](https://cloud.tencent.com/document/api/1493/96031#PublicAccessRule)

### 第 7 次发布

发布时间：2024-01-19 01:23:15

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateMQTTInstance](https://cloud.tencent.com/document/api/1493/103099)
* [DescribeMQTTInstanceList](https://cloud.tencent.com/document/api/1493/103098)
* [DescribeMQTTProductSKUList](https://cloud.tencent.com/document/api/1493/103096)

新增数据结构：

* [MQTTInstanceItem](https://cloud.tencent.com/document/api/1493/96031#MQTTInstanceItem)
* [MQTTProductSkuItem](https://cloud.tencent.com/document/api/1493/96031#MQTTProductSkuItem)

### 第 6 次发布

发布时间：2023-11-21 01:38:03

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [ImportSourceClusterConsumerGroups](https://cloud.tencent.com/document/api/1493/101770)
* [ImportSourceClusterTopics](https://cloud.tencent.com/document/api/1493/101769)

新增数据结构：

* [SourceClusterGroupConfig](https://cloud.tencent.com/document/api/1493/96031#SourceClusterGroupConfig)
* [SourceClusterTopicConfig](https://cloud.tencent.com/document/api/1493/96031#SourceClusterTopicConfig)

### 第 5 次发布

发布时间：2023-11-13 00:24:24

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeConsumerGroupList](https://cloud.tencent.com/document/api/1493/101535)

新增数据结构：

* [ConsumeGroupItem](https://cloud.tencent.com/document/api/1493/96031#ConsumeGroupItem)

### 第 4 次发布

发布时间：2023-09-26 01:33:40

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateRole](https://cloud.tencent.com/document/api/1493/98864)
* [DeleteRole](https://cloud.tencent.com/document/api/1493/98863)
* [DescribeRoleList](https://cloud.tencent.com/document/api/1493/98862)
* [ModifyRole](https://cloud.tencent.com/document/api/1493/98861)

新增数据结构：

* [RoleItem](https://cloud.tencent.com/document/api/1493/96031#RoleItem)

### 第 3 次发布

发布时间：2023-09-12 02:49:45

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateConsumerGroup](https://cloud.tencent.com/document/api/1493/97943)
* [CreateTopic](https://cloud.tencent.com/document/api/1493/97947)
* [DeleteConsumerGroup](https://cloud.tencent.com/document/api/1493/97942)
* [DeleteTopic](https://cloud.tencent.com/document/api/1493/97946)
* [DescribeConsumerGroup](https://cloud.tencent.com/document/api/1493/97941)
* [DescribeTopic](https://cloud.tencent.com/document/api/1493/97945)
* [DescribeTopicStatsOp](https://cloud.tencent.com/document/api/#/#)
* [ModifyConsumerGroup](https://cloud.tencent.com/document/api/1493/97940)
* [ModifyTopic](https://cloud.tencent.com/document/api/1493/97944)

新增数据结构：

* [SubscriptionData](https://cloud.tencent.com/document/api/1493/96031#SubscriptionData)

### 第 2 次发布

发布时间：2023-09-08 02:48:21

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateInstance](https://cloud.tencent.com/document/api/1493/97868)
* [DeleteInstance](https://cloud.tencent.com/document/api/1493/97867)
* [DescribeInstance](https://cloud.tencent.com/document/api/1493/97866)
* [ModifyInstance](https://cloud.tencent.com/document/api/1493/97865)

新增数据结构：

* [Endpoint](https://cloud.tencent.com/document/api/1493/96031#Endpoint)
* [IpRule](https://cloud.tencent.com/document/api/1493/96031#IpRule)
* [VpcInfo](https://cloud.tencent.com/document/api/1493/96031#VpcInfo)

### 第 1 次发布

发布时间：2023-08-07 10:45:38

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeInstanceList](https://cloud.tencent.com/document/api/1493/96028)
* [DescribeTopicList](https://cloud.tencent.com/document/api/1493/96030)

新增数据结构：

* [Filter](https://cloud.tencent.com/document/api/1493/96031#Filter)
* [InstanceItem](https://cloud.tencent.com/document/api/1493/96031#InstanceItem)
* [Tag](https://cloud.tencent.com/document/api/1493/96031#Tag)
* [TagFilter](https://cloud.tencent.com/document/api/1493/96031#TagFilter)
* [TopicItem](https://cloud.tencent.com/document/api/1493/96031#TopicItem)




## T-Sec-安心平台(RP)(trp) 版本：2021-05-15

### 第 35 次发布

发布时间：2024-06-06 02:42:14

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateChainBatch](https://cloud.tencent.com/document/api/1458/106917)

新增数据结构：

* [Chain](https://cloud.tencent.com/document/api/1458/75030#Chain)
* [ChainValue](https://cloud.tencent.com/document/api/1458/75030#ChainValue)

### 第 34 次发布

发布时间：2024-05-30 02:20:31

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateCodePack](https://cloud.tencent.com/document/api/1458/75028)

	* 新增入参：SceneCode

* [CreateCustomPack](https://cloud.tencent.com/document/api/1458/81464)

	* 新增入参：SceneCode

* [DescribeCodePacks](https://cloud.tencent.com/document/api/1458/75016)

	* 新增入参：SceneCode, Status


修改数据结构：

* [CodePack](https://cloud.tencent.com/document/api/1458/75030#CodePack)

	* 新增成员：SceneCode, CodeRule, UsedAmount, SerialStart, SerialEnd

* [Job](https://cloud.tencent.com/document/api/1458/75030#Job)

	* 新增成员：ErrorMessage

* [PackSpec](https://cloud.tencent.com/document/api/1458/75030#PackSpec)

	* 新增成员：Unit, SceneCode

* [ScanLog](https://cloud.tencent.com/document/api/1458/75030#ScanLog)

	* 新增成员：ProductLogo, Status, Verify

	* <font color="#dd0000">**修改成员**：</font>Unionid, First, BatchId, Type, MerchantName, ProductName

* [TraceCode](https://cloud.tencent.com/document/api/1458/75030#TraceCode)

	* 新增成员：PackSpec, SceneCode, SerialCode

	* <font color="#dd0000">**修改成员**：</font>AgentId, Level


### 第 33 次发布

发布时间：2024-03-15 01:24:38

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [Quota](https://cloud.tencent.com/document/api/1458/75030#Quota)

	* 新增成员：AigcTextQuota, AigcImageQuota


### 第 32 次发布

发布时间：2024-03-04 01:26:24

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeCodeBatches](https://cloud.tencent.com/document/api/1458/101819)

	* 新增入参：Status

* [DescribeCodeBatchs](https://cloud.tencent.com/document/api/1458/75017)

	* 新增入参：Status


### 第 31 次发布

发布时间：2023-12-29 01:27:21

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeProducts](https://cloud.tencent.com/document/api/1458/75011)

	* 新增入参：CertState


修改数据结构：

* [Ext](https://cloud.tencent.com/document/api/1458/75030#Ext)

	* <font color="#dd0000">**修改成员**：</font>Value

* [Product](https://cloud.tencent.com/document/api/1458/75030#Product)

	* 新增成员：CertState

* [Quota](https://cloud.tencent.com/document/api/1458/75030#Quota)

	* 新增成员：ProductCertify


### 第 30 次发布

发布时间：2023-12-21 10:26:13

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribePlanQRCodeScanRecords](https://cloud.tencent.com/document/api/1458/102574)

新增数据结构：

* [PlanQRCodeRecord](https://cloud.tencent.com/document/api/1458/75030#PlanQRCodeRecord)

修改数据结构：

* [CodeBatch](https://cloud.tencent.com/document/api/1458/75030#CodeBatch)

	* <font color="#dd0000">**修改成员**：</font>TplName, Job, ProductionDate, ValidDate, Attrs

* [Ext](https://cloud.tencent.com/document/api/1458/75030#Ext)

	* 新增成员：Value


### 第 29 次发布

发布时间：2023-10-26 14:46:10

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribePlanQRCodes](https://cloud.tencent.com/document/api/1458/100783)

新增数据结构：

* [PlanQRCode](https://cloud.tencent.com/document/api/1458/75030#PlanQRCode)

### 第 28 次发布

发布时间：2023-10-09 11:35:49

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeCodeBatches](https://cloud.tencent.com/document/api/1458/101819)

### 第 27 次发布

发布时间：2023-09-21 06:25:32

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateCodePack](https://cloud.tencent.com/document/api/1458/75028)

	* 新增入参：ProductId, RelateType

* [CreateCustomPack](https://cloud.tencent.com/document/api/1458/81464)

	* 新增入参：ProductId, RelateType


修改数据结构：

* [CodePack](https://cloud.tencent.com/document/api/1458/75030#CodePack)

	* 新增成员：ProductName, ProductSpecification, ProductId, RelateType


### 第 26 次发布

发布时间：2023-08-15 01:44:16

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeCodePacks](https://cloud.tencent.com/document/api/1458/75016)

	* 新增入参：ResType, ResId


### 第 25 次发布

发布时间：2023-07-10 01:51:20

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeRawScanLogs](https://cloud.tencent.com/document/api/1458/94488)

	* 新增入参：StartTime, EndTime


### 第 24 次发布

发布时间：2023-07-05 01:50:44

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeRawScanLogs](https://cloud.tencent.com/document/api/1458/94488)

新增数据结构：

* [RawScanLog](https://cloud.tencent.com/document/api/1458/75030#RawScanLog)

### 第 23 次发布

发布时间：2023-06-29 01:45:43

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeAgentCorps](https://cloud.tencent.com/document/api/1458/94378)

### 第 22 次发布

发布时间：2023-06-26 02:00:13

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateCodeBatch](https://cloud.tencent.com/document/api/1458/75029)

	* 新增入参：ValidDate, ProductionDate

* [DescribeScanLogs](https://cloud.tencent.com/document/api/1458/85943)

	* 新增入参：PageSize, PageNumber, Openid

	* <font color="#dd0000">**修改入参**：</font>Code

* [DescribeTraceCodeById](https://cloud.tencent.com/document/api/1458/75010)

	* 新增出参：CodePath

* [ModifyCodeBatch](https://cloud.tencent.com/document/api/1458/75007)

	* 新增入参：ValidDate, ProductionDate


新增数据结构：

* [AttrItem](https://cloud.tencent.com/document/api/1458/75030#AttrItem)

修改数据结构：

* [CodeBatch](https://cloud.tencent.com/document/api/1458/75030#CodeBatch)

	* 新增成员：ProductionDate, ValidDate, Attrs

* [Product](https://cloud.tencent.com/document/api/1458/75030#Product)

	* <font color="#dd0000">**修改成员**：</font>ProductId, CorpId, ProductCode, Specification, Remark, Logo, CreateTime, UpdateTime, Ext, MerchantName

* [ScanLog](https://cloud.tencent.com/document/api/1458/75030#ScanLog)

	* 新增成员：Type, MerchantName, ProductName

* [TraceData](https://cloud.tencent.com/document/api/1458/75030#TraceData)

	* <font color="#dd0000">**修改成员**：</font>TraceItems

* [TraceItem](https://cloud.tencent.com/document/api/1458/75030#TraceItem)

	* <font color="#dd0000">**修改成员**：</font>ReadOnly, Hidden, Key, Ext


### 第 21 次发布

发布时间：2023-04-24 01:46:22

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateTraceCodes](https://cloud.tencent.com/document/api/1458/75024)

	* 新增入参：CodeType, CheckType


修改数据结构：

* [ChainData](https://cloud.tencent.com/document/api/1458/75030#ChainData)

	* <font color="#dd0000">**修改成员**：</font>BlockHash, BlockHeight, BlockTime

* [TraceItem](https://cloud.tencent.com/document/api/1458/75030#TraceItem)

	* 新增成员：Attrs, List


### 第 20 次发布

发布时间：2023-04-18 01:48:00

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [AuthorizedTransfer](https://cloud.tencent.com/document/api/1458/90248)
* [EffectFeedback](https://cloud.tencent.com/document/api/1458/90247)
* [ReportBatchCallbackStatus](https://cloud.tencent.com/document/api/1458/90246)

新增数据结构：

* [InputEncryptData](https://cloud.tencent.com/document/api/1458/75030#InputEncryptData)
* [OutputAuthorizedTransfer](https://cloud.tencent.com/document/api/1458/75030#OutputAuthorizedTransfer)

### 第 19 次发布

发布时间：2023-04-17 01:41:34

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeTraceDataById](https://cloud.tencent.com/document/api/1458/90218)

### 第 18 次发布

发布时间：2023-04-12 02:05:50

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeScanStats](https://cloud.tencent.com/document/api/1458/85942)

	* 新增入参：Code


### 第 17 次发布

发布时间：2023-03-21 02:26:25

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeScanStats](https://cloud.tencent.com/document/api/1458/85942)

	* 新增入参：MerchantId, ProductId

	* <font color="#dd0000">**修改入参**：</font>BatchId


修改数据结构：

* [ScanStat](https://cloud.tencent.com/document/api/1458/75030#ScanStat)

	* 新增成员：MerchantName, ProductName


### 第 16 次发布

发布时间：2023-01-31 02:06:12

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeScanLogs](https://cloud.tencent.com/document/api/1458/85943)
* [DescribeScanStats](https://cloud.tencent.com/document/api/1458/85942)

新增数据结构：

* [ScanLog](https://cloud.tencent.com/document/api/1458/75030#ScanLog)
* [ScanStat](https://cloud.tencent.com/document/api/1458/75030#ScanStat)

### 第 15 次发布

发布时间：2023-01-16 02:15:33

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [TraceCode](https://cloud.tencent.com/document/api/1458/75030#TraceCode)

	* 新增成员：AgentId, Level


### 第 14 次发布

发布时间：2022-12-28 16:01:40

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [ModifyTraceCodeUnlink](https://cloud.tencent.com/document/api/1458/84602)

	* 新增出参：CodeCnt, BatchId


### 第 13 次发布

发布时间：2022-12-27 22:11:23

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [ModifyTraceCodeUnlink](https://cloud.tencent.com/document/api/1458/84602)

### 第 12 次发布

发布时间：2022-12-27 02:17:04

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateCodeBatch](https://cloud.tencent.com/document/api/1458/75029)

	* 新增入参：BatchCode

* [CreateCodePack](https://cloud.tencent.com/document/api/1458/75028)

	* 新增入参：SerialType

* [CreateCustomPack](https://cloud.tencent.com/document/api/1458/81464)

	* 新增入参：SerialType

* [DescribeCodePacks](https://cloud.tencent.com/document/api/1458/75016)

	* 新增入参：SerialType

* [ModifyCodeBatch](https://cloud.tencent.com/document/api/1458/75007)

	* 新增入参：BatchCode


### 第 11 次发布

发布时间：2022-12-07 07:14:07

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeCorpQuotas](https://cloud.tencent.com/document/api/1458/83733)

新增数据结构：

* [CorpQuota](https://cloud.tencent.com/document/api/1458/75030#CorpQuota)
* [Quota](https://cloud.tencent.com/document/api/1458/75030#Quota)
* [UsageQuota](https://cloud.tencent.com/document/api/1458/75030#UsageQuota)

### 第 10 次发布

发布时间：2022-11-22 07:04:58

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateCodePack](https://cloud.tencent.com/document/api/1458/75028)

	* 新增入参：BatchId

* [CreateCustomPack](https://cloud.tencent.com/document/api/1458/81464)

	* 新增入参：BatchId

* [ModifyCustomRuleStatus](https://cloud.tencent.com/document/api/1458/81458)

	* 新增入参：CorpId


### 第 9 次发布

发布时间：2022-11-02 10:37:26

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateCorporationOrder](https://cloud.tencent.com/document/api/1458/82298)

### 第 8 次发布

发布时间：2022-10-17 22:02:42

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeTmpToken](https://cloud.tencent.com/document/api/1458/81515)

修改接口：

* [CreateCustomPack](https://cloud.tencent.com/document/api/1458/81464)

	* 新增入参：CodeParts

* [DescribeCodePackStatus](https://cloud.tencent.com/document/api/1458/81457)

	* 新增出参：Status

* [DescribeCodePackUrl](https://cloud.tencent.com/document/api/1458/81456)

	* 新增出参：ImgUrl, FileKey

* [DescribeCodePacks](https://cloud.tencent.com/document/api/1458/75016)

	* 新增出参：CodePacks, TotalCount

* [DescribeJobFileUrl](https://cloud.tencent.com/document/api/1458/81455)

	* 新增出参：Url


新增数据结构：

* [CodePack](https://cloud.tencent.com/document/api/1458/75030#CodePack)

修改数据结构：

* [PackSpec](https://cloud.tencent.com/document/api/1458/75030#PackSpec)

	* 新增成员：CodeParts

* [TraceData](https://cloud.tencent.com/document/api/1458/75030#TraceData)

	* 新增成员：PhaseData, Status


### 第 7 次发布

发布时间：2022-10-14 20:26:32

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateCustomPack](https://cloud.tencent.com/document/api/1458/81464)
* [CreateCustomRule](https://cloud.tencent.com/document/api/1458/81463)
* [CreateTraceCodesAsync](https://cloud.tencent.com/document/api/1458/81462)
* [DescribeCustomRuleById](https://cloud.tencent.com/document/api/1458/81461)
* [DescribeCustomRules](https://cloud.tencent.com/document/api/1458/81460)
* [ModifyCustomRule](https://cloud.tencent.com/document/api/1458/81459)
* [ModifyCustomRuleStatus](https://cloud.tencent.com/document/api/1458/81458)

新增数据结构：

* [CodePart](https://cloud.tencent.com/document/api/1458/75030#CodePart)
* [CustomRule](https://cloud.tencent.com/document/api/1458/75030#CustomRule)

### 第 6 次发布

发布时间：2022-10-14 20:11:39

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeCodePackStatus](https://cloud.tencent.com/document/api/1458/81457)
* [DescribeCodePackUrl](https://cloud.tencent.com/document/api/1458/81456)
* [DescribeJobFileUrl](https://cloud.tencent.com/document/api/1458/81455)

### 第 5 次发布

发布时间：2022-10-12 19:31:50

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateMerchant](https://cloud.tencent.com/document/api/1458/75027)

	* 新增入参：CodeType, CodeUrl

* [DescribeMerchants](https://cloud.tencent.com/document/api/1458/75013)

	* 新增入参：CodeType

* [ModifyMerchant](https://cloud.tencent.com/document/api/1458/75006)

	* 新增入参：CodeType, CodeUrl


新增数据结构：

* [Job](https://cloud.tencent.com/document/api/1458/75030#Job)

修改数据结构：

* [CodeBatch](https://cloud.tencent.com/document/api/1458/75030#CodeBatch)

	* 新增成员：Job

* [Merchant](https://cloud.tencent.com/document/api/1458/75030#Merchant)

	* 新增成员：CodeType, CodeUrl

* [PackSpec](https://cloud.tencent.com/document/api/1458/75030#PackSpec)

	* 新增成员：CustomId

* [TraceItem](https://cloud.tencent.com/document/api/1458/75030#TraceItem)

	* 新增成员：Ext


### 第 4 次发布

发布时间：2022-09-02 07:00:24

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateCodeBatch](https://cloud.tencent.com/document/api/1458/75029)

	* 新增入参：CloneId


### 第 3 次发布

发布时间：2022-09-01 06:55:12

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateTraceData](https://cloud.tencent.com/document/api/1458/75023)

	* 新增入参：Status, PhaseData

* [ModifyTraceData](https://cloud.tencent.com/document/api/1458/75003)

	* 新增入参：PhaseData


新增数据结构：

* [PhaseData](https://cloud.tencent.com/document/api/1458/75030#PhaseData)

修改数据结构：

* [TraceItem](https://cloud.tencent.com/document/api/1458/75030#TraceItem)

	* 新增成员：Key


### 第 2 次发布

发布时间：2022-07-27 06:17:54

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateCodeBatch](https://cloud.tencent.com/document/api/1458/75029)

	* 新增入参：MpTpl

* [ModifyCodeBatch](https://cloud.tencent.com/document/api/1458/75007)

	* 新增入参：MerchantId, ProductId, Remark


### 第 1 次发布

发布时间：2022-06-07 16:18:00

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateCodeBatch](https://cloud.tencent.com/document/api/1458/75029)
* [CreateCodePack](https://cloud.tencent.com/document/api/1458/75028)
* [CreateMerchant](https://cloud.tencent.com/document/api/1458/75027)
* [CreateProduct](https://cloud.tencent.com/document/api/1458/75026)
* [CreateTraceChain](https://cloud.tencent.com/document/api/1458/75025)
* [CreateTraceCodes](https://cloud.tencent.com/document/api/1458/75024)
* [CreateTraceData](https://cloud.tencent.com/document/api/1458/75023)
* [DeleteCodeBatch](https://cloud.tencent.com/document/api/1458/75022)
* [DeleteMerchant](https://cloud.tencent.com/document/api/1458/75021)
* [DeleteProduct](https://cloud.tencent.com/document/api/1458/75020)
* [DeleteTraceData](https://cloud.tencent.com/document/api/1458/75019)
* [DescribeCodeBatchById](https://cloud.tencent.com/document/api/1458/75018)
* [DescribeCodeBatchs](https://cloud.tencent.com/document/api/1458/75017)
* [DescribeCodePacks](https://cloud.tencent.com/document/api/1458/75016)
* [DescribeCodesByPack](https://cloud.tencent.com/document/api/1458/75015)
* [DescribeMerchantById](https://cloud.tencent.com/document/api/1458/75014)
* [DescribeMerchants](https://cloud.tencent.com/document/api/1458/75013)
* [DescribeProductById](https://cloud.tencent.com/document/api/1458/75012)
* [DescribeProducts](https://cloud.tencent.com/document/api/1458/75011)
* [DescribeTraceCodeById](https://cloud.tencent.com/document/api/1458/75010)
* [DescribeTraceCodes](https://cloud.tencent.com/document/api/1458/75009)
* [DescribeTraceDataList](https://cloud.tencent.com/document/api/1458/75008)
* [ModifyCodeBatch](https://cloud.tencent.com/document/api/1458/75007)
* [ModifyMerchant](https://cloud.tencent.com/document/api/1458/75006)
* [ModifyProduct](https://cloud.tencent.com/document/api/1458/75005)
* [ModifyTraceCode](https://cloud.tencent.com/document/api/1458/75004)
* [ModifyTraceData](https://cloud.tencent.com/document/api/1458/75003)
* [ModifyTraceDataRanks](https://cloud.tencent.com/document/api/1458/75002)

新增数据结构：

* [ChainData](https://cloud.tencent.com/document/api/1458/75030#ChainData)
* [CodeBatch](https://cloud.tencent.com/document/api/1458/75030#CodeBatch)
* [CodeItem](https://cloud.tencent.com/document/api/1458/75030#CodeItem)
* [Ext](https://cloud.tencent.com/document/api/1458/75030#Ext)
* [Merchant](https://cloud.tencent.com/document/api/1458/75030#Merchant)
* [PackSpec](https://cloud.tencent.com/document/api/1458/75030#PackSpec)
* [Product](https://cloud.tencent.com/document/api/1458/75030#Product)
* [TraceCode](https://cloud.tencent.com/document/api/1458/75030#TraceCode)
* [TraceData](https://cloud.tencent.com/document/api/1458/75030#TraceData)
* [TraceItem](https://cloud.tencent.com/document/api/1458/75030#TraceItem)




## 远程实时操控(trro) 版本：2022-03-25

### 第 6 次发布

发布时间：2024-07-31 02:17:29

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeDeviceList](https://cloud.tencent.com/document/api/1584/89815)

	* 新增入参：DeviceStatus


新增数据结构：

* [MultiNet](https://cloud.tencent.com/document/api/1584/89828#MultiNet)

修改数据结构：

* [SessionDeviceDetail](https://cloud.tencent.com/document/api/1584/89828#SessionDeviceDetail)

	* 新增成员：RenderCost, ConfigWidth, ConfigHeight, FrameDelta, MaxFrameDelta, TotalBitrateEstimate, Lag100Duration, Lag150Duration, MultiMode, MultiNet


### 第 5 次发布

发布时间：2024-06-21 02:25:01

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeProjectInfo](https://cloud.tencent.com/document/api/1584/89810)

	* <font color="#dd0000">**修改入参**：</font>ProjectId


### 第 4 次发布

发布时间：2024-01-31 01:25:41

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [GetLicenseStat](https://cloud.tencent.com/document/api/1584/89901)

	* 新增出参：MonthlyExpire

* [GetLicenses](https://cloud.tencent.com/document/api/1584/89900)

	* 新增入参：Status


修改数据结构：

* [Device](https://cloud.tencent.com/document/api/1584/89828#Device)

	* 新增成员：MonthlyRemainTime

	* <font color="#dd0000">**修改成员**：</font>DeviceId, DeviceName, LicenseCount, RemainDay, ExpireTime, Duration, LicenseIds


### 第 3 次发布

发布时间：2023-07-18 01:53:24

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [SessionDeviceDetail](https://cloud.tencent.com/document/api/1584/89828#SessionDeviceDetail)

	* 新增成员：Ver, SdkMode, DecodeCost, RenderConst, K100, K150, NACK, BitRateEstimate, Width, Height, EncodeCost, CaptureCost


### 第 2 次发布

发布时间：2023-04-05 02:05:51

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [BoundLicenses](https://cloud.tencent.com/document/api/1584/89904)
* [DescribeRecentSessionList](https://cloud.tencent.com/document/api/1584/89905)
* [GetDeviceLicense](https://cloud.tencent.com/document/api/1584/89903)
* [GetDevices](https://cloud.tencent.com/document/api/1584/89902)
* [GetLicenseStat](https://cloud.tencent.com/document/api/1584/89901)
* [GetLicenses](https://cloud.tencent.com/document/api/1584/89900)

新增数据结构：

* [Device](https://cloud.tencent.com/document/api/1584/89828#Device)
* [License](https://cloud.tencent.com/document/api/1584/89828#License)
* [RecentSessionInfo](https://cloud.tencent.com/document/api/1584/89828#RecentSessionInfo)

### 第 1 次发布

发布时间：2023-04-04 09:21:02

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [BatchDeleteDevices](https://cloud.tencent.com/document/api/1584/89818)
* [BatchDeletePolicy](https://cloud.tencent.com/document/api/1584/89822)
* [CreateDevice](https://cloud.tencent.com/document/api/1584/89817)
* [CreateProject](https://cloud.tencent.com/document/api/1584/89812)
* [DeleteProject](https://cloud.tencent.com/document/api/1584/89811)
* [DescribeDeviceInfo](https://cloud.tencent.com/document/api/1584/89816)
* [DescribeDeviceList](https://cloud.tencent.com/document/api/1584/89815)
* [DescribeDeviceSessionDetails](https://cloud.tencent.com/document/api/1584/89827)
* [DescribeDeviceSessionList](https://cloud.tencent.com/document/api/1584/89826)
* [DescribePolicy](https://cloud.tencent.com/document/api/1584/89821)
* [DescribeProjectInfo](https://cloud.tencent.com/document/api/1584/89810)
* [DescribeProjectList](https://cloud.tencent.com/document/api/1584/89809)
* [DescribeSessionStatistics](https://cloud.tencent.com/document/api/1584/89825)
* [DescribeSessionStatisticsByInterval](https://cloud.tencent.com/document/api/1584/89824)
* [ModifyDevice](https://cloud.tencent.com/document/api/1584/89814)
* [ModifyPolicy](https://cloud.tencent.com/document/api/1584/89820)
* [ModifyProject](https://cloud.tencent.com/document/api/1584/89808)

新增数据结构：

* [DeviceInfo](https://cloud.tencent.com/document/api/1584/89828#DeviceInfo)
* [PolicyInfo](https://cloud.tencent.com/document/api/1584/89828#PolicyInfo)
* [ProjectInfo](https://cloud.tencent.com/document/api/1584/89828#ProjectInfo)
* [SessionDeviceDetail](https://cloud.tencent.com/document/api/1584/89828#SessionDeviceDetail)
* [SessionInfo](https://cloud.tencent.com/document/api/1584/89828#SessionInfo)
* [SessionIntervalStatistic](https://cloud.tencent.com/document/api/1584/89828#SessionIntervalStatistic)




## 实时音视频(trtc) 版本：2019-07-22

### 第 84 次发布

发布时间：2024-08-02 02:18:56

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [McuUserInfoParams](https://cloud.tencent.com/document/api/647/44055#McuUserInfoParams)

	* 新增成员：SoundLevel


### 第 83 次发布

发布时间：2024-07-30 02:22:25

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [ControlAIConversation](https://cloud.tencent.com/document/api/647/109408)

新增数据结构：

* [ServerPushText](https://cloud.tencent.com/document/api/647/44055#ServerPushText)

### 第 82 次发布

发布时间：2024-07-12 01:27:45

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [TrtcUsage](https://cloud.tencent.com/document/api/647/44055#TrtcUsage)

	* 新增成员：TimeStampKey


### 第 81 次发布

发布时间：2024-07-10 01:27:37

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeAIConversation](https://cloud.tencent.com/document/api/647/108515)
* [StartAIConversation](https://cloud.tencent.com/document/api/647/108514)
* [StopAIConversation](https://cloud.tencent.com/document/api/647/108513)

新增数据结构：

* [AgentConfig](https://cloud.tencent.com/document/api/647/44055#AgentConfig)
* [STTConfig](https://cloud.tencent.com/document/api/647/44055#STTConfig)

### 第 80 次发布

发布时间：2024-07-08 01:24:35

本次发布包含了以下内容：

改善已有的文档。

<font color="#dd0000">**预下线接口**：</font>

* SummarizeTranscription

修改数据结构：

* [RecognizeConfig](https://cloud.tencent.com/document/api/647/44055#RecognizeConfig)

	* 新增成员：AlternativeLanguage


### 第 79 次发布

发布时间：2024-06-25 01:25:02

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [McuLayout](https://cloud.tencent.com/document/api/647/44055#McuLayout)

	* 新增成员：BackGroundColorMode


### 第 78 次发布

发布时间：2024-06-24 01:24:46

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [StartStreamIngest](https://cloud.tencent.com/document/api/647/101872)


### 第 77 次发布

发布时间：2024-06-18 02:25:06

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [TranscriptionParams](https://cloud.tencent.com/document/api/647/44055#TranscriptionParams)


### 第 76 次发布

发布时间：2024-06-03 02:25:00

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeAITranscription](https://cloud.tencent.com/document/api/647/106493)

	* 新增入参：SdkAppId, SessionId

	* 新增出参：TaskId, SessionId

* [StartAITranscription](https://cloud.tencent.com/document/api/647/106492)

	* 新增入参：SessionId


修改数据结构：

* [RecognizeConfig](https://cloud.tencent.com/document/api/647/44055#RecognizeConfig)

	* 新增成员：Model


### 第 75 次发布

发布时间：2024-05-21 02:21:25

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeAITranscription](https://cloud.tencent.com/document/api/647/106493)
* [StartAITranscription](https://cloud.tencent.com/document/api/647/106492)
* [StopAITranscription](https://cloud.tencent.com/document/api/647/106491)
* [SummarizeTranscription](https://cloud.tencent.com/document/api/647/106490)

新增数据结构：

* [RecognizeConfig](https://cloud.tencent.com/document/api/647/44055#RecognizeConfig)
* [TranscriptionParams](https://cloud.tencent.com/document/api/647/44055#TranscriptionParams)

### 第 74 次发布

发布时间：2024-05-17 02:28:57

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [StartStreamIngest](https://cloud.tencent.com/document/api/647/101872)

	* 新增入参：SeekSecond


### 第 73 次发布

发布时间：2024-05-14 02:45:49

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [McuWaterMarkText](https://cloud.tencent.com/document/api/647/44055#McuWaterMarkText)

	* 新增成员：Font


### 第 72 次发布

发布时间：2024-05-07 11:13:32

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [RecordParams](https://cloud.tencent.com/document/api/647/44055#RecordParams)

	* 新增成员：FillType

* [WebRecordVideoParams](https://cloud.tencent.com/document/api/647/44055#WebRecordVideoParams)

	* 新增成员：MaxMediaFileDuration


### 第 71 次发布

发布时间：2024-04-22 19:56:18

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeWebRecord](https://cloud.tencent.com/document/api/647/104542)

	* 新增出参：TaskId, RecordId


### 第 70 次发布

发布时间：2024-04-12 01:26:18

本次发布包含了以下内容：

改善已有的文档。

新增数据结构：

* [McuBackgroundCustomRender](https://cloud.tencent.com/document/api/647/44055#McuBackgroundCustomRender)

修改数据结构：

* [McuLayout](https://cloud.tencent.com/document/api/647/44055#McuLayout)

	* 新增成员：BackgroundCustomRender


### 第 69 次发布

发布时间：2024-04-11 01:24:46

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeWebRecord](https://cloud.tencent.com/document/api/647/104542)

	* 新增入参：SdkAppId, RecordId

	* <font color="#dd0000">**修改入参**：</font>TaskId


### 第 68 次发布

发布时间：2024-04-10 01:25:26

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [StartWebRecord](https://cloud.tencent.com/document/api/647/104541)

	* 新增入参：PublishCdnParams


### 第 67 次发布

发布时间：2024-03-22 01:25:05

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeWebRecord](https://cloud.tencent.com/document/api/647/104542)
* [StartWebRecord](https://cloud.tencent.com/document/api/647/104541)
* [StopWebRecord](https://cloud.tencent.com/document/api/647/104540)

新增数据结构：

* [WebRecordVideoParams](https://cloud.tencent.com/document/api/647/44055#WebRecordVideoParams)

### 第 66 次发布

发布时间：2024-03-01 01:27:10

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [McuWaterMarkText](https://cloud.tencent.com/document/api/647/44055#McuWaterMarkText)

	* 新增成员：ZOrder


### 第 65 次发布

发布时间：2024-01-24 17:17:12

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [AudioEncodeParams](https://cloud.tencent.com/document/api/647/44055#AudioEncodeParams)

	* 新增成员：Volume

	* <font color="#dd0000">**修改成员**：</font>SampleRate, Channel, BitRate

* [VideoEncodeParams](https://cloud.tencent.com/document/api/647/44055#VideoEncodeParams)

	* <font color="#dd0000">**修改成员**：</font>Width, Height, Fps, BitRate, Gop


### 第 64 次发布

发布时间：2024-01-09 01:27:58

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [McuLayout](https://cloud.tencent.com/document/api/647/44055#McuLayout)

	* 新增成员：TransparentUrl


### 第 63 次发布

发布时间：2024-01-08 00:21:01

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [StartStreamIngest](https://cloud.tencent.com/document/api/647/101872)

	* 新增入参：StreamUrl

	* <font color="#dd0000">**修改入参**：</font>SourceUrl


### 第 62 次发布

发布时间：2023-12-01 01:27:18

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [WaterMarkChar](https://cloud.tencent.com/document/api/647/44055#WaterMarkChar)

	* 新增成员：Font

* [WaterMarkTimestamp](https://cloud.tencent.com/document/api/647/44055#WaterMarkTimestamp)

	* 新增成员：Font


### 第 61 次发布

发布时间：2023-11-24 01:26:16

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeStreamIngest](https://cloud.tencent.com/document/api/647/101873)
* [StartStreamIngest](https://cloud.tencent.com/document/api/647/101872)
* [StopStreamIngest](https://cloud.tencent.com/document/api/647/101871)

新增数据结构：

* [AudioEncodeParams](https://cloud.tencent.com/document/api/647/44055#AudioEncodeParams)
* [VideoEncodeParams](https://cloud.tencent.com/document/api/647/44055#VideoEncodeParams)

### 第 60 次发布

发布时间：2023-11-16 01:34:14

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [McuWaterMarkImage](https://cloud.tencent.com/document/api/647/44055#McuWaterMarkImage)

	* 新增成员：DynamicPosType

* [McuWaterMarkText](https://cloud.tencent.com/document/api/647/44055#McuWaterMarkText)

	* 新增成员：DynamicPosType


### 第 59 次发布

发布时间：2023-08-28 02:42:57

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeTRTCMarketQualityData](https://cloud.tencent.com/document/api/647/97441)
* [DescribeTRTCRealTimeQualityData](https://cloud.tencent.com/document/api/647/97440)

### 第 58 次发布

发布时间：2023-08-25 17:00:53

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeTRTCRealTimeScaleData](https://cloud.tencent.com/document/api/647/97310)

### 第 57 次发布

发布时间：2023-08-25 16:40:56

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeTRTCMarketScaleData](https://cloud.tencent.com/document/api/647/97297)

新增数据结构：

* [RowValues](https://cloud.tencent.com/document/api/647/44055#RowValues)
* [SeriesInfos](https://cloud.tencent.com/document/api/647/44055#SeriesInfos)
* [TRTCDataResult](https://cloud.tencent.com/document/api/647/44055#TRTCDataResult)

### 第 56 次发布

发布时间：2023-07-28 01:54:49

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [McuLayout](https://cloud.tencent.com/document/api/647/44055#McuLayout)

	* 新增成员：BackgroundRenderMode

* [McuVideoParams](https://cloud.tencent.com/document/api/647/44055#McuVideoParams)

	* 新增成员：BackgroundRenderMode


### 第 55 次发布

发布时间：2023-07-11 01:48:58

本次发布包含了以下内容：

改善已有的文档。

<font color="#dd0000">**删除接口**：</font>

* DescribeExternalTrtcMeasure

<font color="#dd0000">**删除数据结构**：</font>

* SdkAppIdNewTrtcTimeUsage
* TrtcTimeNewUsage

### 第 54 次发布

发布时间：2023-04-14 02:00:19

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeTrtcRoomUsage](https://cloud.tencent.com/document/api/647/89181)

	* 新增出参：Data


### 第 53 次发布

发布时间：2023-03-28 02:14:35

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeTrtcRoomUsage](https://cloud.tencent.com/document/api/647/89181)

	* 新增入参：SdkAppid, StartTime, EndTime


### 第 52 次发布

发布时间：2023-03-27 17:15:46

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [McuLayoutParams](https://cloud.tencent.com/document/api/647/44055#McuLayoutParams)

	* 新增成员：RenderMode


### 第 51 次发布

发布时间：2023-03-23 02:55:58

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeTrtcRoomUsage](https://cloud.tencent.com/document/api/647/89181)

### 第 50 次发布

发布时间：2023-03-15 02:17:31

本次发布包含了以下内容：

改善已有的文档。

新增数据结构：

* [WaterMarkChar](https://cloud.tencent.com/document/api/647/44055#WaterMarkChar)
* [WaterMarkTimestamp](https://cloud.tencent.com/document/api/647/44055#WaterMarkTimestamp)

修改数据结构：

* [WaterMark](https://cloud.tencent.com/document/api/647/44055#WaterMark)

	* 新增成员：WaterMarkChar, WaterMarkTimestamp


### 第 49 次发布

发布时间：2023-03-08 02:20:49

本次发布包含了以下内容：

改善已有的文档。

新增数据结构：

* [McuWaterMarkText](https://cloud.tencent.com/document/api/647/44055#McuWaterMarkText)

修改数据结构：

* [McuWaterMarkParams](https://cloud.tencent.com/document/api/647/44055#McuWaterMarkParams)

	* 新增成员：WaterMarkText


### 第 48 次发布

发布时间：2023-03-06 02:10:52

本次发布包含了以下内容：

改善已有的文档。

<font color="#dd0000">**预下线接口**：</font>

* DescribeExternalTrtcMeasure

### 第 47 次发布

发布时间：2023-03-03 01:57:42

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [McuLayoutVolume](https://cloud.tencent.com/document/api/647/44055#McuLayoutVolume)

	* 新增成员：Interval, FollowIdr

* [McuPassThrough](https://cloud.tencent.com/document/api/647/44055#McuPassThrough)

	* 新增成员：Interval, FollowIdr


### 第 46 次发布

发布时间：2023-02-21 02:18:14

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [RecordParams](https://cloud.tencent.com/document/api/647/44055#RecordParams)

	* 新增成员：MediaId


### 第 45 次发布

发布时间：2023-01-06 01:51:15

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [LayoutParams](https://cloud.tencent.com/document/api/647/44055#LayoutParams)

	* 新增成员：RenderMode


### 第 44 次发布

发布时间：2022-12-08 01:52:42

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [MixLayoutParams](https://cloud.tencent.com/document/api/647/44055#MixLayoutParams)

	* 新增成员：RenderMode, MaxResolutionUserAlign

* [RecordParams](https://cloud.tencent.com/document/api/647/44055#RecordParams)

	* 新增成员：MaxMediaFileDuration

* [TencentVod](https://cloud.tencent.com/document/api/647/44055#TencentVod)

	* 新增成员：UserDefineRecordId


### 第 43 次发布

发布时间：2022-12-06 07:15:51

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [StartPublishCdnStream](https://cloud.tencent.com/document/api/647/81479)
* [StopPublishCdnStream](https://cloud.tencent.com/document/api/647/81478)
* [UpdatePublishCdnStream](https://cloud.tencent.com/document/api/647/81477)

新增数据结构：

* [AgentParams](https://cloud.tencent.com/document/api/647/44055#AgentParams)
* [AudioEncode](https://cloud.tencent.com/document/api/647/44055#AudioEncode)
* [MaxVideoUser](https://cloud.tencent.com/document/api/647/44055#MaxVideoUser)
* [McuAudioParams](https://cloud.tencent.com/document/api/647/44055#McuAudioParams)
* [McuCustomCrop](https://cloud.tencent.com/document/api/647/44055#McuCustomCrop)
* [McuFeedBackRoomParams](https://cloud.tencent.com/document/api/647/44055#McuFeedBackRoomParams)
* [McuLayout](https://cloud.tencent.com/document/api/647/44055#McuLayout)
* [McuLayoutParams](https://cloud.tencent.com/document/api/647/44055#McuLayoutParams)
* [McuLayoutVolume](https://cloud.tencent.com/document/api/647/44055#McuLayoutVolume)
* [McuPassThrough](https://cloud.tencent.com/document/api/647/44055#McuPassThrough)
* [McuPublishCdnParam](https://cloud.tencent.com/document/api/647/44055#McuPublishCdnParam)
* [McuSeiParams](https://cloud.tencent.com/document/api/647/44055#McuSeiParams)
* [McuUserInfoParams](https://cloud.tencent.com/document/api/647/44055#McuUserInfoParams)
* [McuVideoParams](https://cloud.tencent.com/document/api/647/44055#McuVideoParams)
* [McuWaterMarkImage](https://cloud.tencent.com/document/api/647/44055#McuWaterMarkImage)
* [McuWaterMarkParams](https://cloud.tencent.com/document/api/647/44055#McuWaterMarkParams)
* [MixUserInfo](https://cloud.tencent.com/document/api/647/44055#MixUserInfo)
* [SingleSubscribeParams](https://cloud.tencent.com/document/api/647/44055#SingleSubscribeParams)
* [UserMediaStream](https://cloud.tencent.com/document/api/647/44055#UserMediaStream)
* [VideoEncode](https://cloud.tencent.com/document/api/647/44055#VideoEncode)

### 第 42 次发布

发布时间：2022-11-04 15:36:29

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeTRTCMarketQualityMetricData](https://cloud.tencent.com/document/api/647/82405)
* [DescribeTRTCMarketScaleMetricData](https://cloud.tencent.com/document/api/647/82404)
* [DescribeTRTCRealTimeQualityMetricData](https://cloud.tencent.com/document/api/647/82403)
* [DescribeTRTCRealTimeScaleMetricData](https://cloud.tencent.com/document/api/647/82402)

新增数据结构：

* [SeriesInfo](https://cloud.tencent.com/document/api/647/44055#SeriesInfo)
* [TRTCDataResp](https://cloud.tencent.com/document/api/647/44055#TRTCDataResp)

### 第 41 次发布

发布时间：2022-10-19 15:31:57

本次发布包含了以下内容：

改善已有的文档。

<font color="#dd0000">**删除接口**：</font>

* StartPublishCdnStream
* StopPublishCdnStream
* UpdatePublishCdnStream

<font color="#dd0000">**删除数据结构**：</font>

* AgentParams
* AudioEncode
* MaxVideoUser
* McuAudioParams
* McuCustomCrop
* McuLayout
* McuLayoutParams
* McuLayoutVolume
* McuPassThrough
* McuPublishCdnParam
* McuSeiParams
* McuUserInfoParams
* McuVideoParams
* McuWaterMarkImage
* McuWaterMarkParams
* MixUserInfo
* SingleSubscribeParams
* UserMediaStream
* VideoEncode

### 第 40 次发布

发布时间：2022-10-17 06:50:00

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [StartPublishCdnStream](https://cloud.tencent.com/document/api/647/81479)
* [StopPublishCdnStream](https://cloud.tencent.com/document/api/647/81478)
* [UpdatePublishCdnStream](https://cloud.tencent.com/document/api/647/81477)

新增数据结构：

* [AgentParams](https://cloud.tencent.com/document/api/647/44055#AgentParams)
* [AudioEncode](https://cloud.tencent.com/document/api/647/44055#AudioEncode)
* [MaxVideoUser](https://cloud.tencent.com/document/api/647/44055#MaxVideoUser)
* [McuAudioParams](https://cloud.tencent.com/document/api/647/44055#McuAudioParams)
* [McuCustomCrop](https://cloud.tencent.com/document/api/647/44055#McuCustomCrop)
* [McuLayout](https://cloud.tencent.com/document/api/647/44055#McuLayout)
* [McuLayoutParams](https://cloud.tencent.com/document/api/647/44055#McuLayoutParams)
* [McuLayoutVolume](https://cloud.tencent.com/document/api/647/44055#McuLayoutVolume)
* [McuPassThrough](https://cloud.tencent.com/document/api/647/44055#McuPassThrough)
* [McuPublishCdnParam](https://cloud.tencent.com/document/api/647/44055#McuPublishCdnParam)
* [McuSeiParams](https://cloud.tencent.com/document/api/647/44055#McuSeiParams)
* [McuUserInfoParams](https://cloud.tencent.com/document/api/647/44055#McuUserInfoParams)
* [McuVideoParams](https://cloud.tencent.com/document/api/647/44055#McuVideoParams)
* [McuWaterMarkImage](https://cloud.tencent.com/document/api/647/44055#McuWaterMarkImage)
* [McuWaterMarkParams](https://cloud.tencent.com/document/api/647/44055#McuWaterMarkParams)
* [MixUserInfo](https://cloud.tencent.com/document/api/647/44055#MixUserInfo)
* [SingleSubscribeParams](https://cloud.tencent.com/document/api/647/44055#SingleSubscribeParams)
* [UserMediaStream](https://cloud.tencent.com/document/api/647/44055#UserMediaStream)
* [VideoEncode](https://cloud.tencent.com/document/api/647/44055#VideoEncode)

### 第 39 次发布

发布时间：2022-10-14 06:56:44

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeMixTranscodingUsage](https://cloud.tencent.com/document/api/647/81428)
* [DescribeRecordingUsage](https://cloud.tencent.com/document/api/647/81427)
* [DescribeRelayUsage](https://cloud.tencent.com/document/api/647/81426)
* [DescribeTrtcUsage](https://cloud.tencent.com/document/api/647/81425)

新增数据结构：

* [TrtcUsage](https://cloud.tencent.com/document/api/647/44055#TrtcUsage)

修改数据结构：

* [SdkAppIdTrtcMcuTranscodeTimeUsage](https://cloud.tencent.com/document/api/647/44055#SdkAppIdTrtcMcuTranscodeTimeUsage)

	* 新增成员：Flux


### 第 38 次发布

发布时间：2022-09-14 06:40:34

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [RecordParams](https://cloud.tencent.com/document/api/647/44055#RecordParams)

	* 新增成员：AvMerge

* [TencentVod](https://cloud.tencent.com/document/api/647/44055#TencentVod)

	* 新增成员：MediaType


### 第 37 次发布

发布时间：2022-08-08 06:44:27

本次发布包含了以下内容：

改善已有的文档。

<font color="#dd0000">**删除接口**：</font>

* DescribeAbnormalEvent
* DescribeCallDetail
* DescribeDetailEvent
* DescribeHistoryScale
* DescribeRoomInformation
* DescribeUserInformation

### 第 36 次发布

发布时间：2022-08-02 06:36:18

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateCloudRecording](https://cloud.tencent.com/document/api/647/73786)
* [DeleteCloudRecording](https://cloud.tencent.com/document/api/647/73785)
* [DescribeCloudRecording](https://cloud.tencent.com/document/api/647/73784)
* [ModifyCloudRecording](https://cloud.tencent.com/document/api/647/73783)

新增数据结构：

* [AudioParams](https://cloud.tencent.com/document/api/647/44055#AudioParams)
* [CloudStorage](https://cloud.tencent.com/document/api/647/44055#CloudStorage)
* [CloudVod](https://cloud.tencent.com/document/api/647/44055#CloudVod)
* [MixLayout](https://cloud.tencent.com/document/api/647/44055#MixLayout)
* [MixLayoutParams](https://cloud.tencent.com/document/api/647/44055#MixLayoutParams)
* [MixTranscodeParams](https://cloud.tencent.com/document/api/647/44055#MixTranscodeParams)
* [RecordParams](https://cloud.tencent.com/document/api/647/44055#RecordParams)
* [StorageFile](https://cloud.tencent.com/document/api/647/44055#StorageFile)
* [StorageParams](https://cloud.tencent.com/document/api/647/44055#StorageParams)
* [SubscribeStreamUserIds](https://cloud.tencent.com/document/api/647/44055#SubscribeStreamUserIds)
* [TencentVod](https://cloud.tencent.com/document/api/647/44055#TencentVod)
* [VideoParams](https://cloud.tencent.com/document/api/647/44055#VideoParams)
* [WaterMark](https://cloud.tencent.com/document/api/647/44055#WaterMark)
* [WaterMarkImage](https://cloud.tencent.com/document/api/647/44055#WaterMarkImage)

### 第 35 次发布

发布时间：2022-07-25 06:16:06

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeCallDetailInfo](https://cloud.tencent.com/document/api/647/77746)
* [DescribeRoomInfo](https://cloud.tencent.com/document/api/647/77745)
* [DescribeScaleInfo](https://cloud.tencent.com/document/api/647/77744)
* [DescribeUnusualEvent](https://cloud.tencent.com/document/api/647/77743)
* [DescribeUserEvent](https://cloud.tencent.com/document/api/647/77742)
* [DescribeUserInfo](https://cloud.tencent.com/document/api/647/77741)

### 第 34 次发布

发布时间：2022-07-15 06:17:08

本次发布包含了以下内容：

改善已有的文档。

<font color="#dd0000">**删除接口**：</font>

* CreateTroubleInfo

### 第 33 次发布

发布时间：2022-06-28 11:47:33

本次发布包含了以下内容：

改善已有的文档。

<font color="#dd0000">**删除接口**：</font>

* CreateCloudRecording
* DeleteCloudRecording
* DescribeCloudRecording
* ModifyCloudRecording

<font color="#dd0000">**删除数据结构**：</font>

* AudioParams
* CloudStorage
* CloudVod
* MixLayout
* MixLayoutParams
* MixTranscodeParams
* RecordParams
* StorageFile
* StorageParams
* SubscribeStreamUserIds
* TencentVod
* VideoParams
* WaterMark
* WaterMarkImage

### 第 32 次发布

发布时间：2022-06-21 06:15:46

本次发布包含了以下内容：

改善已有的文档。

<font color="#dd0000">**删除接口**：</font>

* MeasureTrtcMcuExternal

<font color="#dd0000">**删除数据结构**：</font>

* OneSdkAppIdTranscodeTimeUsagesNewInfo
* SdkAppIdTrtcMcuTranscodeTimeNewUsage

### 第 31 次发布

发布时间：2022-06-13 06:19:26

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [MeasureTrtcMcuExternal](https://cloud.tencent.com/document/api/647/74977)

	* 新增出参：Usages, Type


新增数据结构：

* [OneSdkAppIdTranscodeTimeUsagesNewInfo](https://cloud.tencent.com/document/api/647/44055#OneSdkAppIdTranscodeTimeUsagesNewInfo)
* [SdkAppIdTrtcMcuTranscodeTimeNewUsage](https://cloud.tencent.com/document/api/647/44055#SdkAppIdTrtcMcuTranscodeTimeNewUsage)

### 第 30 次发布

发布时间：2022-06-07 06:15:13

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeExternalTrtcMeasure](https://cloud.tencent.com/document/api/647/74978)
* [MeasureTrtcMcuExternal](https://cloud.tencent.com/document/api/647/74977)

新增数据结构：

* [SdkAppIdNewTrtcTimeUsage](https://cloud.tencent.com/document/api/647/44055#SdkAppIdNewTrtcTimeUsage)
* [TrtcTimeNewUsage](https://cloud.tencent.com/document/api/647/44055#TrtcTimeNewUsage)

### 第 29 次发布

发布时间：2022-05-17 06:17:44

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateCloudRecording](https://cloud.tencent.com/document/api/647/73786)
* [DeleteCloudRecording](https://cloud.tencent.com/document/api/647/73785)
* [DescribeCloudRecording](https://cloud.tencent.com/document/api/647/73784)
* [ModifyCloudRecording](https://cloud.tencent.com/document/api/647/73783)

新增数据结构：

* [AudioParams](https://cloud.tencent.com/document/api/647/44055#AudioParams)
* [CloudStorage](https://cloud.tencent.com/document/api/647/44055#CloudStorage)
* [CloudVod](https://cloud.tencent.com/document/api/647/44055#CloudVod)
* [MixLayout](https://cloud.tencent.com/document/api/647/44055#MixLayout)
* [MixLayoutParams](https://cloud.tencent.com/document/api/647/44055#MixLayoutParams)
* [MixTranscodeParams](https://cloud.tencent.com/document/api/647/44055#MixTranscodeParams)
* [RecordParams](https://cloud.tencent.com/document/api/647/44055#RecordParams)
* [StorageFile](https://cloud.tencent.com/document/api/647/44055#StorageFile)
* [StorageParams](https://cloud.tencent.com/document/api/647/44055#StorageParams)
* [SubscribeStreamUserIds](https://cloud.tencent.com/document/api/647/44055#SubscribeStreamUserIds)
* [TencentVod](https://cloud.tencent.com/document/api/647/44055#TencentVod)
* [VideoParams](https://cloud.tencent.com/document/api/647/44055#VideoParams)
* [WaterMark](https://cloud.tencent.com/document/api/647/44055#WaterMark)
* [WaterMarkImage](https://cloud.tencent.com/document/api/647/44055#WaterMarkImage)

### 第 28 次发布

发布时间：2022-03-11 08:15:26

本次发布包含了以下内容：

改善已有的文档。

<font color="#dd0000">**删除接口**：</font>

* DescribeTrtcInteractiveTime

<font color="#dd0000">**删除数据结构**：</font>

* OneSdkAppIdUsagesInfo
* SdkAppIdTrtcUsage

### 第 27 次发布

发布时间：2021-10-29 08:10:53

本次发布包含了以下内容：

改善已有的文档。

<font color="#dd0000">**删除接口**：</font>

* DescribeRealtimeNetwork
* DescribeRealtimeQuality
* DescribeRealtimeScale

<font color="#dd0000">**删除数据结构**：</font>

* RealtimeData

### 第 26 次发布

发布时间：2021-10-15 08:16:00

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [EncodeParams](https://cloud.tencent.com/document/api/647/44055#EncodeParams)

	* 新增成员：BackgroundImageUrl

* [WaterMarkParams](https://cloud.tencent.com/document/api/647/44055#WaterMarkParams)

	* 新增成员：WaterMarkUrl


### 第 25 次发布

发布时间：2021-05-25 08:11:20

本次发布包含了以下内容：

改善已有的文档。

新增数据结构：

* [WaterMarkParams](https://cloud.tencent.com/document/api/647/44055#WaterMarkParams)

修改数据结构：

* [LayoutParams](https://cloud.tencent.com/document/api/647/44055#LayoutParams)

	* 新增成员：WaterMarkParams


### 第 24 次发布

发布时间：2021-04-14 08:09:27

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreatePicture](https://cloud.tencent.com/document/api/647/54689)
* [DeletePicture](https://cloud.tencent.com/document/api/647/54688)
* [DescribePicture](https://cloud.tencent.com/document/api/647/54687)
* [ModifyPicture](https://cloud.tencent.com/document/api/647/54686)

新增数据结构：

* [PictureInfo](https://cloud.tencent.com/document/api/647/44055#PictureInfo)

### 第 23 次发布

发布时间：2021-03-19 08:09:14

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [EncodeParams](https://cloud.tencent.com/document/api/647/44055#EncodeParams)

	* 新增成员：AudioCodec


### 第 22 次发布

发布时间：2021-02-02 08:10:28

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [LayoutParams](https://cloud.tencent.com/document/api/647/44055#LayoutParams)

	* 新增成员：PureAudioHoldPlaceMode


### 第 21 次发布

发布时间：2021-01-11 08:08:23

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [StartMCUMixTranscode](https://cloud.tencent.com/document/api/647/44270)

	* 新增入参：PublishCdnParams

* [StartMCUMixTranscodeByStrRoomId](https://cloud.tencent.com/document/api/647/50236)

	* 新增入参：PublishCdnParams


新增数据结构：

* [PublishCdnParams](https://cloud.tencent.com/document/api/647/44055#PublishCdnParams)

### 第 20 次发布

发布时间：2020-12-30 08:08:21

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [LayoutParams](https://cloud.tencent.com/document/api/647/44055#LayoutParams)

	* 新增成员：PlaceHolderMode

* [PresetLayoutConfig](https://cloud.tencent.com/document/api/647/44055#PresetLayoutConfig)

	* 新增成员：MixInputType, PlaceImageId


### 第 19 次发布

发布时间：2020-11-24 12:27:28

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [StartMCUMixTranscodeByStrRoomId](https://cloud.tencent.com/document/api/647/50236)
* [StopMCUMixTranscodeByStrRoomId](https://cloud.tencent.com/document/api/647/50235)

### 第 18 次发布

发布时间：2020-11-17 08:09:36

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeRecordStatistic](https://cloud.tencent.com/document/api/647/49982)
* [DescribeTrtcInteractiveTime](https://cloud.tencent.com/document/api/647/49981)
* [DescribeTrtcMcuTranscodeTime](https://cloud.tencent.com/document/api/647/49980)
* [DismissRoomByStrRoomId](https://cloud.tencent.com/document/api/647/37088)
* [RemoveUserByStrRoomId](https://cloud.tencent.com/document/api/647/50426)

新增数据结构：

* [OneSdkAppIdTranscodeTimeUsagesInfo](https://cloud.tencent.com/document/api/647/44055#OneSdkAppIdTranscodeTimeUsagesInfo)
* [OneSdkAppIdUsagesInfo](https://cloud.tencent.com/document/api/647/44055#OneSdkAppIdUsagesInfo)
* [RecordUsage](https://cloud.tencent.com/document/api/647/44055#RecordUsage)
* [SdkAppIdRecordUsage](https://cloud.tencent.com/document/api/647/44055#SdkAppIdRecordUsage)
* [SdkAppIdTrtcMcuTranscodeTimeUsage](https://cloud.tencent.com/document/api/647/44055#SdkAppIdTrtcMcuTranscodeTimeUsage)
* [SdkAppIdTrtcUsage](https://cloud.tencent.com/document/api/647/44055#SdkAppIdTrtcUsage)

### 第 17 次发布

发布时间：2020-11-16 08:08:23

本次发布包含了以下内容：

改善已有的文档。

新增数据结构：

* [PresetLayoutConfig](https://cloud.tencent.com/document/api/647/44055#PresetLayoutConfig)

修改数据结构：

* [LayoutParams](https://cloud.tencent.com/document/api/647/44055#LayoutParams)

	* 新增成员：PresetLayoutConfig


### 第 16 次发布

发布时间：2020-10-30 08:07:31

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeUserInformation](https://cloud.tencent.com/document/api/647/49568)

### 第 15 次发布

发布时间：2020-09-17 08:07:49

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [LayoutParams](https://cloud.tencent.com/document/api/647/44055#LayoutParams)

	* 新增成员：MixVideoUids


### 第 14 次发布

发布时间：2020-09-04 08:08:11

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeCallDetail](https://cloud.tencent.com/document/api/647/44054)

	* 新增入参：PageNumber, PageSize


### 第 13 次发布

发布时间：2020-08-24 08:07:26

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [LayoutParams](https://cloud.tencent.com/document/api/647/44055#LayoutParams)

	* 新增成员：MainVideoRightAlign


### 第 12 次发布

发布时间：2020-07-22 08:22:24

本次发布包含了以下内容：

改善已有的文档。

新增数据结构：

* [SmallVideoLayoutParams](https://cloud.tencent.com/document/api/647/44055#SmallVideoLayoutParams)

修改数据结构：

* [LayoutParams](https://cloud.tencent.com/document/api/647/44055#LayoutParams)

	* 新增成员：SmallVideoLayoutParams


### 第 11 次发布

发布时间：2020-07-02 08:21:01

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [EncodeParams](https://cloud.tencent.com/document/api/647/44055#EncodeParams)

	* 新增成员：BackgroundImageId


### 第 10 次发布

发布时间：2020-06-23 08:20:35

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeAbnormalEvent](https://cloud.tencent.com/document/api/647/45712)

新增数据结构：

* [AbnormalEvent](https://cloud.tencent.com/document/api/647/44055#AbnormalEvent)
* [AbnormalExperience](https://cloud.tencent.com/document/api/647/44055#AbnormalExperience)

### 第 9 次发布

发布时间：2020-05-26 08:20:19

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeDetailEvent](https://cloud.tencent.com/document/api/647/44864)

新增数据结构：

* [EventList](https://cloud.tencent.com/document/api/647/44055#EventList)
* [EventMessage](https://cloud.tencent.com/document/api/647/44055#EventMessage)

修改数据结构：

* [UserInformation](https://cloud.tencent.com/document/api/647/44055#UserInformation)

	* 新增成员：Finished


### 第 8 次发布

发布时间：2020-05-19 08:19:33

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateTroubleInfo](https://cloud.tencent.com/document/api/647/44683)

### 第 7 次发布

发布时间：2020-05-08 08:20:12

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [StartMCUMixTranscode](https://cloud.tencent.com/document/api/647/44270)
* [StopMCUMixTranscode](https://cloud.tencent.com/document/api/647/44269)

新增数据结构：

* [EncodeParams](https://cloud.tencent.com/document/api/647/44055#EncodeParams)
* [LayoutParams](https://cloud.tencent.com/document/api/647/44055#LayoutParams)
* [OutputParams](https://cloud.tencent.com/document/api/647/44055#OutputParams)

### 第 6 次发布

发布时间：2020-04-30 08:19:35

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeHistoryScale](https://cloud.tencent.com/document/api/647/44165)

新增数据结构：

* [ScaleInfomation](https://cloud.tencent.com/document/api/647/44055#ScaleInfomation)

### 第 5 次发布

发布时间：2020-04-29 08:20:23

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeCallDetail](https://cloud.tencent.com/document/api/647/44054)
* [DescribeRealtimeNetwork](https://cloud.tencent.com/document/api/647/44053)
* [DescribeRealtimeQuality](https://cloud.tencent.com/document/api/647/44052)
* [DescribeRealtimeScale](https://cloud.tencent.com/document/api/647/44051)
* [DescribeRoomInformation](https://cloud.tencent.com/document/api/647/44050)

新增数据结构：

* [QualityData](https://cloud.tencent.com/document/api/647/44055#QualityData)
* [RealtimeData](https://cloud.tencent.com/document/api/647/44055#RealtimeData)
* [RoomState](https://cloud.tencent.com/document/api/647/44055#RoomState)
* [TimeValue](https://cloud.tencent.com/document/api/647/44055#TimeValue)
* [UserInformation](https://cloud.tencent.com/document/api/647/44055#UserInformation)

### 第 4 次发布

发布时间：2019-12-27 09:54:28

本次发布包含了以下内容：

改善已有的文档。

<font color="#dd0000">**删除接口**：</font>

* DissolveRoom
* KickOutUser

### 第 3 次发布

发布时间：2019-12-27 09:42:39

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DismissRoom](https://cloud.tencent.com/document/api/647/50089)
* [RemoveUser](https://cloud.tencent.com/document/api/647/40496)

### 第 2 次发布

发布时间：2019-08-16 00:24:14

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DissolveRoom](https://cloud.tencent.com/document/api/#/#)

### 第 1 次发布

发布时间：2019-08-12 22:24:02

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [KickOutUser](https://cloud.tencent.com/document/api/647/37087)




## 微服务引擎(tse) 版本：2020-12-07

### 第 74 次发布

发布时间：2024-08-02 02:19:29

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [KongActiveHealthCheck](https://cloud.tencent.com/document/api/1364/54942#KongActiveHealthCheck)

	* 新增成员：Timeout


### 第 73 次发布

发布时间：2024-07-10 01:27:48

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateCloudNativeAPIGateway](https://cloud.tencent.com/document/api/1364/96757)

	* 新增入参：PromId


修改数据结构：

* [PublicAddressConfig](https://cloud.tencent.com/document/api/1364/54942#PublicAddressConfig)

	* 新增成员：Description


### 第 72 次发布

发布时间：2024-06-20 02:26:25

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [UpstreamHealthCheckConfig](https://cloud.tencent.com/document/api/1364/54942#UpstreamHealthCheckConfig)

	* 新增成员：ZeroWeightHeathCheck


### 第 71 次发布

发布时间：2024-06-18 02:25:40

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribePublicAddressConfig](https://cloud.tencent.com/document/api/1364/107147)

	* 新增出参：Result


新增数据结构：

* [DescribePublicAddressConfigResult](https://cloud.tencent.com/document/api/1364/54942#DescribePublicAddressConfigResult)
* [PublicAddressConfig](https://cloud.tencent.com/document/api/1364/54942#PublicAddressConfig)

### 第 70 次发布

发布时间：2024-06-17 02:25:45

本次发布包含了以下内容：

改善已有的文档。

新增数据结构：

* [ZookeeperRegionInfo](https://cloud.tencent.com/document/api/1364/54942#ZookeeperRegionInfo)
* [ZookeeperRegionMyIdInfo](https://cloud.tencent.com/document/api/1364/54942#ZookeeperRegionMyIdInfo)

修改数据结构：

* [SREInstance](https://cloud.tencent.com/document/api/1364/54942#SREInstance)

	* 新增成员：ZookeeperRegionInfo, DeployMode

* [VpcInfo](https://cloud.tencent.com/document/api/1364/54942#VpcInfo)

	* 新增成员：LbSubnetId


### 第 69 次发布

发布时间：2024-06-10 02:42:22

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribePublicAddressConfig](https://cloud.tencent.com/document/api/1364/107147)

### 第 68 次发布

发布时间：2024-06-04 02:26:13

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [KongUpstreamInfo](https://cloud.tencent.com/document/api/1364/54942#KongUpstreamInfo)

	* 新增成员：ScfIsBase64Encoded, ScfIsIntegratedResponse


### 第 67 次发布

发布时间：2024-05-15 01:35:13

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateEngine](https://cloud.tencent.com/document/api/1364/75218)

	* 新增入参：StorageType, StorageCapacity


### 第 66 次发布

发布时间：2024-05-14 02:46:25

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [CloudNativeAPIGatewayNode](https://cloud.tencent.com/document/api/1364/54942#CloudNativeAPIGatewayNode)

	* 新增成员：Weight, IsDefaultWeight

	* <font color="#dd0000">**修改成员**：</font>ZoneId, Zone, GroupId, GroupName, Status

* [NativeGatewayServerGroup](https://cloud.tencent.com/document/api/1364/54942#NativeGatewayServerGroup)

	* 新增成员：DefaultWeight


### 第 65 次发布

发布时间：2024-04-29 01:27:04

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateEngine](https://cloud.tencent.com/document/api/1364/75218)

	* 新增入参：AffinityConstraint


新增数据结构：

* [AccurateQpsThreshold](https://cloud.tencent.com/document/api/1364/54942#AccurateQpsThreshold)

修改数据结构：

* [LimitRule](https://cloud.tencent.com/document/api/1364/54942#LimitRule)

	* 新增成员：AccurateQpsThresholds


### 第 64 次发布

发布时间：2024-04-17 01:25:12

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateEngine](https://cloud.tencent.com/document/api/1364/75218)

	* 新增入参：StorageOption


### 第 63 次发布

发布时间：2024-04-02 01:25:46

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeCloudNativeAPIGatewayCanaryRules](https://cloud.tencent.com/document/api/1364/94844)

	* 新增入参：RuleType


新增数据结构：

* [KeyValue](https://cloud.tencent.com/document/api/1364/54942#KeyValue)
* [LimitRule](https://cloud.tencent.com/document/api/1364/54942#LimitRule)
* [RuleFilter](https://cloud.tencent.com/document/api/1364/54942#RuleFilter)

修改数据结构：

* [CloudNativeAPIGatewayCanaryRule](https://cloud.tencent.com/document/api/1364/54942#CloudNativeAPIGatewayCanaryRule)

	* 新增成员：RuleType, MatchType, GroupId, GroupName, LaneId, LaneName, MatchMode, LaneTag

* [CloudNativeAPIGatewayRateLimitDetail](https://cloud.tencent.com/document/api/1364/54942#CloudNativeAPIGatewayRateLimitDetail)

	* 新增成员：BasicLimitQpsThresholds, LimitRules

	* <font color="#dd0000">**修改成员**：</font>Enabled, QpsThresholds, LimitBy, ResponseType, HideClientHeaders, IsDelay

* [KongTarget](https://cloud.tencent.com/document/api/1364/54942#KongTarget)

	* 新增成员：Tags


### 第 62 次发布

发布时间：2024-03-21 01:28:04

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeGovernanceServiceContracts](https://cloud.tencent.com/document/api/1364/104402)

	* <font color="#dd0000">**修改入参**：</font>Offset, Limit


### 第 61 次发布

发布时间：2024-03-15 14:54:19

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateConfigFile](https://cloud.tencent.com/document/api/1364/104363)
* [CreateConfigFileGroup](https://cloud.tencent.com/document/api/1364/104368)
* [CreateGovernanceAlias](https://cloud.tencent.com/document/api/1364/104385)
* [CreateGovernanceNamespaces](https://cloud.tencent.com/document/api/1364/104408)
* [CreateGovernanceServices](https://cloud.tencent.com/document/api/1364/104384)
* [CreateOrUpdateConfigFileAndRelease](https://cloud.tencent.com/document/api/1364/104362)
* [DeleteConfigFileGroup](https://cloud.tencent.com/document/api/1364/104367)
* [DeleteConfigFileReleases](https://cloud.tencent.com/document/api/1364/104361)
* [DeleteConfigFiles](https://cloud.tencent.com/document/api/1364/104360)
* [DeleteGovernanceAliases](https://cloud.tencent.com/document/api/1364/104383)
* [DeleteGovernanceInstancesByHost](https://cloud.tencent.com/document/api/1364/104400)
* [DeleteGovernanceNamespaces](https://cloud.tencent.com/document/api/1364/104407)
* [DeleteGovernanceServices](https://cloud.tencent.com/document/api/1364/104382)
* [DescribeAllConfigFileTemplates](https://cloud.tencent.com/document/api/1364/104348)
* [DescribeConfigFile](https://cloud.tencent.com/document/api/1364/104359)
* [DescribeConfigFileGroups](https://cloud.tencent.com/document/api/1364/104366)
* [DescribeConfigFileRelease](https://cloud.tencent.com/document/api/1364/104358)
* [DescribeConfigFileReleaseHistories](https://cloud.tencent.com/document/api/1364/104357)
* [DescribeConfigFileReleaseVersions](https://cloud.tencent.com/document/api/1364/104356)
* [DescribeConfigFileReleases](https://cloud.tencent.com/document/api/1364/104355)
* [DescribeConfigFiles](https://cloud.tencent.com/document/api/1364/104354)
* [DescribeConfigFilesByGroup](https://cloud.tencent.com/document/api/1364/104353)
* [DescribeGovernanceAliases](https://cloud.tencent.com/document/api/1364/104381)
* [DescribeGovernanceNamespaces](https://cloud.tencent.com/document/api/1364/104406)
* [DescribeGovernanceServiceContractVersions](https://cloud.tencent.com/document/api/1364/104403)
* [DescribeGovernanceServiceContracts](https://cloud.tencent.com/document/api/1364/104402)
* [DescribeGovernanceServices](https://cloud.tencent.com/document/api/1364/104380)
* [ModifyConfigFileGroup](https://cloud.tencent.com/document/api/1364/104365)
* [ModifyConfigFiles](https://cloud.tencent.com/document/api/1364/104352)
* [ModifyGovernanceAlias](https://cloud.tencent.com/document/api/1364/104379)
* [ModifyGovernanceNamespaces](https://cloud.tencent.com/document/api/1364/104405)
* [ModifyGovernanceServices](https://cloud.tencent.com/document/api/1364/104378)
* [PublishConfigFiles](https://cloud.tencent.com/document/api/1364/104351)
* [RollbackConfigFileReleases](https://cloud.tencent.com/document/api/1364/104350)

新增数据结构：

* [ConfigFile](https://cloud.tencent.com/document/api/1364/54942#ConfigFile)
* [ConfigFileGroup](https://cloud.tencent.com/document/api/1364/54942#ConfigFileGroup)
* [ConfigFileGroupTag](https://cloud.tencent.com/document/api/1364/54942#ConfigFileGroupTag)
* [ConfigFilePublishInfo](https://cloud.tencent.com/document/api/1364/54942#ConfigFilePublishInfo)
* [ConfigFileRelease](https://cloud.tencent.com/document/api/1364/54942#ConfigFileRelease)
* [ConfigFileReleaseDeletion](https://cloud.tencent.com/document/api/1364/54942#ConfigFileReleaseDeletion)
* [ConfigFileReleaseHistory](https://cloud.tencent.com/document/api/1364/54942#ConfigFileReleaseHistory)
* [ConfigFileTag](https://cloud.tencent.com/document/api/1364/54942#ConfigFileTag)
* [ConfigFileTemplate](https://cloud.tencent.com/document/api/1364/54942#ConfigFileTemplate)
* [GovernanceAlias](https://cloud.tencent.com/document/api/1364/54942#GovernanceAlias)
* [GovernanceInterfaceDescription](https://cloud.tencent.com/document/api/1364/54942#GovernanceInterfaceDescription)
* [GovernanceNamespace](https://cloud.tencent.com/document/api/1364/54942#GovernanceNamespace)
* [GovernanceNamespaceInput](https://cloud.tencent.com/document/api/1364/54942#GovernanceNamespaceInput)
* [GovernanceService](https://cloud.tencent.com/document/api/1364/54942#GovernanceService)
* [GovernanceServiceContract](https://cloud.tencent.com/document/api/1364/54942#GovernanceServiceContract)
* [GovernanceServiceContractVersion](https://cloud.tencent.com/document/api/1364/54942#GovernanceServiceContractVersion)
* [GovernanceServiceInput](https://cloud.tencent.com/document/api/1364/54942#GovernanceServiceInput)
* [ReleaseVersion](https://cloud.tencent.com/document/api/1364/54942#ReleaseVersion)

修改数据结构：

* [GovernanceInstance](https://cloud.tencent.com/document/api/1364/54942#GovernanceInstance)

	* 新增成员：InstanceVersion, HealthStatus, Comment


### 第 60 次发布

发布时间：2024-03-12 01:59:06

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [GovernanceInstanceUpdate](https://cloud.tencent.com/document/api/1364/54942#GovernanceInstanceUpdate)

	* <font color="#dd0000">**修改成员**：</font>Id


### 第 59 次发布

发布时间：2024-03-07 01:27:04

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [KongUpstreamInfo](https://cloud.tencent.com/document/api/1364/54942#KongUpstreamInfo)

	* 新增成员：ScfCamAuthEnable

* [UpstreamHealthCheckConfig](https://cloud.tencent.com/document/api/1364/54942#UpstreamHealthCheckConfig)

	* 新增成员：IgnoreZeroWeightNodes


### 第 58 次发布

发布时间：2024-03-04 01:26:55

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateGovernanceInstances](https://cloud.tencent.com/document/api/1364/104069)
* [DeleteGovernanceInstances](https://cloud.tencent.com/document/api/1364/104068)
* [DescribeGovernanceInstances](https://cloud.tencent.com/document/api/1364/104399)
* [ModifyGovernanceInstances](https://cloud.tencent.com/document/api/1364/104066)

新增数据结构：

* [GovernanceInstance](https://cloud.tencent.com/document/api/1364/54942#GovernanceInstance)
* [GovernanceInstanceInput](https://cloud.tencent.com/document/api/1364/54942#GovernanceInstanceInput)
* [GovernanceInstanceUpdate](https://cloud.tencent.com/document/api/1364/54942#GovernanceInstanceUpdate)
* [Metadata](https://cloud.tencent.com/document/api/1364/54942#Metadata)

### 第 57 次发布

发布时间：2024-02-02 01:24:40

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [BindAutoScalerResourceStrategyToGroups](https://cloud.tencent.com/document/api/1364/103728)
* [CreateAutoScalerResourceStrategy](https://cloud.tencent.com/document/api/1364/103727)
* [DeleteAutoScalerResourceStrategy](https://cloud.tencent.com/document/api/1364/103726)
* [DescribeAutoScalerResourceStrategies](https://cloud.tencent.com/document/api/1364/103725)
* [DescribeAutoScalerResourceStrategyBindingGroups](https://cloud.tencent.com/document/api/1364/103724)
* [DescribePublicNetwork](https://cloud.tencent.com/document/api/1364/103723)
* [ModifyAutoScalerResourceStrategy](https://cloud.tencent.com/document/api/1364/103722)
* [UnbindAutoScalerResourceStrategyFromGroups](https://cloud.tencent.com/document/api/1364/103721)

新增数据结构：

* [CloudNativeAPIGatewayStrategyBindingGroupInfo](https://cloud.tencent.com/document/api/1364/54942#CloudNativeAPIGatewayStrategyBindingGroupInfo)
* [DescribePublicNetworkResult](https://cloud.tencent.com/document/api/1364/54942#DescribePublicNetworkResult)
* [ListCloudNativeAPIGatewayStrategyBindingGroupInfoResult](https://cloud.tencent.com/document/api/1364/54942#ListCloudNativeAPIGatewayStrategyBindingGroupInfoResult)
* [ListCloudNativeAPIGatewayStrategyResult](https://cloud.tencent.com/document/api/1364/54942#ListCloudNativeAPIGatewayStrategyResult)

### 第 56 次发布

发布时间：2024-01-31 01:25:54

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateCloudNativeAPIGatewayPublicNetwork](https://cloud.tencent.com/document/api/1364/102778)

	* 新增出参：Result


新增数据结构：

* [CreatePublicNetworkResult](https://cloud.tencent.com/document/api/1364/54942#CreatePublicNetworkResult)

修改数据结构：

* [CloudNativeAPIGatewayStrategyAutoScalerConfig](https://cloud.tencent.com/document/api/1364/54942#CloudNativeAPIGatewayStrategyAutoScalerConfig)

* [CloudNativeAPIGatewayStrategyCronScalerConfig](https://cloud.tencent.com/document/api/1364/54942#CloudNativeAPIGatewayStrategyCronScalerConfig)


### 第 55 次发布

发布时间：2023-12-29 01:27:46

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateCloudNativeAPIGatewayPublicNetwork](https://cloud.tencent.com/document/api/1364/102778)
* [DeleteCloudNativeAPIGatewayPublicNetwork](https://cloud.tencent.com/document/api/1364/102777)
* [ModifyConsoleNetwork](https://cloud.tencent.com/document/api/1364/102776)
* [ModifyNetworkAccessStrategy](https://cloud.tencent.com/document/api/1364/102775)
* [ModifyNetworkBasicInfo](https://cloud.tencent.com/document/api/1364/102774)

### 第 54 次发布

发布时间：2023-11-23 01:30:34

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DeleteWafDomains](https://cloud.tencent.com/document/api/1364/101828)
* [DescribeWafDomains](https://cloud.tencent.com/document/api/1364/101827)
* [DescribeWafProtection](https://cloud.tencent.com/document/api/1364/101826)

新增数据结构：

* [DescribeWafDomainsResult](https://cloud.tencent.com/document/api/1364/54942#DescribeWafDomainsResult)
* [DescribeWafProtectionResult](https://cloud.tencent.com/document/api/1364/54942#DescribeWafProtectionResult)
* [RouteWafStatus](https://cloud.tencent.com/document/api/1364/54942#RouteWafStatus)
* [ServiceWafStatus](https://cloud.tencent.com/document/api/1364/54942#ServiceWafStatus)

### 第 53 次发布

发布时间：2023-11-22 07:09:30

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CloseWafProtection](https://cloud.tencent.com/document/api/1364/101822)
* [CreateWafDomains](https://cloud.tencent.com/document/api/1364/101821)
* [OpenWafProtection](https://cloud.tencent.com/document/api/1364/101820)

### 第 52 次发布

发布时间：2023-11-21 01:38:30

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [KongTarget](https://cloud.tencent.com/document/api/1364/54942#KongTarget)

	* 新增成员：CvmInstanceId, CvmInstanceName

* [SREInstance](https://cloud.tencent.com/document/api/1364/54942#SREInstance)

	* <font color="#dd0000">**修改成员**：</font>FeatureVersion, EnableClientIntranet, StorageOption


### 第 51 次发布

发布时间：2023-11-15 02:34:06

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeCloudNativeAPIGatewayUpstream](https://cloud.tencent.com/document/api/1364/101586)
* [DescribeUpstreamHealthCheckConfig](https://cloud.tencent.com/document/api/1364/101585)
* [ModifyUpstreamNodeStatus](https://cloud.tencent.com/document/api/1364/101584)
* [UpdateUpstreamHealthCheckConfig](https://cloud.tencent.com/document/api/1364/101583)

新增数据结构：

* [KongActiveHealthCheck](https://cloud.tencent.com/document/api/1364/54942#KongActiveHealthCheck)
* [KongPassiveHealthCheck](https://cloud.tencent.com/document/api/1364/54942#KongPassiveHealthCheck)
* [KongUpstreamList](https://cloud.tencent.com/document/api/1364/54942#KongUpstreamList)
* [KongUpstreamPreview](https://cloud.tencent.com/document/api/1364/54942#KongUpstreamPreview)
* [UpstreamHealthCheckConfig](https://cloud.tencent.com/document/api/1364/54942#UpstreamHealthCheckConfig)

### 第 50 次发布

发布时间：2023-10-20 01:26:31

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [InstancePort](https://cloud.tencent.com/document/api/1364/54942#InstancePort)

	* 新增成员：TcpPort, UdpPort


### 第 49 次发布

发布时间：2023-10-19 16:21:31

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [UpdateUpstreamTargets](https://cloud.tencent.com/document/api/1364/100461)

修改接口：

* [CreateCloudNativeAPIGatewayService](https://cloud.tencent.com/document/api/1364/94851)

	* 新增出参：Result


新增数据结构：

* [CreateGatewayServiceResult](https://cloud.tencent.com/document/api/1364/54942#CreateGatewayServiceResult)

修改数据结构：

* [CloudNativeAPIGatewayConfig](https://cloud.tencent.com/document/api/1364/54942#CloudNativeAPIGatewayConfig)

	* 新增成员：SlaName


### 第 48 次发布

发布时间：2023-10-17 01:29:39

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeSREInstanceAccessAddress](https://cloud.tencent.com/document/api/1364/54941)

	* 新增出参：CLBMultiRegion


新增数据结构：

* [CLBMultiRegion](https://cloud.tencent.com/document/api/1364/54942#CLBMultiRegion)
* [PolarisCLSTopicInfo](https://cloud.tencent.com/document/api/1364/54942#PolarisCLSTopicInfo)
* [StorageOption](https://cloud.tencent.com/document/api/1364/54942#StorageOption)

修改数据结构：

* [BoundK8SInfo](https://cloud.tencent.com/document/api/1364/54942#BoundK8SInfo)

	* 新增成员：BindRegion

* [DescribeInstanceRegionInfo](https://cloud.tencent.com/document/api/1364/54942#DescribeInstanceRegionInfo)

	* 新增成员：ConsoleIntranetVpcInfos, LimiterIntranetVpcInfos, MainRegion, EKSClusterID

* [EngineRegionInfo](https://cloud.tencent.com/document/api/1364/54942#EngineRegionInfo)

	* 新增成员：MainRegion, SpecId

* [EnvAddressInfo](https://cloud.tencent.com/document/api/1364/54942#EnvAddressInfo)

	* 新增成员：CLBMultiRegion

	* <font color="#dd0000">**修改成员**：</font>EnableConfigIntranet, InternetBandWidth

* [SREInstance](https://cloud.tencent.com/document/api/1364/54942#SREInstance)

	* 新增成员：StorageOption

* [ServiceGovernanceInfo](https://cloud.tencent.com/document/api/1364/54942#ServiceGovernanceInfo)

	* 新增成员：CLSTopics


### 第 47 次发布

发布时间：2023-10-13 01:27:15

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [ModifyCloudNativeAPIGatewayCertificate](https://cloud.tencent.com/document/api/1364/100199)

### 第 46 次发布

发布时间：2023-09-26 01:34:02

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [KongUpstreamInfo](https://cloud.tencent.com/document/api/1364/54942#KongUpstreamInfo)

	* 新增成员：HealthStatus


### 第 45 次发布

发布时间：2023-09-25 01:28:54

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateCloudNativeAPIGatewayCertificate](https://cloud.tencent.com/document/api/1364/98591)


### 第 44 次发布

发布时间：2023-09-18 02:36:04

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateCloudNativeAPIGatewayCertificate](https://cloud.tencent.com/document/api/1364/98591)
* [DeleteCloudNativeAPIGatewayCertificate](https://cloud.tencent.com/document/api/1364/98590)
* [DescribeCloudNativeAPIGatewayCertificateDetails](https://cloud.tencent.com/document/api/1364/98589)
* [DescribeCloudNativeAPIGatewayCertificates](https://cloud.tencent.com/document/api/1364/98588)
* [UpdateCloudNativeAPIGatewayCertificateInfo](https://cloud.tencent.com/document/api/1364/98587)

新增数据结构：

* [CertificateInfo](https://cloud.tencent.com/document/api/1364/54942#CertificateInfo)
* [KongCertificate](https://cloud.tencent.com/document/api/1364/54942#KongCertificate)
* [KongCertificatesList](https://cloud.tencent.com/document/api/1364/54942#KongCertificatesList)
* [KongCertificatesPreview](https://cloud.tencent.com/document/api/1364/54942#KongCertificatesPreview)

### 第 43 次发布

发布时间：2023-09-14 02:35:41

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeCloudNativeAPIGatewayConfig](https://cloud.tencent.com/document/api/1364/98203)

新增数据结构：

* [CloudNativeAPIGatewayConfig](https://cloud.tencent.com/document/api/1364/54942#CloudNativeAPIGatewayConfig)
* [DescribeCloudNativeAPIGatewayConfigResult](https://cloud.tencent.com/document/api/1364/54942#DescribeCloudNativeAPIGatewayConfigResult)
* [NetworkAccessControl](https://cloud.tencent.com/document/api/1364/54942#NetworkAccessControl)

### 第 42 次发布

发布时间：2023-09-06 02:36:56

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [KongServicePreview](https://cloud.tencent.com/document/api/1364/54942#KongServicePreview)

	* 新增成员：Path


### 第 41 次发布

发布时间：2023-09-01 01:25:13

本次发布包含了以下内容：

改善已有的文档。

新增数据结构：

* [AutoScalerBehavior](https://cloud.tencent.com/document/api/1364/54942#AutoScalerBehavior)
* [AutoScalerPolicy](https://cloud.tencent.com/document/api/1364/54942#AutoScalerPolicy)
* [AutoScalerRules](https://cloud.tencent.com/document/api/1364/54942#AutoScalerRules)

修改数据结构：

* [CloudNativeAPIGatewayStrategy](https://cloud.tencent.com/document/api/1364/54942#CloudNativeAPIGatewayStrategy)

	* <font color="#dd0000">**修改成员**：</font>CronConfig, MaxReplicas

* [CloudNativeAPIGatewayStrategyAutoScalerConfig](https://cloud.tencent.com/document/api/1364/54942#CloudNativeAPIGatewayStrategyAutoScalerConfig)

	* 新增成员：Behavior

* [CloudNativeAPIGatewayStrategyCronScalerConfig](https://cloud.tencent.com/document/api/1364/54942#CloudNativeAPIGatewayStrategyCronScalerConfig)


### 第 40 次发布

发布时间：2023-08-25 02:19:29

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeNativeGatewayServerGroups](https://cloud.tencent.com/document/api/1364/97280)

新增数据结构：

* [CloudNativeAPIGatewayStrategy](https://cloud.tencent.com/document/api/1364/54942#CloudNativeAPIGatewayStrategy)
* [CloudNativeAPIGatewayStrategyAutoScalerConfig](https://cloud.tencent.com/document/api/1364/54942#CloudNativeAPIGatewayStrategyAutoScalerConfig)
* [CloudNativeAPIGatewayStrategyAutoScalerConfigMetric](https://cloud.tencent.com/document/api/1364/54942#CloudNativeAPIGatewayStrategyAutoScalerConfigMetric)
* [CloudNativeAPIGatewayStrategyCronScalerConfig](https://cloud.tencent.com/document/api/1364/54942#CloudNativeAPIGatewayStrategyCronScalerConfig)
* [CloudNativeAPIGatewayStrategyCronScalerConfigParam](https://cloud.tencent.com/document/api/1364/54942#CloudNativeAPIGatewayStrategyCronScalerConfigParam)
* [NativeGatewayServerGroup](https://cloud.tencent.com/document/api/1364/54942#NativeGatewayServerGroup)
* [NativeGatewayServerGroups](https://cloud.tencent.com/document/api/1364/54942#NativeGatewayServerGroups)

### 第 39 次发布

发布时间：2023-08-21 01:19:32

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateCloudNativeAPIGateway](https://cloud.tencent.com/document/api/1364/96757)
* [CreateNativeGatewayServerGroup](https://cloud.tencent.com/document/api/1364/96756)
* [DeleteCloudNativeAPIGateway](https://cloud.tencent.com/document/api/1364/96755)
* [DeleteNativeGatewayServerGroup](https://cloud.tencent.com/document/api/1364/96754)
* [DescribeCloudNativeAPIGateway](https://cloud.tencent.com/document/api/1364/96753)
* [DescribeCloudNativeAPIGateways](https://cloud.tencent.com/document/api/1364/96752)
* [ModifyCloudNativeAPIGateway](https://cloud.tencent.com/document/api/1364/96751)
* [ModifyNativeGatewayServerGroup](https://cloud.tencent.com/document/api/1364/96750)
* [UpdateCloudNativeAPIGatewaySpec](https://cloud.tencent.com/document/api/1364/96749)

新增数据结构：

* [CloudNativeAPIGatewayNodeConfig](https://cloud.tencent.com/document/api/1364/54942#CloudNativeAPIGatewayNodeConfig)
* [CloudNativeAPIGatewayVpcConfig](https://cloud.tencent.com/document/api/1364/54942#CloudNativeAPIGatewayVpcConfig)
* [CreateCloudNativeAPIGatewayResult](https://cloud.tencent.com/document/api/1364/54942#CreateCloudNativeAPIGatewayResult)
* [CreateCloudNativeAPIGatewayServerGroupResult](https://cloud.tencent.com/document/api/1364/54942#CreateCloudNativeAPIGatewayServerGroupResult)
* [DeleteCloudNativeAPIGatewayResult](https://cloud.tencent.com/document/api/1364/54942#DeleteCloudNativeAPIGatewayResult)
* [DeleteNativeGatewayServerGroupResult](https://cloud.tencent.com/document/api/1364/54942#DeleteNativeGatewayServerGroupResult)
* [DescribeCloudNativeAPIGatewayResult](https://cloud.tencent.com/document/api/1364/54942#DescribeCloudNativeAPIGatewayResult)
* [InstancePort](https://cloud.tencent.com/document/api/1364/54942#InstancePort)
* [InternetConfig](https://cloud.tencent.com/document/api/1364/54942#InternetConfig)
* [ListCloudNativeAPIGatewayResult](https://cloud.tencent.com/document/api/1364/54942#ListCloudNativeAPIGatewayResult)
* [UpdateCloudNativeAPIGatewayResult](https://cloud.tencent.com/document/api/1364/54942#UpdateCloudNativeAPIGatewayResult)

### 第 38 次发布

发布时间：2023-08-11 01:44:23

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [KongRoutePreview](https://cloud.tencent.com/document/api/1364/54942#KongRoutePreview)

	* <font color="#dd0000">**修改成员**：</font>Headers


### 第 37 次发布

发布时间：2023-08-07 01:19:09

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [KongRoutePreview](https://cloud.tencent.com/document/api/1364/54942#KongRoutePreview)


### 第 36 次发布

发布时间：2023-07-19 01:46:53

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeCloudNativeAPIGatewayPorts](https://cloud.tencent.com/document/api/1364/95139)

新增数据结构：

* [DescribeGatewayInstancePortResult](https://cloud.tencent.com/document/api/1364/54942#DescribeGatewayInstancePortResult)
* [GatewayInstanceSchemeAndPorts](https://cloud.tencent.com/document/api/1364/54942#GatewayInstanceSchemeAndPorts)

### 第 35 次发布

发布时间：2023-07-10 01:52:00

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateCloudNativeAPIGatewayCanaryRule](https://cloud.tencent.com/document/api/1364/94854)
* [CreateCloudNativeAPIGatewayRoute](https://cloud.tencent.com/document/api/1364/94853)
* [CreateCloudNativeAPIGatewayRouteRateLimit](https://cloud.tencent.com/document/api/1364/94852)
* [CreateCloudNativeAPIGatewayService](https://cloud.tencent.com/document/api/1364/94851)
* [CreateCloudNativeAPIGatewayServiceRateLimit](https://cloud.tencent.com/document/api/1364/94850)
* [DeleteCloudNativeAPIGatewayCanaryRule](https://cloud.tencent.com/document/api/1364/94849)
* [DeleteCloudNativeAPIGatewayRoute](https://cloud.tencent.com/document/api/1364/94848)
* [DeleteCloudNativeAPIGatewayRouteRateLimit](https://cloud.tencent.com/document/api/1364/94847)
* [DeleteCloudNativeAPIGatewayService](https://cloud.tencent.com/document/api/1364/94846)
* [DeleteCloudNativeAPIGatewayServiceRateLimit](https://cloud.tencent.com/document/api/1364/94845)
* [DescribeCloudNativeAPIGatewayCanaryRules](https://cloud.tencent.com/document/api/1364/94844)
* [DescribeCloudNativeAPIGatewayRouteRateLimit](https://cloud.tencent.com/document/api/1364/94843)
* [DescribeCloudNativeAPIGatewayRoutes](https://cloud.tencent.com/document/api/1364/94842)
* [DescribeCloudNativeAPIGatewayServiceRateLimit](https://cloud.tencent.com/document/api/1364/94841)
* [DescribeCloudNativeAPIGatewayServices](https://cloud.tencent.com/document/api/1364/94840)
* [DescribeOneCloudNativeAPIGatewayService](https://cloud.tencent.com/document/api/1364/94839)
* [ModifyCloudNativeAPIGatewayCanaryRule](https://cloud.tencent.com/document/api/1364/94838)
* [ModifyCloudNativeAPIGatewayRoute](https://cloud.tencent.com/document/api/1364/94837)
* [ModifyCloudNativeAPIGatewayRouteRateLimit](https://cloud.tencent.com/document/api/1364/94836)
* [ModifyCloudNativeAPIGatewayService](https://cloud.tencent.com/document/api/1364/94835)
* [ModifyCloudNativeAPIGatewayServiceRateLimit](https://cloud.tencent.com/document/api/1364/94834)

新增数据结构：

* [CloudAPIGatewayCanaryRuleList](https://cloud.tencent.com/document/api/1364/54942#CloudAPIGatewayCanaryRuleList)
* [CloudNativeAPIGatewayBalancedService](https://cloud.tencent.com/document/api/1364/54942#CloudNativeAPIGatewayBalancedService)
* [CloudNativeAPIGatewayCanaryRule](https://cloud.tencent.com/document/api/1364/54942#CloudNativeAPIGatewayCanaryRule)
* [CloudNativeAPIGatewayCanaryRuleCondition](https://cloud.tencent.com/document/api/1364/54942#CloudNativeAPIGatewayCanaryRuleCondition)
* [CloudNativeAPIGatewayRateLimitDetail](https://cloud.tencent.com/document/api/1364/54942#CloudNativeAPIGatewayRateLimitDetail)
* [ExternalRedis](https://cloud.tencent.com/document/api/1364/54942#ExternalRedis)
* [KVMapping](https://cloud.tencent.com/document/api/1364/54942#KVMapping)
* [KongRoutePreview](https://cloud.tencent.com/document/api/1364/54942#KongRoutePreview)
* [KongServiceDetail](https://cloud.tencent.com/document/api/1364/54942#KongServiceDetail)
* [KongServicePreview](https://cloud.tencent.com/document/api/1364/54942#KongServicePreview)
* [KongServiceRouteList](https://cloud.tencent.com/document/api/1364/54942#KongServiceRouteList)
* [KongServices](https://cloud.tencent.com/document/api/1364/54942#KongServices)
* [KongTarget](https://cloud.tencent.com/document/api/1364/54942#KongTarget)
* [KongUpstreamInfo](https://cloud.tencent.com/document/api/1364/54942#KongUpstreamInfo)
* [ListFilter](https://cloud.tencent.com/document/api/1364/54942#ListFilter)
* [QpsThreshold](https://cloud.tencent.com/document/api/1364/54942#QpsThreshold)
* [RateLimitResponse](https://cloud.tencent.com/document/api/1364/54942#RateLimitResponse)

### 第 34 次发布

发布时间：2023-05-16 02:36:35

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [EnvInfo](https://cloud.tencent.com/document/api/1364/54942#EnvInfo)

	* 新增成员：EnableConfigIntranet


### 第 33 次发布

发布时间：2023-03-30 02:46:07

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [CloudNativeAPIGatewayNode](https://cloud.tencent.com/document/api/1364/54942#CloudNativeAPIGatewayNode)

	* 新增成员：ZoneId, Zone, GroupId, GroupName, Status


### 第 32 次发布

发布时间：2023-03-07 01:56:08

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateEngine](https://cloud.tencent.com/document/api/1364/75218)

	* 新增入参：EngineRegionInfos


新增数据结构：

* [EngineRegionInfo](https://cloud.tencent.com/document/api/1364/54942#EngineRegionInfo)

### 第 31 次发布

发布时间：2023-02-24 01:39:04

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [EnvAddressInfo](https://cloud.tencent.com/document/api/1364/54942#EnvAddressInfo)

	* 新增成员：InternetBandWidth

* [NacosReplica](https://cloud.tencent.com/document/api/1364/54942#NacosReplica)

	* 新增成员：VpcId

* [SREInstance](https://cloud.tencent.com/document/api/1364/54942#SREInstance)

	* 新增成员：EKSType, FeatureVersion, EnableClientIntranet

* [ZookeeperReplica](https://cloud.tencent.com/document/api/1364/54942#ZookeeperReplica)

	* 新增成员：VpcId


### 第 30 次发布

发布时间：2023-02-10 02:12:51

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [ApolloEnvParam](https://cloud.tencent.com/document/api/1364/54942#ApolloEnvParam)

	* 新增成员：EnvDesc

* [EnvAddressInfo](https://cloud.tencent.com/document/api/1364/54942#EnvAddressInfo)

	* 新增成员：EnableConfigIntranet


### 第 29 次发布

发布时间：2022-10-25 07:07:46

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeSREInstanceAccessAddress](https://cloud.tencent.com/document/api/1364/54941)

	* 新增出参：LimiterAddressInfos


新增数据结构：

* [PolarisLimiterAddress](https://cloud.tencent.com/document/api/1364/54942#PolarisLimiterAddress)

修改数据结构：

* [ServiceGovernanceInfo](https://cloud.tencent.com/document/api/1364/54942#ServiceGovernanceInfo)

	* 新增成员：LimiterVpcInfos


### 第 28 次发布

发布时间：2022-10-12 07:03:55

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [UpdateEngineInternetAccess](https://cloud.tencent.com/document/api/1364/81352)

### 第 27 次发布

发布时间：2022-09-27 06:48:42

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeCloudNativeAPIGatewayNodes](https://cloud.tencent.com/document/api/1364/78800)

	* 新增入参：GroupId


### 第 26 次发布

发布时间：2022-08-24 06:56:05

本次发布包含了以下内容：

改善已有的文档。

新增数据结构：

* [DescribeInstanceRegionInfo](https://cloud.tencent.com/document/api/1364/54942#DescribeInstanceRegionInfo)

修改数据结构：

* [SREInstance](https://cloud.tencent.com/document/api/1364/54942#SREInstance)

	* 新增成员：RegionInfos


### 第 25 次发布

发布时间：2022-08-10 06:55:45

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeSREInstanceAccessAddress](https://cloud.tencent.com/document/api/1364/54941)

	* 新增入参：EngineRegion


修改数据结构：

* [ZookeeperReplica](https://cloud.tencent.com/document/api/1364/54942#ZookeeperReplica)

	* 新增成员：AliasName


### 第 24 次发布

发布时间：2022-08-09 12:30:23

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeCloudNativeAPIGatewayNodes](https://cloud.tencent.com/document/api/1364/78800)

新增数据结构：

* [CloudNativeAPIGatewayNode](https://cloud.tencent.com/document/api/1364/54942#CloudNativeAPIGatewayNode)
* [DescribeCloudNativeAPIGatewayNodesResult](https://cloud.tencent.com/document/api/1364/54942#DescribeCloudNativeAPIGatewayNodesResult)

### 第 23 次发布

发布时间：2022-07-19 06:20:45

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [EnvInfo](https://cloud.tencent.com/document/api/1364/54942#EnvInfo)

	* 新增成员：EnvDesc, ClientBandWidth


### 第 22 次发布

发布时间：2022-07-12 06:19:15

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeSREInstanceAccessAddress](https://cloud.tencent.com/document/api/1364/54941)

	* 新增入参：Workload


修改数据结构：

* [EnvAddressInfo](https://cloud.tencent.com/document/api/1364/54942#EnvAddressInfo)

	* 新增成员：ConfigIntranetAddress

* [ServiceGovernanceInfo](https://cloud.tencent.com/document/api/1364/54942#ServiceGovernanceInfo)

	* 新增成员：PgwVpcInfos


### 第 21 次发布

发布时间：2022-06-28 06:18:34

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeNacosReplicas](https://cloud.tencent.com/document/api/1364/76101)
* [DescribeNacosServerInterfaces](https://cloud.tencent.com/document/api/1364/76100)
* [DescribeZookeeperReplicas](https://cloud.tencent.com/document/api/1364/76099)
* [DescribeZookeeperServerInterfaces](https://cloud.tencent.com/document/api/1364/76098)

新增数据结构：

* [NacosReplica](https://cloud.tencent.com/document/api/1364/54942#NacosReplica)
* [NacosServerInterface](https://cloud.tencent.com/document/api/1364/54942#NacosServerInterface)
* [ZookeeperReplica](https://cloud.tencent.com/document/api/1364/54942#ZookeeperReplica)
* [ZookeeperServerInterface](https://cloud.tencent.com/document/api/1364/54942#ZookeeperServerInterface)

### 第 20 次发布

发布时间：2022-06-10 06:15:33

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateEngine](https://cloud.tencent.com/document/api/1364/75218)
* [DeleteEngine](https://cloud.tencent.com/document/api/1364/75217)

新增数据结构：

* [ApolloEnvParam](https://cloud.tencent.com/document/api/1364/54942#ApolloEnvParam)
* [EngineAdmin](https://cloud.tencent.com/document/api/1364/54942#EngineAdmin)
* [InstanceTagInfo](https://cloud.tencent.com/document/api/1364/54942#InstanceTagInfo)

### 第 19 次发布

发布时间：2022-06-02 06:16:18

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [EnvInfo](https://cloud.tencent.com/document/api/1364/54942#EnvInfo)

	* 新增成员：AliasEnvName


### 第 18 次发布

发布时间：2022-04-22 06:17:09

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeSREInstanceAccessAddress](https://cloud.tencent.com/document/api/1364/54941)

	* 新增出参：InternetBandWidth, ConsoleInternetBandWidth


修改数据结构：

* [SREInstance](https://cloud.tencent.com/document/api/1364/54942#SREInstance)

	* 新增成员：TradeType, AutoRenewFlag, CurDeadline, IsolateTime


### 第 17 次发布

发布时间：2022-03-29 08:17:32

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [BoundK8SInfo](https://cloud.tencent.com/document/api/1364/54942#BoundK8SInfo)

	* 新增成员：SyncMode

* [SREInstance](https://cloud.tencent.com/document/api/1364/54942#SREInstance)

	* 新增成员：ConsoleDefaultPwd

* [ServiceGovernanceInfo](https://cloud.tencent.com/document/api/1364/54942#ServiceGovernanceInfo)

	* 新增成员：MainPassword


### 第 16 次发布

发布时间：2022-03-15 08:16:57

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [SREInstance](https://cloud.tencent.com/document/api/1364/54942#SREInstance)

	* 新增成员：ConfigInfoVisible


### 第 15 次发布

发布时间：2022-03-08 08:20:05

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [EnvInfo](https://cloud.tencent.com/document/api/1364/54942#EnvInfo)

	* 新增成员：SpecId, EnvReplica, RunningCount


### 第 14 次发布

发布时间：2022-02-18 08:16:25

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [ServiceGovernanceInfo](https://cloud.tencent.com/document/api/1364/54942#ServiceGovernanceInfo)

	* 新增成员：AuthOpen, Features


### 第 13 次发布

发布时间：2021-12-14 08:16:15

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeSREInstances](https://cloud.tencent.com/document/api/1364/54940)

	* 新增入参：QuerySource


### 第 12 次发布

发布时间：2021-11-16 08:15:49

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeSREInstanceAccessAddress](https://cloud.tencent.com/document/api/1364/54941)

	* 新增出参：ConsoleInternetAddress, ConsoleIntranetAddress


修改数据结构：

* [SREInstance](https://cloud.tencent.com/document/api/1364/54942#SREInstance)

	* 新增成员：EnableConsoleInternet, EnableConsoleIntranet


### 第 11 次发布

发布时间：2021-10-27 08:12:44

本次发布包含了以下内容：

改善已有的文档。

新增数据结构：

* [KVPair](https://cloud.tencent.com/document/api/1364/54942#KVPair)

修改数据结构：

* [SREInstance](https://cloud.tencent.com/document/api/1364/54942#SREInstance)

	* 新增成员：Tags


### 第 10 次发布

发布时间：2021-09-07 08:00:46

本次发布包含了以下内容：

改善已有的文档。

新增数据结构：

* [BoundK8SInfo](https://cloud.tencent.com/document/api/1364/54942#BoundK8SInfo)
* [ServiceGovernanceInfo](https://cloud.tencent.com/document/api/1364/54942#ServiceGovernanceInfo)

修改数据结构：

* [SREInstance](https://cloud.tencent.com/document/api/1364/54942#SREInstance)

	* 新增成员：ServiceGovernanceInfos


### 第 9 次发布

发布时间：2021-08-19 08:00:53

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeSREInstanceAccessAddress](https://cloud.tencent.com/document/api/1364/54941)

	* 新增入参：VpcId, SubnetId


修改数据结构：

* [SREInstance](https://cloud.tencent.com/document/api/1364/54942#SREInstance)

	* 新增成员：VpcInfos

* [VpcInfo](https://cloud.tencent.com/document/api/1364/54942#VpcInfo)

	* 新增成员：IntranetAddress


### 第 8 次发布

发布时间：2021-07-29 08:00:49

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeSREInstanceAccessAddress](https://cloud.tencent.com/document/api/1364/54941)

	* 新增出参：EnvAddressInfos


新增数据结构：

* [EnvAddressInfo](https://cloud.tencent.com/document/api/1364/54942#EnvAddressInfo)

修改数据结构：

* [EnvInfo](https://cloud.tencent.com/document/api/1364/54942#EnvInfo)

	* 新增成员：EnableConfigInternet, ConfigInternetServiceIp

* [SREInstance](https://cloud.tencent.com/document/api/1364/54942#SREInstance)

	* 新增成员：EngineRegion, EnableInternet


### 第 7 次发布

发布时间：2021-07-23 11:13:31

本次发布包含了以下内容：

改善已有的文档。

<font color="#dd0000">**删除接口**：</font>

* DescribeConfig
* ManageConfig

### 第 6 次发布

发布时间：2021-07-09 08:00:45

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeSREInstances](https://cloud.tencent.com/document/api/1364/54940)

	* 新增入参：QueryType


新增数据结构：

* [EnvInfo](https://cloud.tencent.com/document/api/1364/54942#EnvInfo)
* [VpcInfo](https://cloud.tencent.com/document/api/1364/54942#VpcInfo)

修改数据结构：

* [SREInstance](https://cloud.tencent.com/document/api/1364/54942#SREInstance)

	* 新增成员：EnvInfos


### 第 5 次发布

发布时间：2021-07-07 09:55:03

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeSREInstanceAccessAddress](https://cloud.tencent.com/document/api/1364/54941)

	* 新增出参：InternetAddress


### 第 4 次发布

发布时间：2021-06-21 08:00:41

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [SREInstance](https://cloud.tencent.com/document/api/1364/54942#SREInstance)

	* 新增成员：EKSClusterID, CreateTime


### 第 3 次发布

发布时间：2021-05-25 08:00:36

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeConfig](https://cloud.tencent.com/document/api/1364/56241)

修改接口：

* [ManageConfig](https://cloud.tencent.com/document/api/1364/54616)

	* 新增出参：OpResult


### 第 2 次发布

发布时间：2021-04-22 08:00:07

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeSREInstanceAccessAddress](https://cloud.tencent.com/document/api/1364/54941)
* [DescribeSREInstances](https://cloud.tencent.com/document/api/1364/54940)

新增数据结构：

* [Filter](https://cloud.tencent.com/document/api/1364/54942#Filter)
* [SREInstance](https://cloud.tencent.com/document/api/1364/54942#SREInstance)

### 第 1 次发布

发布时间：2021-04-13 08:00:03

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [ManageConfig](https://cloud.tencent.com/document/api/1364/54616)




## 微服务平台 TSF(tsf) 版本：2018-03-26

### 第 112 次发布

发布时间：2024-07-30 11:37:37

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeContainerGroups](https://cloud.tencent.com/document/api/649/36068)

	* <font color="#dd0000">**修改入参**：</font>ApplicationId


### 第 111 次发布

发布时间：2024-07-11 01:28:05

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateProgram](https://cloud.tencent.com/document/api/649/108544)
* [ModifyProgram](https://cloud.tencent.com/document/api/649/108543)

### 第 110 次发布

发布时间：2024-06-21 02:26:46

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [MsInstance](https://cloud.tencent.com/document/api/649/36099#MsInstance)

	* 新增成员：MetaJson


### 第 109 次发布

发布时间：2024-06-20 02:27:26

本次发布包含了以下内容：

改善已有的文档。

<font color="#dd0000">**预下线接口**：</font>

* DescribeApplicationBusinessLogConfig

### 第 108 次发布

发布时间：2024-06-18 02:26:44

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [FileConfigRelease](https://cloud.tencent.com/document/api/649/36099#FileConfigRelease)

	* 新增成员：ConfigCenters

	* <font color="#dd0000">**修改成员**：</font>ConfigReleaseId, ConfigId, ConfigName, ConfigVersion, ReleaseDesc, ReleaseTime, GroupId, GroupName, NamespaceId, NamespaceName, ClusterId, ClusterName

* [Instance](https://cloud.tencent.com/document/api/649/36099#Instance)

	* <font color="#dd0000">**修改成员**：</font>InstanceId, InstanceName, LanIp, WanIp, InstanceDesc, ClusterId, ClusterName, InstanceStatus, InstanceAvailableStatus, ServiceInstanceStatus, CountInTsf, GroupId, ApplicationId, ApplicationName, InstanceCreatedTime, InstanceExpiredTime, InstanceChargeType, InstanceTotalCpu, InstanceTotalMem, InstanceUsedCpu, InstanceUsedMem, InstanceLimitCpu, InstanceLimitMem, InstancePkgVersion, ClusterType, RestrictState, UpdateTime, OperationState, NamespaceId, InstanceZoneId, InstanceImportMode, ApplicationType, ApplicationResourceType, ServiceSidecarStatus, GroupName, NamespaceName, Reason, AgentVersion, NodeInstanceId


### 第 107 次发布

发布时间：2024-06-04 02:27:15

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DeleteApplication](https://cloud.tencent.com/document/api/649/36093)

	* 新增入参：SyncDeleteImageRepository

* [DescribeMicroservices](https://cloud.tencent.com/document/api/649/36084)

	* 新增入参：ConfigCenterInstanceId

* [DescribeStatistics](https://cloud.tencent.com/document/api/649/70427)

	* 新增入参：ConfigCenterInstanceId


修改数据结构：

* [ConfigRelease](https://cloud.tencent.com/document/api/649/36099#ConfigRelease)

	* 新增成员：DaulStatus

* [TsfConfigCenter](https://cloud.tencent.com/document/api/649/36099#TsfConfigCenter)

	* 新增成员：CurrentVersion, TargetVersion


### 第 106 次发布

发布时间：2024-05-22 02:22:39

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DisableLaneRule](https://cloud.tencent.com/document/api/649/106511)
* [EnableLaneRule](https://cloud.tencent.com/document/api/649/106510)

### 第 105 次发布

发布时间：2024-05-07 01:28:28

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateCluster](https://cloud.tencent.com/document/api/649/36049)

	* 新增入参：EnableLogCollection

* [ModifyCluster](https://cloud.tencent.com/document/api/649/85853)

	* 新增入参：EnableLogCollection, RepairLog


修改数据结构：

* [ClusterV2](https://cloud.tencent.com/document/api/649/36099#ClusterV2)

	* 新增成员：EnableLogCollection


### 第 104 次发布

发布时间：2024-01-15 01:25:03

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [LaneInfo](https://cloud.tencent.com/document/api/649/36099#LaneInfo)

	* 新增成员：LaneGroupId

	* <font color="#dd0000">**修改成员**：</font>LaneId, LaneName, Remark, CreateTime, UpdateTime, LaneGroupList, Entrance, NamespaceIdList


### 第 103 次发布

发布时间：2024-01-05 01:28:46

本次发布包含了以下内容：

改善已有的文档。

新增数据结构：

* [BusinessLogConfigAssociatedGroup](https://cloud.tencent.com/document/api/649/36099#BusinessLogConfigAssociatedGroup)

修改数据结构：

* [BusinessLogConfig](https://cloud.tencent.com/document/api/649/36099#BusinessLogConfig)

	* 新增成员：ConfigAssociatedGroupList


### 第 102 次发布

发布时间：2023-12-29 01:28:01

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [ContainerGroupOther](https://cloud.tencent.com/document/api/649/36099#ContainerGroupOther)

	* 新增成员：LbDns


### 第 101 次发布

发布时间：2023-11-30 07:09:40

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [LaneRuleTag](https://cloud.tencent.com/document/api/649/36099#LaneRuleTag)

	* <font color="#dd0000">**修改成员**：</font>TagId, TagName, TagOperator, TagValue, LaneRuleId, CreateTime, UpdateTime


### 第 100 次发布

发布时间：2023-11-09 01:27:51

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeImageRepository](https://cloud.tencent.com/document/api/649/49526)

	* 新增入参：RepoName

* [DescribeImageTags](https://cloud.tencent.com/document/api/649/36052)

	* 新增入参：RepoName

	* <font color="#dd0000">**修改入参**：</font>ApplicationId


新增数据结构：

* [GroupContainerInfo](https://cloud.tencent.com/document/api/649/36099#GroupContainerInfo)

修改数据结构：

* [ContainerGroupDeploy](https://cloud.tencent.com/document/api/649/36099#ContainerGroupDeploy)

	* 新增成员：ContainerName, AdditionalContainerList, InternalContainerList


### 第 99 次发布

发布时间：2023-09-12 02:52:20

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeDeliveryConfigs](https://cloud.tencent.com/document/api/649/75774)

	* 新增入参：ProgramIdList, ConfigIdList

* [DescribeGatewayApis](https://cloud.tencent.com/document/api/649/63178)

	* 新增入参：ReleaseStatus

* [DescribeGroupsWithPlugin](https://cloud.tencent.com/document/api/649/53936)

	* <font color="#dd0000">**修改入参**：</font>Bound

* [DescribeLaneRules](https://cloud.tencent.com/document/api/649/44505)

	* <font color="#dd0000">**修改入参**：</font>Limit, Offset

* [DescribePluginInstances](https://cloud.tencent.com/document/api/649/53935)

	* <font color="#dd0000">**修改入参**：</font>Bound


修改数据结构：

* [GatewayPluginBoundParam](https://cloud.tencent.com/document/api/649/36099#GatewayPluginBoundParam)

	* 新增成员：MicroserviceId, GatewayInstanceId


### 第 98 次发布

发布时间：2023-08-22 01:21:52

本次发布包含了以下内容：

改善已有的文档。

新增数据结构：

* [TsfConfigCenter](https://cloud.tencent.com/document/api/649/36099#TsfConfigCenter)

修改数据结构：

* [ConfigRelease](https://cloud.tencent.com/document/api/649/36099#ConfigRelease)

	* 新增成员：ConfigCenters

* [ConfigReleaseLog](https://cloud.tencent.com/document/api/649/36099#ConfigReleaseLog)

	* 新增成员：ReleasedConfigCenter


### 第 97 次发布

发布时间：2023-08-02 01:26:52

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DeployGroup](https://cloud.tencent.com/document/api/649/36070)

	* 新增入参：EnableBatchHealthCheck


修改数据结构：

* [VmGroup](https://cloud.tencent.com/document/api/649/36099#VmGroup)

	* 新增成员：EnableBatchHealthCheck

	* <font color="#dd0000">**修改成员**：</font>GroupId, GroupName, GroupStatus, PackageId, PackageName, PackageVersion, ClusterId, ClusterName, NamespaceId, NamespaceName, ApplicationId, ApplicationName, InstanceCount, RunInstanceCount, StartupParameters, CreateTime, UpdateTime, OffInstanceCount, GroupDesc, MicroserviceType, ApplicationType, GroupResourceType, UpdatedTime, DeployDesc, UpdateType, DeployBetaEnable, DeployBatch, DeployExeMode, DeployWaitTime, EnableHealthCheck, HealthCheckSettings, PackageType, StartScript, StopScript, Alias, AgentProfileList, WarmupSetting, GatewayConfig


### 第 96 次发布

发布时间：2023-06-08 02:06:11

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [ContainerGroupOther](https://cloud.tencent.com/document/api/649/36099#ContainerGroupOther)

	* <font color="#dd0000">**修改成员**：</font>HealthCheckSettings


### 第 95 次发布

发布时间：2023-06-07 01:54:25

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeContainerGroupAttribute](https://cloud.tencent.com/document/api/649/93216)

新增数据结构：

* [ContainerGroupOther](https://cloud.tencent.com/document/api/649/36099#ContainerGroupOther)

### 第 94 次发布

发布时间：2023-05-22 02:10:28

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [UnitRuleItem](https://cloud.tencent.com/document/api/649/36099#UnitRuleItem)

	* 新增成员：ItemIndex, CreatedTime, UpdatedTime


### 第 93 次发布

发布时间：2023-05-18 02:02:22

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateUnitNamespaces](https://cloud.tencent.com/document/api/649/91139)

### 第 92 次发布

发布时间：2023-05-11 01:55:10

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DeleteGatewayApi](https://cloud.tencent.com/document/api/649/90937)

### 第 91 次发布

发布时间：2023-04-26 11:35:57

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeUnitRulesV2](https://cloud.tencent.com/document/api/649/90667)

新增数据结构：

* [TsfPageUnitRuleV2](https://cloud.tencent.com/document/api/649/36099#TsfPageUnitRuleV2)

### 第 90 次发布

发布时间：2023-04-19 01:58:00

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateConfigWithDetailResp](https://cloud.tencent.com/document/api/649/90302)
* [CreateFileConfigWithDetailResp](https://cloud.tencent.com/document/api/649/90301)

### 第 89 次发布

发布时间：2023-03-23 15:53:56

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateApiRateLimitRuleWithDetailResp](https://cloud.tencent.com/document/api/649/89211)
* [CreateConfigTemplateWithDetailResp](https://cloud.tencent.com/document/api/649/89213)
* [CreatePathRewritesWithDetailResp](https://cloud.tencent.com/document/api/649/89210)
* [CreatePublicConfigWithDetailResp](https://cloud.tencent.com/document/api/649/89207)
* [CreateUnitRuleWithDetailResp](https://cloud.tencent.com/document/api/649/89209)
* [DeleteApiRateLimitRule](https://cloud.tencent.com/document/api/649/89208)
* [DescribeResourceTaskStatus](https://cloud.tencent.com/document/api/649/89212)
* [ReleaseConfigWithDetailResp](https://cloud.tencent.com/document/api/649/89206)

新增数据结构：

* [ResourceTaskStatusResult](https://cloud.tencent.com/document/api/649/36099#ResourceTaskStatusResult)

### 第 88 次发布

发布时间：2023-02-17 06:34:04

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [ApplicationForPage](https://cloud.tencent.com/document/api/649/36099#ApplicationForPage)

	* 新增成员：IgnoreCreateImageRepository

* [ContainGroup](https://cloud.tencent.com/document/api/649/36099#ContainGroup)

	* 新增成员：UpdatedTime

* [DeliveryConfigBindGroup](https://cloud.tencent.com/document/api/649/36099#DeliveryConfigBindGroup)

	* 新增成员：KafkaVIp, KafkaAddress, KafkaVPort, Topic, LineRule, CustomRule, EnableGlobalLineRule, EnableAuth, Username, Password, KafkaInfos

* [UnitRule](https://cloud.tencent.com/document/api/649/36099#UnitRule)

	* 新增成员：CreatedTime, UpdatedTime


### 第 87 次发布

发布时间：2023-02-16 02:04:15

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [AddInstances](https://cloud.tencent.com/document/api/649/36050)

	* 新增入参：SecurityGroupIds


### 第 86 次发布

发布时间：2023-02-15 02:08:50

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [ModifyNamespace](https://cloud.tencent.com/document/api/649/85851)

	* 新增出参：Result


修改数据结构：

* [VmGroupOther](https://cloud.tencent.com/document/api/649/36099#VmGroupOther)

	* 新增成员：HealthCheckSettings


### 第 85 次发布

发布时间：2023-02-14 01:59:38

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [ImageRepository](https://cloud.tencent.com/document/api/649/36099#ImageRepository)

	* 新增成员：Public

* [KafkaDeliveryConfig](https://cloud.tencent.com/document/api/649/36099#KafkaDeliveryConfig)

	* 新增成员：KafkaAddress

* [ScalableRule](https://cloud.tencent.com/document/api/649/36099#ScalableRule)

	* 新增成员：DisableMetricAS, EnableCronAS

	* <font color="#dd0000">**修改成员**：</font>RuleId, Name, ExpandVmCountLimit, ShrinkVmCountLimit, GroupCount, Desc, Description

* [UnitNamespace](https://cloud.tencent.com/document/api/649/36099#UnitNamespace)

	* 新增成员：GatewayInstanceId, CreatedTime, UpdatedTime


### 第 84 次发布

发布时间：2023-02-13 02:17:25

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [ApiDetailInfo](https://cloud.tencent.com/document/api/649/36099#ApiDetailInfo)

	* 新增成员：RpcExt, GatewayDeployGroupId, Md5, RpcType


### 第 83 次发布

发布时间：2023-02-10 02:13:06

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DeleteFileConfig](https://cloud.tencent.com/document/api/649/86369)

修改数据结构：

* [ContainerGroupDetail](https://cloud.tencent.com/document/api/649/36099#ContainerGroupDetail)

	* 新增成员：AllowPlainYamlDeploy, IsNotEqualServiceConfig, RepoName, Alias


### 第 82 次发布

发布时间：2023-01-17 01:58:04

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateConfigTemplate](https://cloud.tencent.com/document/api/649/85861)
* [CreateMicroserviceWithDetailResp](https://cloud.tencent.com/document/api/649/85860)
* [DeleteCluster](https://cloud.tencent.com/document/api/649/85859)
* [DeleteConfigTemplate](https://cloud.tencent.com/document/api/649/85858)
* [DescribeClusters](https://cloud.tencent.com/document/api/649/85857)
* [DescribeConfigTemplate](https://cloud.tencent.com/document/api/649/85856)
* [DescribeFileConfigReleases](https://cloud.tencent.com/document/api/649/85855)
* [ModifyApplication](https://cloud.tencent.com/document/api/649/85854)
* [ModifyCluster](https://cloud.tencent.com/document/api/649/85853)
* [ModifyGroup](https://cloud.tencent.com/document/api/649/85852)
* [ModifyNamespace](https://cloud.tencent.com/document/api/649/85851)
* [RevokeFileConfig](https://cloud.tencent.com/document/api/649/85850)
* [UpdateConfigTemplate](https://cloud.tencent.com/document/api/649/85849)

新增数据结构：

* [ClusterV2](https://cloud.tencent.com/document/api/649/36099#ClusterV2)
* [ConfigTemplate](https://cloud.tencent.com/document/api/649/36099#ConfigTemplate)
* [TsfPageClusterV2](https://cloud.tencent.com/document/api/649/36099#TsfPageClusterV2)
* [TsfPageFileConfigRelease](https://cloud.tencent.com/document/api/649/36099#TsfPageFileConfigRelease)

### 第 81 次发布

发布时间：2023-01-10 01:53:48

本次发布包含了以下内容：

改善已有的文档。

新增数据结构：

* [DeliveryKafkaInfo](https://cloud.tencent.com/document/api/649/36099#DeliveryKafkaInfo)

修改数据结构：

* [ApiDetailInfo](https://cloud.tencent.com/document/api/649/36099#ApiDetailInfo)

	* 新增成员：ApiMatchType

* [KafkaDeliveryConfig](https://cloud.tencent.com/document/api/649/36099#KafkaDeliveryConfig)

	* 新增成员：EnableAuth, Username, Password, KafkaInfos, EnableGlobalLineRule, CustomRule


### 第 80 次发布

发布时间：2022-12-07 07:15:23

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateApiGroup](https://cloud.tencent.com/document/api/649/50641)

	* 新增入参：NamespaceNameKey, ServiceNameKey, NamespaceNameKeyPosition, ServiceNameKeyPosition

* [UpdateApiGroup](https://cloud.tencent.com/document/api/649/50625)

	* 新增入参：NamespaceNameKey, ServiceNameKey, NamespaceNameKeyPosition, ServiceNameKeyPosition


新增数据结构：

* [GatewayConfig](https://cloud.tencent.com/document/api/649/36099#GatewayConfig)

修改数据结构：

* [ApiGroupInfo](https://cloud.tencent.com/document/api/649/36099#ApiGroupInfo)

	* 新增成员：NamespaceNameKey, ServiceNameKey, NamespaceNameKeyPosition, ServiceNameKeyPosition

* [ContainerGroupDeploy](https://cloud.tencent.com/document/api/649/36099#ContainerGroupDeploy)

	* 新增成员：WarmupSetting, GatewayConfig

* [VmGroup](https://cloud.tencent.com/document/api/649/36099#VmGroup)

	* 新增成员：GatewayConfig

	* <font color="#dd0000">**修改成员**：</font>GroupId, GroupName, GroupStatus, PackageId, PackageName, PackageVersion, ClusterId, ClusterName, NamespaceId, NamespaceName, ApplicationId, ApplicationName, InstanceCount, RunInstanceCount, StartupParameters, CreateTime, UpdateTime, OffInstanceCount, GroupDesc, MicroserviceType, ApplicationType, GroupResourceType, UpdatedTime, DeployDesc, UpdateType, DeployBetaEnable, DeployBatch, DeployExeMode, DeployWaitTime, EnableHealthCheck, HealthCheckSettings, PackageType, StartScript, StopScript, Alias, AgentProfileList, WarmupSetting


### 第 79 次发布

发布时间：2022-10-11 07:02:55

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DeployContainerGroup](https://cloud.tencent.com/document/api/649/36071)

	* 新增入参：AgentProfileList, WarmupSetting

* [DeployGroup](https://cloud.tencent.com/document/api/649/36070)

	* 新增入参：AgentProfileList, WarmupSetting


新增数据结构：

* [AgentProfile](https://cloud.tencent.com/document/api/649/36099#AgentProfile)
* [WarmupSetting](https://cloud.tencent.com/document/api/649/36099#WarmupSetting)

修改数据结构：

* [VmGroup](https://cloud.tencent.com/document/api/649/36099#VmGroup)

	* 新增成员：AgentProfileList, WarmupSetting


### 第 78 次发布

发布时间：2022-07-27 06:18:08

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeMicroservice](https://cloud.tencent.com/document/api/649/36085)

	* 新增入参：Filters


### 第 77 次发布

发布时间：2022-07-01 06:19:44

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeBasicResourceUsage](https://cloud.tencent.com/document/api/649/48898)

	* 新增入参：All

* [DescribeStatistics](https://cloud.tencent.com/document/api/649/70427)

	* 新增入参：NamespaceIdList


修改数据结构：

* [Instance](https://cloud.tencent.com/document/api/649/36099#Instance)

	* 新增成员：NodeInstanceId

* [MetricDataSingleValue](https://cloud.tencent.com/document/api/649/36099#MetricDataSingleValue)

	* 新增成员：DailyPercent


### 第 76 次发布

发布时间：2022-06-21 06:15:54

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [AssociateBusinessLogConfig](https://cloud.tencent.com/document/api/649/75781)
* [AssociateConfigWithGroup](https://cloud.tencent.com/document/api/649/75780)
* [DescribeApplicationBusinessLogConfig](https://cloud.tencent.com/document/api/649/75779)
* [DescribeBusinessLogConfig](https://cloud.tencent.com/document/api/649/75778)
* [DescribeBusinessLogConfigs](https://cloud.tencent.com/document/api/649/75777)
* [DescribeDeliveryConfig](https://cloud.tencent.com/document/api/649/75776)
* [DescribeDeliveryConfigByGroupId](https://cloud.tencent.com/document/api/649/75775)
* [DescribeDeliveryConfigs](https://cloud.tencent.com/document/api/649/75774)
* [DescribeGroupBusinessLogConfigs](https://cloud.tencent.com/document/api/649/75773)
* [DisassociateBusinessLogConfig](https://cloud.tencent.com/document/api/649/75772)
* [DisassociateKafkaConfig](https://cloud.tencent.com/document/api/649/75771)
* [ReassociateBusinessLogConfig](https://cloud.tencent.com/document/api/649/75770)

新增数据结构：

* [BusinesLogConfigAssociatedGroup](https://cloud.tencent.com/document/api/649/36099#BusinesLogConfigAssociatedGroup)
* [BusinessLogConfig](https://cloud.tencent.com/document/api/649/36099#BusinessLogConfig)
* [BusinessLogConfigSchema](https://cloud.tencent.com/document/api/649/36099#BusinessLogConfigSchema)
* [DeliveryConfigBindGroup](https://cloud.tencent.com/document/api/649/36099#DeliveryConfigBindGroup)
* [DeliveryConfigBindGroups](https://cloud.tencent.com/document/api/649/36099#DeliveryConfigBindGroups)
* [GroupInfo](https://cloud.tencent.com/document/api/649/36099#GroupInfo)
* [KafkaDeliveryConfig](https://cloud.tencent.com/document/api/649/36099#KafkaDeliveryConfig)
* [SimpleKafkaDeliveryConfig](https://cloud.tencent.com/document/api/649/36099#SimpleKafkaDeliveryConfig)
* [TsfPageBusinessLogConfig](https://cloud.tencent.com/document/api/649/36099#TsfPageBusinessLogConfig)

### 第 75 次发布

发布时间：2022-05-16 06:16:28

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [ContainerGroupDeploy](https://cloud.tencent.com/document/api/649/36099#ContainerGroupDeploy)

	* 新增成员：RepoType


### 第 74 次发布

发布时间：2022-05-09 06:15:37

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribePrograms](https://cloud.tencent.com/document/api/649/73477)

新增数据结构：

* [PagedProgram](https://cloud.tencent.com/document/api/649/36099#PagedProgram)
* [Program](https://cloud.tencent.com/document/api/649/36099#Program)
* [ProgramItem](https://cloud.tencent.com/document/api/649/36099#ProgramItem)
* [Resource](https://cloud.tencent.com/document/api/649/36099#Resource)

### 第 73 次发布

发布时间：2022-04-28 06:19:24

本次发布包含了以下内容：

改善已有的文档。

<font color="#dd0000">**删除接口**：</font>

* CreateServerlessGroup
* DeployServerlessGroup
* DescribeServerlessGroup
* DescribeServerlessGroups

<font color="#dd0000">**删除数据结构**：</font>

* ServerlessGroup
* ServerlessGroupPage

### 第 72 次发布

发布时间：2022-04-12 06:23:46

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [ContainGroup](https://cloud.tencent.com/document/api/649/36099#ContainGroup)

	* 新增成员：KubeInjectEnable

* [ContainerGroupDeploy](https://cloud.tencent.com/document/api/649/36099#ContainerGroupDeploy)

	* 新增成员：KubeInjectEnable

* [ImageRepository](https://cloud.tencent.com/document/api/649/36099#ImageRepository)

	* 新增成员：ApplicationNameReal

* [Namespace](https://cloud.tencent.com/document/api/649/36099#Namespace)

	* 新增成员：KubeInjectEnable

* [ServiceStatisticsResult](https://cloud.tencent.com/document/api/649/36099#ServiceStatisticsResult)

	* 新增成员：Apdex, Qps, InstanceOnlineCount, InstanceTotalCount, Status, ErrorRateLevel, AvgTimeConsumingLevel, ApdexLevel


### 第 71 次发布

发布时间：2022-04-11 06:19:17

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeInstances](https://cloud.tencent.com/document/api/649/72342)

新增数据结构：

* [Filter](https://cloud.tencent.com/document/api/649/36099#Filter)
* [InstanceEnrichedInfo](https://cloud.tencent.com/document/api/649/36099#InstanceEnrichedInfo)
* [InstanceEnrichedInfoPage](https://cloud.tencent.com/document/api/649/36099#InstanceEnrichedInfoPage)

### 第 70 次发布

发布时间：2022-03-01 08:14:14

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeInovcationIndicators](https://cloud.tencent.com/document/api/649/70434)
* [DescribeInvocationMetricDataCurve](https://cloud.tencent.com/document/api/649/70433)
* [DescribeInvocationMetricDataDimension](https://cloud.tencent.com/document/api/649/70432)
* [DescribeInvocationMetricDataPoint](https://cloud.tencent.com/document/api/649/70431)
* [DescribeInvocationMetricScatterPlot](https://cloud.tencent.com/document/api/649/70430)
* [DescribeJvmMonitor](https://cloud.tencent.com/document/api/649/70429)
* [DescribeOverviewInvocation](https://cloud.tencent.com/document/api/649/70428)
* [DescribeStatistics](https://cloud.tencent.com/document/api/649/70427)

新增数据结构：

* [CurvePoint](https://cloud.tencent.com/document/api/649/36099#CurvePoint)
* [IndicatorCoord](https://cloud.tencent.com/document/api/649/36099#IndicatorCoord)
* [InvocationIndicator](https://cloud.tencent.com/document/api/649/36099#InvocationIndicator)
* [InvocationMetricScatterPlot](https://cloud.tencent.com/document/api/649/36099#InvocationMetricScatterPlot)
* [JvmMonitorData](https://cloud.tencent.com/document/api/649/36099#JvmMonitorData)
* [MemoryPicture](https://cloud.tencent.com/document/api/649/36099#MemoryPicture)
* [Metric](https://cloud.tencent.com/document/api/649/36099#Metric)
* [MetricDataCurve](https://cloud.tencent.com/document/api/649/36099#MetricDataCurve)
* [MetricDataSingleValue](https://cloud.tencent.com/document/api/649/36099#MetricDataSingleValue)
* [MetricDimension](https://cloud.tencent.com/document/api/649/36099#MetricDimension)
* [MetricDimensionValue](https://cloud.tencent.com/document/api/649/36099#MetricDimensionValue)
* [MultiValue](https://cloud.tencent.com/document/api/649/36099#MultiValue)
* [MultiValueDataPoints](https://cloud.tencent.com/document/api/649/36099#MultiValueDataPoints)
* [ServiceStatisticsResult](https://cloud.tencent.com/document/api/649/36099#ServiceStatisticsResult)
* [ServiceStatisticsResults](https://cloud.tencent.com/document/api/649/36099#ServiceStatisticsResults)
* [ThreadPicture](https://cloud.tencent.com/document/api/649/36099#ThreadPicture)
* [TsfPageDimension](https://cloud.tencent.com/document/api/649/36099#TsfPageDimension)

### 第 69 次发布

发布时间：2022-02-24 08:15:06

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [ServiceSetting](https://cloud.tencent.com/document/api/649/36099#ServiceSetting)

	* 新增成员：OpenSessionAffinity, SessionAffinityTimeoutSeconds


### 第 68 次发布

发布时间：2022-01-20 08:16:32

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateTask](https://cloud.tencent.com/document/api/649/48886)

	* 新增入参：ProgramIdList

* [CreateTaskFlow](https://cloud.tencent.com/document/api/649/50088)

	* 新增入参：ProgramIdList

* [DescribeTaskRecords](https://cloud.tencent.com/document/api/649/56136)

	* 新增入参：Ids

* [ModifyTask](https://cloud.tencent.com/document/api/649/50087)

	* 新增入参：ProgramIdList


### 第 67 次发布

发布时间：2022-01-19 08:17:04

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DeployContainerGroup](https://cloud.tencent.com/document/api/649/36071)

	* 新增入参：VolumeClean


### 第 66 次发布

发布时间：2022-01-07 08:15:02

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [ContainerGroupDeploy](https://cloud.tencent.com/document/api/649/36099#ContainerGroupDeploy)

	* 新增成员：VolumeInfos, VolumeMountInfos


### 第 65 次发布

发布时间：2022-01-05 08:15:18

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DeployContainerGroup](https://cloud.tencent.com/document/api/649/36071)

	* 新增入参：VolumeInfoList, VolumeMountInfoList


### 第 64 次发布

发布时间：2021-12-30 08:15:43

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeContainerGroupDeployInfo](https://cloud.tencent.com/document/api/649/67221)

新增数据结构：

* [ContainerGroupDeploy](https://cloud.tencent.com/document/api/649/36099#ContainerGroupDeploy)

### 第 63 次发布

发布时间：2021-12-24 08:16:33

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeMicroservices](https://cloud.tencent.com/document/api/649/36084)

	* 新增入参：MicroserviceNameList


### 第 62 次发布

发布时间：2021-12-23 08:16:46

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DeployContainerGroup](https://cloud.tencent.com/document/api/649/36071)

	* 新增入参：VolumeInfos, VolumeMountInfos


新增数据结构：

* [VolumeInfo](https://cloud.tencent.com/document/api/649/36099#VolumeInfo)
* [VolumeMountInfo](https://cloud.tencent.com/document/api/649/36099#VolumeMountInfo)

### 第 61 次发布

发布时间：2021-11-30 08:13:08

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeGroupAttribute](https://cloud.tencent.com/document/api/649/64979)

新增数据结构：

* [VmGroupOther](https://cloud.tencent.com/document/api/649/36099#VmGroupOther)

### 第 60 次发布

发布时间：2021-11-12 08:10:33

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateApplication](https://cloud.tencent.com/document/api/649/36094)

	* 新增入参：ProgramIdList

* [CreateCluster](https://cloud.tencent.com/document/api/649/36049)

	* 新增入参：KuberneteApiServer, KuberneteNativeType, KuberneteNativeSecret, ProgramIdList

* [CreateConfig](https://cloud.tencent.com/document/api/649/38348)

	* 新增入参：ProgramIdList

* [CreateFileConfig](https://cloud.tencent.com/document/api/649/58594)

	* 新增入参：ProgramIdList

* [CreateGatewayApi](https://cloud.tencent.com/document/api/649/50639)

	* 新增入参：ProgramIdList

* [CreateLane](https://cloud.tencent.com/document/api/649/44508)

	* 新增入参：ProgramIdList

* [CreateLaneRule](https://cloud.tencent.com/document/api/649/44507)

	* 新增入参：ProgramIdList

* [CreateNamespace](https://cloud.tencent.com/document/api/649/36098)

	* 新增入参：ProgramIdList

* [CreatePublicConfig](https://cloud.tencent.com/document/api/649/38347)

	* 新增入参：ProgramIdList

* [DescribeConfigSummary](https://cloud.tencent.com/document/api/649/38341)

	* 新增入参：ConfigTagList, DisableProgramAuthCheck, ConfigIdList

* [DescribeGroups](https://cloud.tencent.com/document/api/649/36065)

	* 新增入参：GroupIdList

* [DescribeLaneRules](https://cloud.tencent.com/document/api/649/44505)

	* 新增入参：RuleIdList

* [DescribeLanes](https://cloud.tencent.com/document/api/649/44504)

	* 新增入参：LaneIdList, DisableProgramAuthCheck

	* <font color="#dd0000">**修改入参**：</font>Limit, Offset

* [DescribePublicConfigSummary](https://cloud.tencent.com/document/api/649/38336)

	* 新增入参：ConfigTagList, DisableProgramAuthCheck, ConfigIdList

* [DescribeServerlessGroups](https://cloud.tencent.com/document/api/649/39421)

	* 新增入参：GroupIdList

* [DescribeSimpleApplications](https://cloud.tencent.com/document/api/649/36089)

	* 新增入参：DisableProgramAuthCheck

* [DescribeSimpleClusters](https://cloud.tencent.com/document/api/649/36047)

	* 新增入参：DisableProgramAuthCheck

* [DescribeSimpleNamespaces](https://cloud.tencent.com/document/api/649/36096)

	* 新增入参：DisableProgramAuthCheck


### 第 59 次发布

发布时间：2021-10-21 11:40:48

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DeleteLaneRule](https://cloud.tencent.com/document/api/649/63177)
* [DescribeGatewayApis](https://cloud.tencent.com/document/api/649/63178)

新增数据结构：

* [TsfPageApiDetailInfo](https://cloud.tencent.com/document/api/649/36099#TsfPageApiDetailInfo)

### 第 58 次发布

发布时间：2021-09-28 08:11:05

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DeployGroup](https://cloud.tencent.com/document/api/649/36070)

	* 新增入参：JdkName, JdkVersion


修改数据结构：

* [ScalableRule](https://cloud.tencent.com/document/api/649/36099#ScalableRule)

	* 新增成员：Description


### 第 57 次发布

发布时间：2021-09-27 08:17:31

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateApplication](https://cloud.tencent.com/document/api/649/36094)

	* 新增入参：IgnoreCreateImageRepository


### 第 56 次发布

发布时间：2021-08-19 08:09:10

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeGroupRelease](https://cloud.tencent.com/document/api/649/60441)
* [OperateApplicationTcrBinding](https://cloud.tencent.com/document/api/649/60442)

修改接口：

* [DeleteImageTags](https://cloud.tencent.com/document/api/649/36053)

	* 新增入参：RepoType

* [DeployContainerGroup](https://cloud.tencent.com/document/api/649/36071)

	* 新增入参：IncrementalDeployment, RepoType

* [DeployGroup](https://cloud.tencent.com/document/api/649/36070)

	* 新增入参：IncrementalDeployment

* [DescribeImageRepository](https://cloud.tencent.com/document/api/649/49526)

	* 新增入参：RepoType, ApplicationId, TcrRepoInfo

* [DescribeImageTags](https://cloud.tencent.com/document/api/649/36052)

	* 新增入参：RepoType, TcrRepoInfo


新增数据结构：

* [FileConfigRelease](https://cloud.tencent.com/document/api/649/36099#FileConfigRelease)
* [GroupRelease](https://cloud.tencent.com/document/api/649/36099#GroupRelease)
* [ScalableRule](https://cloud.tencent.com/document/api/649/36099#ScalableRule)
* [TcrRepoInfo](https://cloud.tencent.com/document/api/649/36099#TcrRepoInfo)

修改数据结构：

* [ImageRepository](https://cloud.tencent.com/document/api/649/36099#ImageRepository)

	* 新增成员：TcrRepoInfo, TcrBindingId, ApplicationId, ApplicationName

* [ImageTag](https://cloud.tencent.com/document/api/649/36099#ImageTag)

	* 新增成员：TcrRepoInfo


### 第 55 次发布

发布时间：2021-07-15 08:08:58

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeConfigSummary](https://cloud.tencent.com/document/api/649/38341)

	* 新增入参：OrderBy, OrderType

* [DescribePublicConfigSummary](https://cloud.tencent.com/document/api/649/38336)

	* 新增入参：OrderBy, OrderType


修改数据结构：

* [ServiceSetting](https://cloud.tencent.com/document/api/649/36099#ServiceSetting)

	* 新增成员：DisableService, HeadlessService, AllowDeleteService


### 第 54 次发布

发布时间：2021-07-14 08:08:59

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateFileConfig](https://cloud.tencent.com/document/api/649/58594)
* [DescribeFileConfigs](https://cloud.tencent.com/document/api/649/58593)
* [ReleaseFileConfig](https://cloud.tencent.com/document/api/649/58592)

新增数据结构：

* [FileConfig](https://cloud.tencent.com/document/api/649/36099#FileConfig)
* [TsfPageFileConfig](https://cloud.tencent.com/document/api/649/36099#TsfPageFileConfig)

### 第 53 次发布

发布时间：2021-06-16 08:08:41

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [SearchBusinessLog](https://cloud.tencent.com/document/api/649/57371)
* [SearchStdoutLog](https://cloud.tencent.com/document/api/649/57370)

新增数据结构：

* [BusinessLogV2](https://cloud.tencent.com/document/api/649/36099#BusinessLogV2)
* [StdoutLogV2](https://cloud.tencent.com/document/api/649/36099#StdoutLogV2)
* [TsfPageBusinessLogV2](https://cloud.tencent.com/document/api/649/36099#TsfPageBusinessLogV2)
* [TsfPageStdoutLogV2](https://cloud.tencent.com/document/api/649/36099#TsfPageStdoutLogV2)

### 第 52 次发布

发布时间：2021-05-21 08:08:26

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeTaskRecords](https://cloud.tencent.com/document/api/649/56136)

新增数据结构：

* [TaskRecordPage](https://cloud.tencent.com/document/api/649/36099#TaskRecordPage)

### 第 51 次发布

发布时间：2021-04-29 08:07:38

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [ConfigRelease](https://cloud.tencent.com/document/api/649/36099#ConfigRelease)

	* 新增成员：ApplicationId


### 第 50 次发布

发布时间：2021-04-27 08:08:59

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeContainerEvents](https://cloud.tencent.com/document/api/649/55200)
* [DescribeUnitApiUseDetail](https://cloud.tencent.com/document/api/649/55199)

修改接口：

* [CreateGroup](https://cloud.tencent.com/document/api/649/36074)

	* 新增入参：Alias

* [ModifyContainerGroup](https://cloud.tencent.com/document/api/649/36062)

	* 新增入参：Alias


新增数据结构：

* [ContainerEvent](https://cloud.tencent.com/document/api/649/36099#ContainerEvent)
* [FieldRef](https://cloud.tencent.com/document/api/649/36099#FieldRef)
* [GroupUnitApiDailyUseStatistics](https://cloud.tencent.com/document/api/649/36099#GroupUnitApiDailyUseStatistics)
* [GroupUnitApiUseStatistics](https://cloud.tencent.com/document/api/649/36099#GroupUnitApiUseStatistics)
* [MetricDataPoint](https://cloud.tencent.com/document/api/649/36099#MetricDataPoint)
* [MetricDataPointMap](https://cloud.tencent.com/document/api/649/36099#MetricDataPointMap)
* [ResourceFieldRef](https://cloud.tencent.com/document/api/649/36099#ResourceFieldRef)
* [TsfPageContainerEvent](https://cloud.tencent.com/document/api/649/36099#TsfPageContainerEvent)
* [ValueFrom](https://cloud.tencent.com/document/api/649/36099#ValueFrom)

修改数据结构：

* [ApiGroupInfo](https://cloud.tencent.com/document/api/649/36099#ApiGroupInfo)

	* 新增成员：GatewayInstanceType, GatewayInstanceId

* [ContainGroup](https://cloud.tencent.com/document/api/649/36099#ContainGroup)

	* 新增成员：Alias

* [Env](https://cloud.tencent.com/document/api/649/36099#Env)

	* 新增成员：ValueFrom

	* <font color="#dd0000">**修改成员**：</font>Value

* [GatewayApiGroupVo](https://cloud.tencent.com/document/api/649/36099#GatewayApiGroupVo)

	* 新增成员：GatewayInstanceType, GatewayInstanceId

* [VmGroup](https://cloud.tencent.com/document/api/649/36099#VmGroup)

	* 新增成员：Alias

* [VmGroupSimple](https://cloud.tencent.com/document/api/649/36099#VmGroupSimple)

	* 新增成员：Alias


### 第 49 次发布

发布时间：2021-03-23 08:09:03

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [BindPlugin](https://cloud.tencent.com/document/api/649/53937)
* [DescribeGroupsWithPlugin](https://cloud.tencent.com/document/api/649/53936)
* [DescribePluginInstances](https://cloud.tencent.com/document/api/649/53935)

新增数据结构：

* [GatewayPlugin](https://cloud.tencent.com/document/api/649/36099#GatewayPlugin)
* [GatewayPluginBoundParam](https://cloud.tencent.com/document/api/649/36099#GatewayPluginBoundParam)
* [TsfPageGatewayPlugin](https://cloud.tencent.com/document/api/649/36099#TsfPageGatewayPlugin)

### 第 48 次发布

发布时间：2021-03-22 08:07:55

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateUnitRule](https://cloud.tencent.com/document/api/649/53904)
* [DeleteUnitNamespaces](https://cloud.tencent.com/document/api/649/53903)
* [DeleteUnitRule](https://cloud.tencent.com/document/api/649/53902)
* [DescribeEnabledUnitRule](https://cloud.tencent.com/document/api/649/53901)
* [DescribeUnitNamespaces](https://cloud.tencent.com/document/api/649/53900)
* [DescribeUnitRule](https://cloud.tencent.com/document/api/649/53899)
* [DescribeUnitRules](https://cloud.tencent.com/document/api/649/53898)
* [DescribeUsableUnitNamespaces](https://cloud.tencent.com/document/api/649/53897)
* [DisableUnitRoute](https://cloud.tencent.com/document/api/649/53896)
* [DisableUnitRule](https://cloud.tencent.com/document/api/649/53895)
* [EnableUnitRoute](https://cloud.tencent.com/document/api/649/53894)
* [EnableUnitRule](https://cloud.tencent.com/document/api/649/53893)
* [UpdateApiTimeouts](https://cloud.tencent.com/document/api/649/53892)
* [UpdateUnitRule](https://cloud.tencent.com/document/api/649/53891)

修改接口：

* [CreateApiGroup](https://cloud.tencent.com/document/api/649/50641)

	* 新增入参：GatewayInstanceId

* [DescribeApiGroups](https://cloud.tencent.com/document/api/649/50636)

	* 新增入参：GatewayInstanceId


新增数据结构：

* [TsfPageUnitNamespace](https://cloud.tencent.com/document/api/649/36099#TsfPageUnitNamespace)
* [TsfPageUnitRule](https://cloud.tencent.com/document/api/649/36099#TsfPageUnitRule)
* [UnitNamespace](https://cloud.tencent.com/document/api/649/36099#UnitNamespace)
* [UnitRule](https://cloud.tencent.com/document/api/649/36099#UnitRule)
* [UnitRuleItem](https://cloud.tencent.com/document/api/649/36099#UnitRuleItem)
* [UnitRuleTag](https://cloud.tencent.com/document/api/649/36099#UnitRuleTag)

### 第 47 次发布

发布时间：2021-03-19 08:07:54

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeMicroservice](https://cloud.tencent.com/document/api/649/36085)

	* 新增入参：GroupIds


### 第 46 次发布

发布时间：2021-03-18 08:08:30

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeApplications](https://cloud.tencent.com/document/api/649/36090)

	* 新增入参：ApplicationIdList

* [DescribeMicroservices](https://cloud.tencent.com/document/api/649/36084)

	* 新增入参：MicroserviceIdList

* [DescribePodInstances](https://cloud.tencent.com/document/api/649/43108)

	* 新增入参：PodNameList


### 第 45 次发布

发布时间：2021-03-17 08:08:37

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateApplication](https://cloud.tencent.com/document/api/649/36094)

	* 新增入参：ServiceConfigList

* [DeployGroup](https://cloud.tencent.com/document/api/649/36070)

	* 新增入参：StartScript, StopScript

* [DescribePkgs](https://cloud.tencent.com/document/api/649/36079)

	* 新增入参：PackageTypeList


新增数据结构：

* [HealthCheckConfig](https://cloud.tencent.com/document/api/649/36099#HealthCheckConfig)
* [Ports](https://cloud.tencent.com/document/api/649/36099#Ports)
* [ServiceConfig](https://cloud.tencent.com/document/api/649/36099#ServiceConfig)

修改数据结构：

* [ApplicationForPage](https://cloud.tencent.com/document/api/649/36099#ApplicationForPage)

	* 新增成员：ServiceConfigList

* [Instance](https://cloud.tencent.com/document/api/649/36099#Instance)

	* 新增成员：AgentVersion

* [VmGroup](https://cloud.tencent.com/document/api/649/36099#VmGroup)

	* 新增成员：PackageType, StartScript, StopScript


### 第 44 次发布

发布时间：2021-03-09 08:08:41

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeTaskDetail](https://cloud.tencent.com/document/api/649/53439)

修改接口：

* [ModifyTask](https://cloud.tencent.com/document/api/649/50087)

	* <font color="#dd0000">**修改入参**：</font>ShardArguments


新增数据结构：

* [TaskRecord](https://cloud.tencent.com/document/api/649/36099#TaskRecord)

### 第 43 次发布

发布时间：2021-03-02 08:08:56

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [TaskRule](https://cloud.tencent.com/document/api/649/36099#TaskRule)

	* <font color="#dd0000">**修改成员**：</font>RepeatInterval


### 第 42 次发布

发布时间：2021-01-28 08:07:35

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [ContainerGroupDetail](https://cloud.tencent.com/document/api/649/36099#ContainerGroupDetail)

	* 新增成员：HealthCheckSettings


### 第 41 次发布

发布时间：2021-01-20 08:07:07

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreatePathRewrites](https://cloud.tencent.com/document/api/649/52211)
* [DeletePathRewrites](https://cloud.tencent.com/document/api/649/52210)
* [DescribePathRewrite](https://cloud.tencent.com/document/api/649/52209)
* [DescribePathRewrites](https://cloud.tencent.com/document/api/649/52208)
* [ModifyPathRewrite](https://cloud.tencent.com/document/api/649/52207)

修改接口：

* [AddClusterInstances](https://cloud.tencent.com/document/api/649/41225)

	* 新增入参：InstanceAdvancedSettings, SecurityGroupIds

* [CreateApplication](https://cloud.tencent.com/document/api/649/36094)

	* 新增入参：ProgramId

* [CreateCluster](https://cloud.tencent.com/document/api/649/36049)

	* 新增入参：MaxNodePodNum, MaxClusterServiceNum, ProgramId

* [CreateNamespace](https://cloud.tencent.com/document/api/649/36098)

	* 新增入参：ProgramId


新增数据结构：

* [InstanceAdvancedSettings](https://cloud.tencent.com/document/api/649/36099#InstanceAdvancedSettings)
* [PathRewrite](https://cloud.tencent.com/document/api/649/36099#PathRewrite)
* [PathRewriteCreateObject](https://cloud.tencent.com/document/api/649/36099#PathRewriteCreateObject)
* [PathRewritePage](https://cloud.tencent.com/document/api/649/36099#PathRewritePage)

修改数据结构：

* [AddInstanceResult](https://cloud.tencent.com/document/api/649/36099#AddInstanceResult)

	* 新增成员：FailedReasons

* [ApiDetailResponse](https://cloud.tencent.com/document/api/649/36099#ApiDetailResponse)

	* 新增成员：Description

* [ApplicationForPage](https://cloud.tencent.com/document/api/649/36099#ApplicationForPage)

	* 新增成员：ApplicationRemarkName


### 第 40 次发布

发布时间：2021-01-13 08:06:55

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [MsInstance](https://cloud.tencent.com/document/api/649/36099#MsInstance)

	* <font color="#dd0000">**修改成员**：</font>RegistrationId


### 第 39 次发布

发布时间：2020-12-23 08:07:16

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeGroups](https://cloud.tencent.com/document/api/649/36065)

	* 新增入参：Status


### 第 38 次发布

发布时间：2020-12-03 08:07:07

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [BindApiGroup](https://cloud.tencent.com/document/api/649/50644)
* [ChangeApiUsableStatus](https://cloud.tencent.com/document/api/649/50643)
* [CreateAllGatewayApiAsync](https://cloud.tencent.com/document/api/649/50642)
* [CreateApiGroup](https://cloud.tencent.com/document/api/649/50641)
* [CreateApiRateLimitRule](https://cloud.tencent.com/document/api/649/50640)
* [CreateGatewayApi](https://cloud.tencent.com/document/api/649/50639)
* [DeleteApiGroup](https://cloud.tencent.com/document/api/649/50638)
* [DescribeApiGroup](https://cloud.tencent.com/document/api/649/50637)
* [DescribeApiGroups](https://cloud.tencent.com/document/api/649/50636)
* [DescribeApiRateLimitRules](https://cloud.tencent.com/document/api/649/50635)
* [DescribeApiUseDetail](https://cloud.tencent.com/document/api/649/50634)
* [DescribeCreateGatewayApiStatus](https://cloud.tencent.com/document/api/649/50620)
* [DescribeGatewayAllGroupApis](https://cloud.tencent.com/document/api/649/50633)
* [DescribeGatewayMonitorOverview](https://cloud.tencent.com/document/api/649/50632)
* [DescribeGroupBindedGateways](https://cloud.tencent.com/document/api/649/50631)
* [DescribeGroupGateways](https://cloud.tencent.com/document/api/649/50630)
* [DescribeGroupUseDetail](https://cloud.tencent.com/document/api/649/50629)
* [DraftApiGroup](https://cloud.tencent.com/document/api/649/50628)
* [ReleaseApiGroup](https://cloud.tencent.com/document/api/649/50627)
* [UnbindApiGroup](https://cloud.tencent.com/document/api/649/50626)
* [UpdateApiGroup](https://cloud.tencent.com/document/api/649/50625)
* [UpdateApiRateLimitRule](https://cloud.tencent.com/document/api/649/50624)
* [UpdateApiRateLimitRules](https://cloud.tencent.com/document/api/649/50623)
* [UpdateGatewayApi](https://cloud.tencent.com/document/api/649/50622)

修改接口：

* [AddClusterInstances](https://cloud.tencent.com/document/api/649/41225)

	* 新增入参：FeatureIdList


新增数据结构：

* [ApiDetailInfo](https://cloud.tencent.com/document/api/649/36099#ApiDetailInfo)
* [ApiGroupInfo](https://cloud.tencent.com/document/api/649/36099#ApiGroupInfo)
* [ApiInfo](https://cloud.tencent.com/document/api/649/36099#ApiInfo)
* [ApiRateLimitRule](https://cloud.tencent.com/document/api/649/36099#ApiRateLimitRule)
* [ApiUseStatisticsEntity](https://cloud.tencent.com/document/api/649/36099#ApiUseStatisticsEntity)
* [GatewayApiGroupVo](https://cloud.tencent.com/document/api/649/36099#GatewayApiGroupVo)
* [GatewayDeployGroup](https://cloud.tencent.com/document/api/649/36099#GatewayDeployGroup)
* [GatewayGroupApiVo](https://cloud.tencent.com/document/api/649/36099#GatewayGroupApiVo)
* [GatewayGroupIds](https://cloud.tencent.com/document/api/649/36099#GatewayGroupIds)
* [GatewayVo](https://cloud.tencent.com/document/api/649/36099#GatewayVo)
* [GroupApiUseStatistics](https://cloud.tencent.com/document/api/649/36099#GroupApiUseStatistics)
* [GroupDailyUseStatistics](https://cloud.tencent.com/document/api/649/36099#GroupDailyUseStatistics)
* [GroupUseStatisticsEntity](https://cloud.tencent.com/document/api/649/36099#GroupUseStatisticsEntity)
* [MonitorOverview](https://cloud.tencent.com/document/api/649/36099#MonitorOverview)
* [QuantileEntity](https://cloud.tencent.com/document/api/649/36099#QuantileEntity)
* [TsfPageApiGroupInfo](https://cloud.tencent.com/document/api/649/36099#TsfPageApiGroupInfo)
* [TsfPageGatewayDeployGroup](https://cloud.tencent.com/document/api/649/36099#TsfPageGatewayDeployGroup)

### 第 37 次发布

发布时间：2020-11-19 08:06:52

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateTaskFlow](https://cloud.tencent.com/document/api/649/50088)
* [ModifyTask](https://cloud.tencent.com/document/api/649/50087)
* [RedoTaskExecute](https://cloud.tencent.com/document/api/649/50086)

新增数据结构：

* [TaskFlowEdge](https://cloud.tencent.com/document/api/649/36099#TaskFlowEdge)

修改数据结构：

* [ServiceSetting](https://cloud.tencent.com/document/api/649/36099#ServiceSetting)

	* <font color="#dd0000">**修改成员**：</font>ProtocolPorts


### 第 36 次发布

发布时间：2020-11-18 08:34:11

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [UpdateHealthCheckSettings](https://cloud.tencent.com/document/api/649/50019)

修改接口：

* [DeployGroup](https://cloud.tencent.com/document/api/649/36070)

	* 新增入参：EnableHealthCheck, HealthCheckSettings, UpdateType, DeployBetaEnable, DeployBatch, DeployExeMode, DeployWaitTime


修改数据结构：

* [Instance](https://cloud.tencent.com/document/api/649/36099#Instance)

	* 新增成员：Reason

* [VmGroup](https://cloud.tencent.com/document/api/649/36099#VmGroup)

	* 新增成员：EnableHealthCheck, HealthCheckSettings


### 第 35 次发布

发布时间：2020-11-16 08:07:14

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [HealthCheckSetting](https://cloud.tencent.com/document/api/649/36099#HealthCheckSetting)

	* 新增成员：Type

* [VmGroup](https://cloud.tencent.com/document/api/649/36099#VmGroup)

	* 新增成员：UpdateType, DeployBetaEnable, DeployBatch, DeployExeMode, DeployWaitTime


### 第 34 次发布

发布时间：2020-10-30 08:06:35

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeImageRepository](https://cloud.tencent.com/document/api/649/49526)

	* 新增出参：Result


新增数据结构：

* [ImageRepository](https://cloud.tencent.com/document/api/649/36099#ImageRepository)
* [ImageRepositoryResult](https://cloud.tencent.com/document/api/649/36099#ImageRepositoryResult)

### 第 33 次发布

发布时间：2020-10-29 08:06:53

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeImageRepository](https://cloud.tencent.com/document/api/649/49526)

### 第 32 次发布

发布时间：2020-10-21 08:06:55

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateNamespace](https://cloud.tencent.com/document/api/649/36098)

	* 新增入参：IsHaEnable

* [DeployContainerGroup](https://cloud.tencent.com/document/api/649/36071)

	* 新增入参：SchedulingStrategy

* [DeployGroup](https://cloud.tencent.com/document/api/649/36070)

	* 新增入参：ForceStart

* [DescribeMicroservices](https://cloud.tencent.com/document/api/649/36084)

	* 新增入参：Status


新增数据结构：

* [SchedulingStrategy](https://cloud.tencent.com/document/api/649/36099#SchedulingStrategy)

修改数据结构：

* [Cluster](https://cloud.tencent.com/document/api/649/36099#Cluster)

	* 新增成员：ClusterVersion

* [Namespace](https://cloud.tencent.com/document/api/649/36099#Namespace)

	* 新增成员：IsHaEnable


### 第 31 次发布

发布时间：2020-10-12 08:06:34

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [ModifyUploadInfo](https://cloud.tencent.com/document/api/649/36077)

	* <font color="#dd0000">**修改入参**：</font>Md5


### 第 30 次发布

发布时间：2020-09-29 08:07:07

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [ContinueRunFailedTaskBatch](https://cloud.tencent.com/document/api/649/48887)
* [CreateTask](https://cloud.tencent.com/document/api/649/48886)
* [DescribeBasicResourceUsage](https://cloud.tencent.com/document/api/649/48898)
* [DescribeFlowLastBatchState](https://cloud.tencent.com/document/api/649/48885)
* [DescribeTaskLastStatus](https://cloud.tencent.com/document/api/649/48897)
* [DisableTask](https://cloud.tencent.com/document/api/649/48896)
* [DisableTaskFlow](https://cloud.tencent.com/document/api/649/48895)
* [EnableTask](https://cloud.tencent.com/document/api/649/48894)
* [EnableTaskFlow](https://cloud.tencent.com/document/api/649/48893)
* [ExecuteTask](https://cloud.tencent.com/document/api/649/48892)
* [ExecuteTaskFlow](https://cloud.tencent.com/document/api/649/48891)
* [RedoTask](https://cloud.tencent.com/document/api/649/48890)
* [RedoTaskBatch](https://cloud.tencent.com/document/api/649/48884)
* [RedoTaskFlowBatch](https://cloud.tencent.com/document/api/649/48889)
* [StopTaskBatch](https://cloud.tencent.com/document/api/649/48883)
* [StopTaskExecute](https://cloud.tencent.com/document/api/649/48882)
* [TerminateTaskFlowBatch](https://cloud.tencent.com/document/api/649/48888)

新增数据结构：

* [AdvanceSettings](https://cloud.tencent.com/document/api/649/36099#AdvanceSettings)
* [OverviewBasicResourceUsage](https://cloud.tencent.com/document/api/649/36099#OverviewBasicResourceUsage)
* [ShardArgument](https://cloud.tencent.com/document/api/649/36099#ShardArgument)
* [TaskFlowLastBatchState](https://cloud.tencent.com/document/api/649/36099#TaskFlowLastBatchState)
* [TaskLastExecuteStatus](https://cloud.tencent.com/document/api/649/36099#TaskLastExecuteStatus)
* [TaskRule](https://cloud.tencent.com/document/api/649/36099#TaskRule)

### 第 29 次发布

发布时间：2020-09-28 08:08:47

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DeleteTask](https://cloud.tencent.com/document/api/649/48802)

### 第 28 次发布

发布时间：2020-09-24 08:06:25

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DeployContainerGroup](https://cloud.tencent.com/document/api/649/36071)

	* 新增入参：DeployAgent


修改数据结构：

* [Microservice](https://cloud.tencent.com/document/api/649/36099#Microservice)

	* 新增成员：CriticalInstanceCount

* [MsInstance](https://cloud.tencent.com/document/api/649/36099#MsInstance)

	* 新增成员：ServiceStatus, RegistrationTime, LastHeartbeatTime, RegistrationId, HiddenStatus


### 第 27 次发布

发布时间：2020-09-09 08:08:53

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DeployContainerGroup](https://cloud.tencent.com/document/api/649/36071)

	* <font color="#dd0000">**修改入参**：</font>Server


### 第 26 次发布

发布时间：2020-08-24 08:06:29

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [AddClusterInstances](https://cloud.tencent.com/document/api/649/41225)

	* 新增入参：OsCustomizeType


### 第 25 次发布

发布时间：2020-08-11 08:24:17

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DeployContainerGroup](https://cloud.tencent.com/document/api/649/36071)

	* 新增入参：HealthCheckSettings, Envs, ServiceSetting

* [DeployGroup](https://cloud.tencent.com/document/api/649/36070)

	* 新增入参：DeployDesc


新增数据结构：

* [HealthCheckSetting](https://cloud.tencent.com/document/api/649/36099#HealthCheckSetting)
* [HealthCheckSettings](https://cloud.tencent.com/document/api/649/36099#HealthCheckSettings)
* [ServiceSetting](https://cloud.tencent.com/document/api/649/36099#ServiceSetting)

修改数据结构：

* [VmGroup](https://cloud.tencent.com/document/api/649/36099#VmGroup)

	* 新增成员：DeployDesc

* [VmGroupSimple](https://cloud.tencent.com/document/api/649/36099#VmGroupSimple)

	* 新增成员：DeployDesc


### 第 24 次发布

发布时间：2020-07-02 08:18:27

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateRepository](https://cloud.tencent.com/document/api/649/45927)
* [DeleteRepository](https://cloud.tencent.com/document/api/649/45926)
* [DescribeRepositories](https://cloud.tencent.com/document/api/649/45925)
* [DescribeRepository](https://cloud.tencent.com/document/api/649/45924)
* [UpdateRepository](https://cloud.tencent.com/document/api/649/45923)

修改接口：

* [CreateCluster](https://cloud.tencent.com/document/api/649/36049)

	* 新增入参：ClusterVersion

* [DeletePkgs](https://cloud.tencent.com/document/api/649/36081)

	* 新增入参：RepositoryType, RepositoryId

* [DeployContainerGroup](https://cloud.tencent.com/document/api/649/36071)

	* 新增入参：MaxSurge, MaxUnavailable

* [DescribeDownloadInfo](https://cloud.tencent.com/document/api/649/36080)

	* 新增入参：RepositoryId, RepositoryType

* [DescribePkgs](https://cloud.tencent.com/document/api/649/36079)

	* 新增入参：RepositoryType, RepositoryId

* [DescribeUploadInfo](https://cloud.tencent.com/document/api/649/36078)

	* 新增入参：RepositoryType, RepositoryId

* [ModifyUploadInfo](https://cloud.tencent.com/document/api/649/36077)

	* 新增入参：RepositoryType, RepositoryId


新增数据结构：

* [PkgBind](https://cloud.tencent.com/document/api/649/36099#PkgBind)
* [RepositoryInfo](https://cloud.tencent.com/document/api/649/36099#RepositoryInfo)
* [RepositoryList](https://cloud.tencent.com/document/api/649/36099#RepositoryList)

修改数据结构：

* [ContainerGroupDetail](https://cloud.tencent.com/document/api/649/36099#ContainerGroupDetail)

	* 新增成员：MaxSurge, MaxUnavailable

* [GroupPod](https://cloud.tencent.com/document/api/649/36099#GroupPod)

	* 新增成员：NodeInstanceId

* [PkgInfo](https://cloud.tencent.com/document/api/649/36099#PkgInfo)

	* 新增成员：PkgBindInfo

* [PkgList](https://cloud.tencent.com/document/api/649/36099#PkgList)

	* 新增成员：RepositoryId, RepositoryType, RepositoryName


### 第 23 次发布

发布时间：2020-06-19 08:17:57

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [ModifyContainerGroup](https://cloud.tencent.com/document/api/649/36062)

	* 新增入参：SubnetId


### 第 22 次发布

发布时间：2020-06-15 08:17:58

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeApiDetail](https://cloud.tencent.com/document/api/649/45538)
* [DescribeApiVersions](https://cloud.tencent.com/document/api/649/45537)
* [DescribeMsApiList](https://cloud.tencent.com/document/api/649/45536)

新增数据结构：

* [ApiDefinitionDescr](https://cloud.tencent.com/document/api/649/36099#ApiDefinitionDescr)
* [ApiDetailResponse](https://cloud.tencent.com/document/api/649/36099#ApiDetailResponse)
* [ApiRequestDescr](https://cloud.tencent.com/document/api/649/36099#ApiRequestDescr)
* [ApiResponseDescr](https://cloud.tencent.com/document/api/649/36099#ApiResponseDescr)
* [ApiVersionArray](https://cloud.tencent.com/document/api/649/36099#ApiVersionArray)
* [MsApiArray](https://cloud.tencent.com/document/api/649/36099#MsApiArray)
* [PropertyField](https://cloud.tencent.com/document/api/649/36099#PropertyField)
* [TsfApiListResponse](https://cloud.tencent.com/document/api/649/36099#TsfApiListResponse)

### 第 21 次发布

发布时间：2020-06-09 08:18:22

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [LaneGroup](https://cloud.tencent.com/document/api/649/36099#LaneGroup)

	* <font color="#dd0000">**修改成员**：</font>LaneId


### 第 20 次发布

发布时间：2020-05-14 08:18:42

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateLane](https://cloud.tencent.com/document/api/649/44508)
* [CreateLaneRule](https://cloud.tencent.com/document/api/649/44507)
* [DeleteLane](https://cloud.tencent.com/document/api/649/44506)
* [DescribeLaneRules](https://cloud.tencent.com/document/api/649/44505)
* [DescribeLanes](https://cloud.tencent.com/document/api/649/44504)
* [ModifyLane](https://cloud.tencent.com/document/api/649/44503)
* [ModifyLaneRule](https://cloud.tencent.com/document/api/649/44502)

新增数据结构：

* [LaneGroup](https://cloud.tencent.com/document/api/649/36099#LaneGroup)
* [LaneInfo](https://cloud.tencent.com/document/api/649/36099#LaneInfo)
* [LaneInfos](https://cloud.tencent.com/document/api/649/36099#LaneInfos)
* [LaneRule](https://cloud.tencent.com/document/api/649/36099#LaneRule)
* [LaneRuleTag](https://cloud.tencent.com/document/api/649/36099#LaneRuleTag)
* [LaneRules](https://cloud.tencent.com/document/api/649/36099#LaneRules)

### 第 19 次发布

发布时间：2020-04-28 08:17:18

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateConfig](https://cloud.tencent.com/document/api/649/38348)

	* 新增入参：EncodeWithBase64

* [CreatePublicConfig](https://cloud.tencent.com/document/api/649/38347)

	* 新增入参：EncodeWithBase64


### 第 18 次发布

发布时间：2020-04-27 08:16:48

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [ContainerGroupDetail](https://cloud.tencent.com/document/api/649/36099#ContainerGroupDetail)

	* 新增成员：UpdatedTime

* [ServerlessGroup](https://cloud.tencent.com/document/api/649/36099#ServerlessGroup)

	* 新增成员：ApplicationName

* [VmGroup](https://cloud.tencent.com/document/api/649/36099#VmGroup)

	* 新增成员：UpdatedTime


### 第 17 次发布

发布时间：2020-04-24 08:16:28

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [VmGroupSimple](https://cloud.tencent.com/document/api/649/36099#VmGroupSimple)

	* 新增成员：UpdatedTime


### 第 16 次发布

发布时间：2020-04-16 08:16:24

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateCluster](https://cloud.tencent.com/document/api/649/36049)

	* <font color="#dd0000">**修改出参**：</font>Result

* [CreateContainGroup](https://cloud.tencent.com/document/api/649/36075)

	* 新增入参：GroupResourceType, SubnetId, AgentCpuRequest, AgentCpuLimit, AgentMemRequest, AgentMemLimit, IstioCpuRequest, IstioCpuLimit, IstioMemRequest, IstioMemLimit

* [CreateGroup](https://cloud.tencent.com/document/api/649/36074)

	* 新增入参：GroupResourceType

* [DeployContainerGroup](https://cloud.tencent.com/document/api/649/36071)

	* 新增入参：AgentCpuRequest, AgentCpuLimit, AgentMemRequest, AgentMemLimit, IstioCpuRequest, IstioCpuLimit, IstioMemRequest, IstioMemLimit


### 第 15 次发布

发布时间：2020-04-08 08:15:17

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [ContainerGroupDetail](https://cloud.tencent.com/document/api/649/36099#ContainerGroupDetail)

	* 新增成员：GroupResourceType, InstanceCount


### 第 14 次发布

发布时间：2020-04-03 08:15:41

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribePodInstances](https://cloud.tencent.com/document/api/649/43108)

新增数据结构：

* [GroupPod](https://cloud.tencent.com/document/api/649/36099#GroupPod)
* [GroupPodResult](https://cloud.tencent.com/document/api/649/36099#GroupPodResult)

### 第 13 次发布

发布时间：2020-03-27 08:14:33

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [SimpleGroup](https://cloud.tencent.com/document/api/649/36099#SimpleGroup)

	* 新增成员：StartupParameters, GroupResourceType, AppMicroServiceType


### 第 12 次发布

发布时间：2020-03-26 08:14:05

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [Instance](https://cloud.tencent.com/document/api/649/36099#Instance)

	* 新增成员：NamespaceName


### 第 11 次发布

发布时间：2020-03-25 08:15:28

本次发布包含了以下内容：

改善已有的文档。

新增数据结构：

* [OperationInfo](https://cloud.tencent.com/document/api/649/36099#OperationInfo)
* [OperationInfoDetail](https://cloud.tencent.com/document/api/649/36099#OperationInfoDetail)

修改数据结构：

* [ApplicationForPage](https://cloud.tencent.com/document/api/649/36099#ApplicationForPage)

	* 新增成员：ApigatewayServiceId

* [Cluster](https://cloud.tencent.com/document/api/649/36099#Cluster)

	* 新增成员：SubnetId, OperationInfo

* [Instance](https://cloud.tencent.com/document/api/649/36099#Instance)

	* 新增成员：NamespaceId, InstanceZoneId, InstanceImportMode, ApplicationType, ApplicationResourceType, ServiceSidecarStatus, GroupName

* [SimpleApplication](https://cloud.tencent.com/document/api/649/36099#SimpleApplication)

	* 新增成员：ApigatewayServiceId, ApplicationRuntimeType

* [VmGroup](https://cloud.tencent.com/document/api/649/36099#VmGroup)

	* 新增成员：ApplicationType, GroupResourceType

* [VmGroupSimple](https://cloud.tencent.com/document/api/649/36099#VmGroupSimple)

	* 新增成员：GroupResourceType


### 第 10 次发布

发布时间：2020-03-20 08:15:02

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [ContainerGroupDetail](https://cloud.tencent.com/document/api/649/36099#ContainerGroupDetail)

	* 新增成员：SubnetId

* [ProtocolPort](https://cloud.tencent.com/document/api/649/36099#ProtocolPort)

	* 新增成员：NodePort


### 第 9 次发布

发布时间：2020-03-16 08:20:03

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [Namespace](https://cloud.tencent.com/document/api/649/36099#Namespace)

	* 新增成员：NamespaceResourceType, NamespaceType


### 第 8 次发布

发布时间：2020-03-13 08:01:00

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeConfigs](https://cloud.tencent.com/document/api/649/38340)

	* 新增入参：ConfigVersion

* [DescribeImageTags](https://cloud.tencent.com/document/api/649/36052)

	* 新增入参：SearchWord

* [DescribePublicConfigs](https://cloud.tencent.com/document/api/649/38335)

	* 新增入参：ConfigVersion


### 第 7 次发布

发布时间：2020-02-13 11:24:39

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateApplication](https://cloud.tencent.com/document/api/649/36094)

	* <font color="#dd0000">**修改入参**：</font>MicroserviceType


### 第 6 次发布

发布时间：2020-02-12 20:55:00

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [AddClusterInstances](https://cloud.tencent.com/document/api/649/41225)

修改接口：

* [CreateApplication](https://cloud.tencent.com/document/api/649/36094)

	* 新增入参：ApplicationRuntimeType

* [CreateCluster](https://cloud.tencent.com/document/api/649/36049)

	* 新增入参：SubnetId

* [CreateNamespace](https://cloud.tencent.com/document/api/649/36098)

	* 新增入参：NamespaceType, NamespaceId

	* <font color="#dd0000">**修改入参**：</font>ClusterId

* [CreateServerlessGroup](https://cloud.tencent.com/document/api/649/39424)

	* 新增入参：NamespaceId, ClusterId

	* <font color="#dd0000">**删除入参**：</font>PkgId, VpcConfig

* [DeleteNamespace](https://cloud.tencent.com/document/api/649/36097)

	* <font color="#dd0000">**修改入参**：</font>ClusterId

* [DeployServerlessGroup](https://cloud.tencent.com/document/api/649/39774)

	* 新增入参：Memory, InstanceRequest, StartupParameters

	* <font color="#dd0000">**删除入参**：</font>VpcConfig

* [DescribeServerlessGroups](https://cloud.tencent.com/document/api/649/39421)

	* 新增入参：NamespaceId, ClusterId

	* <font color="#dd0000">**修改入参**：</font>ApplicationId

* [DescribeSimpleGroups](https://cloud.tencent.com/document/api/649/36064)

	* 新增入参：AppMicroServiceType

* [DescribeSimpleNamespaces](https://cloud.tencent.com/document/api/649/36096)

	* 新增入参：NamespaceName, IsDefault


新增数据结构：

* [AddInstanceResult](https://cloud.tencent.com/document/api/649/36099#AddInstanceResult)

<font color="#dd0000">**删除数据结构**：</font>

* VpcConfig

修改数据结构：

* [ServerlessGroup](https://cloud.tencent.com/document/api/649/36099#ServerlessGroup)

	* 新增成员：Memory, InstanceRequest, StartupParameters, ApplicationId, InstanceCount


### 第 5 次发布

发布时间：2019-11-28 22:22:49

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DeployServerlessGroup](https://cloud.tencent.com/document/api/649/39774)

修改数据结构：

* [ApplicationForPage](https://cloud.tencent.com/document/api/649/36099#ApplicationForPage)

	* 新增成员：ApplicationRuntimeType


### 第 4 次发布

发布时间：2019-11-21 19:59:41

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateServerlessGroup](https://cloud.tencent.com/document/api/649/39424)
* [DeleteServerlessGroup](https://cloud.tencent.com/document/api/649/39423)
* [DescribeServerlessGroup](https://cloud.tencent.com/document/api/649/39422)
* [DescribeServerlessGroups](https://cloud.tencent.com/document/api/649/39421)

新增数据结构：

* [ServerlessGroup](https://cloud.tencent.com/document/api/649/36099#ServerlessGroup)
* [ServerlessGroupPage](https://cloud.tencent.com/document/api/649/36099#ServerlessGroupPage)
* [VpcConfig](https://cloud.tencent.com/document/api/649/36099#VpcConfig)

### 第 3 次发布

发布时间：2019-10-11 21:23:59

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateConfig](https://cloud.tencent.com/document/api/649/38348)
* [CreatePublicConfig](https://cloud.tencent.com/document/api/649/38347)
* [DeleteConfig](https://cloud.tencent.com/document/api/649/38346)
* [DeletePublicConfig](https://cloud.tencent.com/document/api/649/38345)
* [DescribeConfig](https://cloud.tencent.com/document/api/649/38344)
* [DescribeConfigReleaseLogs](https://cloud.tencent.com/document/api/649/38343)
* [DescribeConfigReleases](https://cloud.tencent.com/document/api/649/38342)
* [DescribeConfigSummary](https://cloud.tencent.com/document/api/649/38341)
* [DescribeConfigs](https://cloud.tencent.com/document/api/649/38340)
* [DescribePublicConfig](https://cloud.tencent.com/document/api/649/38339)
* [DescribePublicConfigReleaseLogs](https://cloud.tencent.com/document/api/649/38338)
* [DescribePublicConfigReleases](https://cloud.tencent.com/document/api/649/38337)
* [DescribePublicConfigSummary](https://cloud.tencent.com/document/api/649/38336)
* [DescribePublicConfigs](https://cloud.tencent.com/document/api/649/38335)
* [DescribeReleasedConfig](https://cloud.tencent.com/document/api/649/38334)
* [ReleaseConfig](https://cloud.tencent.com/document/api/649/38333)
* [ReleasePublicConfig](https://cloud.tencent.com/document/api/649/38332)
* [RevocationConfig](https://cloud.tencent.com/document/api/649/38331)
* [RevocationPublicConfig](https://cloud.tencent.com/document/api/649/38330)
* [RollbackConfig](https://cloud.tencent.com/document/api/649/38329)

修改接口：

* [DescribeSimpleApplications](https://cloud.tencent.com/document/api/649/36089)

	* 新增入参：SearchWord

* [DescribeSimpleClusters](https://cloud.tencent.com/document/api/649/36047)

	* 新增入参：SearchWord

* [DescribeSimpleNamespaces](https://cloud.tencent.com/document/api/649/36096)

	* 新增入参：SearchWord, NamespaceTypeList


新增数据结构：

* [Config](https://cloud.tencent.com/document/api/649/36099#Config)
* [ConfigRelease](https://cloud.tencent.com/document/api/649/36099#ConfigRelease)
* [ConfigReleaseLog](https://cloud.tencent.com/document/api/649/36099#ConfigReleaseLog)
* [TsfPageConfig](https://cloud.tencent.com/document/api/649/36099#TsfPageConfig)
* [TsfPageConfigRelease](https://cloud.tencent.com/document/api/649/36099#TsfPageConfigRelease)
* [TsfPageConfigReleaseLog](https://cloud.tencent.com/document/api/649/36099#TsfPageConfigReleaseLog)

### 第 2 次发布

发布时间：2019-08-29 21:00:17

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateApplication](https://cloud.tencent.com/document/api/649/36094)

	* 新增入参：ApplicationResourceType

* [CreateNamespace](https://cloud.tencent.com/document/api/649/36098)

	* 新增入参：NamespaceResourceType

	* <font color="#dd0000">**修改出参**：</font>Result

* [DescribeApplications](https://cloud.tencent.com/document/api/649/36090)

	* 新增入参：ApplicationResourceTypeList

* [DescribeGroups](https://cloud.tencent.com/document/api/649/36065)

	* 新增入参：GroupResourceTypeList

* [DescribeSimpleApplications](https://cloud.tencent.com/document/api/649/36089)

	* 新增入参：ApplicationResourceTypeList

* [DescribeSimpleNamespaces](https://cloud.tencent.com/document/api/649/36096)

	* 新增入参：NamespaceResourceTypeList


修改数据结构：

* [ApplicationForPage](https://cloud.tencent.com/document/api/649/36099#ApplicationForPage)

	* 新增成员：ApplicationResourceType

* [SimpleApplication](https://cloud.tencent.com/document/api/649/36099#SimpleApplication)

	* 新增成员：ApplicationDesc, ProgLang, ApplicationResourceType, CreateTime, UpdateTime


### 第 1 次发布

发布时间：2019-07-04 21:24:14

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [AddInstances](https://cloud.tencent.com/document/api/649/36050)
* [CreateApplication](https://cloud.tencent.com/document/api/649/36094)
* [CreateCluster](https://cloud.tencent.com/document/api/649/36049)
* [CreateContainGroup](https://cloud.tencent.com/document/api/649/36075)
* [CreateGroup](https://cloud.tencent.com/document/api/649/36074)
* [CreateMicroservice](https://cloud.tencent.com/document/api/649/36087)
* [CreateNamespace](https://cloud.tencent.com/document/api/649/36098)
* [DeleteApplication](https://cloud.tencent.com/document/api/649/36093)
* [DeleteContainerGroup](https://cloud.tencent.com/document/api/649/36073)
* [DeleteGroup](https://cloud.tencent.com/document/api/649/36072)
* [DeleteImageTags](https://cloud.tencent.com/document/api/649/36053)
* [DeleteMicroservice](https://cloud.tencent.com/document/api/649/36086)
* [DeleteNamespace](https://cloud.tencent.com/document/api/649/36097)
* [DeletePkgs](https://cloud.tencent.com/document/api/649/36081)
* [DeployContainerGroup](https://cloud.tencent.com/document/api/649/36071)
* [DeployGroup](https://cloud.tencent.com/document/api/649/36070)
* [DescribeApplication](https://cloud.tencent.com/document/api/649/36092)
* [DescribeApplicationAttribute](https://cloud.tencent.com/document/api/649/36091)
* [DescribeApplications](https://cloud.tencent.com/document/api/649/36090)
* [DescribeClusterInstances](https://cloud.tencent.com/document/api/649/36048)
* [DescribeContainerGroupDetail](https://cloud.tencent.com/document/api/649/36069)
* [DescribeContainerGroups](https://cloud.tencent.com/document/api/649/36068)
* [DescribeDownloadInfo](https://cloud.tencent.com/document/api/649/36080)
* [DescribeGroup](https://cloud.tencent.com/document/api/649/36067)
* [DescribeGroupInstances](https://cloud.tencent.com/document/api/649/36066)
* [DescribeGroups](https://cloud.tencent.com/document/api/649/36065)
* [DescribeImageTags](https://cloud.tencent.com/document/api/649/36052)
* [DescribeMicroservice](https://cloud.tencent.com/document/api/649/36085)
* [DescribeMicroservices](https://cloud.tencent.com/document/api/649/36084)
* [DescribePkgs](https://cloud.tencent.com/document/api/649/36079)
* [DescribeSimpleApplications](https://cloud.tencent.com/document/api/649/36089)
* [DescribeSimpleClusters](https://cloud.tencent.com/document/api/649/36047)
* [DescribeSimpleGroups](https://cloud.tencent.com/document/api/649/36064)
* [DescribeSimpleNamespaces](https://cloud.tencent.com/document/api/649/36096)
* [DescribeUploadInfo](https://cloud.tencent.com/document/api/649/36078)
* [ExpandGroup](https://cloud.tencent.com/document/api/649/36063)
* [ModifyContainerGroup](https://cloud.tencent.com/document/api/649/36062)
* [ModifyContainerReplicas](https://cloud.tencent.com/document/api/649/36061)
* [ModifyMicroservice](https://cloud.tencent.com/document/api/649/36083)
* [ModifyUploadInfo](https://cloud.tencent.com/document/api/649/36077)
* [RemoveInstances](https://cloud.tencent.com/document/api/649/36046)
* [ShrinkGroup](https://cloud.tencent.com/document/api/649/36060)
* [ShrinkInstances](https://cloud.tencent.com/document/api/649/36059)
* [StartContainerGroup](https://cloud.tencent.com/document/api/649/36058)
* [StartGroup](https://cloud.tencent.com/document/api/649/36057)
* [StopContainerGroup](https://cloud.tencent.com/document/api/649/36056)
* [StopGroup](https://cloud.tencent.com/document/api/649/36055)

新增数据结构：

* [ApplicationAttribute](https://cloud.tencent.com/document/api/649/36099#ApplicationAttribute)
* [ApplicationForPage](https://cloud.tencent.com/document/api/649/36099#ApplicationForPage)
* [Cluster](https://cloud.tencent.com/document/api/649/36099#Cluster)
* [ContainGroup](https://cloud.tencent.com/document/api/649/36099#ContainGroup)
* [ContainGroupResult](https://cloud.tencent.com/document/api/649/36099#ContainGroupResult)
* [ContainerGroupDetail](https://cloud.tencent.com/document/api/649/36099#ContainerGroupDetail)
* [CosCredentials](https://cloud.tencent.com/document/api/649/36099#CosCredentials)
* [CosDownloadInfo](https://cloud.tencent.com/document/api/649/36099#CosDownloadInfo)
* [CosUploadInfo](https://cloud.tencent.com/document/api/649/36099#CosUploadInfo)
* [DeleteImageTag](https://cloud.tencent.com/document/api/649/36099#DeleteImageTag)
* [Env](https://cloud.tencent.com/document/api/649/36099#Env)
* [ImageTag](https://cloud.tencent.com/document/api/649/36099#ImageTag)
* [ImageTagsResult](https://cloud.tencent.com/document/api/649/36099#ImageTagsResult)
* [Instance](https://cloud.tencent.com/document/api/649/36099#Instance)
* [Microservice](https://cloud.tencent.com/document/api/649/36099#Microservice)
* [MsInstance](https://cloud.tencent.com/document/api/649/36099#MsInstance)
* [Namespace](https://cloud.tencent.com/document/api/649/36099#Namespace)
* [PkgInfo](https://cloud.tencent.com/document/api/649/36099#PkgInfo)
* [PkgList](https://cloud.tencent.com/document/api/649/36099#PkgList)
* [ProtocolPort](https://cloud.tencent.com/document/api/649/36099#ProtocolPort)
* [SimpleApplication](https://cloud.tencent.com/document/api/649/36099#SimpleApplication)
* [SimpleGroup](https://cloud.tencent.com/document/api/649/36099#SimpleGroup)
* [TaskId](https://cloud.tencent.com/document/api/649/36099#TaskId)
* [TsfPageApplication](https://cloud.tencent.com/document/api/649/36099#TsfPageApplication)
* [TsfPageCluster](https://cloud.tencent.com/document/api/649/36099#TsfPageCluster)
* [TsfPageInstance](https://cloud.tencent.com/document/api/649/36099#TsfPageInstance)
* [TsfPageMicroservice](https://cloud.tencent.com/document/api/649/36099#TsfPageMicroservice)
* [TsfPageMsInstance](https://cloud.tencent.com/document/api/649/36099#TsfPageMsInstance)
* [TsfPageNamespace](https://cloud.tencent.com/document/api/649/36099#TsfPageNamespace)
* [TsfPageSimpleApplication](https://cloud.tencent.com/document/api/649/36099#TsfPageSimpleApplication)
* [TsfPageSimpleGroup](https://cloud.tencent.com/document/api/649/36099#TsfPageSimpleGroup)
* [TsfPageVmGroup](https://cloud.tencent.com/document/api/649/36099#TsfPageVmGroup)
* [VmGroup](https://cloud.tencent.com/document/api/649/36099#VmGroup)
* [VmGroupSimple](https://cloud.tencent.com/document/api/649/36099#VmGroupSimple)




## 腾讯同传系统(tsi) 版本：2021-03-25

### 第 1 次发布

发布时间：2024-06-24 10:37:18

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [TongChuanDisplay](https://cloud.tencent.com/document/api/1399/107636)
* [TongChuanRecognize](https://cloud.tencent.com/document/api/1399/107635)
* [TongChuanSync](https://cloud.tencent.com/document/api/1399/107634)

新增数据结构：

* [DisplayInfo](https://cloud.tencent.com/document/api/1399/107637#DisplayInfo)




## 微服务观测平台 TSW(tsw) 版本：2020-09-24

### 第 1 次发布

发布时间：2021-02-04 08:50:31

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeAgentShell](https://cloud.tencent.com/document/api/1311/53236)

新增数据结构：

* [AgentShell](https://cloud.tencent.com/document/api/1311/53237#AgentShell)



## 微服务观测平台 TSW(tsw) 版本：2021-04-12

### 第 2 次发布

发布时间：2021-04-30 08:10:47

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeToken](https://cloud.tencent.com/document/api/1311/55324)

### 第 1 次发布

发布时间：2021-04-08 08:10:21

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeComponentAlertObject](https://cloud.tencent.com/document/api/1311/54519)
* [DescribeServiceAlertObject](https://cloud.tencent.com/document/api/1311/54521)




## 语音合成(tts) 版本：2019-08-23

### 第 15 次发布

发布时间：2024-04-02 01:26:37

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateTtsTask](https://cloud.tencent.com/document/api/1073/57373)

	* <font color="#dd0000">**修改入参**：</font>ModelType


### 第 14 次发布

发布时间：2024-03-28 01:30:03

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [TextToVoice](https://cloud.tencent.com/document/api/1073/37995)

	* 新增入参：FastVoiceType


### 第 13 次发布

发布时间：2023-11-27 00:22:20

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [Subtitle](https://cloud.tencent.com/document/api/1073/57374#Subtitle)

	* <font color="#dd0000">**修改成员**：</font>Phoneme


### 第 12 次发布

发布时间：2023-09-19 01:29:02

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateTtsTask](https://cloud.tencent.com/document/api/1073/57373)

	* 新增入参：EmotionCategory, EmotionIntensity


### 第 11 次发布

发布时间：2023-08-22 01:22:20

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateTtsTask](https://cloud.tencent.com/document/api/1073/57373)

	* 新增入参：EnableSubtitle


修改数据结构：

* [DescribeTtsTaskStatusRespData](https://cloud.tencent.com/document/api/1073/57374#DescribeTtsTaskStatusRespData)

	* 新增成员：Subtitles


### 第 10 次发布

发布时间：2023-04-20 01:49:24

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [TextToVoice](https://cloud.tencent.com/document/api/1073/37995)

	* 新增入参：EmotionCategory, EmotionIntensity


### 第 9 次发布

发布时间：2023-03-29 04:28:22

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [Subtitle](https://cloud.tencent.com/document/api/1073/57374#Subtitle)

	* 新增成员：Phoneme


### 第 8 次发布

发布时间：2022-11-18 06:58:13

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [TextToVoice](https://cloud.tencent.com/document/api/1073/37995)

	* 新增入参：SegmentRate


### 第 7 次发布

发布时间：2022-08-15 06:46:14

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [TextToVoice](https://cloud.tencent.com/document/api/1073/37995)

	* 新增入参：EnableSubtitle

	* 新增出参：Subtitles


新增数据结构：

* [Subtitle](https://cloud.tencent.com/document/api/1073/57374#Subtitle)

### 第 6 次发布

发布时间：2022-01-18 08:17:37

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [TextToVoice](https://cloud.tencent.com/document/api/1073/37995)

	* <font color="#dd0000">**修改入参**：</font>ModelType


### 第 5 次发布

发布时间：2021-07-09 08:09:15

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateTtsTask](https://cloud.tencent.com/document/api/1073/57373)

	* 新增入参：VoiceoverDialogueSplit


### 第 4 次发布

发布时间：2021-06-16 08:09:10

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateTtsTask](https://cloud.tencent.com/document/api/1073/57373)
* [DescribeTtsTaskStatus](https://cloud.tencent.com/document/api/1073/57372)

新增数据结构：

* [CreateTtsTaskRespData](https://cloud.tencent.com/document/api/1073/57374#CreateTtsTaskRespData)
* [DescribeTtsTaskStatusRespData](https://cloud.tencent.com/document/api/1073/57374#DescribeTtsTaskStatusRespData)

### 第 3 次发布

发布时间：2020-11-02 08:06:55

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [TextToVoice](https://cloud.tencent.com/document/api/1073/37995)

	* 新增出参：Audio, SessionId


### 第 2 次发布

发布时间：2020-10-23 08:08:54

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [TextToVoice](https://cloud.tencent.com/document/api/1073/37995)

	* <font color="#dd0000">**删除出参**：</font>Audio, SessionId


### 第 1 次发布

发布时间：2019-09-12 19:31:39

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [TextToVoice](https://cloud.tencent.com/document/api/1073/37995)




## 客流数字化平台(ump) 版本：2020-09-18

### 第 5 次发布

发布时间：2024-01-23 01:31:22

本次发布包含了以下内容：

改善已有的文档。

<font color="#dd0000">**预下线接口**：</font>

* CreateCameraAlerts
* CreateCameraState
* CreateMultiBizAlert
* CreateProgramState
* CreateServerState
* DeleteMultiBizAlert
* DeleteTask
* DescribeCameras
* DescribeConfig
* DescribeImage
* DescribeMultiBizBaseImage
* DescribeTasks
* DescribeZones
* ModifyMultiBizConfig
* ReportServiceRegister
* SearchImage

### 第 4 次发布

发布时间：2024-01-22 01:24:15

本次发布包含了以下内容：

改善已有的文档。

<font color="#dd0000">**预下线接口**：</font>

* CreateCapture

### 第 3 次发布

发布时间：2021-02-25 08:00:15

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateCameraState](https://cloud.tencent.com/document/api/1320/53127)
* [ModifyMultiBizConfig](https://cloud.tencent.com/document/api/1320/53126)
* [ReportServiceRegister](https://cloud.tencent.com/document/api/1320/53125)

修改接口：

* [CreateMultiBizAlert](https://cloud.tencent.com/document/api/1320/50569)

	* 新增入参：Warnings


新增数据结构：

* [CameraState](https://cloud.tencent.com/document/api/1320/50571#CameraState)
* [MultiBizWarning](https://cloud.tencent.com/document/api/1320/50571#MultiBizWarning)
* [MultiBizWarningInfo](https://cloud.tencent.com/document/api/1320/50571#MultiBizWarningInfo)
* [ServiceRegisterInfo](https://cloud.tencent.com/document/api/1320/50571#ServiceRegisterInfo)

修改数据结构：

* [CameraZones](https://cloud.tencent.com/document/api/1320/50571#CameraZones)

	* 新增成员：RTSP


### 第 2 次发布

发布时间：2020-12-04 08:00:04

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateCapture](https://cloud.tencent.com/document/api/1320/50684)

### 第 1 次发布

发布时间：2020-12-02 15:43:32

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateCameraAlerts](https://cloud.tencent.com/document/api/1320/50570)
* [CreateMultiBizAlert](https://cloud.tencent.com/document/api/1320/50569)
* [CreateProgramState](https://cloud.tencent.com/document/api/1320/50568)
* [CreateServerState](https://cloud.tencent.com/document/api/1320/50567)
* [DeleteMultiBizAlert](https://cloud.tencent.com/document/api/1320/50566)
* [DeleteTask](https://cloud.tencent.com/document/api/1320/50565)
* [DescribeCameras](https://cloud.tencent.com/document/api/1320/50564)
* [DescribeConfig](https://cloud.tencent.com/document/api/1320/50563)
* [DescribeImage](https://cloud.tencent.com/document/api/1320/50562)
* [DescribeMultiBizBaseImage](https://cloud.tencent.com/document/api/1320/50561)
* [DescribeTasks](https://cloud.tencent.com/document/api/1320/50560)
* [DescribeZones](https://cloud.tencent.com/document/api/1320/50559)
* [SearchImage](https://cloud.tencent.com/document/api/1320/50557)

新增数据结构：

* [BunkZone](https://cloud.tencent.com/document/api/1320/50571#BunkZone)
* [CameraConfig](https://cloud.tencent.com/document/api/1320/50571#CameraConfig)
* [CameraZones](https://cloud.tencent.com/document/api/1320/50571#CameraZones)
* [Config](https://cloud.tencent.com/document/api/1320/50571#Config)
* [CreateCameraAlertAlert](https://cloud.tencent.com/document/api/1320/50571#CreateCameraAlertAlert)
* [CreateCameraAlertsCoverAlert](https://cloud.tencent.com/document/api/1320/50571#CreateCameraAlertsCoverAlert)
* [CreateCameraAlertsMoveAlert](https://cloud.tencent.com/document/api/1320/50571#CreateCameraAlertsMoveAlert)
* [DiskInfo](https://cloud.tencent.com/document/api/1320/50571#DiskInfo)
* [Point](https://cloud.tencent.com/document/api/1320/50571#Point)
* [Polygon](https://cloud.tencent.com/document/api/1320/50571#Polygon)
* [ProgramStateItem](https://cloud.tencent.com/document/api/1320/50571#ProgramStateItem)
* [SearchResult](https://cloud.tencent.com/document/api/1320/50571#SearchResult)
* [ServerStateItem](https://cloud.tencent.com/document/api/1320/50571#ServerStateItem)
* [Task](https://cloud.tencent.com/document/api/1320/50571#Task)
* [TaskContent](https://cloud.tencent.com/document/api/1320/50571#TaskContent)
* [ZoneArea](https://cloud.tencent.com/document/api/1320/50571#ZoneArea)
* [ZoneConfig](https://cloud.tencent.com/document/api/1320/50571#ZoneConfig)




## 视频生成(vcg) 版本：2024-04-04

### 第 1 次发布

发布时间：2024-05-16 16:26:14

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeVideoStylizationJob](https://cloud.tencent.com/document/api/1770/106290)
* [SubmitVideoStylizationJob](https://cloud.tencent.com/document/api/1770/106289)




## 大模型视频创作引擎(vclm) 版本：2024-05-23

### 第 4 次发布

发布时间：2024-07-29 02:25:41

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribePortraitSingJob](https://cloud.tencent.com/document/api/1616/109379)
* [SubmitPortraitSingJob](https://cloud.tencent.com/document/api/1616/109378)

### 第 3 次发布

发布时间：2024-07-24 02:24:15

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [SubmitVideoStylizationJob](https://cloud.tencent.com/document/api/1616/107802)

	* 新增入参：StyleStrength


### 第 2 次发布

发布时间：2024-06-28 01:22:51

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [ConfirmVideoTranslateJob](https://cloud.tencent.com/document/api/1616/107807)
* [DescribeVideoStylizationJob](https://cloud.tencent.com/document/api/1616/107803)
* [DescribeVideoTranslateJob](https://cloud.tencent.com/document/api/1616/107806)
* [SubmitVideoStylizationJob](https://cloud.tencent.com/document/api/1616/107802)
* [SubmitVideoTranslateJob](https://cloud.tencent.com/document/api/1616/107805)

新增数据结构：

* [AsrTimestamps](https://cloud.tencent.com/document/api/1616/107808#AsrTimestamps)
* [TranslateResult](https://cloud.tencent.com/document/api/1616/107808#TranslateResult)

### 第 1 次发布

发布时间：2024-06-27 17:13:58

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeImageAnimateJob](https://cloud.tencent.com/document/api/1616/107785)
* [SubmitImageAnimateJob](https://cloud.tencent.com/document/api/1616/107784)




## 向量数据库(vdb) 版本：2023-06-16

### 第 2 次发布

发布时间：2024-06-28 01:22:56

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [InstanceInfo](https://cloud.tencent.com/document/api/1709/106757#InstanceInfo)

	* 新增成员：IsolateAt, AutoRenew


### 第 1 次发布

发布时间：2024-06-03 15:48:04

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeInstances](https://cloud.tencent.com/document/api/1709/106756)

新增数据结构：

* [InstanceInfo](https://cloud.tencent.com/document/api/1709/106757#InstanceInfo)
* [Network](https://cloud.tencent.com/document/api/1709/106757#Network)
* [Tag](https://cloud.tencent.com/document/api/1709/106757#Tag)




## 视频内容安全(vm) 版本：2020-07-09

### 第 1 次发布

发布时间：2021-01-12 17:45:06

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CancelTask](https://cloud.tencent.com/document/api/#/#)
* [CreateBizConfig](https://cloud.tencent.com/document/api/#/#)
* [CreateVideoModerationTask](https://cloud.tencent.com/document/api/#/#)
* [DescribeTaskDetail](https://cloud.tencent.com/document/api/#/#)
* [DescribeVideoStat](https://cloud.tencent.com/document/api/#/#)

新增数据结构：

* [AudioResult](https://cloud.tencent.com/document/api/#/##AudioResult)
* [AudioResultDetailLanguageResult](https://cloud.tencent.com/document/api/#/##AudioResultDetailLanguageResult)
* [AudioResultDetailMoanResult](https://cloud.tencent.com/document/api/#/##AudioResultDetailMoanResult)
* [AudioResultDetailTextResult](https://cloud.tencent.com/document/api/#/##AudioResultDetailTextResult)
* [AudioSegments](https://cloud.tencent.com/document/api/#/##AudioSegments)
* [BucketInfo](https://cloud.tencent.com/document/api/#/##BucketInfo)
* [EvilCount](https://cloud.tencent.com/document/api/#/##EvilCount)
* [FileOutput](https://cloud.tencent.com/document/api/#/##FileOutput)
* [Filters](https://cloud.tencent.com/document/api/#/##Filters)
* [ImageResult](https://cloud.tencent.com/document/api/#/##ImageResult)
* [ImageResultResult](https://cloud.tencent.com/document/api/#/##ImageResultResult)
* [ImageResultsResultDetail](https://cloud.tencent.com/document/api/#/##ImageResultsResultDetail)
* [ImageResultsResultDetailLocation](https://cloud.tencent.com/document/api/#/##ImageResultsResultDetailLocation)
* [ImageSegments](https://cloud.tencent.com/document/api/#/##ImageSegments)
* [InputInfo](https://cloud.tencent.com/document/api/#/##InputInfo)
* [MediaInfo](https://cloud.tencent.com/document/api/#/##MediaInfo)
* [MediaModerationConfig](https://cloud.tencent.com/document/api/#/##MediaModerationConfig)
* [Overview](https://cloud.tencent.com/document/api/#/##Overview)
* [StorageInfo](https://cloud.tencent.com/document/api/#/##StorageInfo)
* [TaskInput](https://cloud.tencent.com/document/api/#/##TaskInput)
* [TaskLabel](https://cloud.tencent.com/document/api/#/##TaskLabel)
* [TaskResult](https://cloud.tencent.com/document/api/#/##TaskResult)
* [TrendCount](https://cloud.tencent.com/document/api/#/##TrendCount)



## 视频内容安全(vm) 版本：2020-12-29

### 第 8 次发布

发布时间：2024-07-26 02:26:27

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeTaskDetail](https://cloud.tencent.com/document/api/1265/51878)

	* 新增出参：SegmentCosUrlList, AudioText, TryInSeconds, Asrs


新增数据结构：

* [RcbAsr](https://cloud.tencent.com/document/api/1265/51881#RcbAsr)
* [SegmentCosUrlList](https://cloud.tencent.com/document/api/1265/51881#SegmentCosUrlList)

修改数据结构：

* [ImageResult](https://cloud.tencent.com/document/api/1265/51881#ImageResult)

	* 新增成员：RecognitionResults

* [ImageResultsResultDetail](https://cloud.tencent.com/document/api/1265/51881#ImageResultsResultDetail)

	* 新增成员：SubLabel

* [ImageSegments](https://cloud.tencent.com/document/api/1265/51881#ImageSegments)

	* 新增成员：CreatedAt, OffsetusTime


### 第 7 次发布

发布时间：2023-02-07 02:12:35

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [TaskData](https://cloud.tencent.com/document/api/1265/51881#TaskData)

	* 新增成员：InputInfo


### 第 6 次发布

发布时间：2022-08-16 06:49:06

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [AudioResultDetailMoanResult](https://cloud.tencent.com/document/api/1265/51881#AudioResultDetailMoanResult)

	* 新增成员：Suggestion


### 第 5 次发布

发布时间：2022-06-17 06:16:09

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeTaskDetail](https://cloud.tencent.com/document/api/1265/51878)

	* 新增出参：Label


### 第 4 次发布

发布时间：2022-06-09 06:19:53

本次发布包含了以下内容：

改善已有的文档。

新增数据结构：

* [RecognitionResult](https://cloud.tencent.com/document/api/1265/51881#RecognitionResult)
* [Tag](https://cloud.tencent.com/document/api/1265/51881#Tag)

修改数据结构：

* [AudioResult](https://cloud.tencent.com/document/api/1265/51881#AudioResult)

	* 新增成员：RecognitionResults


### 第 3 次发布

发布时间：2021-12-20 08:14:38

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [AudioResult](https://cloud.tencent.com/document/api/1265/51881#AudioResult)

	* 新增成员：SubLabel

* [AudioResultDetailMoanResult](https://cloud.tencent.com/document/api/1265/51881#AudioResultDetailMoanResult)

	* 新增成员：SubLabel

* [AudioResultDetailTextResult](https://cloud.tencent.com/document/api/1265/51881#AudioResultDetailTextResult)

	* 新增成员：SubLabel

* [ImageResult](https://cloud.tencent.com/document/api/1265/51881#ImageResult)

	* 新增成员：SubLabel

* [TaskLabel](https://cloud.tencent.com/document/api/1265/51881#TaskLabel)

	* 新增成员：SubLabel


### 第 2 次发布

发布时间：2021-01-13 08:00:04

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeTasks](https://cloud.tencent.com/document/api/1265/51902)

新增数据结构：

* [TaskData](https://cloud.tencent.com/document/api/1265/51881#TaskData)
* [TaskFilter](https://cloud.tencent.com/document/api/1265/51881#TaskFilter)

### 第 1 次发布

发布时间：2021-01-12 17:45:06

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CancelTask](https://cloud.tencent.com/document/api/1265/51880)
* [CreateVideoModerationTask](https://cloud.tencent.com/document/api/1265/51879)
* [DescribeTaskDetail](https://cloud.tencent.com/document/api/1265/51878)

新增数据结构：

* [AudioResult](https://cloud.tencent.com/document/api/1265/51881#AudioResult)
* [AudioResultDetailLanguageResult](https://cloud.tencent.com/document/api/1265/51881#AudioResultDetailLanguageResult)
* [AudioResultDetailMoanResult](https://cloud.tencent.com/document/api/1265/51881#AudioResultDetailMoanResult)
* [AudioResultDetailTextResult](https://cloud.tencent.com/document/api/1265/51881#AudioResultDetailTextResult)
* [AudioSegments](https://cloud.tencent.com/document/api/1265/51881#AudioSegments)
* [BucketInfo](https://cloud.tencent.com/document/api/1265/51881#BucketInfo)
* [ImageResult](https://cloud.tencent.com/document/api/1265/51881#ImageResult)
* [ImageResultResult](https://cloud.tencent.com/document/api/1265/51881#ImageResultResult)
* [ImageResultsResultDetail](https://cloud.tencent.com/document/api/1265/51881#ImageResultsResultDetail)
* [ImageResultsResultDetailLocation](https://cloud.tencent.com/document/api/1265/51881#ImageResultsResultDetailLocation)
* [ImageSegments](https://cloud.tencent.com/document/api/1265/51881#ImageSegments)
* [InputInfo](https://cloud.tencent.com/document/api/1265/51881#InputInfo)
* [MediaInfo](https://cloud.tencent.com/document/api/1265/51881#MediaInfo)
* [StorageInfo](https://cloud.tencent.com/document/api/1265/51881#StorageInfo)
* [TaskInput](https://cloud.tencent.com/document/api/1265/51881#TaskInput)
* [TaskLabel](https://cloud.tencent.com/document/api/1265/51881#TaskLabel)
* [TaskResult](https://cloud.tencent.com/document/api/1265/51881#TaskResult)



## 视频内容安全(vm) 版本：2021-09-22

### 第 6 次发布

发布时间：2023-12-22 01:27:31

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateVideoModerationTask](https://cloud.tencent.com/document/api/1265/80017)

	* 新增入参：User


新增数据结构：

* [User](https://cloud.tencent.com/document/api/1265/80019#User)

### 第 5 次发布

发布时间：2023-11-10 01:28:11

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeTaskDetail](https://cloud.tencent.com/document/api/1265/80016)

	* 新增出参：SegmentCosUrlList


新增数据结构：

* [SegmentCosUrlList](https://cloud.tencent.com/document/api/1265/80019#SegmentCosUrlList)

修改数据结构：

* [TaskLabel](https://cloud.tencent.com/document/api/1265/80019#TaskLabel)

	* 新增成员：SubLabel


### 第 4 次发布

发布时间：2022-09-16 06:48:14

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [AudioResultDetailTextResult](https://cloud.tencent.com/document/api/1265/80019#AudioResultDetailTextResult)

	* 新增成员：SubLabel


### 第 3 次发布

发布时间：2022-09-14 06:42:07

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeTaskDetail](https://cloud.tencent.com/document/api/1265/80016)

	* 新增出参：Label, AudioText, Asrs


新增数据结构：

* [RcbAsr](https://cloud.tencent.com/document/api/1265/80019#RcbAsr)

修改数据结构：

* [MediaInfo](https://cloud.tencent.com/document/api/1265/80019#MediaInfo)

	* 新增成员：Thumbnail


### 第 2 次发布

发布时间：2022-09-08 06:47:59

本次发布包含了以下内容：

改善已有的文档。

新增数据结构：

* [RecognitionResult](https://cloud.tencent.com/document/api/1265/80019#RecognitionResult)
* [Tag](https://cloud.tencent.com/document/api/1265/80019#Tag)

修改数据结构：

* [AudioResult](https://cloud.tencent.com/document/api/1265/80019#AudioResult)

	* 新增成员：SubLabel, RecognitionResults

* [AudioResultDetailMoanResult](https://cloud.tencent.com/document/api/1265/80019#AudioResultDetailMoanResult)

	* 新增成员：SubLabel, Suggestion


### 第 1 次发布

发布时间：2022-09-01 20:31:39

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CancelTask](https://cloud.tencent.com/document/api/1265/80018)
* [CreateVideoModerationTask](https://cloud.tencent.com/document/api/1265/80017)
* [DescribeTaskDetail](https://cloud.tencent.com/document/api/1265/80016)
* [DescribeTasks](https://cloud.tencent.com/document/api/1265/80015)

新增数据结构：

* [AudioResult](https://cloud.tencent.com/document/api/1265/80019#AudioResult)
* [AudioResultDetailLanguageResult](https://cloud.tencent.com/document/api/1265/80019#AudioResultDetailLanguageResult)
* [AudioResultDetailMoanResult](https://cloud.tencent.com/document/api/1265/80019#AudioResultDetailMoanResult)
* [AudioResultDetailTextResult](https://cloud.tencent.com/document/api/1265/80019#AudioResultDetailTextResult)
* [AudioSegments](https://cloud.tencent.com/document/api/1265/80019#AudioSegments)
* [BucketInfo](https://cloud.tencent.com/document/api/1265/80019#BucketInfo)
* [ImageResult](https://cloud.tencent.com/document/api/1265/80019#ImageResult)
* [ImageResultResult](https://cloud.tencent.com/document/api/1265/80019#ImageResultResult)
* [ImageResultsResultDetail](https://cloud.tencent.com/document/api/1265/80019#ImageResultsResultDetail)
* [ImageResultsResultDetailLocation](https://cloud.tencent.com/document/api/1265/80019#ImageResultsResultDetailLocation)
* [ImageSegments](https://cloud.tencent.com/document/api/1265/80019#ImageSegments)
* [InputInfo](https://cloud.tencent.com/document/api/1265/80019#InputInfo)
* [MediaInfo](https://cloud.tencent.com/document/api/1265/80019#MediaInfo)
* [StorageInfo](https://cloud.tencent.com/document/api/1265/80019#StorageInfo)
* [TaskData](https://cloud.tencent.com/document/api/1265/80019#TaskData)
* [TaskFilter](https://cloud.tencent.com/document/api/1265/80019#TaskFilter)
* [TaskInput](https://cloud.tencent.com/document/api/1265/80019#TaskInput)
* [TaskLabel](https://cloud.tencent.com/document/api/1265/80019#TaskLabel)
* [TaskResult](https://cloud.tencent.com/document/api/1265/80019#TaskResult)




## 语音消息(vms) 版本：2020-09-02

### 第 2 次发布

发布时间：2021-01-27 08:00:09

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [SendTtsVoice](https://cloud.tencent.com/document/api/1128/51558)

	* <font color="#dd0000">**修改入参**：</font>TemplateParamSet


### 第 1 次发布

发布时间：2020-12-28 20:12:56

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [SendCodeVoice](https://cloud.tencent.com/document/api/1128/51559)
* [SendTtsVoice](https://cloud.tencent.com/document/api/1128/51558)

新增数据结构：

* [SendStatus](https://cloud.tencent.com/document/api/1128/51560#SendStatus)




## 云点播(vod) 版本：2018-07-17

### 第 182 次发布

发布时间：2024-07-05 01:20:46

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [SimpleHlsClip](https://cloud.tencent.com/document/api/266/33428)

	* 新增入参：Precision, OutputMediaType


### 第 181 次发布

发布时间：2024-05-17 02:33:00

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [SimpleHlsClip](https://cloud.tencent.com/document/api/266/33428)

	* 新增入参：ExtInfo


### 第 180 次发布

发布时间：2024-04-18 01:33:31

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [RestoreMedia](https://cloud.tencent.com/document/api/266/75728)

	* <font color="#dd0000">**修改入参**：</font>RestoreDay


### 第 179 次发布

发布时间：2024-03-01 01:28:03

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeDefaultDistributionConfig](https://cloud.tencent.com/document/api/266/104040)
* [ModifyDefaultDistributionConfig](https://cloud.tencent.com/document/api/266/104039)

修改接口：

* [CreateDomainVerifyRecord](https://cloud.tencent.com/document/api/266/97950)

	* 新增入参：Domain


### 第 178 次发布

发布时间：2024-01-25 01:25:21

本次发布包含了以下内容：

改善已有的文档。

新增数据结构：

* [MediaCastEvent](https://cloud.tencent.com/document/api/266/31773#MediaCastEvent)

修改数据结构：

* [EventContent](https://cloud.tencent.com/document/api/266/31773#EventContent)

	* 新增成员：MediaCastStatusChangedEvent


### 第 177 次发布

发布时间：2024-01-09 01:28:56

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateCLSLogset](https://cloud.tencent.com/document/api/266/102922)
* [CreateCLSTopic](https://cloud.tencent.com/document/api/266/102921)
* [DeleteCLSTopic](https://cloud.tencent.com/document/api/266/102920)
* [DescribeCLSLogsets](https://cloud.tencent.com/document/api/266/102919)
* [DescribeCLSPushTargets](https://cloud.tencent.com/document/api/266/102918)
* [DescribeCLSTopics](https://cloud.tencent.com/document/api/266/102917)
* [SetCLSPushTarget](https://cloud.tencent.com/document/api/266/102916)

新增数据结构：

* [AreaCLSTargetInfo](https://cloud.tencent.com/document/api/266/31773#AreaCLSTargetInfo)
* [CLSLogsetInfo](https://cloud.tencent.com/document/api/266/31773#CLSLogsetInfo)
* [CLSTopicInfo](https://cloud.tencent.com/document/api/266/31773#CLSTopicInfo)
* [DomainCLSTargetInfo](https://cloud.tencent.com/document/api/266/31773#DomainCLSTargetInfo)

### 第 176 次发布

发布时间：2023-12-21 02:21:45

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [EnhanceMediaQuality](https://cloud.tencent.com/document/api/266/102571)

新增数据结构：

* [EnhanceMediaQualityOutputConfig](https://cloud.tencent.com/document/api/266/31773#EnhanceMediaQualityOutputConfig)

### 第 175 次发布

发布时间：2023-12-04 00:22:12

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [EventContent](https://cloud.tencent.com/document/api/266/31773#EventContent)

	* 新增成员：QualityEnhanceCompleteEvent

	* <font color="#dd0000">**修改成员**：</font>ExtractCopyRightWatermarkCompleteEvent, QualityInspectCompleteEvent


### 第 174 次发布

发布时间：2023-11-30 07:24:28

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [SetVodDomainCertificate](https://cloud.tencent.com/document/api/266/102015)

	* 新增入参：Domain, Operation, SubAppId, CertID


### 第 173 次发布

发布时间：2023-11-29 02:07:53

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [SetVodDomainCertificate](https://cloud.tencent.com/document/api/266/102015)

修改数据结构：

* [EditMediaVideoStream](https://cloud.tencent.com/document/api/266/31773#EditMediaVideoStream)

	* 新增成员：Codec, Bitrate


### 第 172 次发布

发布时间：2023-11-28 01:29:30

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [DomainHTTPSConfig](https://cloud.tencent.com/document/api/266/31773#DomainHTTPSConfig)

	* 新增成员：CloudCertId


### 第 171 次发布

发布时间：2023-11-22 07:26:03

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeTaskDetail](https://cloud.tencent.com/document/api/266/33431)

	* 新增出参：QualityEnhanceTask


新增数据结构：

* [QualityEnhanceTask](https://cloud.tencent.com/document/api/266/31773#QualityEnhanceTask)
* [QualityEnhanceTaskInput](https://cloud.tencent.com/document/api/266/31773#QualityEnhanceTaskInput)
* [QualityEnhanceTaskOutput](https://cloud.tencent.com/document/api/266/31773#QualityEnhanceTaskOutput)

### 第 170 次发布

发布时间：2023-11-16 01:35:27

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateJustInTimeTranscodeTemplate](https://cloud.tencent.com/document/api/266/101622)
* [DeleteJustInTimeTranscodeTemplate](https://cloud.tencent.com/document/api/266/101621)
* [DescribeJustInTimeTranscodeTemplates](https://cloud.tencent.com/document/api/266/101620)
* [ModifyJustInTimeTranscodeTemplate](https://cloud.tencent.com/document/api/266/101619)

新增数据结构：

* [JustInTimeTranscodeTemplate](https://cloud.tencent.com/document/api/266/31773#JustInTimeTranscodeTemplate)
* [VideoConfigureInfo](https://cloud.tencent.com/document/api/266/31773#VideoConfigureInfo)
* [VideoConfigureInfoForUpdate](https://cloud.tencent.com/document/api/266/31773#VideoConfigureInfoForUpdate)
* [WatermarkConfigureData](https://cloud.tencent.com/document/api/266/31773#WatermarkConfigureData)
* [WatermarkConfigureInfo](https://cloud.tencent.com/document/api/266/31773#WatermarkConfigureInfo)
* [WatermarkConfigureInfoForUpdate](https://cloud.tencent.com/document/api/266/31773#WatermarkConfigureInfoForUpdate)

### 第 169 次发布

发布时间：2023-11-15 02:37:10

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [OutputAudioStream](https://cloud.tencent.com/document/api/266/31773#OutputAudioStream)

	* 新增成员：Bitrate


### 第 168 次发布

发布时间：2023-09-15 02:46:32

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [AiRecognitionTaskObjectResult](https://cloud.tencent.com/document/api/266/31773#AiRecognitionTaskObjectResult)

	* <font color="#dd0000">**修改成员**：</font>BeginProcessTime, FinishTime

* [AiReviewTaskPoliticalOcrResult](https://cloud.tencent.com/document/api/266/31773#AiReviewTaskPoliticalOcrResult)

	* <font color="#dd0000">**修改成员**：</font>Progress

* [DomainDetailInfo](https://cloud.tencent.com/document/api/266/31773#DomainDetailInfo)

	* <font color="#dd0000">**修改成员**：</font>QUICConfig

* [FileUploadTask](https://cloud.tencent.com/document/api/266/31773#FileUploadTask)

	* <font color="#dd0000">**修改成员**：</font>FileId, MediaBasicInfo, ProcedureTaskId, ReviewAudioVideoTaskId, MetaData

* [MediaInfo](https://cloud.tencent.com/document/api/266/31773#MediaInfo)

	* <font color="#dd0000">**修改成员**：</font>BasicInfo, MetaData, TranscodeInfo, AnimatedGraphicsInfo, SampleSnapshotInfo, ImageSpriteInfo, SnapshotByTimeOffsetInfo, KeyFrameDescInfo, AdaptiveDynamicStreamingInfo, MiniProgramReviewInfo, SubtitleInfo, FileId, ReviewInfo

* [MediaProcessTaskAdaptiveDynamicStreamingResult](https://cloud.tencent.com/document/api/266/31773#MediaProcessTaskAdaptiveDynamicStreamingResult)

	* <font color="#dd0000">**修改成员**：</font>BeginProcessTime, FinishTime

* [PullUploadTask](https://cloud.tencent.com/document/api/266/31773#PullUploadTask)

	* <font color="#dd0000">**修改成员**：</font>TaskId, Status, ErrCode, Message, FileId, MediaBasicInfo, MetaData, FileUrl, ProcedureTaskId, ReviewAudioVideoTaskId, SessionContext, SessionId, Progress

* [QualityInspectTask](https://cloud.tencent.com/document/api/266/31773#QualityInspectTask)

	* <font color="#dd0000">**修改成员**：</font>TaskId, Status, ErrCodeExt, Message, MetaData, Input, Output, SessionId, SessionContext


### 第 167 次发布

发布时间：2023-09-14 02:39:15

本次发布包含了以下内容：

改善已有的文档。

新增数据结构：

* [AiRecognitionTaskObjectSegmentItem](https://cloud.tencent.com/document/api/266/31773#AiRecognitionTaskObjectSegmentItem)
* [TransitionOperation](https://cloud.tencent.com/document/api/266/31773#TransitionOperation)

修改数据结构：

* [AiAnalysisTaskClassificationResult](https://cloud.tencent.com/document/api/266/31773#AiAnalysisTaskClassificationResult)

	* <font color="#dd0000">**修改成员**：</font>BeginProcessTime, FinishTime

* [AiAnalysisTaskCoverResult](https://cloud.tencent.com/document/api/266/31773#AiAnalysisTaskCoverResult)

	* <font color="#dd0000">**修改成员**：</font>BeginProcessTime, FinishTime

* [AiAnalysisTaskFrameTagResult](https://cloud.tencent.com/document/api/266/31773#AiAnalysisTaskFrameTagResult)

	* <font color="#dd0000">**修改成员**：</font>BeginProcessTime, FinishTime

* [AiAnalysisTaskHighlightResult](https://cloud.tencent.com/document/api/266/31773#AiAnalysisTaskHighlightResult)

	* <font color="#dd0000">**修改成员**：</font>BeginProcessTime, FinishTime

* [AiAnalysisTaskTagResult](https://cloud.tencent.com/document/api/266/31773#AiAnalysisTaskTagResult)

	* <font color="#dd0000">**修改成员**：</font>BeginProcessTime, FinishTime

* [AiRecognitionTaskAsrFullTextResult](https://cloud.tencent.com/document/api/266/31773#AiRecognitionTaskAsrFullTextResult)

	* <font color="#dd0000">**修改成员**：</font>BeginProcessTime, FinishTime

* [AiRecognitionTaskAsrWordsResult](https://cloud.tencent.com/document/api/266/31773#AiRecognitionTaskAsrWordsResult)

	* <font color="#dd0000">**修改成员**：</font>BeginProcessTime, FinishTime

* [AiRecognitionTaskFaceResult](https://cloud.tencent.com/document/api/266/31773#AiRecognitionTaskFaceResult)

	* <font color="#dd0000">**修改成员**：</font>BeginProcessTime, FinishTime

* [AiRecognitionTaskHeadTailResult](https://cloud.tencent.com/document/api/266/31773#AiRecognitionTaskHeadTailResult)

	* <font color="#dd0000">**修改成员**：</font>BeginProcessTime, FinishTime

* [AiRecognitionTaskObjectResultItem](https://cloud.tencent.com/document/api/266/31773#AiRecognitionTaskObjectResultItem)

	* 新增成员：RecognitionSegmentSet

* [AiRecognitionTaskOcrFullTextResult](https://cloud.tencent.com/document/api/266/31773#AiRecognitionTaskOcrFullTextResult)

	* <font color="#dd0000">**修改成员**：</font>BeginProcessTime, FinishTime

* [AiRecognitionTaskOcrWordsResult](https://cloud.tencent.com/document/api/266/31773#AiRecognitionTaskOcrWordsResult)

	* <font color="#dd0000">**修改成员**：</font>BeginProcessTime, FinishTime

* [AiRecognitionTaskSegmentResult](https://cloud.tencent.com/document/api/266/31773#AiRecognitionTaskSegmentResult)

	* <font color="#dd0000">**修改成员**：</font>BeginProcessTime, FinishTime

* [DynamicRangeInfo](https://cloud.tencent.com/document/api/266/31773#DynamicRangeInfo)

	* <font color="#dd0000">**修改成员**：</font>Type, HDRType

* [EditMediaTask](https://cloud.tencent.com/document/api/266/31773#EditMediaTask)

	* <font color="#dd0000">**修改成员**：</font>TaskId, Status, ErrCode, ErrCodeExt, Message, Progress, Input, Output, MetaData, ProcedureTaskId, ReviewAudioVideoTaskId, SessionId, SessionContext

* [ExtractCopyRightWatermarkTask](https://cloud.tencent.com/document/api/266/31773#ExtractCopyRightWatermarkTask)

	* <font color="#dd0000">**修改成员**：</font>TaskId, Status, ErrCode, Message, ErrCodeExt, Input, Output, SessionId, SessionContext

* [ExtractCopyRightWatermarkTaskInput](https://cloud.tencent.com/document/api/266/31773#ExtractCopyRightWatermarkTaskInput)

	* <font color="#dd0000">**修改成员**：</font>Url

* [ExtractCopyRightWatermarkTaskOutput](https://cloud.tencent.com/document/api/266/31773#ExtractCopyRightWatermarkTaskOutput)

	* <font color="#dd0000">**修改成员**：</font>Text

* [ExtractTraceWatermarkTaskInput](https://cloud.tencent.com/document/api/266/31773#ExtractTraceWatermarkTaskInput)

	* <font color="#dd0000">**修改成员**：</font>FileId

* [HeadTailTemplate](https://cloud.tencent.com/document/api/266/31773#HeadTailTemplate)

	* <font color="#dd0000">**修改成员**：</font>CreateTime, UpdateTime

* [MediaProcessTaskAnimatedGraphicResult](https://cloud.tencent.com/document/api/266/31773#MediaProcessTaskAnimatedGraphicResult)

	* <font color="#dd0000">**修改成员**：</font>BeginProcessTime, FinishTime

* [MediaProcessTaskCoverBySnapshotResult](https://cloud.tencent.com/document/api/266/31773#MediaProcessTaskCoverBySnapshotResult)

	* <font color="#dd0000">**修改成员**：</font>BeginProcessTime, FinishTime

* [MediaProcessTaskImageSpriteResult](https://cloud.tencent.com/document/api/266/31773#MediaProcessTaskImageSpriteResult)

	* <font color="#dd0000">**修改成员**：</font>BeginProcessTime, FinishTime

* [MediaProcessTaskSampleSnapshotResult](https://cloud.tencent.com/document/api/266/31773#MediaProcessTaskSampleSnapshotResult)

	* <font color="#dd0000">**修改成员**：</font>BeginProcessTime, FinishTime

* [MediaProcessTaskSnapshotByTimeOffsetResult](https://cloud.tencent.com/document/api/266/31773#MediaProcessTaskSnapshotByTimeOffsetResult)

	* <font color="#dd0000">**修改成员**：</font>BeginProcessTime, FinishTime

* [MediaSubStreamInfoItem](https://cloud.tencent.com/document/api/266/31773#MediaSubStreamInfoItem)

	* <font color="#dd0000">**修改成员**：</font>Type, Width, Height, Size

* [MediaTransitionItem](https://cloud.tencent.com/document/api/266/31773#MediaTransitionItem)

	* 新增成员：MediaTransitions

* [MediaVideoStreamItem](https://cloud.tencent.com/document/api/266/31773#MediaVideoStreamItem)

	* <font color="#dd0000">**修改成员**：</font>Bitrate, Height, Width, Codec, Fps, CodecTag

* [ProcedureTemplate](https://cloud.tencent.com/document/api/266/31773#ProcedureTemplate)

	* <font color="#dd0000">**修改成员**：</font>Name, Type, Comment, MediaProcessTask, AiContentReviewTask, AiAnalysisTask, AiRecognitionTask, MiniProgramPublishTask, ReviewAudioVideoTask, CreateTime, UpdateTime

* [QualityInspectResultItem](https://cloud.tencent.com/document/api/266/31773#QualityInspectResultItem)

	* <font color="#dd0000">**修改成员**：</font>Type, SegmentSet, SegmentSetFileUrl, SegmentSetFileUrlExpireTime

* [QualityInspectTaskInput](https://cloud.tencent.com/document/api/266/31773#QualityInspectTaskInput)

	* <font color="#dd0000">**修改成员**：</font>FileId, Definition

* [QualityInspectTemplateItem](https://cloud.tencent.com/document/api/266/31773#QualityInspectTemplateItem)

	* <font color="#dd0000">**修改成员**：</font>Definition, Type, Name, Comment, ScreenshotInterval, JitterConfigure, BlurConfigure, AbnormalLightingConfigure, CrashScreenConfigure, BlackWhiteEdgeConfigure, NoiseConfigure, MosaicConfigure, QRCodeConfigure, QualityEvaluationConfigure, VoiceConfigure, CreateTime, UpdateTime

* [RebuildMediaTaskInput](https://cloud.tencent.com/document/api/266/31773#RebuildMediaTaskInput)

	* <font color="#dd0000">**修改成员**：</font>Definition, HDRInfo, VideoDenoiseInfo, AudioDenoiseInfo, ColorInfo, SharpInfo, FaceInfo, LowLightInfo, ScratchRepairInfo, ArtifactRepairInfo, TargetInfo

* [RebuildMediaTemplate](https://cloud.tencent.com/document/api/266/31773#RebuildMediaTemplate)

	* <font color="#dd0000">**修改成员**：</font>Definition, Type, Name, Comment, RebuildVideoInfo, RebuildAudioInfo, TargetVideoInfo, TargetAudioInfo, Container, RemoveVideo, RemoveAudio, CreateTime, UpdateTime

* [RemoveWaterMarkTaskOutput](https://cloud.tencent.com/document/api/266/31773#RemoveWaterMarkTaskOutput)

	* <font color="#dd0000">**修改成员**：</font>FileType, FileUrl, MediaName

* [ReviewAudioVideoTaskInput](https://cloud.tencent.com/document/api/266/31773#ReviewAudioVideoTaskInput)

	* <font color="#dd0000">**修改成员**：</font>FileId, Definition, ReviewContents

* [ReviewImageResult](https://cloud.tencent.com/document/api/266/31773#ReviewImageResult)

	* <font color="#dd0000">**修改成员**：</font>Suggestion, Label, Form, SegmentSet, SegmentSetFileUrl, SegmentSetFileUrlExpireTime

* [ReviewImageSegmentItem](https://cloud.tencent.com/document/api/266/31773#ReviewImageSegmentItem)

	* <font color="#dd0000">**修改成员**：</font>Confidence, Suggestion, Label, SubLabel, Form, AreaCoordSet, Text, KeywordSet

* [ReviewInfo](https://cloud.tencent.com/document/api/266/31773#ReviewInfo)

	* <font color="#dd0000">**修改成员**：</font>Definition, Suggestion, TypeSet, ReviewTime

* [RoundPlayInfo](https://cloud.tencent.com/document/api/266/31773#RoundPlayInfo)

	* <font color="#dd0000">**修改成员**：</font>Status, PlayBackMode, Url

* [SplitMediaTaskSegmentInfo](https://cloud.tencent.com/document/api/266/31773#SplitMediaTaskSegmentInfo)

	* <font color="#dd0000">**修改成员**：</font>Input, Output, ProcedureTaskId, ReviewAudioVideoTaskId


### 第 166 次发布

发布时间：2023-09-13 02:40:01

本次发布包含了以下内容：

改善已有的文档。

<font color="#dd0000">**删除接口**：</font>

* VerifyDomainOwnershipForConsole

### 第 165 次发布

发布时间：2023-09-12 02:56:18

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateDomainVerifyRecord](https://cloud.tencent.com/document/api/266/97950)
* [VerifyDomainOwnershipForConsole](https://cloud.tencent.com/document/api/266/97949)
* [VerifyDomainRecord](https://cloud.tencent.com/document/api/266/97948)

新增数据结构：

* [DNSVerifyInfo](https://cloud.tencent.com/document/api/266/31773#DNSVerifyInfo)
* [FileVerifyInfo](https://cloud.tencent.com/document/api/266/31773#FileVerifyInfo)

修改数据结构：

* [TerrorismConfigureInfo](https://cloud.tencent.com/document/api/266/31773#TerrorismConfigureInfo)

	* <font color="#dd0000">**修改成员**：</font>OcrReviewInfo


### 第 164 次发布

发布时间：2023-09-01 01:25:57

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [MediaMiniProgramReviewInfoItem](https://cloud.tencent.com/document/api/266/31773#MediaMiniProgramReviewInfoItem)

	* <font color="#dd0000">**修改成员**：</font>MetaData


### 第 163 次发布

发布时间：2023-08-31 01:27:41

本次发布包含了以下内容：

改善已有的文档。

新增数据结构：

* [ProductInstanceResource](https://cloud.tencent.com/document/api/266/31773#ProductInstanceResource)

修改数据结构：

* [ProductInstance](https://cloud.tencent.com/document/api/266/31773#ProductInstance)

	* 新增成员：ResourceSet


### 第 162 次发布

发布时间：2023-08-25 02:22:14

本次发布包含了以下内容：

改善已有的文档。

新增数据结构：

* [LiveRecordInfo](https://cloud.tencent.com/document/api/266/31773#LiveRecordInfo)
* [WebPageRecordInfo](https://cloud.tencent.com/document/api/266/31773#WebPageRecordInfo)

修改数据结构：

* [MediaSourceData](https://cloud.tencent.com/document/api/266/31773#MediaSourceData)

	* 新增成员：LiveRecordInfo, WebPageRecordInfo


### 第 161 次发布

发布时间：2023-07-20 01:50:53

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [QualityInspectItem](https://cloud.tencent.com/document/api/266/31773#QualityInspectItem)

	* <font color="#dd0000">**修改成员**：</font>StartTimeOffset, EndTimeOffset, AreaCoordSet, Confidence


### 第 160 次发布

发布时间：2023-07-06 20:35:50

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [MediaTranscodeItem](https://cloud.tencent.com/document/api/266/31773#MediaTranscodeItem)

	* <font color="#dd0000">**修改成员**：</font>CopyRightWatermarkText


### 第 159 次发布

发布时间：2023-06-22 02:01:05

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateQualityInspectTemplate](https://cloud.tencent.com/document/api/266/94246)
* [DeleteQualityInspectTemplate](https://cloud.tencent.com/document/api/266/94245)
* [DescribeQualityInspectTemplates](https://cloud.tencent.com/document/api/266/94244)
* [InspectMediaQuality](https://cloud.tencent.com/document/api/266/94242)
* [ModifyQualityInspectTemplate](https://cloud.tencent.com/document/api/266/94243)

修改接口：

* [DescribeTaskDetail](https://cloud.tencent.com/document/api/266/33431)

	* 新增出参：QualityInspectTask


新增数据结构：

* [AbnormalLightingConfigureInfo](https://cloud.tencent.com/document/api/266/31773#AbnormalLightingConfigureInfo)
* [AbnormalLightingConfigureInfoForUpdate](https://cloud.tencent.com/document/api/266/31773#AbnormalLightingConfigureInfoForUpdate)
* [BlackWhiteEdgeConfigureInfo](https://cloud.tencent.com/document/api/266/31773#BlackWhiteEdgeConfigureInfo)
* [BlackWhiteEdgeConfigureInfoForUpdate](https://cloud.tencent.com/document/api/266/31773#BlackWhiteEdgeConfigureInfoForUpdate)
* [BlurConfigureInfo](https://cloud.tencent.com/document/api/266/31773#BlurConfigureInfo)
* [BlurConfigureInfoForUpdate](https://cloud.tencent.com/document/api/266/31773#BlurConfigureInfoForUpdate)
* [CrashScreenConfigureInfo](https://cloud.tencent.com/document/api/266/31773#CrashScreenConfigureInfo)
* [CrashScreenConfigureInfoForUpdate](https://cloud.tencent.com/document/api/266/31773#CrashScreenConfigureInfoForUpdate)
* [JitterConfigureInfo](https://cloud.tencent.com/document/api/266/31773#JitterConfigureInfo)
* [JitterConfigureInfoForUpdate](https://cloud.tencent.com/document/api/266/31773#JitterConfigureInfoForUpdate)
* [MosaicConfigureInfo](https://cloud.tencent.com/document/api/266/31773#MosaicConfigureInfo)
* [MosaicConfigureInfoForUpdate](https://cloud.tencent.com/document/api/266/31773#MosaicConfigureInfoForUpdate)
* [NoiseConfigureInfo](https://cloud.tencent.com/document/api/266/31773#NoiseConfigureInfo)
* [NoiseConfigureInfoForUpdate](https://cloud.tencent.com/document/api/266/31773#NoiseConfigureInfoForUpdate)
* [QRCodeConfigureInfo](https://cloud.tencent.com/document/api/266/31773#QRCodeConfigureInfo)
* [QRCodeConfigureInfoForUpdate](https://cloud.tencent.com/document/api/266/31773#QRCodeConfigureInfoForUpdate)
* [QualityEvaluationConfigureInfo](https://cloud.tencent.com/document/api/266/31773#QualityEvaluationConfigureInfo)
* [QualityEvaluationConfigureInfoForUpdate](https://cloud.tencent.com/document/api/266/31773#QualityEvaluationConfigureInfoForUpdate)
* [QualityInspectItem](https://cloud.tencent.com/document/api/266/31773#QualityInspectItem)
* [QualityInspectResultItem](https://cloud.tencent.com/document/api/266/31773#QualityInspectResultItem)
* [QualityInspectTask](https://cloud.tencent.com/document/api/266/31773#QualityInspectTask)
* [QualityInspectTaskInput](https://cloud.tencent.com/document/api/266/31773#QualityInspectTaskInput)
* [QualityInspectTaskOutput](https://cloud.tencent.com/document/api/266/31773#QualityInspectTaskOutput)
* [QualityInspectTemplateItem](https://cloud.tencent.com/document/api/266/31773#QualityInspectTemplateItem)
* [VoiceConfigureInfo](https://cloud.tencent.com/document/api/266/31773#VoiceConfigureInfo)
* [VoiceConfigureInfoForUpdate](https://cloud.tencent.com/document/api/266/31773#VoiceConfigureInfoForUpdate)

修改数据结构：

* [EventContent](https://cloud.tencent.com/document/api/266/31773#EventContent)

	* 新增成员：QualityInspectCompleteEvent


### 第 158 次发布

发布时间：2023-06-16 01:48:04

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [ExtractCopyRightWatermark](https://cloud.tencent.com/document/api/266/94086)

### 第 157 次发布

发布时间：2023-06-15 01:42:39

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeTaskDetail](https://cloud.tencent.com/document/api/266/33431)

	* 新增出参：ExtractCopyRightWatermarkTask


新增数据结构：

* [CopyRightWatermarkInput](https://cloud.tencent.com/document/api/266/31773#CopyRightWatermarkInput)
* [ExtractCopyRightWatermarkTask](https://cloud.tencent.com/document/api/266/31773#ExtractCopyRightWatermarkTask)
* [ExtractCopyRightWatermarkTaskInput](https://cloud.tencent.com/document/api/266/31773#ExtractCopyRightWatermarkTaskInput)
* [ExtractCopyRightWatermarkTaskOutput](https://cloud.tencent.com/document/api/266/31773#ExtractCopyRightWatermarkTaskOutput)

修改数据结构：

* [AdaptiveDynamicStreamingInfoItem](https://cloud.tencent.com/document/api/266/31773#AdaptiveDynamicStreamingInfoItem)

	* 新增成员：CopyRightWatermarkText

* [AdaptiveDynamicStreamingTaskInput](https://cloud.tencent.com/document/api/266/31773#AdaptiveDynamicStreamingTaskInput)

	* 新增成员：CopyRightWatermark

* [EventContent](https://cloud.tencent.com/document/api/266/31773#EventContent)

	* 新增成员：ExtractCopyRightWatermarkCompleteEvent

* [MediaTranscodeItem](https://cloud.tencent.com/document/api/266/31773#MediaTranscodeItem)

	* 新增成员：CopyRightWatermarkText

* [TranscodeTaskInput](https://cloud.tencent.com/document/api/266/31773#TranscodeTaskInput)

	* 新增成员：CopyRightWatermark


### 第 156 次发布

发布时间：2023-05-26 02:04:20

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateEnhanceMediaTemplate](https://cloud.tencent.com/document/api/266/94603)
* [DeleteEnhanceMediaTemplate](https://cloud.tencent.com/document/api/266/94602)
* [DescribeEnhanceMediaTemplates](https://cloud.tencent.com/document/api/266/94601)
* [EnhanceMediaByTemplate](https://cloud.tencent.com/document/api/266/94544)
* [ModifyEnhanceMediaTemplate](https://cloud.tencent.com/document/api/266/94600)

### 第 155 次发布

发布时间：2023-05-25 02:08:29

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateRoundPlay](https://cloud.tencent.com/document/api/266/86175)

	* 新增入参：PlayBackMode

* [ModifyRoundPlay](https://cloud.tencent.com/document/api/266/86172)

	* 新增入参：Status, PlayBackMode


修改数据结构：

* [RoundPlayInfo](https://cloud.tencent.com/document/api/266/31773#RoundPlayInfo)

	* 新增成员：Status, PlayBackMode, Url


### 第 154 次发布

发布时间：2023-05-24 02:03:42

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [EditMediaVideoStream](https://cloud.tencent.com/document/api/266/31773#EditMediaVideoStream)

	* 新增成员：Fps


### 第 153 次发布

发布时间：2023-05-19 02:13:12

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [AiAnalysisTaskClassificationResult](https://cloud.tencent.com/document/api/266/31773#AiAnalysisTaskClassificationResult)

	* 新增成员：BeginProcessTime, FinishTime

* [AiAnalysisTaskCoverResult](https://cloud.tencent.com/document/api/266/31773#AiAnalysisTaskCoverResult)

	* 新增成员：BeginProcessTime, FinishTime

* [AiAnalysisTaskFrameTagResult](https://cloud.tencent.com/document/api/266/31773#AiAnalysisTaskFrameTagResult)

	* 新增成员：BeginProcessTime, FinishTime

* [AiAnalysisTaskHighlightResult](https://cloud.tencent.com/document/api/266/31773#AiAnalysisTaskHighlightResult)

	* 新增成员：BeginProcessTime, FinishTime

* [AiAnalysisTaskTagResult](https://cloud.tencent.com/document/api/266/31773#AiAnalysisTaskTagResult)

	* 新增成员：BeginProcessTime, FinishTime

* [AiRecognitionTaskAsrFullTextResult](https://cloud.tencent.com/document/api/266/31773#AiRecognitionTaskAsrFullTextResult)

	* 新增成员：BeginProcessTime, FinishTime

* [AiRecognitionTaskAsrWordsResult](https://cloud.tencent.com/document/api/266/31773#AiRecognitionTaskAsrWordsResult)

	* 新增成员：BeginProcessTime, FinishTime

* [AiRecognitionTaskFaceResult](https://cloud.tencent.com/document/api/266/31773#AiRecognitionTaskFaceResult)

	* 新增成员：BeginProcessTime, FinishTime

* [AiRecognitionTaskHeadTailResult](https://cloud.tencent.com/document/api/266/31773#AiRecognitionTaskHeadTailResult)

	* 新增成员：BeginProcessTime, FinishTime

* [AiRecognitionTaskObjectResult](https://cloud.tencent.com/document/api/266/31773#AiRecognitionTaskObjectResult)

	* 新增成员：BeginProcessTime, FinishTime

* [AiRecognitionTaskOcrFullTextResult](https://cloud.tencent.com/document/api/266/31773#AiRecognitionTaskOcrFullTextResult)

	* 新增成员：BeginProcessTime, FinishTime

* [AiRecognitionTaskOcrWordsResult](https://cloud.tencent.com/document/api/266/31773#AiRecognitionTaskOcrWordsResult)

	* 新增成员：BeginProcessTime, FinishTime

* [AiRecognitionTaskSegmentResult](https://cloud.tencent.com/document/api/266/31773#AiRecognitionTaskSegmentResult)

	* 新增成员：BeginProcessTime, FinishTime

* [AiReviewTaskPoliticalOcrResult](https://cloud.tencent.com/document/api/266/31773#AiReviewTaskPoliticalOcrResult)

	* 新增成员：Progress

* [ExtractTraceWatermarkTaskInput](https://cloud.tencent.com/document/api/266/31773#ExtractTraceWatermarkTaskInput)

	* 新增成员：FileId


### 第 152 次发布

发布时间：2023-05-10 01:59:01

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [HeadTailTemplate](https://cloud.tencent.com/document/api/266/31773#HeadTailTemplate)

	* 新增成员：CreateTime, UpdateTime

* [MediaProcessTaskAdaptiveDynamicStreamingResult](https://cloud.tencent.com/document/api/266/31773#MediaProcessTaskAdaptiveDynamicStreamingResult)

	* 新增成员：BeginProcessTime, FinishTime

* [MediaProcessTaskAnimatedGraphicResult](https://cloud.tencent.com/document/api/266/31773#MediaProcessTaskAnimatedGraphicResult)

	* 新增成员：BeginProcessTime, FinishTime

* [MediaProcessTaskCoverBySnapshotResult](https://cloud.tencent.com/document/api/266/31773#MediaProcessTaskCoverBySnapshotResult)

	* 新增成员：BeginProcessTime, FinishTime

* [MediaProcessTaskImageSpriteResult](https://cloud.tencent.com/document/api/266/31773#MediaProcessTaskImageSpriteResult)

	* 新增成员：BeginProcessTime, FinishTime

* [MediaProcessTaskSampleSnapshotResult](https://cloud.tencent.com/document/api/266/31773#MediaProcessTaskSampleSnapshotResult)

	* 新增成员：BeginProcessTime, FinishTime

* [MediaProcessTaskSnapshotByTimeOffsetResult](https://cloud.tencent.com/document/api/266/31773#MediaProcessTaskSnapshotByTimeOffsetResult)

	* 新增成员：BeginProcessTime, FinishTime


### 第 151 次发布

发布时间：2023-04-28 01:46:12

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [DescribeFileAttributesTaskOutput](https://cloud.tencent.com/document/api/266/31773#DescribeFileAttributesTaskOutput)

	* 新增成员：Sha1


### 第 150 次发布

发布时间：2023-04-24 01:48:45

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [AsrFullTextConfigureInfo](https://cloud.tencent.com/document/api/266/31773#AsrFullTextConfigureInfo)

	* 新增成员：SrcLanguage

* [AsrFullTextConfigureInfoForUpdate](https://cloud.tencent.com/document/api/266/31773#AsrFullTextConfigureInfoForUpdate)

	* 新增成员：SrcLanguage


### 第 149 次发布

发布时间：2023-04-21 01:49:58

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [ModifyVodDomainConfig](https://cloud.tencent.com/document/api/266/61479)

	* 新增入参：QUICConfig


新增数据结构：

* [DomainQUICConfig](https://cloud.tencent.com/document/api/266/31773#DomainQUICConfig)

修改数据结构：

* [DomainDetailInfo](https://cloud.tencent.com/document/api/266/31773#DomainDetailInfo)

	* 新增成员：QUICConfig

* [RemoveWaterMarkTaskOutput](https://cloud.tencent.com/document/api/266/31773#RemoveWaterMarkTaskOutput)

	* 新增成员：FileType, FileUrl, MediaName


### 第 148 次发布

发布时间：2023-04-07 02:53:24

本次发布包含了以下内容：

改善已有的文档。

新增数据结构：

* [ImageBlur](https://cloud.tencent.com/document/api/266/31773#ImageBlur)

修改数据结构：

* [ImageOperation](https://cloud.tencent.com/document/api/266/31773#ImageOperation)

	* 新增成员：Blur


### 第 147 次发布

发布时间：2023-04-04 01:52:17

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateRebuildMediaTemplate](https://cloud.tencent.com/document/api/266/89805)
* [DeleteRebuildMediaTemplate](https://cloud.tencent.com/document/api/266/89804)
* [DescribeRebuildMediaTemplates](https://cloud.tencent.com/document/api/266/89803)
* [ModifyRebuildMediaTemplate](https://cloud.tencent.com/document/api/266/89802)
* [RebuildMediaByTemplate](https://cloud.tencent.com/document/api/266/89801)

修改接口：

* [PullUpload](https://cloud.tencent.com/document/api/266/35575)

	* 新增入参：MediaType


新增数据结构：

* [RebuildAudioInfo](https://cloud.tencent.com/document/api/266/31773#RebuildAudioInfo)
* [RebuildMediaOutputConfig](https://cloud.tencent.com/document/api/266/31773#RebuildMediaOutputConfig)
* [RebuildMediaTemplate](https://cloud.tencent.com/document/api/266/31773#RebuildMediaTemplate)
* [RebuildVideoInfo](https://cloud.tencent.com/document/api/266/31773#RebuildVideoInfo)

### 第 146 次发布

发布时间：2023-03-31 02:05:47

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [RebuildMediaTaskInput](https://cloud.tencent.com/document/api/266/31773#RebuildMediaTaskInput)

	* 新增成员：Definition


### 第 145 次发布

发布时间：2023-03-29 04:28:58

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [SearchMedia](https://cloud.tencent.com/document/api/266/31813)

	* 新增入参：Status, ReviewResults


### 第 144 次发布

发布时间：2023-03-15 02:20:53

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [SearchMedia](https://cloud.tencent.com/document/api/266/31813)

	* 新增入参：MediaTypes


### 第 143 次发布

发布时间：2023-03-03 01:59:32

本次发布包含了以下内容：

改善已有的文档。

新增数据结构：

* [MediaSubStreamInfoItem](https://cloud.tencent.com/document/api/266/31773#MediaSubStreamInfoItem)

修改数据结构：

* [AdaptiveDynamicStreamingInfoItem](https://cloud.tencent.com/document/api/266/31773#AdaptiveDynamicStreamingInfoItem)

	* 新增成员：SubStreamSet


### 第 142 次发布

发布时间：2023-02-17 06:48:43

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [RebuildMedia](https://cloud.tencent.com/document/api/266/86649)

修改接口：

* [DescribeTaskDetail](https://cloud.tencent.com/document/api/266/33431)

	* 新增出参：RebuildMediaTask


### 第 141 次发布

发布时间：2023-02-16 02:06:38

本次发布包含了以下内容：

改善已有的文档。

新增数据结构：

* [ArtifactRepairInfo](https://cloud.tencent.com/document/api/266/31773#ArtifactRepairInfo)
* [AudioDenoiseInfo](https://cloud.tencent.com/document/api/266/31773#AudioDenoiseInfo)
* [ColorEnhanceInfo](https://cloud.tencent.com/document/api/266/31773#ColorEnhanceInfo)
* [FaceEnhanceInfo](https://cloud.tencent.com/document/api/266/31773#FaceEnhanceInfo)
* [HDRInfo](https://cloud.tencent.com/document/api/266/31773#HDRInfo)
* [LowLightEnhanceInfo](https://cloud.tencent.com/document/api/266/31773#LowLightEnhanceInfo)
* [RebuildMediaTargetAudioStream](https://cloud.tencent.com/document/api/266/31773#RebuildMediaTargetAudioStream)
* [RebuildMediaTargetInfo](https://cloud.tencent.com/document/api/266/31773#RebuildMediaTargetInfo)
* [RebuildMediaTargetVideoStream](https://cloud.tencent.com/document/api/266/31773#RebuildMediaTargetVideoStream)
* [RebuildMediaTask](https://cloud.tencent.com/document/api/266/31773#RebuildMediaTask)
* [RebuildMediaTaskInput](https://cloud.tencent.com/document/api/266/31773#RebuildMediaTaskInput)
* [RebuildMediaTaskOutput](https://cloud.tencent.com/document/api/266/31773#RebuildMediaTaskOutput)
* [RepairInfo](https://cloud.tencent.com/document/api/266/31773#RepairInfo)
* [ScratchRepairInfo](https://cloud.tencent.com/document/api/266/31773#ScratchRepairInfo)
* [SharpEnhanceInfo](https://cloud.tencent.com/document/api/266/31773#SharpEnhanceInfo)
* [SuperResolutionInfo](https://cloud.tencent.com/document/api/266/31773#SuperResolutionInfo)
* [VideoDenoiseInfo](https://cloud.tencent.com/document/api/266/31773#VideoDenoiseInfo)
* [VideoFrameInterpolationInfo](https://cloud.tencent.com/document/api/266/31773#VideoFrameInterpolationInfo)

修改数据结构：

* [EventContent](https://cloud.tencent.com/document/api/266/31773#EventContent)

	* 新增成员：RebuildMediaCompleteEvent


### 第 140 次发布

发布时间：2023-02-07 02:12:55

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateRoundPlay](https://cloud.tencent.com/document/api/266/86175)
* [DeleteRoundPlay](https://cloud.tencent.com/document/api/266/86174)
* [DescribeRoundPlays](https://cloud.tencent.com/document/api/266/86173)
* [ModifyRoundPlay](https://cloud.tencent.com/document/api/266/86172)

新增数据结构：

* [RoundPlayInfo](https://cloud.tencent.com/document/api/266/31773#RoundPlayInfo)
* [RoundPlayListItemInfo](https://cloud.tencent.com/document/api/266/31773#RoundPlayListItemInfo)

### 第 139 次发布

发布时间：2023-01-10 01:56:06

本次发布包含了以下内容：

改善已有的文档。

新增数据结构：

* [DynamicRangeInfo](https://cloud.tencent.com/document/api/266/31773#DynamicRangeInfo)

修改数据结构：

* [MediaVideoStreamItem](https://cloud.tencent.com/document/api/266/31773#MediaVideoStreamItem)

	* 新增成员：DynamicRangeInfo


### 第 138 次发布

发布时间：2023-01-06 01:53:33

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [ExtractTraceWatermark](https://cloud.tencent.com/document/api/266/80525)

	* 新增入参：FileId


### 第 137 次发布

发布时间：2023-01-04 01:50:30

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [ReviewAudioVideo](https://cloud.tencent.com/document/api/266/80283)

	* 新增入参：ReviewContents


修改数据结构：

* [ReviewAudioVideoTaskOutput](https://cloud.tencent.com/document/api/266/31773#ReviewAudioVideoTaskOutput)

	* 新增成员：CoverReviewResult


### 第 136 次发布

发布时间：2023-01-02 01:51:21

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [ProcessMediaByProcedure](https://cloud.tencent.com/document/api/266/34782)

	* 新增出参：ReviewAudioVideoTaskId


修改数据结构：

* [EditMediaTask](https://cloud.tencent.com/document/api/266/31773#EditMediaTask)

	* 新增成员：ReviewAudioVideoTaskId

	* <font color="#dd0000">**修改成员**：</font>TaskId, Status, ErrCode, ErrCodeExt, Message, Progress, Input, Output, MetaData, ProcedureTaskId, SessionId, SessionContext

* [FileUploadTask](https://cloud.tencent.com/document/api/266/31773#FileUploadTask)

	* 新增成员：ReviewAudioVideoTaskId

	* <font color="#dd0000">**修改成员**：</font>FileId, MediaBasicInfo, ProcedureTaskId, MetaData

* [MediaVideoStreamItem](https://cloud.tencent.com/document/api/266/31773#MediaVideoStreamItem)

	* <font color="#dd0000">**修改成员**：</font>Bitrate, Height, Width, Codec, Fps, CodecTag

* [PullUploadTask](https://cloud.tencent.com/document/api/266/31773#PullUploadTask)

	* 新增成员：ReviewAudioVideoTaskId

	* <font color="#dd0000">**修改成员**：</font>TaskId, Status, ErrCode, Message, FileId, MediaBasicInfo, MetaData, FileUrl, ProcedureTaskId, SessionContext, SessionId, Progress

* [ReviewAudioVideoTaskInput](https://cloud.tencent.com/document/api/266/31773#ReviewAudioVideoTaskInput)

	* 新增成员：ReviewContents

	* <font color="#dd0000">**修改成员**：</font>FileId, Definition

* [SplitMediaTaskSegmentInfo](https://cloud.tencent.com/document/api/266/31773#SplitMediaTaskSegmentInfo)

	* 新增成员：ReviewAudioVideoTaskId

	* <font color="#dd0000">**修改成员**：</font>Input, Output, ProcedureTaskId


### 第 135 次发布

发布时间：2022-12-30 01:55:04

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateProcedureTemplate](https://cloud.tencent.com/document/api/266/33897)

	* 新增入参：ReviewAudioVideoTask

* [ResetProcedureTemplate](https://cloud.tencent.com/document/api/266/33894)

	* 新增入参：ReviewAudioVideoTask


新增数据结构：

* [ProcedureReviewAudioVideoTaskInput](https://cloud.tencent.com/document/api/266/31773#ProcedureReviewAudioVideoTaskInput)

修改数据结构：

* [ProcedureTemplate](https://cloud.tencent.com/document/api/266/31773#ProcedureTemplate)

	* 新增成员：ReviewAudioVideoTask

	* <font color="#dd0000">**修改成员**：</font>Name, Type, Comment, MediaProcessTask, AiContentReviewTask, AiAnalysisTask, AiRecognitionTask, MiniProgramPublishTask, CreateTime, UpdateTime


### 第 134 次发布

发布时间：2022-12-22 02:14:59

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [ReviewImage](https://cloud.tencent.com/document/api/266/73217)

	* 新增出参：MediaReviewResult


新增数据结构：

* [ReviewImageResult](https://cloud.tencent.com/document/api/266/31773#ReviewImageResult)
* [ReviewImageSegmentItem](https://cloud.tencent.com/document/api/266/31773#ReviewImageSegmentItem)

### 第 133 次发布

发布时间：2022-12-21 02:16:04

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateReviewTemplate](https://cloud.tencent.com/document/api/266/84391)
* [DeleteReviewTemplate](https://cloud.tencent.com/document/api/266/84390)
* [DescribeReviewTemplates](https://cloud.tencent.com/document/api/266/84389)
* [ModifyReviewTemplate](https://cloud.tencent.com/document/api/266/84388)

新增数据结构：

* [FileReviewInfo](https://cloud.tencent.com/document/api/266/31773#FileReviewInfo)
* [ReviewInfo](https://cloud.tencent.com/document/api/266/31773#ReviewInfo)
* [ReviewTemplate](https://cloud.tencent.com/document/api/266/31773#ReviewTemplate)

修改数据结构：

* [MediaInfo](https://cloud.tencent.com/document/api/266/31773#MediaInfo)

	* 新增成员：ReviewInfo

	* <font color="#dd0000">**修改成员**：</font>BasicInfo, MetaData, TranscodeInfo, AnimatedGraphicsInfo, SampleSnapshotInfo, ImageSpriteInfo, SnapshotByTimeOffsetInfo, KeyFrameDescInfo, AdaptiveDynamicStreamingInfo, MiniProgramReviewInfo, SubtitleInfo, FileId


### 第 132 次发布

发布时间：2022-12-20 02:07:06

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeDrmDataKey](https://cloud.tencent.com/document/api/266/54177)

	* 新增入参：SubAppId


### 第 131 次发布

发布时间：2022-12-09 10:06:16

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeFileAttributes](https://cloud.tencent.com/document/api/266/83796)

### 第 130 次发布

发布时间：2022-12-09 02:12:52

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeTaskDetail](https://cloud.tencent.com/document/api/266/33431)

	* 新增出参：DescribeFileAttributesTask


新增数据结构：

* [DescribeFileAttributesTask](https://cloud.tencent.com/document/api/266/31773#DescribeFileAttributesTask)
* [DescribeFileAttributesTaskOutput](https://cloud.tencent.com/document/api/266/31773#DescribeFileAttributesTaskOutput)

修改数据结构：

* [EventContent](https://cloud.tencent.com/document/api/266/31773#EventContent)

	* 新增成员：DescribeFileAttributesCompleteEvent

* [MediaMetaData](https://cloud.tencent.com/document/api/266/31773#MediaMetaData)

	* 新增成员：Md5

* [ReviewAudioVideoSegmentItem](https://cloud.tencent.com/document/api/266/31773#ReviewAudioVideoSegmentItem)

	* 新增成员：Url, PicUrlExpireTime


### 第 129 次发布

发布时间：2022-12-01 07:13:39

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [ReviewAudioVideo](https://cloud.tencent.com/document/api/266/80283)

	* 新增入参：Definition


修改数据结构：

* [ReviewAudioVideoTaskInput](https://cloud.tencent.com/document/api/266/31773#ReviewAudioVideoTaskInput)

	* 新增成员：Definition


### 第 128 次发布

发布时间：2022-11-28 07:19:44

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [AiAnalysisTaskClassificationResult](https://cloud.tencent.com/document/api/266/31773#AiAnalysisTaskClassificationResult)

	* 新增成员：Progress

* [AiAnalysisTaskCoverResult](https://cloud.tencent.com/document/api/266/31773#AiAnalysisTaskCoverResult)

	* 新增成员：Progress

* [AiAnalysisTaskFrameTagResult](https://cloud.tencent.com/document/api/266/31773#AiAnalysisTaskFrameTagResult)

	* 新增成员：Progress

* [AiAnalysisTaskHighlightResult](https://cloud.tencent.com/document/api/266/31773#AiAnalysisTaskHighlightResult)

	* 新增成员：Progress

* [AiAnalysisTaskTagResult](https://cloud.tencent.com/document/api/266/31773#AiAnalysisTaskTagResult)

	* 新增成员：Progress

* [AiRecognitionTaskAsrWordsResult](https://cloud.tencent.com/document/api/266/31773#AiRecognitionTaskAsrWordsResult)

	* 新增成员：Progress

* [AiRecognitionTaskFaceResult](https://cloud.tencent.com/document/api/266/31773#AiRecognitionTaskFaceResult)

	* 新增成员：Progress

* [AiRecognitionTaskHeadTailResult](https://cloud.tencent.com/document/api/266/31773#AiRecognitionTaskHeadTailResult)

	* 新增成员：Progress

* [AiRecognitionTaskObjectResult](https://cloud.tencent.com/document/api/266/31773#AiRecognitionTaskObjectResult)

	* 新增成员：Progress

* [AiRecognitionTaskOcrFullTextResult](https://cloud.tencent.com/document/api/266/31773#AiRecognitionTaskOcrFullTextResult)

	* 新增成员：Progress

* [AiRecognitionTaskOcrWordsResult](https://cloud.tencent.com/document/api/266/31773#AiRecognitionTaskOcrWordsResult)

	* 新增成员：Progress

* [AiRecognitionTaskSegmentResult](https://cloud.tencent.com/document/api/266/31773#AiRecognitionTaskSegmentResult)

	* 新增成员：Progress

* [AiReviewTaskPoliticalAsrResult](https://cloud.tencent.com/document/api/266/31773#AiReviewTaskPoliticalAsrResult)

	* 新增成员：Progress

* [AiReviewTaskPoliticalResult](https://cloud.tencent.com/document/api/266/31773#AiReviewTaskPoliticalResult)

	* 新增成员：Progress

* [AiReviewTaskPornAsrResult](https://cloud.tencent.com/document/api/266/31773#AiReviewTaskPornAsrResult)

	* 新增成员：Progress

* [AiReviewTaskPornOcrResult](https://cloud.tencent.com/document/api/266/31773#AiReviewTaskPornOcrResult)

	* 新增成员：Progress

* [AiReviewTaskPornResult](https://cloud.tencent.com/document/api/266/31773#AiReviewTaskPornResult)

	* 新增成员：Progress

* [AiReviewTaskProhibitedAsrResult](https://cloud.tencent.com/document/api/266/31773#AiReviewTaskProhibitedAsrResult)

	* 新增成员：Progress

* [AiReviewTaskProhibitedOcrResult](https://cloud.tencent.com/document/api/266/31773#AiReviewTaskProhibitedOcrResult)

	* 新增成员：Progress

* [AiReviewTaskTerrorismOcrResult](https://cloud.tencent.com/document/api/266/31773#AiReviewTaskTerrorismOcrResult)

	* 新增成员：Progress

* [AiReviewTaskTerrorismResult](https://cloud.tencent.com/document/api/266/31773#AiReviewTaskTerrorismResult)

	* 新增成员：Progress

* [MediaProcessTaskAnimatedGraphicResult](https://cloud.tencent.com/document/api/266/31773#MediaProcessTaskAnimatedGraphicResult)

	* 新增成员：Progress

* [MediaProcessTaskCoverBySnapshotResult](https://cloud.tencent.com/document/api/266/31773#MediaProcessTaskCoverBySnapshotResult)

	* 新增成员：Progress

* [MediaProcessTaskImageSpriteResult](https://cloud.tencent.com/document/api/266/31773#MediaProcessTaskImageSpriteResult)

	* 新增成员：Progress

* [MediaProcessTaskSampleSnapshotResult](https://cloud.tencent.com/document/api/266/31773#MediaProcessTaskSampleSnapshotResult)

	* 新增成员：Progress

* [MediaProcessTaskSnapshotByTimeOffsetResult](https://cloud.tencent.com/document/api/266/31773#MediaProcessTaskSnapshotByTimeOffsetResult)

	* 新增成员：Progress

* [ProcedureTask](https://cloud.tencent.com/document/api/266/31773#ProcedureTask)

	* 新增成员：Operator, OperationType

* [PullUploadTask](https://cloud.tencent.com/document/api/266/31773#PullUploadTask)

	* 新增成员：Progress

* [SplitMediaTask](https://cloud.tencent.com/document/api/266/31773#SplitMediaTask)

	* 新增成员：Progress


### 第 127 次发布

发布时间：2022-11-15 06:48:04

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateImageSpriteTemplate](https://cloud.tencent.com/document/api/266/37788)

	* 新增入参：Format

* [ModifyImageSpriteTemplate](https://cloud.tencent.com/document/api/266/37776)

	* 新增入参：Format


修改数据结构：

* [ImageSpriteTemplate](https://cloud.tencent.com/document/api/266/31773#ImageSpriteTemplate)

	* 新增成员：Format


### 第 126 次发布

发布时间：2022-11-08 06:50:59

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [StorageRegionInfo](https://cloud.tencent.com/document/api/266/31773#StorageRegionInfo)

	* 新增成员：Area


### 第 125 次发布

发布时间：2022-11-07 06:44:29

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [MediaProcessTaskAdaptiveDynamicStreamingResult](https://cloud.tencent.com/document/api/266/31773#MediaProcessTaskAdaptiveDynamicStreamingResult)

	* 新增成员：Progress


### 第 124 次发布

发布时间：2022-11-01 06:56:00

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [AudioTrackItem](https://cloud.tencent.com/document/api/266/31773#AudioTrackItem)

	* 新增成员：TargetDuration

* [VideoTrackItem](https://cloud.tencent.com/document/api/266/31773#VideoTrackItem)

	* 新增成员：TargetDuration


### 第 123 次发布

发布时间：2022-10-28 06:58:26

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateAdaptiveDynamicStreamingTemplate](https://cloud.tencent.com/document/api/266/43068)

	* 新增入参：SegmentType

* [CreateTranscodeTemplate](https://cloud.tencent.com/document/api/266/33773)

	* 新增入参：SegmentType

* [ModifyAdaptiveDynamicStreamingTemplate](https://cloud.tencent.com/document/api/266/43063)

	* 新增入参：SegmentType

* [ModifyTranscodeTemplate](https://cloud.tencent.com/document/api/266/33767)

	* 新增入参：SegmentType


修改数据结构：

* [AdaptiveDynamicStreamingTemplate](https://cloud.tencent.com/document/api/266/31773#AdaptiveDynamicStreamingTemplate)

	* 新增成员：SegmentType

* [TranscodeTemplate](https://cloud.tencent.com/document/api/266/31773#TranscodeTemplate)

	* 新增成员：SegmentType


### 第 122 次发布

发布时间：2022-10-13 06:54:26

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [MediaVideoStreamItem](https://cloud.tencent.com/document/api/266/31773#MediaVideoStreamItem)

	* 新增成员：CodecTag


### 第 121 次发布

发布时间：2022-10-12 07:06:19

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [VideoTemplateInfo](https://cloud.tencent.com/document/api/266/31773#VideoTemplateInfo)

	* 新增成员：CodecTag

* [VideoTemplateInfoForUpdate](https://cloud.tencent.com/document/api/266/31773#VideoTemplateInfoForUpdate)

	* 新增成员：CodecTag


### 第 120 次发布

发布时间：2022-09-16 06:48:25

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [ExtractTraceWatermark](https://cloud.tencent.com/document/api/266/80525)

修改接口：

* [DescribeTaskDetail](https://cloud.tencent.com/document/api/266/33431)

	* 新增出参：ExtractTraceWatermarkTask, ReduceMediaBitrateTask


新增数据结构：

* [ExtractTraceWatermarkTask](https://cloud.tencent.com/document/api/266/31773#ExtractTraceWatermarkTask)
* [ExtractTraceWatermarkTaskInput](https://cloud.tencent.com/document/api/266/31773#ExtractTraceWatermarkTaskInput)
* [ExtractTraceWatermarkTaskOutput](https://cloud.tencent.com/document/api/266/31773#ExtractTraceWatermarkTaskOutput)
* [ReduceMediaBitrateAdaptiveDynamicStreamingResult](https://cloud.tencent.com/document/api/266/31773#ReduceMediaBitrateAdaptiveDynamicStreamingResult)
* [ReduceMediaBitrateMediaProcessTaskResult](https://cloud.tencent.com/document/api/266/31773#ReduceMediaBitrateMediaProcessTaskResult)
* [ReduceMediaBitrateTask](https://cloud.tencent.com/document/api/266/31773#ReduceMediaBitrateTask)
* [ReduceMediaBitrateTranscodeResult](https://cloud.tencent.com/document/api/266/31773#ReduceMediaBitrateTranscodeResult)

修改数据结构：

* [AdaptiveDynamicStreamingInfoItem](https://cloud.tencent.com/document/api/266/31773#AdaptiveDynamicStreamingInfoItem)

	* 新增成员：DigitalWatermarkType

* [EventContent](https://cloud.tencent.com/document/api/266/31773#EventContent)

	* 新增成员：ExtractTraceWatermarkCompleteEvent, ReduceMediaBitrateCompleteEvent

* [MediaTranscodeItem](https://cloud.tencent.com/document/api/266/31773#MediaTranscodeItem)

	* 新增成员：DigitalWatermarkType

* [TraceWatermarkInput](https://cloud.tencent.com/document/api/266/31773#TraceWatermarkInput)

	* 新增成员：Switch


### 第 119 次发布

发布时间：2022-09-08 06:48:08

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [ReviewAudioVideo](https://cloud.tencent.com/document/api/266/80283)

新增数据结构：

* [ReviewAudioVideoTaskInput](https://cloud.tencent.com/document/api/266/31773#ReviewAudioVideoTaskInput)

修改数据结构：

* [ReviewAudioVideoTask](https://cloud.tencent.com/document/api/266/31773#ReviewAudioVideoTask)

	* 新增成员：Input


### 第 118 次发布

发布时间：2022-09-02 07:03:01

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [ProductInstance](https://cloud.tencent.com/document/api/266/31773#ProductInstance)

	* 新增成员：RenewStatus


### 第 117 次发布

发布时间：2022-09-01 06:57:37

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeTaskDetail](https://cloud.tencent.com/document/api/266/33431)

	* 新增出参：ReviewAudioVideoTask


新增数据结构：

* [ReviewAudioVideoSegmentItem](https://cloud.tencent.com/document/api/266/31773#ReviewAudioVideoSegmentItem)
* [ReviewAudioVideoTask](https://cloud.tencent.com/document/api/266/31773#ReviewAudioVideoTask)
* [ReviewAudioVideoTaskOutput](https://cloud.tencent.com/document/api/266/31773#ReviewAudioVideoTaskOutput)

修改数据结构：

* [EventContent](https://cloud.tencent.com/document/api/266/31773#EventContent)

	* 新增成员：ReviewAudioVideoCompleteEvent


### 第 116 次发布

发布时间：2022-08-25 06:58:49

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeDrmKeyProviderInfo](https://cloud.tencent.com/document/api/266/79586)
* [SetDrmKeyProviderInfo](https://cloud.tencent.com/document/api/266/79585)

修改接口：

* [SearchMedia](https://cloud.tencent.com/document/api/266/31813)

	* 新增入参：TrtcSdkAppIds, TrtcRoomIds


新增数据结构：

* [SDMCDrmKeyProviderInfo](https://cloud.tencent.com/document/api/266/31773#SDMCDrmKeyProviderInfo)

### 第 115 次发布

发布时间：2022-08-24 06:58:00

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateAdaptiveDynamicStreamingTemplate](https://cloud.tencent.com/document/api/266/43068)

	* 新增入参：DrmKeyProvider

* [DescribeTaskDetail](https://cloud.tencent.com/document/api/266/33431)

	* 新增出参：RemoveWatermarkTask


新增数据结构：

* [AiRecognitionTaskAsrFullTextResultOutputSubtitleItem](https://cloud.tencent.com/document/api/266/31773#AiRecognitionTaskAsrFullTextResultOutputSubtitleItem)
* [RemoveWaterMarkTaskInput](https://cloud.tencent.com/document/api/266/31773#RemoveWaterMarkTaskInput)
* [RemoveWaterMarkTaskOutput](https://cloud.tencent.com/document/api/266/31773#RemoveWaterMarkTaskOutput)
* [RemoveWatermarkTask](https://cloud.tencent.com/document/api/266/31773#RemoveWatermarkTask)
* [SubtitleFormatsOperation](https://cloud.tencent.com/document/api/266/31773#SubtitleFormatsOperation)
* [TrtcRecordInfo](https://cloud.tencent.com/document/api/266/31773#TrtcRecordInfo)

修改数据结构：

* [AdaptiveDynamicStreamingTemplate](https://cloud.tencent.com/document/api/266/31773#AdaptiveDynamicStreamingTemplate)

	* 新增成员：DrmKeyProvider

* [AiRecognitionTaskAsrFullTextResultOutput](https://cloud.tencent.com/document/api/266/31773#AiRecognitionTaskAsrFullTextResultOutput)

	* 新增成员：SubtitleSet

* [AsrFullTextConfigureInfo](https://cloud.tencent.com/document/api/266/31773#AsrFullTextConfigureInfo)

	* 新增成员：SubtitleFormats

* [AsrFullTextConfigureInfoForUpdate](https://cloud.tencent.com/document/api/266/31773#AsrFullTextConfigureInfoForUpdate)

	* 新增成员：SubtitleFormatsOperation

* [EventContent](https://cloud.tencent.com/document/api/266/31773#EventContent)

	* 新增成员：RemoveWatermarkCompleteEvent

* [MediaSourceData](https://cloud.tencent.com/document/api/266/31773#MediaSourceData)

	* 新增成员：TrtcRecordInfo


### 第 114 次发布

发布时间：2022-08-22 06:57:10

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [RemoveWatermark](https://cloud.tencent.com/document/api/266/79257)

### 第 113 次发布

发布时间：2022-08-19 06:43:39

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [LiveRealTimeClip](https://cloud.tencent.com/document/api/266/32587)

	* 新增入参：ClassId, SourceContext, SessionContext, StreamInfo

* [SimpleHlsClip](https://cloud.tencent.com/document/api/266/33428)

	* 新增入参：ExpireTime, Procedure, ClassId, SourceContext, SessionContext

	* 新增出参：TaskId


新增数据结构：

* [LiveRealTimeClipStreamInfo](https://cloud.tencent.com/document/api/266/31773#LiveRealTimeClipStreamInfo)

### 第 112 次发布

发布时间：2022-08-11 07:05:14

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeClientUploadAccelerationUsageData](https://cloud.tencent.com/document/api/266/78907)

### 第 111 次发布

发布时间：2022-08-09 11:53:09

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [PlayerConfig](https://cloud.tencent.com/document/api/266/31773#PlayerConfig)

	* 新增成员：AudioVideoType, TranscodeDefinition

* [TraceWatermarkInput](https://cloud.tencent.com/document/api/266/31773#TraceWatermarkInput)

	* <font color="#dd0000">**修改成员**：</font>Definition


### 第 110 次发布

发布时间：2022-07-29 06:17:29

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [VideoTemplateInfo](https://cloud.tencent.com/document/api/266/31773#VideoTemplateInfo)

	* 新增成员：PreserveHDRSwitch

* [VideoTemplateInfoForUpdate](https://cloud.tencent.com/document/api/266/31773#VideoTemplateInfoForUpdate)

	* 新增成员：PreserveHDRSwitch


### 第 109 次发布

发布时间：2022-07-19 06:21:28

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [MediaClassInfo](https://cloud.tencent.com/document/api/266/31773#MediaClassInfo)

	* 新增成员：Name

* [SubAppIdInfo](https://cloud.tencent.com/document/api/266/31773#SubAppIdInfo)

	* 新增成员：SubAppIdName


### 第 108 次发布

发布时间：2022-07-12 06:19:53

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [ImageWatermarkInput](https://cloud.tencent.com/document/api/266/31773#ImageWatermarkInput)

	* 新增成员：Transparency

* [ImageWatermarkInputForUpdate](https://cloud.tencent.com/document/api/266/31773#ImageWatermarkInputForUpdate)

	* 新增成员：Transparency

* [ImageWatermarkTemplate](https://cloud.tencent.com/document/api/266/31773#ImageWatermarkTemplate)

	* 新增成员：Transparency


### 第 107 次发布

发布时间：2022-07-08 06:17:05

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [AiRecognitionTaskAsrFullTextResult](https://cloud.tencent.com/document/api/266/31773#AiRecognitionTaskAsrFullTextResult)

	* 新增成员：Progress


### 第 106 次发布

发布时间：2022-06-21 06:16:46

本次发布包含了以下内容：

改善已有的文档。

新增数据结构：

* [TraceWatermarkInput](https://cloud.tencent.com/document/api/266/31773#TraceWatermarkInput)

修改数据结构：

* [AdaptiveDynamicStreamingTaskInput](https://cloud.tencent.com/document/api/266/31773#AdaptiveDynamicStreamingTaskInput)

	* 新增成员：TraceWatermark

* [TranscodeTaskInput](https://cloud.tencent.com/document/api/266/31773#TranscodeTaskInput)

	* 新增成员：TraceWatermark


### 第 105 次发布

发布时间：2022-06-17 06:16:12

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [RefreshUrlCache](https://cloud.tencent.com/document/api/266/75729)
* [RestoreMedia](https://cloud.tencent.com/document/api/266/75728)

修改接口：

* [DescribeStorageData](https://cloud.tencent.com/document/api/266/41463)

	* 新增出参：ArchiveStorage, DeepArchiveStorage


### 第 104 次发布

发布时间：2022-05-17 06:18:35

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeLicenseUsageData](https://cloud.tencent.com/document/api/266/73787)

新增数据结构：

* [LicenseUsageDataItem](https://cloud.tencent.com/document/api/266/31773#LicenseUsageDataItem)

### 第 103 次发布

发布时间：2022-05-13 06:19:52

本次发布包含了以下内容：

改善已有的文档。

新增数据结构：

* [FileDeleteResultItem](https://cloud.tencent.com/document/api/266/31773#FileDeleteResultItem)

修改数据结构：

* [FileDeleteTask](https://cloud.tencent.com/document/api/266/31773#FileDeleteTask)

	* 新增成员：FileDeleteResultInfo


### 第 102 次发布

发布时间：2022-04-29 06:15:32

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeImageReviewUsageData](https://cloud.tencent.com/document/api/266/73215)
* [ReviewImage](https://cloud.tencent.com/document/api/266/73217)

新增数据结构：

* [ImageReviewUsageDataItem](https://cloud.tencent.com/document/api/266/31773#ImageReviewUsageDataItem)

### 第 101 次发布

发布时间：2022-04-21 06:20:00

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [DrmStreamingsInfo](https://cloud.tencent.com/document/api/266/31773#DrmStreamingsInfo)

	* 新增成员：WidevineDefinition, FairPlayDefinition

* [DrmStreamingsInfoForUpdate](https://cloud.tencent.com/document/api/266/31773#DrmStreamingsInfoForUpdate)

	* 新增成员：WidevineDefinition, FairPlayDefinition


### 第 100 次发布

发布时间：2022-04-13 07:24:51

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateStorageRegion](https://cloud.tencent.com/document/api/266/72481)
* [DescribeStorageRegions](https://cloud.tencent.com/document/api/266/72480)
* [ModifyDefaultStorageRegion](https://cloud.tencent.com/document/api/266/72479)

新增数据结构：

* [StorageRegionInfo](https://cloud.tencent.com/document/api/266/31773#StorageRegionInfo)

### 第 99 次发布

发布时间：2022-03-28 08:15:45

本次发布包含了以下内容：

改善已有的文档。

新增数据结构：

* [EditMediaTEHDConfig](https://cloud.tencent.com/document/api/266/31773#EditMediaTEHDConfig)
* [EditMediaVideoStream](https://cloud.tencent.com/document/api/266/31773#EditMediaVideoStream)

修改数据结构：

* [EditMediaOutputConfig](https://cloud.tencent.com/document/api/266/31773#EditMediaOutputConfig)

	* 新增成员：VideoStream, TEHDConfig


### 第 98 次发布

发布时间：2022-03-23 08:14:23

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeMediaPlayStatDetails](https://cloud.tencent.com/document/api/266/71555)

新增数据结构：

* [PlayStatInfo](https://cloud.tencent.com/document/api/266/31773#PlayStatInfo)

### 第 97 次发布

发布时间：2022-03-21 08:18:21

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [ProcessImage](https://cloud.tencent.com/document/api/266/71437)

新增数据结构：

* [ContentReviewOcrResult](https://cloud.tencent.com/document/api/266/31773#ContentReviewOcrResult)
* [ContentReviewResult](https://cloud.tencent.com/document/api/266/31773#ContentReviewResult)
* [ImageContentReviewInput](https://cloud.tencent.com/document/api/266/31773#ImageContentReviewInput)
* [PoliticalImageResult](https://cloud.tencent.com/document/api/266/31773#PoliticalImageResult)
* [PornImageResult](https://cloud.tencent.com/document/api/266/31773#PornImageResult)
* [TerrorismImageResult](https://cloud.tencent.com/document/api/266/31773#TerrorismImageResult)

### 第 96 次发布

发布时间：2022-03-10 08:17:15

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [ModifyMediaStorageClass](https://cloud.tencent.com/document/api/266/70862)

修改数据结构：

* [AdaptiveStreamTemplate](https://cloud.tencent.com/document/api/266/31773#AdaptiveStreamTemplate)

	* 新增成员：TEHDConfig


### 第 95 次发布

发布时间：2022-01-26 08:14:54

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateSuperPlayerConfig](https://cloud.tencent.com/document/api/266/43067)

	* 新增入参：AudioVideoType, TranscodeDefinition

* [ModifySuperPlayerConfig](https://cloud.tencent.com/document/api/266/43062)

	* 新增入参：AudioVideoType, TranscodeDefinition


### 第 94 次发布

发布时间：2022-01-11 08:17:35

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [AdaptiveDynamicStreamingInfoItem](https://cloud.tencent.com/document/api/266/31773#AdaptiveDynamicStreamingInfoItem)

	* 新增成员：Size


### 第 93 次发布

发布时间：2021-12-09 08:12:57

本次发布包含了以下内容：

改善已有的文档。

新增数据结构：

* [RestoreMediaTask](https://cloud.tencent.com/document/api/266/31773#RestoreMediaTask)

修改数据结构：

* [AiAnalysisTaskClassificationOutput](https://cloud.tencent.com/document/api/266/31773#AiAnalysisTaskClassificationOutput)

	* 新增成员：ClassificationSetFileUrl, ClassificationSetFileUrlExpireTime

* [AiAnalysisTaskCoverOutput](https://cloud.tencent.com/document/api/266/31773#AiAnalysisTaskCoverOutput)

	* 新增成员：CoverSetFileUrl, CoverSetFileUrlExpireTime

* [AiAnalysisTaskFrameTagOutput](https://cloud.tencent.com/document/api/266/31773#AiAnalysisTaskFrameTagOutput)

	* 新增成员：SegmentSetFileUrl, SegmentSetFileUrlExpireTime

* [AiAnalysisTaskHighlightOutput](https://cloud.tencent.com/document/api/266/31773#AiAnalysisTaskHighlightOutput)

	* 新增成员：HighlightSetFileUrl, HighlightSetFileUrlExpireTime

* [AiAnalysisTaskTagOutput](https://cloud.tencent.com/document/api/266/31773#AiAnalysisTaskTagOutput)

	* 新增成员：TagSetFileUrl, TagSetFileUrlExpireTime

* [AiReviewPoliticalAsrTaskOutput](https://cloud.tencent.com/document/api/266/31773#AiReviewPoliticalAsrTaskOutput)

	* 新增成员：SegmentSetFileUrl, SegmentSetFileUrlExpireTime

* [AiReviewPoliticalOcrTaskOutput](https://cloud.tencent.com/document/api/266/31773#AiReviewPoliticalOcrTaskOutput)

	* 新增成员：SegmentSetFileUrl, SegmentSetFileUrlExpireTime

* [AiReviewPoliticalTaskOutput](https://cloud.tencent.com/document/api/266/31773#AiReviewPoliticalTaskOutput)

	* 新增成员：SegmentSetFileUrl, SegmentSetFileUrlExpireTime

* [AiReviewPornAsrTaskOutput](https://cloud.tencent.com/document/api/266/31773#AiReviewPornAsrTaskOutput)

	* 新增成员：SegmentSetFileUrl, SegmentSetFileUrlExpireTime

* [AiReviewPornOcrTaskOutput](https://cloud.tencent.com/document/api/266/31773#AiReviewPornOcrTaskOutput)

	* 新增成员：SegmentSetFileUrl, SegmentSetFileUrlExpireTime

* [AiReviewPornTaskOutput](https://cloud.tencent.com/document/api/266/31773#AiReviewPornTaskOutput)

	* 新增成员：SegmentSetFileUrl, SegmentSetFileUrlExpireTime

* [AiReviewProhibitedAsrTaskOutput](https://cloud.tencent.com/document/api/266/31773#AiReviewProhibitedAsrTaskOutput)

	* 新增成员：SegmentSetFileUrl, SegmentSetFileUrlExpireTime

* [AiReviewProhibitedOcrTaskOutput](https://cloud.tencent.com/document/api/266/31773#AiReviewProhibitedOcrTaskOutput)

	* 新增成员：SegmentSetFileUrl, SegmentSetFileUrlExpireTime

* [AiReviewTerrorismOcrTaskOutput](https://cloud.tencent.com/document/api/266/31773#AiReviewTerrorismOcrTaskOutput)

	* 新增成员：SegmentSetFileUrl, SegmentSetFileUrlExpireTime

* [AiReviewTerrorismTaskOutput](https://cloud.tencent.com/document/api/266/31773#AiReviewTerrorismTaskOutput)

	* 新增成员：SegmentSetFileUrl, SegmentSetFileUrlExpireTime

* [EventContent](https://cloud.tencent.com/document/api/266/31773#EventContent)

	* 新增成员：RestoreMediaCompleteEvent


### 第 92 次发布

发布时间：2021-11-02 08:12:52

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [ComposeMediaTask](https://cloud.tencent.com/document/api/266/31773#ComposeMediaTask)

	* 新增成员：Progress

* [EditMediaTask](https://cloud.tencent.com/document/api/266/31773#EditMediaTask)

	* 新增成员：Progress


### 第 91 次发布

发布时间：2021-09-14 08:09:57

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateVodDomain](https://cloud.tencent.com/document/api/266/61482)
* [DeleteVodDomain](https://cloud.tencent.com/document/api/266/61481)
* [ModifyVodDomainAccelerateConfig](https://cloud.tencent.com/document/api/266/61480)
* [ModifyVodDomainConfig](https://cloud.tencent.com/document/api/266/61479)

修改数据结构：

* [UrlSignatureAuthPolicy](https://cloud.tencent.com/document/api/266/31773#UrlSignatureAuthPolicy)

	* <font color="#dd0000">**修改成员**：</font>EncryptedKey


### 第 90 次发布

发布时间：2021-08-04 08:09:55

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [SearchMedia](https://cloud.tencent.com/document/api/266/31813)

	* 新增入参：ExpireTime, StorageClasses


### 第 89 次发布

发布时间：2021-07-30 08:10:33

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [MediaProcessTaskTranscodeResult](https://cloud.tencent.com/document/api/266/31773#MediaProcessTaskTranscodeResult)

	* 新增成员：BeginProcessTime, FinishTime


### 第 88 次发布

发布时间：2021-07-29 08:10:42

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [AiRecognitionTaskAsrFullTextResultOutput](https://cloud.tencent.com/document/api/266/31773#AiRecognitionTaskAsrFullTextResultOutput)

	* 新增成员：SegmentSetFileUrl, SegmentSetFileUrlExpireTime

* [AiRecognitionTaskAsrWordsResultOutput](https://cloud.tencent.com/document/api/266/31773#AiRecognitionTaskAsrWordsResultOutput)

	* 新增成员：ResultSetFileUrl, ResultSetFileUrlExpireTime

* [AiRecognitionTaskFaceResultOutput](https://cloud.tencent.com/document/api/266/31773#AiRecognitionTaskFaceResultOutput)

	* 新增成员：ResultSetFileUrl, ResultSetFileUrlExpireTime

* [AiRecognitionTaskObjectResultOutput](https://cloud.tencent.com/document/api/266/31773#AiRecognitionTaskObjectResultOutput)

	* 新增成员：ResultSetFileUrl, ResultSetFileUrlExpireTime

* [AiRecognitionTaskOcrFullTextResultOutput](https://cloud.tencent.com/document/api/266/31773#AiRecognitionTaskOcrFullTextResultOutput)

	* 新增成员：SegmentSetFileUrl, SegmentSetFileUrlExpireTime

* [AiRecognitionTaskOcrWordsResultOutput](https://cloud.tencent.com/document/api/266/31773#AiRecognitionTaskOcrWordsResultOutput)

	* 新增成员：ResultSetFileUrl, ResultSetFileUrlExpireTime

* [AiRecognitionTaskSegmentResultOutput](https://cloud.tencent.com/document/api/266/31773#AiRecognitionTaskSegmentResultOutput)

	* 新增成员：SegmentSetFileUrl, SegmentSetFileUrlExpireTime


### 第 87 次发布

发布时间：2021-07-16 08:10:26

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [EditMediaTask](https://cloud.tencent.com/document/api/266/31773#EditMediaTask)

	* 新增成员：ErrCodeExt


### 第 86 次发布

发布时间：2021-05-27 08:09:22

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [StorageStatData](https://cloud.tencent.com/document/api/266/31773#StorageStatData)

	* 新增成员：ArchiveStorage, DeepArchiveStorage


### 第 85 次发布

发布时间：2021-05-10 08:08:49

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateHeadTailTemplate](https://cloud.tencent.com/document/api/266/55579)
* [DeleteHeadTailTemplate](https://cloud.tencent.com/document/api/266/55578)
* [DescribeHeadTailTemplates](https://cloud.tencent.com/document/api/266/55577)
* [ModifyHeadTailTemplate](https://cloud.tencent.com/document/api/266/55576)

新增数据结构：

* [HeadTailTaskInput](https://cloud.tencent.com/document/api/266/31773#HeadTailTaskInput)
* [HeadTailTemplate](https://cloud.tencent.com/document/api/266/31773#HeadTailTemplate)

修改数据结构：

* [TranscodeTaskInput](https://cloud.tencent.com/document/api/266/31773#TranscodeTaskInput)

	* 新增成员：HeadTailSet


### 第 84 次发布

发布时间：2021-04-29 08:08:35

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeEventConfig](https://cloud.tencent.com/document/api/266/55296)

### 第 83 次发布

发布时间：2021-04-28 08:11:47

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [ModifyEventConfig](https://cloud.tencent.com/document/api/266/55244)

### 第 82 次发布

发布时间：2021-04-27 08:10:24

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeTasks](https://cloud.tencent.com/document/api/266/33430)

	* 新增入参：CreateTime, FinishTime, Sort

	* <font color="#dd0000">**修改入参**：</font>Status


修改数据结构：

* [MediaBasicInfo](https://cloud.tencent.com/document/api/266/31773#MediaBasicInfo)

	* 新增成员：StorageClass

* [TaskSimpleInfo](https://cloud.tencent.com/document/api/266/31773#TaskSimpleInfo)

	* 新增成员：Status, FileId


### 第 81 次发布

发布时间：2021-04-21 08:08:56

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [AttachMediaSubtitles](https://cloud.tencent.com/document/api/266/54235)

	* 新增入参：SubAppId


### 第 80 次发布

发布时间：2021-03-31 08:08:54

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [AttachMediaSubtitles](https://cloud.tencent.com/document/api/266/54235)

修改接口：

* [ModifyMediaInfo](https://cloud.tencent.com/document/api/266/31762)

	* 新增入参：AddSubtitles, DeleteSubtitleIds, ClearSubtitles

	* 新增出参：AddedSubtitleSet

* [SearchMedia](https://cloud.tencent.com/document/api/266/31813)

	* 新增入参：StorageRegions


新增数据结构：

* [MediaSubtitleInput](https://cloud.tencent.com/document/api/266/31773#MediaSubtitleInput)

### 第 79 次发布

发布时间：2021-03-30 08:10:17

本次发布包含了以下内容：

改善已有的文档。

新增数据结构：

* [MediaSubtitleInfo](https://cloud.tencent.com/document/api/266/31773#MediaSubtitleInfo)
* [MediaSubtitleItem](https://cloud.tencent.com/document/api/266/31773#MediaSubtitleItem)

修改数据结构：

* [MediaInfo](https://cloud.tencent.com/document/api/266/31773#MediaInfo)

	* 新增成员：SubtitleInfo


### 第 78 次发布

发布时间：2021-03-29 08:08:31

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeDrmDataKey](https://cloud.tencent.com/document/api/266/54177)
* [DescribeVodDomains](https://cloud.tencent.com/document/api/266/54176)

新增数据结构：

* [AccelerateAreaInfo](https://cloud.tencent.com/document/api/266/31773#AccelerateAreaInfo)
* [DomainDetailInfo](https://cloud.tencent.com/document/api/266/31773#DomainDetailInfo)
* [DomainHTTPSConfig](https://cloud.tencent.com/document/api/266/31773#DomainHTTPSConfig)
* [RefererAuthPolicy](https://cloud.tencent.com/document/api/266/31773#RefererAuthPolicy)
* [SimpleAesEdkPair](https://cloud.tencent.com/document/api/266/31773#SimpleAesEdkPair)
* [UrlSignatureAuthPolicy](https://cloud.tencent.com/document/api/266/31773#UrlSignatureAuthPolicy)

修改数据结构：

* [AdaptiveDynamicStreamingTaskInput](https://cloud.tencent.com/document/api/266/31773#AdaptiveDynamicStreamingTaskInput)

	* 新增成员：SubtitleSet


### 第 77 次发布

发布时间：2021-03-25 08:08:44

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribePrepaidProducts](https://cloud.tencent.com/document/api/266/54091)

新增数据结构：

* [ProductInstance](https://cloud.tencent.com/document/api/266/31773#ProductInstance)
* [ProductInstanceRecource](https://cloud.tencent.com/document/api/266/31773#ProductInstanceRecource)

### 第 76 次发布

发布时间：2021-03-24 08:08:58

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [ComposeMediaTask](https://cloud.tencent.com/document/api/266/31773#ComposeMediaTask)

	* 新增成员：SessionContext, SessionId


### 第 75 次发布

发布时间：2021-03-19 08:08:50

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeCdnLogs](https://cloud.tencent.com/document/api/266/47706)

	* 新增入参：Limit, Offset

	* 新增出参：TotalCount


修改数据结构：

* [CdnLogInfo](https://cloud.tencent.com/document/api/266/31773#CdnLogInfo)

	* 新增成员：StartTime, EndTime


### 第 74 次发布

发布时间：2021-03-09 08:09:47

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [LiveRealTimeClip](https://cloud.tencent.com/document/api/266/32587)

	* 新增出参：SegmentSet


新增数据结构：

* [LiveRealTimeClipMediaSegmentInfo](https://cloud.tencent.com/document/api/266/31773#LiveRealTimeClipMediaSegmentInfo)

### 第 73 次发布

发布时间：2021-03-02 08:10:00

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeDailyMediaPlayStat](https://cloud.tencent.com/document/api/266/53312)
* [DescribeDailyMostPlayedStat](https://cloud.tencent.com/document/api/266/53311)

新增数据结构：

* [DailyPlayStatInfo](https://cloud.tencent.com/document/api/266/31773#DailyPlayStatInfo)

### 第 72 次发布

发布时间：2021-02-24 08:08:14

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [ComposeMediaTask](https://cloud.tencent.com/document/api/266/31773#ComposeMediaTask)

	* 新增成员：MetaData

* [EditMediaTask](https://cloud.tencent.com/document/api/266/31773#EditMediaTask)

	* 新增成员：MetaData

* [PullUploadTask](https://cloud.tencent.com/document/api/266/31773#PullUploadTask)

	* 新增成员：MetaData


### 第 71 次发布

发布时间：2021-01-15 08:08:20

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [ImageWatermarkInput](https://cloud.tencent.com/document/api/266/31773#ImageWatermarkInput)

	* 新增成员：RepeatType

* [ImageWatermarkInputForUpdate](https://cloud.tencent.com/document/api/266/31773#ImageWatermarkInputForUpdate)

	* 新增成员：RepeatType

* [ImageWatermarkTemplate](https://cloud.tencent.com/document/api/266/31773#ImageWatermarkTemplate)

	* 新增成员：RepeatType


### 第 70 次发布

发布时间：2021-01-14 08:08:16

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [ImageProcessingTemplate](https://cloud.tencent.com/document/api/266/31773#ImageProcessingTemplate)

	* 新增成员：CreateTime


### 第 69 次发布

发布时间：2020-12-29 08:10:42

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeSubAppIds](https://cloud.tencent.com/document/api/266/36304)

	* 新增入参：Name


### 第 68 次发布

发布时间：2020-12-25 08:09:06

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [ManageTask](https://cloud.tencent.com/document/api/266/51502)

### 第 67 次发布

发布时间：2020-12-17 08:08:25

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [SplitMedia](https://cloud.tencent.com/document/api/266/51098)

修改接口：

* [DescribeTaskDetail](https://cloud.tencent.com/document/api/266/33431)

	* 新增出参：SplitMediaTask


新增数据结构：

* [SplitMediaOutputConfig](https://cloud.tencent.com/document/api/266/31773#SplitMediaOutputConfig)
* [SplitMediaTask](https://cloud.tencent.com/document/api/266/31773#SplitMediaTask)
* [SplitMediaTaskConfig](https://cloud.tencent.com/document/api/266/31773#SplitMediaTaskConfig)
* [SplitMediaTaskInput](https://cloud.tencent.com/document/api/266/31773#SplitMediaTaskInput)
* [SplitMediaTaskSegmentInfo](https://cloud.tencent.com/document/api/266/31773#SplitMediaTaskSegmentInfo)
* [TaskOutputMediaInfo](https://cloud.tencent.com/document/api/266/31773#TaskOutputMediaInfo)

修改数据结构：

* [EventContent](https://cloud.tencent.com/document/api/266/31773#EventContent)

	* 新增成员：SplitMediaCompleteEvent


### 第 66 次发布

发布时间：2020-12-16 08:08:45

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeDailyPlayStatFileList](https://cloud.tencent.com/document/api/266/51026)

修改接口：

* [DescribeSubAppIds](https://cloud.tencent.com/document/api/266/36304)

	* 新增入参：Limit, Offset

	* 新增出参：TotalCount


新增数据结构：

* [PlayStatFileInfo](https://cloud.tencent.com/document/api/266/31773#PlayStatFileInfo)

修改数据结构：

* [MediaProcessTaskTranscodeResult](https://cloud.tencent.com/document/api/266/31773#MediaProcessTaskTranscodeResult)

	* 新增成员：Progress


### 第 65 次发布

发布时间：2020-12-09 08:07:43

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [SimpleHlsClip](https://cloud.tencent.com/document/api/266/33428)

	* 新增入参：IsPersistence

	* 新增出参：FileId


修改数据结构：

* [VideoTemplateInfo](https://cloud.tencent.com/document/api/266/31773#VideoTemplateInfo)

	* 新增成员：Gop

* [VideoTemplateInfoForUpdate](https://cloud.tencent.com/document/api/266/31773#VideoTemplateInfoForUpdate)

	* 新增成员：Gop


### 第 64 次发布

发布时间：2020-12-03 08:08:16

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [AiAnalysisTaskClassificationResult](https://cloud.tencent.com/document/api/266/31773#AiAnalysisTaskClassificationResult)

	* 新增成员：ErrCodeExt

* [AiAnalysisTaskCoverResult](https://cloud.tencent.com/document/api/266/31773#AiAnalysisTaskCoverResult)

	* 新增成员：ErrCodeExt

* [AiAnalysisTaskFrameTagResult](https://cloud.tencent.com/document/api/266/31773#AiAnalysisTaskFrameTagResult)

	* 新增成员：ErrCodeExt

* [AiAnalysisTaskHighlightResult](https://cloud.tencent.com/document/api/266/31773#AiAnalysisTaskHighlightResult)

	* 新增成员：ErrCodeExt

* [AiAnalysisTaskTagResult](https://cloud.tencent.com/document/api/266/31773#AiAnalysisTaskTagResult)

	* 新增成员：ErrCodeExt

* [AiRecognitionTaskAsrFullTextResult](https://cloud.tencent.com/document/api/266/31773#AiRecognitionTaskAsrFullTextResult)

	* 新增成员：ErrCodeExt

* [AiRecognitionTaskAsrWordsResult](https://cloud.tencent.com/document/api/266/31773#AiRecognitionTaskAsrWordsResult)

	* 新增成员：ErrCodeExt

* [AiRecognitionTaskFaceResult](https://cloud.tencent.com/document/api/266/31773#AiRecognitionTaskFaceResult)

	* 新增成员：ErrCodeExt

* [AiRecognitionTaskHeadTailResult](https://cloud.tencent.com/document/api/266/31773#AiRecognitionTaskHeadTailResult)

	* 新增成员：ErrCodeExt

* [AiRecognitionTaskObjectResult](https://cloud.tencent.com/document/api/266/31773#AiRecognitionTaskObjectResult)

	* 新增成员：ErrCodeExt

* [AiRecognitionTaskOcrFullTextResult](https://cloud.tencent.com/document/api/266/31773#AiRecognitionTaskOcrFullTextResult)

	* 新增成员：ErrCodeExt

* [AiRecognitionTaskOcrWordsResult](https://cloud.tencent.com/document/api/266/31773#AiRecognitionTaskOcrWordsResult)

	* 新增成员：ErrCodeExt

* [AiRecognitionTaskSegmentResult](https://cloud.tencent.com/document/api/266/31773#AiRecognitionTaskSegmentResult)

	* 新增成员：ErrCodeExt

* [AiReviewTaskPoliticalAsrResult](https://cloud.tencent.com/document/api/266/31773#AiReviewTaskPoliticalAsrResult)

	* 新增成员：ErrCodeExt

* [AiReviewTaskPoliticalOcrResult](https://cloud.tencent.com/document/api/266/31773#AiReviewTaskPoliticalOcrResult)

	* 新增成员：ErrCodeExt

* [AiReviewTaskPoliticalResult](https://cloud.tencent.com/document/api/266/31773#AiReviewTaskPoliticalResult)

	* 新增成员：ErrCodeExt

* [AiReviewTaskPornAsrResult](https://cloud.tencent.com/document/api/266/31773#AiReviewTaskPornAsrResult)

	* 新增成员：ErrCodeExt

* [AiReviewTaskPornOcrResult](https://cloud.tencent.com/document/api/266/31773#AiReviewTaskPornOcrResult)

	* 新增成员：ErrCodeExt

* [AiReviewTaskPornResult](https://cloud.tencent.com/document/api/266/31773#AiReviewTaskPornResult)

	* 新增成员：ErrCodeExt

* [AiReviewTaskProhibitedAsrResult](https://cloud.tencent.com/document/api/266/31773#AiReviewTaskProhibitedAsrResult)

	* 新增成员：ErrCodeExt

* [AiReviewTaskProhibitedOcrResult](https://cloud.tencent.com/document/api/266/31773#AiReviewTaskProhibitedOcrResult)

	* 新增成员：ErrCodeExt

* [AiReviewTaskTerrorismOcrResult](https://cloud.tencent.com/document/api/266/31773#AiReviewTaskTerrorismOcrResult)

	* 新增成员：ErrCodeExt

* [AiReviewTaskTerrorismResult](https://cloud.tencent.com/document/api/266/31773#AiReviewTaskTerrorismResult)

	* 新增成员：ErrCodeExt

* [MediaProcessTaskAdaptiveDynamicStreamingResult](https://cloud.tencent.com/document/api/266/31773#MediaProcessTaskAdaptiveDynamicStreamingResult)

	* 新增成员：ErrCodeExt

* [MediaProcessTaskAnimatedGraphicResult](https://cloud.tencent.com/document/api/266/31773#MediaProcessTaskAnimatedGraphicResult)

	* 新增成员：ErrCodeExt

* [MediaProcessTaskCoverBySnapshotResult](https://cloud.tencent.com/document/api/266/31773#MediaProcessTaskCoverBySnapshotResult)

	* 新增成员：ErrCodeExt

* [MediaProcessTaskImageSpriteResult](https://cloud.tencent.com/document/api/266/31773#MediaProcessTaskImageSpriteResult)

	* 新增成员：ErrCodeExt

* [MediaProcessTaskSampleSnapshotResult](https://cloud.tencent.com/document/api/266/31773#MediaProcessTaskSampleSnapshotResult)

	* 新增成员：ErrCodeExt

* [MediaProcessTaskSnapshotByTimeOffsetResult](https://cloud.tencent.com/document/api/266/31773#MediaProcessTaskSnapshotByTimeOffsetResult)

	* 新增成员：ErrCodeExt

* [MediaProcessTaskTranscodeResult](https://cloud.tencent.com/document/api/266/31773#MediaProcessTaskTranscodeResult)

	* 新增成员：ErrCodeExt


### 第 63 次发布

发布时间：2020-12-02 08:06:51

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeCDNStatDetails](https://cloud.tencent.com/document/api/266/50519)

修改接口：

* [DescribeStorageData](https://cloud.tencent.com/document/api/266/41463)

	* 新增出参：StorageStat

* [DescribeStorageDetails](https://cloud.tencent.com/document/api/266/41462)

	* 新增入参：Area


新增数据结构：

* [StorageStatData](https://cloud.tencent.com/document/api/266/31773#StorageStatData)

### 第 62 次发布

发布时间：2020-11-09 08:07:54

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [TranscodeTaskInput](https://cloud.tencent.com/document/api/266/31773#TranscodeTaskInput)

	* 新增成员：StartTimeOffset, EndTimeOffset


### 第 61 次发布

发布时间：2020-10-29 08:07:35

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeSubAppIds](https://cloud.tencent.com/document/api/266/36304)

	* 新增入参：Tags


新增数据结构：

* [ResourceTag](https://cloud.tencent.com/document/api/266/31773#ResourceTag)

### 第 60 次发布

发布时间：2020-10-27 08:08:33

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [AdaptiveStreamTemplate](https://cloud.tencent.com/document/api/266/31773#AdaptiveStreamTemplate)

	* 新增成员：RemoveVideo


### 第 59 次发布

发布时间：2020-10-21 08:07:39

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [VideoTemplateInfo](https://cloud.tencent.com/document/api/266/31773#VideoTemplateInfo)

	* 新增成员：Vcrf

* [VideoTemplateInfoForUpdate](https://cloud.tencent.com/document/api/266/31773#VideoTemplateInfoForUpdate)

	* 新增成员：Vcrf


### 第 58 次发布

发布时间：2020-09-29 08:08:19

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateImageProcessingTemplate](https://cloud.tencent.com/document/api/266/48901)
* [DeleteImageProcessingTemplate](https://cloud.tencent.com/document/api/266/48900)
* [DescribeImageProcessingTemplates](https://cloud.tencent.com/document/api/266/48899)

新增数据结构：

* [ImageCenterCut](https://cloud.tencent.com/document/api/266/31773#ImageCenterCut)
* [ImageOperation](https://cloud.tencent.com/document/api/266/31773#ImageOperation)
* [ImageProcessingTemplate](https://cloud.tencent.com/document/api/266/31773#ImageProcessingTemplate)
* [ImageScale](https://cloud.tencent.com/document/api/266/31773#ImageScale)

### 第 57 次发布

发布时间：2020-09-25 08:07:27

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeEventsState](https://cloud.tencent.com/document/api/266/48758)

### 第 56 次发布

发布时间：2020-09-16 08:06:57

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [EditMedia](https://cloud.tencent.com/document/api/266/34783)

	* 新增入参：ExtInfo


### 第 55 次发布

发布时间：2020-08-25 08:08:32

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [MediaAiAnalysisFrameTagItem](https://cloud.tencent.com/document/api/266/31773#MediaAiAnalysisFrameTagItem)

	* 新增成员：CategorySet


### 第 54 次发布

发布时间：2020-08-21 08:22:40

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeCdnLogs](https://cloud.tencent.com/document/api/266/47706)

新增数据结构：

* [CdnLogInfo](https://cloud.tencent.com/document/api/266/31773#CdnLogInfo)

### 第 53 次发布

发布时间：2020-08-20 08:23:52

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [SearchMedia](https://cloud.tencent.com/document/api/266/31813)

	* 新增入参：StreamIds, Vids, SourceTypes, CreateTime, FileIds, Names, NamePrefixes, Descriptions, Filters


新增数据结构：

* [TimeRange](https://cloud.tencent.com/document/api/266/31773#TimeRange)

### 第 52 次发布

发布时间：2020-07-15 08:19:43

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateSuperPlayerConfig](https://cloud.tencent.com/document/api/266/43067)

	* 新增入参：Domain, Scheme

* [ModifySuperPlayerConfig](https://cloud.tencent.com/document/api/266/43062)

	* 新增入参：Domain, Scheme


修改数据结构：

* [PlayerConfig](https://cloud.tencent.com/document/api/266/31773#PlayerConfig)

	* 新增成员：Domain, Scheme


### 第 51 次发布

发布时间：2020-07-06 08:19:28

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [PullUpload](https://cloud.tencent.com/document/api/266/35575)

	* 新增入参：SourceContext


### 第 50 次发布

发布时间：2020-06-30 08:22:37

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [MediaBasicInfo](https://cloud.tencent.com/document/api/266/31773#MediaBasicInfo)

	* 新增成员：Status


### 第 49 次发布

发布时间：2020-06-05 08:19:14

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [SearchMedia](https://cloud.tencent.com/document/api/266/31813)

	* 新增入参：Categories


### 第 48 次发布

发布时间：2020-05-01 08:18:05

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [SnapshotByTimeOffsetTaskInput](https://cloud.tencent.com/document/api/266/31773#SnapshotByTimeOffsetTaskInput)

	* 新增成员：ExtTimeOffsetSet

	* <font color="#dd0000">**修改成员**：</font>TimeOffsetSet


### 第 47 次发布

发布时间：2020-04-30 08:18:34

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [ApplyUpload](https://cloud.tencent.com/document/api/266/31767)

	* 新增入参：ExtInfo


### 第 46 次发布

发布时间：2020-04-28 08:18:40

本次发布包含了以下内容：

改善已有的文档。

<font color="#dd0000">**删除接口**：</font>

* DescribeAudioTrackTemplates
* DescribeVideoTrackTemplates

<font color="#dd0000">**删除数据结构**：</font>

* AudioTrackTemplateInfo
* VideoTrackTemplateInfo

### 第 45 次发布

发布时间：2020-04-27 08:18:15

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateImageSpriteTemplate](https://cloud.tencent.com/document/api/266/37788)

	* 新增入参：Comment

* [CreateProcedureTemplate](https://cloud.tencent.com/document/api/266/33897)

	* 新增入参：Comment

* [CreateSuperPlayerConfig](https://cloud.tencent.com/document/api/266/43067)

	* 新增入参：Comment

* [ModifyImageSpriteTemplate](https://cloud.tencent.com/document/api/266/37776)

	* 新增入参：Comment

* [ModifySuperPlayerConfig](https://cloud.tencent.com/document/api/266/43062)

	* 新增入参：Comment

* [ResetProcedureTemplate](https://cloud.tencent.com/document/api/266/33894)

	* 新增入参：Comment


修改数据结构：

* [MediaBasicInfo](https://cloud.tencent.com/document/api/266/31773#MediaBasicInfo)

	* 新增成员：Category


### 第 44 次发布

发布时间：2020-04-24 08:17:44

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateSubAppId](https://cloud.tencent.com/document/api/266/43744)

修改数据结构：

* [ImageSpriteTemplate](https://cloud.tencent.com/document/api/266/31773#ImageSpriteTemplate)

	* 新增成员：Comment

* [PlayerConfig](https://cloud.tencent.com/document/api/266/31773#PlayerConfig)

	* 新增成员：Comment

* [ProcedureTemplate](https://cloud.tencent.com/document/api/266/31773#ProcedureTemplate)

	* 新增成员：Comment


### 第 43 次发布

发布时间：2020-04-22 08:18:38

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateAdaptiveDynamicStreamingTemplate](https://cloud.tencent.com/document/api/266/43068)

	* 新增入参：SubAppId

* [DeleteAdaptiveDynamicStreamingTemplate](https://cloud.tencent.com/document/api/266/43066)

	* 新增入参：SubAppId

* [ModifyAdaptiveDynamicStreamingTemplate](https://cloud.tencent.com/document/api/266/43063)

	* 新增入参：SubAppId


### 第 42 次发布

发布时间：2020-04-03 08:16:56

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [ComposeMedia](https://cloud.tencent.com/document/api/266/35286)

	* 新增入参：SessionContext, SessionId


### 第 41 次发布

发布时间：2020-04-02 08:18:42

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateAdaptiveDynamicStreamingTemplate](https://cloud.tencent.com/document/api/266/43068)
* [CreateSuperPlayerConfig](https://cloud.tencent.com/document/api/266/43067)
* [DeleteAdaptiveDynamicStreamingTemplate](https://cloud.tencent.com/document/api/266/43066)
* [DeleteSuperPlayerConfig](https://cloud.tencent.com/document/api/266/43065)
* [DescribeSuperPlayerConfigs](https://cloud.tencent.com/document/api/266/43064)
* [ModifyAdaptiveDynamicStreamingTemplate](https://cloud.tencent.com/document/api/266/43063)
* [ModifySuperPlayerConfig](https://cloud.tencent.com/document/api/266/43062)

新增数据结构：

* [DrmStreamingsInfo](https://cloud.tencent.com/document/api/266/31773#DrmStreamingsInfo)
* [DrmStreamingsInfoForUpdate](https://cloud.tencent.com/document/api/266/31773#DrmStreamingsInfoForUpdate)
* [PlayerConfig](https://cloud.tencent.com/document/api/266/31773#PlayerConfig)
* [ResolutionNameInfo](https://cloud.tencent.com/document/api/266/31773#ResolutionNameInfo)

### 第 40 次发布

发布时间：2020-04-01 08:49:22

本次发布包含了以下内容：

改善已有的文档。

<font color="#dd0000">**删除接口**：</font>

* ModifyEventNotificationConfigForConsole

修改数据结构：

* [AdaptiveDynamicStreamingTemplate](https://cloud.tencent.com/document/api/266/31773#AdaptiveDynamicStreamingTemplate)

	* <font color="#dd0000">**删除成员**：</font>PackageType, VideoTrackTemplateSet, AudioTrackTemplateSet


### 第 39 次发布

发布时间：2020-03-31 08:15:34

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [ModifyEventNotificationConfigForConsole](https://cloud.tencent.com/document/api/266/43011)

### 第 38 次发布

发布时间：2020-03-25 08:17:04

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreatePersonSample](https://cloud.tencent.com/document/api/266/34800)

	* <font color="#dd0000">**修改入参**：</font>FaceContents


### 第 37 次发布

发布时间：2020-02-25 16:36:08

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [EditMedia](https://cloud.tencent.com/document/api/266/34783)

	* 新增入参：TasksPriority


### 第 36 次发布

发布时间：2020-02-24 10:07:05

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeMediaProcessUsageData](https://cloud.tencent.com/document/api/266/41464)
* [DescribeStorageData](https://cloud.tencent.com/document/api/266/41463)
* [DescribeStorageDetails](https://cloud.tencent.com/document/api/266/41462)

修改接口：

* [CreateContentReviewTemplate](https://cloud.tencent.com/document/api/266/34790)

	* 新增入参：ProhibitedConfigure

* [ModifyContentReviewTemplate](https://cloud.tencent.com/document/api/266/34784)

	* 新增入参：ProhibitedConfigure


新增数据结构：

* [ProhibitedAsrReviewTemplateInfoForUpdate](https://cloud.tencent.com/document/api/266/31773#ProhibitedAsrReviewTemplateInfoForUpdate)
* [ProhibitedConfigureInfoForUpdate](https://cloud.tencent.com/document/api/266/31773#ProhibitedConfigureInfoForUpdate)
* [ProhibitedOcrReviewTemplateInfoForUpdate](https://cloud.tencent.com/document/api/266/31773#ProhibitedOcrReviewTemplateInfoForUpdate)
* [SpecificationDataItem](https://cloud.tencent.com/document/api/266/31773#SpecificationDataItem)
* [TaskStatData](https://cloud.tencent.com/document/api/266/31773#TaskStatData)
* [TaskStatDataItem](https://cloud.tencent.com/document/api/266/31773#TaskStatDataItem)

### 第 35 次发布

发布时间：2020-02-20 09:30:58

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [ParseStreamingManifest](https://cloud.tencent.com/document/api/266/41399)

新增数据结构：

* [AdaptiveStreamTemplate](https://cloud.tencent.com/document/api/266/31773#AdaptiveStreamTemplate)

修改数据结构：

* [AdaptiveDynamicStreamingTemplate](https://cloud.tencent.com/document/api/266/31773#AdaptiveDynamicStreamingTemplate)

	* 新增成员：Format, StreamInfos


### 第 34 次发布

发布时间：2020-02-13 14:34:58

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [LiveRealTimeClip](https://cloud.tencent.com/document/api/266/32587)

	* 新增入参：Host, ExtInfo

* [SimpleHlsClip](https://cloud.tencent.com/document/api/266/33428)

	* 新增入参：SubAppId


新增数据结构：

* [AiReviewProhibitedAsrTaskInput](https://cloud.tencent.com/document/api/266/31773#AiReviewProhibitedAsrTaskInput)
* [AiReviewProhibitedAsrTaskOutput](https://cloud.tencent.com/document/api/266/31773#AiReviewProhibitedAsrTaskOutput)
* [AiReviewProhibitedOcrTaskInput](https://cloud.tencent.com/document/api/266/31773#AiReviewProhibitedOcrTaskInput)
* [AiReviewProhibitedOcrTaskOutput](https://cloud.tencent.com/document/api/266/31773#AiReviewProhibitedOcrTaskOutput)
* [AiReviewTaskProhibitedAsrResult](https://cloud.tencent.com/document/api/266/31773#AiReviewTaskProhibitedAsrResult)
* [AiReviewTaskProhibitedOcrResult](https://cloud.tencent.com/document/api/266/31773#AiReviewTaskProhibitedOcrResult)
* [AiReviewTaskTerrorismOcrResult](https://cloud.tencent.com/document/api/266/31773#AiReviewTaskTerrorismOcrResult)
* [AiReviewTerrorismOcrTaskInput](https://cloud.tencent.com/document/api/266/31773#AiReviewTerrorismOcrTaskInput)
* [AiReviewTerrorismOcrTaskOutput](https://cloud.tencent.com/document/api/266/31773#AiReviewTerrorismOcrTaskOutput)
* [MosaicInput](https://cloud.tencent.com/document/api/266/31773#MosaicInput)
* [ProhibitedAsrReviewTemplateInfo](https://cloud.tencent.com/document/api/266/31773#ProhibitedAsrReviewTemplateInfo)
* [ProhibitedConfigureInfo](https://cloud.tencent.com/document/api/266/31773#ProhibitedConfigureInfo)
* [ProhibitedOcrReviewTemplateInfo](https://cloud.tencent.com/document/api/266/31773#ProhibitedOcrReviewTemplateInfo)
* [TerrorismOcrReviewTemplateInfo](https://cloud.tencent.com/document/api/266/31773#TerrorismOcrReviewTemplateInfo)
* [TerrorismOcrReviewTemplateInfoForUpdate](https://cloud.tencent.com/document/api/266/31773#TerrorismOcrReviewTemplateInfoForUpdate)

修改数据结构：

* [AiContentReviewResult](https://cloud.tencent.com/document/api/266/31773#AiContentReviewResult)

	* 新增成员：TerrorismOcrTask, ProhibitedAsrTask, ProhibitedOcrTask

* [ContentReviewTemplateItem](https://cloud.tencent.com/document/api/266/31773#ContentReviewTemplateItem)

	* 新增成员：ProhibitedConfigure

* [TerrorismConfigureInfo](https://cloud.tencent.com/document/api/266/31773#TerrorismConfigureInfo)

	* 新增成员：OcrReviewInfo

* [TerrorismConfigureInfoForUpdate](https://cloud.tencent.com/document/api/266/31773#TerrorismConfigureInfoForUpdate)

	* 新增成员：OcrReviewInfo

* [TranscodeTaskInput](https://cloud.tencent.com/document/api/266/31773#TranscodeTaskInput)

	* 新增成员：MosaicSet


### 第 33 次发布

发布时间：2020-01-02 16:47:02

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateAnimatedGraphicsTemplate](https://cloud.tencent.com/document/api/266/37789)

	* 新增入参：ResolutionAdaptive

	* <font color="#dd0000">**修改入参**：</font>Width, Height

* [CreateImageSpriteTemplate](https://cloud.tencent.com/document/api/266/37788)

	* 新增入参：ResolutionAdaptive, FillType

	* <font color="#dd0000">**修改入参**：</font>Width, Height

* [CreateSampleSnapshotTemplate](https://cloud.tencent.com/document/api/266/37787)

	* 新增入参：ResolutionAdaptive, FillType

	* <font color="#dd0000">**修改入参**：</font>Width, Height

* [CreateSnapshotByTimeOffsetTemplate](https://cloud.tencent.com/document/api/266/37786)

	* 新增入参：ResolutionAdaptive, FillType

	* <font color="#dd0000">**修改入参**：</font>Width, Height

* [ModifyAnimatedGraphicsTemplate](https://cloud.tencent.com/document/api/266/37777)

	* 新增入参：ResolutionAdaptive

* [ModifyImageSpriteTemplate](https://cloud.tencent.com/document/api/266/37776)

	* 新增入参：ResolutionAdaptive, FillType

* [ModifySampleSnapshotTemplate](https://cloud.tencent.com/document/api/266/37775)

	* 新增入参：ResolutionAdaptive, FillType

* [ModifySnapshotByTimeOffsetTemplate](https://cloud.tencent.com/document/api/266/37774)

	* 新增入参：ResolutionAdaptive, FillType


### 第 32 次发布

发布时间：2020-01-02 16:25:55

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [ForbidMediaDistribution](https://cloud.tencent.com/document/api/266/40636)

### 第 31 次发布

发布时间：2019-12-26 10:28:51

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [ConfirmEvents](https://cloud.tencent.com/document/api/266/33434)

	* 新增入参：ExtInfo

* [ExecuteFunction](https://cloud.tencent.com/document/api/266/35479)

	* 新增入参：SessionContext, SessionId, ExtInfo

* [ProcessMediaByProcedure](https://cloud.tencent.com/document/api/266/34782)

	* 新增入参：ExtInfo

* [PullEvents](https://cloud.tencent.com/document/api/266/33433)

	* 新增入参：ExtInfo


修改数据结构：

* [ImageSpriteTemplate](https://cloud.tencent.com/document/api/266/31773#ImageSpriteTemplate)

	* 新增成员：ResolutionAdaptive

* [TaskSimpleInfo](https://cloud.tencent.com/document/api/266/31773#TaskSimpleInfo)

	* 新增成员：SessionId, SessionContext


### 第 30 次发布

发布时间：2019-11-21 19:41:23

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeCDNUsageData](https://cloud.tencent.com/document/api/266/38291)

	* 新增入参：DataInterval, DomainNames

	* 新增出参：DataInterval

* [ProcessMedia](https://cloud.tencent.com/document/api/266/33427)

	* 新增入参：ExtInfo

* [PullUpload](https://cloud.tencent.com/document/api/266/35575)

	* 新增入参：ExtInfo


修改数据结构：

* [AnimatedGraphicsTemplate](https://cloud.tencent.com/document/api/266/31773#AnimatedGraphicsTemplate)

	* 新增成员：ResolutionAdaptive

* [ComposeMediaOutput](https://cloud.tencent.com/document/api/266/31773#ComposeMediaOutput)

	* 新增成员：ClassId, ExpireTime

* [ComposeMediaTaskOutput](https://cloud.tencent.com/document/api/266/31773#ComposeMediaTaskOutput)

	* 新增成员：MediaName, ClassId, ExpireTime

* [EditMediaOutputConfig](https://cloud.tencent.com/document/api/266/31773#EditMediaOutputConfig)

	* 新增成员：MediaName, ClassId

* [EditMediaTaskOutput](https://cloud.tencent.com/document/api/266/31773#EditMediaTaskOutput)

	* 新增成员：MediaName, ClassId, ExpireTime

* [ImageSpriteTemplate](https://cloud.tencent.com/document/api/266/31773#ImageSpriteTemplate)

	* 新增成员：FillType

* [SampleSnapshotTemplate](https://cloud.tencent.com/document/api/266/31773#SampleSnapshotTemplate)

	* 新增成员：ResolutionAdaptive, FillType

* [SnapshotByTimeOffsetTemplate](https://cloud.tencent.com/document/api/266/31773#SnapshotByTimeOffsetTemplate)

	* 新增成员：ResolutionAdaptive, FillType

* [TaskSimpleInfo](https://cloud.tencent.com/document/api/266/31773#TaskSimpleInfo)

	* 新增成员：CreateTime

	* <font color="#dd0000">**删除成员**：</font>CreatTime

* [WatermarkInput](https://cloud.tencent.com/document/api/266/31773#WatermarkInput)

	* 新增成员：StartTimeOffset, EndTimeOffset


### 第 29 次发布

发布时间：2019-11-05 20:31:47

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeProcedureTemplates](https://cloud.tencent.com/document/api/266/33895)

	* 新增入参：Type

* [EditMedia](https://cloud.tencent.com/document/api/266/34783)

	* 新增入参：SessionContext, SessionId


修改数据结构：

* [AudioVolumeParam](https://cloud.tencent.com/document/api/266/31773#AudioVolumeParam)

	* <font color="#dd0000">**修改成员**：</font>Gain


### 第 28 次发布

发布时间：2019-10-28 15:54:25

本次发布包含了以下内容：

改善已有的文档。

新增数据结构：

* [WatermarkCycleConfigForUpdate](https://cloud.tencent.com/document/api/266/31773#WatermarkCycleConfigForUpdate)
* [WechatMiniProgramPublishTaskInput](https://cloud.tencent.com/document/api/266/31773#WechatMiniProgramPublishTaskInput)

修改数据结构：

* [MediaContentReviewOcrTextSegmentItem](https://cloud.tencent.com/document/api/266/31773#MediaContentReviewOcrTextSegmentItem)

	* <font color="#dd0000">**修改成员**：</font>PicUrlExpireTime

* [ProcedureTemplate](https://cloud.tencent.com/document/api/266/31773#ProcedureTemplate)

	* 新增成员：MiniProgramPublishTask

* [SvgWatermarkInputForUpdate](https://cloud.tencent.com/document/api/266/31773#SvgWatermarkInputForUpdate)

	* 新增成员：CycleConfig


### 第 27 次发布

发布时间：2019-10-17 19:33:44

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [MediaContentReviewOcrTextSegmentItem](https://cloud.tencent.com/document/api/266/31773#MediaContentReviewOcrTextSegmentItem)

	* 新增成员：Url, PicUrlExpireTime

* [MediaContentReviewPoliticalSegmentItem](https://cloud.tencent.com/document/api/266/31773#MediaContentReviewPoliticalSegmentItem)

	* 新增成员：PicUrlExpireTime

* [MediaContentReviewSegmentItem](https://cloud.tencent.com/document/api/266/31773#MediaContentReviewSegmentItem)

	* 新增成员：PicUrlExpireTime

* [ProcedureTemplate](https://cloud.tencent.com/document/api/266/31773#ProcedureTemplate)

	* 新增成员：Type


### 第 26 次发布

发布时间：2019-10-11 14:26:42

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeCDNUsageData](https://cloud.tencent.com/document/api/266/38291)

### 第 25 次发布

发布时间：2019-09-20 16:07:59

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeAdaptiveDynamicStreamingTemplates](https://cloud.tencent.com/document/api/266/38084)
* [DescribeAudioTrackTemplates](https://cloud.tencent.com/document/api/266/38083)
* [DescribeVideoTrackTemplates](https://cloud.tencent.com/document/api/266/38082)

新增数据结构：

* [AdaptiveDynamicStreamingTemplate](https://cloud.tencent.com/document/api/266/31773#AdaptiveDynamicStreamingTemplate)
* [AudioTrackTemplateInfo](https://cloud.tencent.com/document/api/266/31773#AudioTrackTemplateInfo)
* [VideoTrackTemplateInfo](https://cloud.tencent.com/document/api/266/31773#VideoTrackTemplateInfo)

修改数据结构：

* [AiRecognitionTaskSegmentSegmentItem](https://cloud.tencent.com/document/api/266/31773#AiRecognitionTaskSegmentSegmentItem)

	* 新增成员：FileId

* [FileUploadTask](https://cloud.tencent.com/document/api/266/31773#FileUploadTask)

	* 新增成员：MetaData


### 第 24 次发布

发布时间：2019-09-05 16:32:33

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateAnimatedGraphicsTemplate](https://cloud.tencent.com/document/api/266/37789)
* [CreateImageSpriteTemplate](https://cloud.tencent.com/document/api/266/37788)
* [CreateSampleSnapshotTemplate](https://cloud.tencent.com/document/api/266/37787)
* [CreateSnapshotByTimeOffsetTemplate](https://cloud.tencent.com/document/api/266/37786)
* [DeleteAnimatedGraphicsTemplate](https://cloud.tencent.com/document/api/266/37785)
* [DeleteImageSpriteTemplate](https://cloud.tencent.com/document/api/266/37784)
* [DeleteSampleSnapshotTemplate](https://cloud.tencent.com/document/api/266/37783)
* [DeleteSnapshotByTimeOffsetTemplate](https://cloud.tencent.com/document/api/266/37782)
* [DescribeAnimatedGraphicsTemplates](https://cloud.tencent.com/document/api/266/37781)
* [DescribeImageSpriteTemplates](https://cloud.tencent.com/document/api/266/37780)
* [DescribeSampleSnapshotTemplates](https://cloud.tencent.com/document/api/266/37779)
* [DescribeSnapshotByTimeOffsetTemplates](https://cloud.tencent.com/document/api/266/37778)
* [ModifyAnimatedGraphicsTemplate](https://cloud.tencent.com/document/api/266/37777)
* [ModifyImageSpriteTemplate](https://cloud.tencent.com/document/api/266/37776)
* [ModifySampleSnapshotTemplate](https://cloud.tencent.com/document/api/266/37775)
* [ModifySnapshotByTimeOffsetTemplate](https://cloud.tencent.com/document/api/266/37774)

修改接口：

* [CreateAIAnalysisTemplate](https://cloud.tencent.com/document/api/266/34463)

	* 新增入参：HighlightConfigure

* [CreateTranscodeTemplate](https://cloud.tencent.com/document/api/266/33773)

	* 新增入参：TEHDConfig

* [DescribeTranscodeTemplates](https://cloud.tencent.com/document/api/266/33769)

	* 新增入参：TEHDType

* [ModifyAIAnalysisTemplate](https://cloud.tencent.com/document/api/266/34460)

	* 新增入参：HighlightConfigure

* [ModifyTranscodeTemplate](https://cloud.tencent.com/document/api/266/33767)

	* 新增入参：TEHDConfig


新增数据结构：

* [AnimatedGraphicsTemplate](https://cloud.tencent.com/document/api/266/31773#AnimatedGraphicsTemplate)
* [HighlightSegmentItem](https://cloud.tencent.com/document/api/266/31773#HighlightSegmentItem)
* [HighlightsConfigureInfo](https://cloud.tencent.com/document/api/266/31773#HighlightsConfigureInfo)
* [HighlightsConfigureInfoForUpdate](https://cloud.tencent.com/document/api/266/31773#HighlightsConfigureInfoForUpdate)
* [ImageSpriteTemplate](https://cloud.tencent.com/document/api/266/31773#ImageSpriteTemplate)
* [SampleSnapshotTemplate](https://cloud.tencent.com/document/api/266/31773#SampleSnapshotTemplate)
* [SnapshotByTimeOffsetTemplate](https://cloud.tencent.com/document/api/266/31773#SnapshotByTimeOffsetTemplate)
* [TEHDConfigForUpdate](https://cloud.tencent.com/document/api/266/31773#TEHDConfigForUpdate)

修改数据结构：

* [AIAnalysisTemplateItem](https://cloud.tencent.com/document/api/266/31773#AIAnalysisTemplateItem)

	* 新增成员：HighlightConfigure

* [AiAnalysisResult](https://cloud.tencent.com/document/api/266/31773#AiAnalysisResult)

	* 新增成员：HighlightTask

	* <font color="#dd0000">**删除成员**：</font>HighlightsTask

* [MediaAiAnalysisHighlightItem](https://cloud.tencent.com/document/api/266/31773#MediaAiAnalysisHighlightItem)

	* 新增成员：SegmentSet

* [MediaMiniProgramReviewElem](https://cloud.tencent.com/document/api/266/31773#MediaMiniProgramReviewElem)

	* <font color="#dd0000">**修改成员**：</font>Confidence

* [MediaMiniProgramReviewInfoItem](https://cloud.tencent.com/document/api/266/31773#MediaMiniProgramReviewInfoItem)

	* 新增成员：ReviewSummary

	* <font color="#dd0000">**删除成员**：</font>ReviewSummery


### 第 23 次发布

发布时间：2019-08-29 20:04:34

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [MediaMiniProgramReviewInfo](https://cloud.tencent.com/document/api/266/31773#MediaMiniProgramReviewInfo)

	* 新增成员：MiniProgramReviewList

	* <font color="#dd0000">**删除成员**：</font>MiniProgramReivewList

* [MediaMiniProgramReviewInfoItem](https://cloud.tencent.com/document/api/266/31773#MediaMiniProgramReviewInfoItem)

	* <font color="#dd0000">**修改成员**：</font>ReviewSummery


### 第 22 次发布

发布时间：2019-08-22 20:06:33

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [ApplyUpload](https://cloud.tencent.com/document/api/266/31767)

	* 新增入参：SessionContext


新增数据结构：

* [AiAnalysisTaskHighlightInput](https://cloud.tencent.com/document/api/266/31773#AiAnalysisTaskHighlightInput)
* [AiAnalysisTaskHighlightOutput](https://cloud.tencent.com/document/api/266/31773#AiAnalysisTaskHighlightOutput)
* [AiAnalysisTaskHighlightResult](https://cloud.tencent.com/document/api/266/31773#AiAnalysisTaskHighlightResult)
* [MediaAiAnalysisHighlightItem](https://cloud.tencent.com/document/api/266/31773#MediaAiAnalysisHighlightItem)
* [TEHDConfig](https://cloud.tencent.com/document/api/266/31773#TEHDConfig)

修改数据结构：

* [AiAnalysisResult](https://cloud.tencent.com/document/api/266/31773#AiAnalysisResult)

	* 新增成员：HighlightsTask

* [TranscodeTemplate](https://cloud.tencent.com/document/api/266/31773#TranscodeTemplate)

	* 新增成员：TEHDConfig


### 第 21 次发布

发布时间：2019-08-01 19:02:06

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateAIRecognitionTemplate](https://cloud.tencent.com/document/api/266/34791)

	* 新增入参：SegmentConfigure

* [EditMedia](https://cloud.tencent.com/document/api/266/34783)

	* 新增入参：Definition, OutputConfig

* [ModifyAIRecognitionTemplate](https://cloud.tencent.com/document/api/266/34785)

	* 新增入参：SegmentConfigure


新增数据结构：

* [EditMediaOutputConfig](https://cloud.tencent.com/document/api/266/31773#EditMediaOutputConfig)
* [SegmentConfigureInfoForUpdate](https://cloud.tencent.com/document/api/266/31773#SegmentConfigureInfoForUpdate)

修改数据结构：

* [VideoTemplateInfoForUpdate](https://cloud.tencent.com/document/api/266/31773#VideoTemplateInfoForUpdate)

	* 新增成员：FillType


### 第 20 次发布

发布时间：2019-07-25 20:09:29

本次发布包含了以下内容：

改善已有的文档。

新增数据结构：

* [AiRecognitionTaskSegmentResult](https://cloud.tencent.com/document/api/266/31773#AiRecognitionTaskSegmentResult)
* [AiRecognitionTaskSegmentResultInput](https://cloud.tencent.com/document/api/266/31773#AiRecognitionTaskSegmentResultInput)
* [AiRecognitionTaskSegmentResultOutput](https://cloud.tencent.com/document/api/266/31773#AiRecognitionTaskSegmentResultOutput)
* [AiRecognitionTaskSegmentSegmentItem](https://cloud.tencent.com/document/api/266/31773#AiRecognitionTaskSegmentSegmentItem)
* [MediaMiniProgramReviewElem](https://cloud.tencent.com/document/api/266/31773#MediaMiniProgramReviewElem)
* [MediaMiniProgramReviewInfo](https://cloud.tencent.com/document/api/266/31773#MediaMiniProgramReviewInfo)
* [MediaMiniProgramReviewInfoItem](https://cloud.tencent.com/document/api/266/31773#MediaMiniProgramReviewInfoItem)
* [SegmentConfigureInfo](https://cloud.tencent.com/document/api/266/31773#SegmentConfigureInfo)

修改数据结构：

* [AIRecognitionTemplateItem](https://cloud.tencent.com/document/api/266/31773#AIRecognitionTemplateItem)

	* 新增成员：SegmentConfigure

* [AiRecognitionResult](https://cloud.tencent.com/document/api/266/31773#AiRecognitionResult)

	* 新增成员：SegmentTask

* [MediaInfo](https://cloud.tencent.com/document/api/266/31773#MediaInfo)

	* 新增成员：MiniProgramReviewInfo

* [VideoTemplateInfo](https://cloud.tencent.com/document/api/266/31773#VideoTemplateInfo)

	* 新增成员：FillType


### 第 19 次发布

发布时间：2019-07-18 20:16:29

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeSubAppIds](https://cloud.tencent.com/document/api/266/36304)
* [ModifySubAppIdInfo](https://cloud.tencent.com/document/api/266/36303)
* [ModifySubAppIdStatus](https://cloud.tencent.com/document/api/266/36302)

新增数据结构：

* [SubAppIdInfo](https://cloud.tencent.com/document/api/266/31773#SubAppIdInfo)

### 第 18 次发布

发布时间：2019-07-04 19:30:55

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [WeChatMiniProgramPublish](https://cloud.tencent.com/document/api/266/36035)

修改接口：

* [DescribeTaskDetail](https://cloud.tencent.com/document/api/266/33431)

	* 新增出参：WechatMiniProgramPublishTask


### 第 17 次发布

发布时间：2019-06-27 15:42:33

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [ComposeMedia](https://cloud.tencent.com/document/api/266/35286)

	* 新增入参：SubAppId


新增数据结构：

* [WechatMiniProgramPublishTask](https://cloud.tencent.com/document/api/266/31773#WechatMiniProgramPublishTask)

修改数据结构：

* [EventContent](https://cloud.tencent.com/document/api/266/31773#EventContent)

	* 新增成员：WechatMiniProgramPublishCompleteEvent


### 第 16 次发布

发布时间：2019-06-20 17:23:54

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [PullUpload](https://cloud.tencent.com/document/api/266/35575)

修改接口：

* [DescribeTaskDetail](https://cloud.tencent.com/document/api/266/33431)

	* 新增出参：PullUploadTask


新增数据结构：

* [PullUploadTask](https://cloud.tencent.com/document/api/266/31773#PullUploadTask)

<font color="#dd0000">**删除数据结构**：</font>

* PullFileTask

修改数据结构：

* [EditMediaTask](https://cloud.tencent.com/document/api/266/31773#EditMediaTask)

	* 新增成员：SessionContext, SessionId

* [EventContent](https://cloud.tencent.com/document/api/266/31773#EventContent)

	* <font color="#dd0000">**修改成员**：</font>PullCompleteEvent


### 第 15 次发布

发布时间：2019-06-13 19:30:20

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [ExecuteFunction](https://cloud.tencent.com/document/api/266/35479)
* [PushUrlCache](https://cloud.tencent.com/document/api/266/35481)

修改数据结构：

* [PullFileTask](https://cloud.tencent.com/document/api/266/31773#PullFileTask)

	* <font color="#dd0000">**修改成员**：</font>MediaBasicInfo


### 第 14 次发布

发布时间：2019-06-06 19:50:46

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeReviewDetails](https://cloud.tencent.com/document/api/266/35290)

新增数据结构：

* [StatDataItem](https://cloud.tencent.com/document/api/266/31773#StatDataItem)

### 第 13 次发布

发布时间：2019-06-06 17:10:01

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [ComposeMedia](https://cloud.tencent.com/document/api/266/35286)

修改接口：

* [DescribeTaskDetail](https://cloud.tencent.com/document/api/266/33431)

	* 新增出参：ComposeMediaTask


<font color="#dd0000">**删除数据结构**：</font>

* WechatMiniProgramPublishTask

修改数据结构：

* [EventContent](https://cloud.tencent.com/document/api/266/31773#EventContent)

	* <font color="#dd0000">**删除成员**：</font>WechatMiniProgramPublishEvent


### 第 12 次发布

发布时间：2019-05-30 20:47:53

本次发布包含了以下内容：

改善已有的文档。

新增数据结构：

* [AudioTrackItem](https://cloud.tencent.com/document/api/266/31773#AudioTrackItem)
* [AudioTransform](https://cloud.tencent.com/document/api/266/31773#AudioTransform)
* [AudioVolumeParam](https://cloud.tencent.com/document/api/266/31773#AudioVolumeParam)
* [Canvas](https://cloud.tencent.com/document/api/266/31773#Canvas)
* [ComposeMediaOutput](https://cloud.tencent.com/document/api/266/31773#ComposeMediaOutput)
* [ComposeMediaTask](https://cloud.tencent.com/document/api/266/31773#ComposeMediaTask)
* [ComposeMediaTaskInput](https://cloud.tencent.com/document/api/266/31773#ComposeMediaTaskInput)
* [ComposeMediaTaskOutput](https://cloud.tencent.com/document/api/266/31773#ComposeMediaTaskOutput)
* [EmptyTrackItem](https://cloud.tencent.com/document/api/266/31773#EmptyTrackItem)
* [ImageTransform](https://cloud.tencent.com/document/api/266/31773#ImageTransform)
* [MediaAdaptiveDynamicStreamingInfo](https://cloud.tencent.com/document/api/266/31773#MediaAdaptiveDynamicStreamingInfo)
* [MediaTrack](https://cloud.tencent.com/document/api/266/31773#MediaTrack)
* [MediaTrackItem](https://cloud.tencent.com/document/api/266/31773#MediaTrackItem)
* [MediaTransitionItem](https://cloud.tencent.com/document/api/266/31773#MediaTransitionItem)
* [OutputAudioStream](https://cloud.tencent.com/document/api/266/31773#OutputAudioStream)
* [OutputVideoStream](https://cloud.tencent.com/document/api/266/31773#OutputVideoStream)
* [StickerTrackItem](https://cloud.tencent.com/document/api/266/31773#StickerTrackItem)
* [TransitionOpertion](https://cloud.tencent.com/document/api/266/31773#TransitionOpertion)
* [VideoTrackItem](https://cloud.tencent.com/document/api/266/31773#VideoTrackItem)
* [WechatMiniProgramPublishTask](https://cloud.tencent.com/document/api/266/31773#WechatMiniProgramPublishTask)

修改数据结构：

* [AdaptiveDynamicStreamingTaskInput](https://cloud.tencent.com/document/api/266/31773#AdaptiveDynamicStreamingTaskInput)

	* 新增成员：WatermarkSet

* [EventContent](https://cloud.tencent.com/document/api/266/31773#EventContent)

	* 新增成员：ComposeMediaCompleteEvent, WechatMiniProgramPublishEvent

* [MediaInfo](https://cloud.tencent.com/document/api/266/31773#MediaInfo)

	* 新增成员：AdaptiveDynamicStreamingInfo

* [PullFileTask](https://cloud.tencent.com/document/api/266/31773#PullFileTask)

	* 新增成员：MediaBasicInfo


### 第 11 次发布

发布时间：2019-05-09 19:15:37

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateAIRecognitionTemplate](https://cloud.tencent.com/document/api/266/34791)
* [CreateContentReviewTemplate](https://cloud.tencent.com/document/api/266/34790)
* [CreatePersonSample](https://cloud.tencent.com/document/api/266/34800)
* [CreateWordSamples](https://cloud.tencent.com/document/api/266/34799)
* [DeleteAIRecognitionTemplate](https://cloud.tencent.com/document/api/266/34789)
* [DeleteContentReviewTemplate](https://cloud.tencent.com/document/api/266/34788)
* [DeletePersonSample](https://cloud.tencent.com/document/api/266/34798)
* [DeleteWordSamples](https://cloud.tencent.com/document/api/266/34797)
* [DescribeAIRecognitionTemplates](https://cloud.tencent.com/document/api/266/34787)
* [DescribeContentReviewTemplates](https://cloud.tencent.com/document/api/266/34786)
* [DescribePersonSamples](https://cloud.tencent.com/document/api/266/34796)
* [DescribeWordSamples](https://cloud.tencent.com/document/api/266/34795)
* [EditMedia](https://cloud.tencent.com/document/api/266/34783)
* [ModifyAIRecognitionTemplate](https://cloud.tencent.com/document/api/266/34785)
* [ModifyContentReviewTemplate](https://cloud.tencent.com/document/api/266/34784)
* [ModifyPersonSample](https://cloud.tencent.com/document/api/266/34794)
* [ModifyWordSample](https://cloud.tencent.com/document/api/266/34793)
* [ProcessMediaByProcedure](https://cloud.tencent.com/document/api/266/34782)

修改接口：

* [ProcessMedia](https://cloud.tencent.com/document/api/266/33427)

	* 新增入参：AiRecognitionTask

* [ProcessMediaByUrl](https://cloud.tencent.com/document/api/266/33426)

	* 新增入参：AiRecognitionTask


新增数据结构：

* [AIRecognitionTemplateItem](https://cloud.tencent.com/document/api/266/31773#AIRecognitionTemplateItem)
* [AiSampleFaceInfo](https://cloud.tencent.com/document/api/266/31773#AiSampleFaceInfo)
* [AiSampleFaceOperation](https://cloud.tencent.com/document/api/266/31773#AiSampleFaceOperation)
* [AiSampleFailFaceInfo](https://cloud.tencent.com/document/api/266/31773#AiSampleFailFaceInfo)
* [AiSamplePerson](https://cloud.tencent.com/document/api/266/31773#AiSamplePerson)
* [AiSampleTagOperation](https://cloud.tencent.com/document/api/266/31773#AiSampleTagOperation)
* [AiSampleWord](https://cloud.tencent.com/document/api/266/31773#AiSampleWord)
* [AiSampleWordInfo](https://cloud.tencent.com/document/api/266/31773#AiSampleWordInfo)
* [AsrFullTextConfigureInfo](https://cloud.tencent.com/document/api/266/31773#AsrFullTextConfigureInfo)
* [AsrFullTextConfigureInfoForUpdate](https://cloud.tencent.com/document/api/266/31773#AsrFullTextConfigureInfoForUpdate)
* [AsrWordsConfigureInfo](https://cloud.tencent.com/document/api/266/31773#AsrWordsConfigureInfo)
* [AsrWordsConfigureInfoForUpdate](https://cloud.tencent.com/document/api/266/31773#AsrWordsConfigureInfoForUpdate)
* [ContentReviewTemplateItem](https://cloud.tencent.com/document/api/266/31773#ContentReviewTemplateItem)
* [FaceConfigureInfo](https://cloud.tencent.com/document/api/266/31773#FaceConfigureInfo)
* [FaceConfigureInfoForUpdate](https://cloud.tencent.com/document/api/266/31773#FaceConfigureInfoForUpdate)
* [HeadTailConfigureInfo](https://cloud.tencent.com/document/api/266/31773#HeadTailConfigureInfo)
* [HeadTailConfigureInfoForUpdate](https://cloud.tencent.com/document/api/266/31773#HeadTailConfigureInfoForUpdate)
* [ObjectConfigureInfo](https://cloud.tencent.com/document/api/266/31773#ObjectConfigureInfo)
* [ObjectConfigureInfoForUpdate](https://cloud.tencent.com/document/api/266/31773#ObjectConfigureInfoForUpdate)
* [OcrFullTextConfigureInfo](https://cloud.tencent.com/document/api/266/31773#OcrFullTextConfigureInfo)
* [OcrFullTextConfigureInfoForUpdate](https://cloud.tencent.com/document/api/266/31773#OcrFullTextConfigureInfoForUpdate)
* [OcrWordsConfigureInfo](https://cloud.tencent.com/document/api/266/31773#OcrWordsConfigureInfo)
* [OcrWordsConfigureInfoForUpdate](https://cloud.tencent.com/document/api/266/31773#OcrWordsConfigureInfoForUpdate)
* [PoliticalAsrReviewTemplateInfo](https://cloud.tencent.com/document/api/266/31773#PoliticalAsrReviewTemplateInfo)
* [PoliticalAsrReviewTemplateInfoForUpdate](https://cloud.tencent.com/document/api/266/31773#PoliticalAsrReviewTemplateInfoForUpdate)
* [PoliticalConfigureInfo](https://cloud.tencent.com/document/api/266/31773#PoliticalConfigureInfo)
* [PoliticalConfigureInfoForUpdate](https://cloud.tencent.com/document/api/266/31773#PoliticalConfigureInfoForUpdate)
* [PoliticalImgReviewTemplateInfo](https://cloud.tencent.com/document/api/266/31773#PoliticalImgReviewTemplateInfo)
* [PoliticalImgReviewTemplateInfoForUpdate](https://cloud.tencent.com/document/api/266/31773#PoliticalImgReviewTemplateInfoForUpdate)
* [PoliticalOcrReviewTemplateInfo](https://cloud.tencent.com/document/api/266/31773#PoliticalOcrReviewTemplateInfo)
* [PoliticalOcrReviewTemplateInfoForUpdate](https://cloud.tencent.com/document/api/266/31773#PoliticalOcrReviewTemplateInfoForUpdate)
* [PornAsrReviewTemplateInfo](https://cloud.tencent.com/document/api/266/31773#PornAsrReviewTemplateInfo)
* [PornAsrReviewTemplateInfoForUpdate](https://cloud.tencent.com/document/api/266/31773#PornAsrReviewTemplateInfoForUpdate)
* [PornConfigureInfo](https://cloud.tencent.com/document/api/266/31773#PornConfigureInfo)
* [PornConfigureInfoForUpdate](https://cloud.tencent.com/document/api/266/31773#PornConfigureInfoForUpdate)
* [PornImgReviewTemplateInfo](https://cloud.tencent.com/document/api/266/31773#PornImgReviewTemplateInfo)
* [PornImgReviewTemplateInfoForUpdate](https://cloud.tencent.com/document/api/266/31773#PornImgReviewTemplateInfoForUpdate)
* [PornOcrReviewTemplateInfo](https://cloud.tencent.com/document/api/266/31773#PornOcrReviewTemplateInfo)
* [PornOcrReviewTemplateInfoForUpdate](https://cloud.tencent.com/document/api/266/31773#PornOcrReviewTemplateInfoForUpdate)
* [TerrorismConfigureInfo](https://cloud.tencent.com/document/api/266/31773#TerrorismConfigureInfo)
* [TerrorismConfigureInfoForUpdate](https://cloud.tencent.com/document/api/266/31773#TerrorismConfigureInfoForUpdate)
* [TerrorismImgReviewTemplateInfo](https://cloud.tencent.com/document/api/266/31773#TerrorismImgReviewTemplateInfo)
* [TerrorismImgReviewTemplateInfoForUpdate](https://cloud.tencent.com/document/api/266/31773#TerrorismImgReviewTemplateInfoForUpdate)
* [UserDefineAsrTextReviewTemplateInfo](https://cloud.tencent.com/document/api/266/31773#UserDefineAsrTextReviewTemplateInfo)
* [UserDefineAsrTextReviewTemplateInfoForUpdate](https://cloud.tencent.com/document/api/266/31773#UserDefineAsrTextReviewTemplateInfoForUpdate)
* [UserDefineConfigureInfo](https://cloud.tencent.com/document/api/266/31773#UserDefineConfigureInfo)
* [UserDefineConfigureInfoForUpdate](https://cloud.tencent.com/document/api/266/31773#UserDefineConfigureInfoForUpdate)
* [UserDefineFaceReviewTemplateInfo](https://cloud.tencent.com/document/api/266/31773#UserDefineFaceReviewTemplateInfo)
* [UserDefineFaceReviewTemplateInfoForUpdate](https://cloud.tencent.com/document/api/266/31773#UserDefineFaceReviewTemplateInfoForUpdate)
* [UserDefineOcrTextReviewTemplateInfo](https://cloud.tencent.com/document/api/266/31773#UserDefineOcrTextReviewTemplateInfo)
* [UserDefineOcrTextReviewTemplateInfoForUpdate](https://cloud.tencent.com/document/api/266/31773#UserDefineOcrTextReviewTemplateInfoForUpdate)

修改数据结构：

* [AiRecognitionResult](https://cloud.tencent.com/document/api/266/31773#AiRecognitionResult)

	* 新增成员：FaceTask

	* <font color="#dd0000">**删除成员**：</font>FaceRecognitionTask


### 第 10 次发布

发布时间：2019-04-25 19:31:16

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateAIAnalysisTemplate](https://cloud.tencent.com/document/api/266/34463)
* [DeleteAIAnalysisTemplate](https://cloud.tencent.com/document/api/266/34462)
* [DescribeAIAnalysisTemplates](https://cloud.tencent.com/document/api/266/34461)
* [ModifyAIAnalysisTemplate](https://cloud.tencent.com/document/api/266/34460)

新增数据结构：

* [AIAnalysisTemplateItem](https://cloud.tencent.com/document/api/266/31773#AIAnalysisTemplateItem)
* [AiAnalysisTaskFrameTagInput](https://cloud.tencent.com/document/api/266/31773#AiAnalysisTaskFrameTagInput)
* [AiAnalysisTaskFrameTagOutput](https://cloud.tencent.com/document/api/266/31773#AiAnalysisTaskFrameTagOutput)
* [AiAnalysisTaskFrameTagResult](https://cloud.tencent.com/document/api/266/31773#AiAnalysisTaskFrameTagResult)
* [AiRecognitionResult](https://cloud.tencent.com/document/api/266/31773#AiRecognitionResult)
* [AiRecognitionTaskAsrFullTextResult](https://cloud.tencent.com/document/api/266/31773#AiRecognitionTaskAsrFullTextResult)
* [AiRecognitionTaskAsrFullTextResultInput](https://cloud.tencent.com/document/api/266/31773#AiRecognitionTaskAsrFullTextResultInput)
* [AiRecognitionTaskAsrFullTextResultOutput](https://cloud.tencent.com/document/api/266/31773#AiRecognitionTaskAsrFullTextResultOutput)
* [AiRecognitionTaskAsrFullTextSegmentItem](https://cloud.tencent.com/document/api/266/31773#AiRecognitionTaskAsrFullTextSegmentItem)
* [AiRecognitionTaskAsrWordsResult](https://cloud.tencent.com/document/api/266/31773#AiRecognitionTaskAsrWordsResult)
* [AiRecognitionTaskAsrWordsResultInput](https://cloud.tencent.com/document/api/266/31773#AiRecognitionTaskAsrWordsResultInput)
* [AiRecognitionTaskAsrWordsResultItem](https://cloud.tencent.com/document/api/266/31773#AiRecognitionTaskAsrWordsResultItem)
* [AiRecognitionTaskAsrWordsResultOutput](https://cloud.tencent.com/document/api/266/31773#AiRecognitionTaskAsrWordsResultOutput)
* [AiRecognitionTaskAsrWordsSegmentItem](https://cloud.tencent.com/document/api/266/31773#AiRecognitionTaskAsrWordsSegmentItem)
* [AiRecognitionTaskFaceResult](https://cloud.tencent.com/document/api/266/31773#AiRecognitionTaskFaceResult)
* [AiRecognitionTaskFaceResultInput](https://cloud.tencent.com/document/api/266/31773#AiRecognitionTaskFaceResultInput)
* [AiRecognitionTaskFaceResultItem](https://cloud.tencent.com/document/api/266/31773#AiRecognitionTaskFaceResultItem)
* [AiRecognitionTaskFaceResultOutput](https://cloud.tencent.com/document/api/266/31773#AiRecognitionTaskFaceResultOutput)
* [AiRecognitionTaskFaceSegmentItem](https://cloud.tencent.com/document/api/266/31773#AiRecognitionTaskFaceSegmentItem)
* [AiRecognitionTaskHeadTailResult](https://cloud.tencent.com/document/api/266/31773#AiRecognitionTaskHeadTailResult)
* [AiRecognitionTaskHeadTailResultInput](https://cloud.tencent.com/document/api/266/31773#AiRecognitionTaskHeadTailResultInput)
* [AiRecognitionTaskHeadTailResultOutput](https://cloud.tencent.com/document/api/266/31773#AiRecognitionTaskHeadTailResultOutput)
* [AiRecognitionTaskObjectResult](https://cloud.tencent.com/document/api/266/31773#AiRecognitionTaskObjectResult)
* [AiRecognitionTaskObjectResultInput](https://cloud.tencent.com/document/api/266/31773#AiRecognitionTaskObjectResultInput)
* [AiRecognitionTaskObjectResultItem](https://cloud.tencent.com/document/api/266/31773#AiRecognitionTaskObjectResultItem)
* [AiRecognitionTaskObjectResultOutput](https://cloud.tencent.com/document/api/266/31773#AiRecognitionTaskObjectResultOutput)
* [AiRecognitionTaskObjectSeqmentItem](https://cloud.tencent.com/document/api/266/31773#AiRecognitionTaskObjectSeqmentItem)
* [AiRecognitionTaskOcrFullTextResult](https://cloud.tencent.com/document/api/266/31773#AiRecognitionTaskOcrFullTextResult)
* [AiRecognitionTaskOcrFullTextResultInput](https://cloud.tencent.com/document/api/266/31773#AiRecognitionTaskOcrFullTextResultInput)
* [AiRecognitionTaskOcrFullTextResultOutput](https://cloud.tencent.com/document/api/266/31773#AiRecognitionTaskOcrFullTextResultOutput)
* [AiRecognitionTaskOcrFullTextSegmentItem](https://cloud.tencent.com/document/api/266/31773#AiRecognitionTaskOcrFullTextSegmentItem)
* [AiRecognitionTaskOcrFullTextSegmentTextItem](https://cloud.tencent.com/document/api/266/31773#AiRecognitionTaskOcrFullTextSegmentTextItem)
* [AiRecognitionTaskOcrWordsResult](https://cloud.tencent.com/document/api/266/31773#AiRecognitionTaskOcrWordsResult)
* [AiRecognitionTaskOcrWordsResultInput](https://cloud.tencent.com/document/api/266/31773#AiRecognitionTaskOcrWordsResultInput)
* [AiRecognitionTaskOcrWordsResultItem](https://cloud.tencent.com/document/api/266/31773#AiRecognitionTaskOcrWordsResultItem)
* [AiRecognitionTaskOcrWordsResultOutput](https://cloud.tencent.com/document/api/266/31773#AiRecognitionTaskOcrWordsResultOutput)
* [AiRecognitionTaskOcrWordsSegmentItem](https://cloud.tencent.com/document/api/266/31773#AiRecognitionTaskOcrWordsSegmentItem)
* [ClassificationConfigureInfo](https://cloud.tencent.com/document/api/266/31773#ClassificationConfigureInfo)
* [ClassificationConfigureInfoForUpdate](https://cloud.tencent.com/document/api/266/31773#ClassificationConfigureInfoForUpdate)
* [CoverConfigureInfo](https://cloud.tencent.com/document/api/266/31773#CoverConfigureInfo)
* [CoverConfigureInfoForUpdate](https://cloud.tencent.com/document/api/266/31773#CoverConfigureInfoForUpdate)
* [FrameTagConfigureInfo](https://cloud.tencent.com/document/api/266/31773#FrameTagConfigureInfo)
* [FrameTagConfigureInfoForUpdate](https://cloud.tencent.com/document/api/266/31773#FrameTagConfigureInfoForUpdate)
* [MediaAiAnalysisFrameTagItem](https://cloud.tencent.com/document/api/266/31773#MediaAiAnalysisFrameTagItem)
* [MediaAiAnalysisFrameTagSegmentItem](https://cloud.tencent.com/document/api/266/31773#MediaAiAnalysisFrameTagSegmentItem)
* [TagConfigureInfo](https://cloud.tencent.com/document/api/266/31773#TagConfigureInfo)
* [TagConfigureInfoForUpdate](https://cloud.tencent.com/document/api/266/31773#TagConfigureInfoForUpdate)

修改数据结构：

* [AiAnalysisResult](https://cloud.tencent.com/document/api/266/31773#AiAnalysisResult)

	* 新增成员：FrameTagTask

* [ProcedureTask](https://cloud.tencent.com/document/api/266/31773#ProcedureTask)

	* 新增成员：AiRecognitionResultSet

* [WatermarkTemplate](https://cloud.tencent.com/document/api/266/31773#WatermarkTemplate)

	* 新增成员：SvgTemplate


### 第 9 次发布

发布时间：2019-03-29 14:21:03

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [ProcedureTask](https://cloud.tencent.com/document/api/266/31773#ProcedureTask)

	* 新增成员：SessionContext, SessionId


### 第 8 次发布

发布时间：2019-03-22 14:55:51

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateProcedureTemplate](https://cloud.tencent.com/document/api/266/33897)
* [DeleteProcedureTemplate](https://cloud.tencent.com/document/api/266/33896)
* [DescribeProcedureTemplates](https://cloud.tencent.com/document/api/266/33895)
* [ResetProcedureTemplate](https://cloud.tencent.com/document/api/266/33894)

修改接口：

* [CreateWatermarkTemplate](https://cloud.tencent.com/document/api/266/33772)

	* 新增入参：SvgTemplate

	* <font color="#dd0000">**修改入参**：</font>TextTemplate

* [LiveRealTimeClip](https://cloud.tencent.com/document/api/266/32587)

	* 新增入参：MetaDataRequired, SubAppId

	* 新增出参：MetaData

* [ModifyTranscodeTemplate](https://cloud.tencent.com/document/api/266/33767)

	* <font color="#dd0000">**修改入参**：</font>VideoTemplate, AudioTemplate

* [ModifyWatermarkTemplate](https://cloud.tencent.com/document/api/266/33766)

	* 新增入参：SvgTemplate

	* <font color="#dd0000">**修改入参**：</font>ImageTemplate, TextTemplate


新增数据结构：

* [AdaptiveDynamicStreamingInfoItem](https://cloud.tencent.com/document/api/266/31773#AdaptiveDynamicStreamingInfoItem)
* [AdaptiveDynamicStreamingTaskInput](https://cloud.tencent.com/document/api/266/31773#AdaptiveDynamicStreamingTaskInput)
* [AiRecognitionTaskInput](https://cloud.tencent.com/document/api/266/31773#AiRecognitionTaskInput)
* [AudioTemplateInfoForUpdate](https://cloud.tencent.com/document/api/266/31773#AudioTemplateInfoForUpdate)
* [ImageWatermarkInputForUpdate](https://cloud.tencent.com/document/api/266/31773#ImageWatermarkInputForUpdate)
* [MediaProcessTaskAdaptiveDynamicStreamingResult](https://cloud.tencent.com/document/api/266/31773#MediaProcessTaskAdaptiveDynamicStreamingResult)
* [ProcedureTemplate](https://cloud.tencent.com/document/api/266/31773#ProcedureTemplate)
* [SvgWatermarkInput](https://cloud.tencent.com/document/api/266/31773#SvgWatermarkInput)
* [SvgWatermarkInputForUpdate](https://cloud.tencent.com/document/api/266/31773#SvgWatermarkInputForUpdate)
* [TextWatermarkTemplateInput](https://cloud.tencent.com/document/api/266/31773#TextWatermarkTemplateInput)
* [TextWatermarkTemplateInputForUpdate](https://cloud.tencent.com/document/api/266/31773#TextWatermarkTemplateInputForUpdate)
* [VideoTemplateInfoForUpdate](https://cloud.tencent.com/document/api/266/31773#VideoTemplateInfoForUpdate)

<font color="#dd0000">**删除数据结构**：</font>

* TextWatermarkTemplate

修改数据结构：

* [AiAnalysisTaskTagOutput](https://cloud.tencent.com/document/api/266/31773#AiAnalysisTaskTagOutput)

	* <font color="#dd0000">**修改成员**：</font>TagSet

* [AiAnalysisTaskTagResult](https://cloud.tencent.com/document/api/266/31773#AiAnalysisTaskTagResult)

	* <font color="#dd0000">**修改成员**：</font>Output

* [ClipFileInfo2017](https://cloud.tencent.com/document/api/266/31773#ClipFileInfo2017)

	* <font color="#dd0000">**修改成员**：</font>Message

* [EventContent](https://cloud.tencent.com/document/api/266/31773#EventContent)

	* 新增成员：WechatPublishCompleteEvent

	* <font color="#dd0000">**删除成员**：</font>WechatPublishComplete

* [MediaProcessTaskInput](https://cloud.tencent.com/document/api/266/31773#MediaProcessTaskInput)

	* 新增成员：AdaptiveDynamicStreamingTaskSet

* [MediaProcessTaskResult](https://cloud.tencent.com/document/api/266/31773#MediaProcessTaskResult)

	* 新增成员：AdaptiveDynamicStreamingTask

* [SnapshotByTimeOffset2017](https://cloud.tencent.com/document/api/266/31773#SnapshotByTimeOffset2017)

	* <font color="#dd0000">**修改成员**：</font>ErrCode

* [WatermarkInput](https://cloud.tencent.com/document/api/266/31773#WatermarkInput)

	* 新增成员：SvgContent

* [WatermarkTemplate](https://cloud.tencent.com/document/api/266/31773#WatermarkTemplate)

	* <font color="#dd0000">**修改成员**：</font>TextTemplate


### 第 7 次发布

发布时间：2019-03-14 17:24:30

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateTranscodeTemplate](https://cloud.tencent.com/document/api/266/33773)
* [CreateWatermarkTemplate](https://cloud.tencent.com/document/api/266/33772)
* [DeleteTranscodeTemplate](https://cloud.tencent.com/document/api/266/33771)
* [DeleteWatermarkTemplate](https://cloud.tencent.com/document/api/266/33770)
* [DescribeTranscodeTemplates](https://cloud.tencent.com/document/api/266/33769)
* [DescribeWatermarkTemplates](https://cloud.tencent.com/document/api/266/33768)
* [ModifyTranscodeTemplate](https://cloud.tencent.com/document/api/266/33767)
* [ModifyWatermarkTemplate](https://cloud.tencent.com/document/api/266/33766)

新增数据结构：

* [AudioTemplateInfo](https://cloud.tencent.com/document/api/266/31773#AudioTemplateInfo)
* [ImageWatermarkInput](https://cloud.tencent.com/document/api/266/31773#ImageWatermarkInput)
* [ImageWatermarkTemplate](https://cloud.tencent.com/document/api/266/31773#ImageWatermarkTemplate)
* [TextWatermarkTemplate](https://cloud.tencent.com/document/api/266/31773#TextWatermarkTemplate)
* [TranscodeTemplate](https://cloud.tencent.com/document/api/266/31773#TranscodeTemplate)
* [VideoTemplateInfo](https://cloud.tencent.com/document/api/266/31773#VideoTemplateInfo)
* [WatermarkTemplate](https://cloud.tencent.com/document/api/266/31773#WatermarkTemplate)

### 第 6 次发布

发布时间：2019-03-01 19:24:29

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [ConfirmEvents](https://cloud.tencent.com/document/api/266/33434)
* [DescribeTaskDetail](https://cloud.tencent.com/document/api/266/33431)
* [DescribeTasks](https://cloud.tencent.com/document/api/266/33430)
* [ProcessMedia](https://cloud.tencent.com/document/api/266/33427)
* [ProcessMediaByUrl](https://cloud.tencent.com/document/api/266/33426)
* [PullEvents](https://cloud.tencent.com/document/api/266/33433)

修改接口：

* [DescribeMediaInfos](https://cloud.tencent.com/document/api/266/31763)

	* 新增入参：SubAppId


新增数据结构：

* [AiAnalysisResult](https://cloud.tencent.com/document/api/266/31773#AiAnalysisResult)
* [AiAnalysisTaskClassificationInput](https://cloud.tencent.com/document/api/266/31773#AiAnalysisTaskClassificationInput)
* [AiAnalysisTaskClassificationOutput](https://cloud.tencent.com/document/api/266/31773#AiAnalysisTaskClassificationOutput)
* [AiAnalysisTaskClassificationResult](https://cloud.tencent.com/document/api/266/31773#AiAnalysisTaskClassificationResult)
* [AiAnalysisTaskCoverInput](https://cloud.tencent.com/document/api/266/31773#AiAnalysisTaskCoverInput)
* [AiAnalysisTaskCoverOutput](https://cloud.tencent.com/document/api/266/31773#AiAnalysisTaskCoverOutput)
* [AiAnalysisTaskCoverResult](https://cloud.tencent.com/document/api/266/31773#AiAnalysisTaskCoverResult)
* [AiAnalysisTaskInput](https://cloud.tencent.com/document/api/266/31773#AiAnalysisTaskInput)
* [AiAnalysisTaskTagInput](https://cloud.tencent.com/document/api/266/31773#AiAnalysisTaskTagInput)
* [AiAnalysisTaskTagOutput](https://cloud.tencent.com/document/api/266/31773#AiAnalysisTaskTagOutput)
* [AiAnalysisTaskTagResult](https://cloud.tencent.com/document/api/266/31773#AiAnalysisTaskTagResult)
* [AiContentReviewResult](https://cloud.tencent.com/document/api/266/31773#AiContentReviewResult)
* [AiContentReviewTaskInput](https://cloud.tencent.com/document/api/266/31773#AiContentReviewTaskInput)
* [AiReviewPoliticalAsrTaskInput](https://cloud.tencent.com/document/api/266/31773#AiReviewPoliticalAsrTaskInput)
* [AiReviewPoliticalAsrTaskOutput](https://cloud.tencent.com/document/api/266/31773#AiReviewPoliticalAsrTaskOutput)
* [AiReviewPoliticalOcrTaskInput](https://cloud.tencent.com/document/api/266/31773#AiReviewPoliticalOcrTaskInput)
* [AiReviewPoliticalOcrTaskOutput](https://cloud.tencent.com/document/api/266/31773#AiReviewPoliticalOcrTaskOutput)
* [AiReviewPoliticalTaskInput](https://cloud.tencent.com/document/api/266/31773#AiReviewPoliticalTaskInput)
* [AiReviewPoliticalTaskOutput](https://cloud.tencent.com/document/api/266/31773#AiReviewPoliticalTaskOutput)
* [AiReviewPornAsrTaskInput](https://cloud.tencent.com/document/api/266/31773#AiReviewPornAsrTaskInput)
* [AiReviewPornAsrTaskOutput](https://cloud.tencent.com/document/api/266/31773#AiReviewPornAsrTaskOutput)
* [AiReviewPornOcrTaskInput](https://cloud.tencent.com/document/api/266/31773#AiReviewPornOcrTaskInput)
* [AiReviewPornOcrTaskOutput](https://cloud.tencent.com/document/api/266/31773#AiReviewPornOcrTaskOutput)
* [AiReviewPornTaskInput](https://cloud.tencent.com/document/api/266/31773#AiReviewPornTaskInput)
* [AiReviewPornTaskOutput](https://cloud.tencent.com/document/api/266/31773#AiReviewPornTaskOutput)
* [AiReviewTaskPoliticalAsrResult](https://cloud.tencent.com/document/api/266/31773#AiReviewTaskPoliticalAsrResult)
* [AiReviewTaskPoliticalOcrResult](https://cloud.tencent.com/document/api/266/31773#AiReviewTaskPoliticalOcrResult)
* [AiReviewTaskPoliticalResult](https://cloud.tencent.com/document/api/266/31773#AiReviewTaskPoliticalResult)
* [AiReviewTaskPornAsrResult](https://cloud.tencent.com/document/api/266/31773#AiReviewTaskPornAsrResult)
* [AiReviewTaskPornOcrResult](https://cloud.tencent.com/document/api/266/31773#AiReviewTaskPornOcrResult)
* [AiReviewTaskPornResult](https://cloud.tencent.com/document/api/266/31773#AiReviewTaskPornResult)
* [AiReviewTaskTerrorismResult](https://cloud.tencent.com/document/api/266/31773#AiReviewTaskTerrorismResult)
* [AiReviewTerrorismTaskInput](https://cloud.tencent.com/document/api/266/31773#AiReviewTerrorismTaskInput)
* [AiReviewTerrorismTaskOutput](https://cloud.tencent.com/document/api/266/31773#AiReviewTerrorismTaskOutput)
* [AnimatedGraphicTaskInput](https://cloud.tencent.com/document/api/266/31773#AnimatedGraphicTaskInput)
* [ClipFileInfo2017](https://cloud.tencent.com/document/api/266/31773#ClipFileInfo2017)
* [ClipTask2017](https://cloud.tencent.com/document/api/266/31773#ClipTask2017)
* [ConcatFileInfo2017](https://cloud.tencent.com/document/api/266/31773#ConcatFileInfo2017)
* [ConcatTask2017](https://cloud.tencent.com/document/api/266/31773#ConcatTask2017)
* [CoverBySnapshotTaskInput](https://cloud.tencent.com/document/api/266/31773#CoverBySnapshotTaskInput)
* [CoverBySnapshotTaskOutput](https://cloud.tencent.com/document/api/266/31773#CoverBySnapshotTaskOutput)
* [CreateImageSpriteTask2017](https://cloud.tencent.com/document/api/266/31773#CreateImageSpriteTask2017)
* [EditMediaFileInfo](https://cloud.tencent.com/document/api/266/31773#EditMediaFileInfo)
* [EditMediaStreamInfo](https://cloud.tencent.com/document/api/266/31773#EditMediaStreamInfo)
* [EditMediaTask](https://cloud.tencent.com/document/api/266/31773#EditMediaTask)
* [EditMediaTaskInput](https://cloud.tencent.com/document/api/266/31773#EditMediaTaskInput)
* [EditMediaTaskOutput](https://cloud.tencent.com/document/api/266/31773#EditMediaTaskOutput)
* [EventContent](https://cloud.tencent.com/document/api/266/31773#EventContent)
* [FileDeleteTask](https://cloud.tencent.com/document/api/266/31773#FileDeleteTask)
* [FileUploadTask](https://cloud.tencent.com/document/api/266/31773#FileUploadTask)
* [ImageSpriteTaskInput](https://cloud.tencent.com/document/api/266/31773#ImageSpriteTaskInput)
* [MediaAiAnalysisClassificationItem](https://cloud.tencent.com/document/api/266/31773#MediaAiAnalysisClassificationItem)
* [MediaAiAnalysisCoverItem](https://cloud.tencent.com/document/api/266/31773#MediaAiAnalysisCoverItem)
* [MediaAiAnalysisTagItem](https://cloud.tencent.com/document/api/266/31773#MediaAiAnalysisTagItem)
* [MediaContentReviewAsrTextSegmentItem](https://cloud.tencent.com/document/api/266/31773#MediaContentReviewAsrTextSegmentItem)
* [MediaContentReviewOcrTextSegmentItem](https://cloud.tencent.com/document/api/266/31773#MediaContentReviewOcrTextSegmentItem)
* [MediaContentReviewPoliticalSegmentItem](https://cloud.tencent.com/document/api/266/31773#MediaContentReviewPoliticalSegmentItem)
* [MediaContentReviewSegmentItem](https://cloud.tencent.com/document/api/266/31773#MediaContentReviewSegmentItem)
* [MediaInputInfo](https://cloud.tencent.com/document/api/266/31773#MediaInputInfo)
* [MediaOutputInfo](https://cloud.tencent.com/document/api/266/31773#MediaOutputInfo)
* [MediaProcessTaskAnimatedGraphicResult](https://cloud.tencent.com/document/api/266/31773#MediaProcessTaskAnimatedGraphicResult)
* [MediaProcessTaskCoverBySnapshotResult](https://cloud.tencent.com/document/api/266/31773#MediaProcessTaskCoverBySnapshotResult)
* [MediaProcessTaskImageSpriteResult](https://cloud.tencent.com/document/api/266/31773#MediaProcessTaskImageSpriteResult)
* [MediaProcessTaskInput](https://cloud.tencent.com/document/api/266/31773#MediaProcessTaskInput)
* [MediaProcessTaskResult](https://cloud.tencent.com/document/api/266/31773#MediaProcessTaskResult)
* [MediaProcessTaskSampleSnapshotResult](https://cloud.tencent.com/document/api/266/31773#MediaProcessTaskSampleSnapshotResult)
* [MediaProcessTaskSnapshotByTimeOffsetResult](https://cloud.tencent.com/document/api/266/31773#MediaProcessTaskSnapshotByTimeOffsetResult)
* [MediaProcessTaskTranscodeResult](https://cloud.tencent.com/document/api/266/31773#MediaProcessTaskTranscodeResult)
* [ProcedureTask](https://cloud.tencent.com/document/api/266/31773#ProcedureTask)
* [PullFileTask](https://cloud.tencent.com/document/api/266/31773#PullFileTask)
* [SampleSnapshotTaskInput](https://cloud.tencent.com/document/api/266/31773#SampleSnapshotTaskInput)
* [SnapshotByTimeOffset2017](https://cloud.tencent.com/document/api/266/31773#SnapshotByTimeOffset2017)
* [SnapshotByTimeOffsetTask2017](https://cloud.tencent.com/document/api/266/31773#SnapshotByTimeOffsetTask2017)
* [SnapshotByTimeOffsetTaskInput](https://cloud.tencent.com/document/api/266/31773#SnapshotByTimeOffsetTaskInput)
* [TaskSimpleInfo](https://cloud.tencent.com/document/api/266/31773#TaskSimpleInfo)
* [TranscodePlayInfo2017](https://cloud.tencent.com/document/api/266/31773#TranscodePlayInfo2017)
* [TranscodeTask2017](https://cloud.tencent.com/document/api/266/31773#TranscodeTask2017)
* [TranscodeTaskInput](https://cloud.tencent.com/document/api/266/31773#TranscodeTaskInput)
* [WatermarkInput](https://cloud.tencent.com/document/api/266/31773#WatermarkInput)
* [WechatPublishTask](https://cloud.tencent.com/document/api/266/31773#WechatPublishTask)

### 第 5 次发布

发布时间：2019-01-25 11:57:53

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [SimpleHlsClip](https://cloud.tencent.com/document/api/266/33428)

### 第 4 次发布

发布时间：2019-01-17 16:38:39

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [LiveRealTimeClip](https://cloud.tencent.com/document/api/266/32587)

### 第 3 次发布

发布时间：2018-12-27 20:44:17

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [SearchMedia](https://cloud.tencent.com/document/api/266/31813)

	* <font color="#dd0000">**修改入参**：</font>SourceType


### 第 2 次发布

发布时间：2018-12-20 19:39:12

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [SearchMedia](https://cloud.tencent.com/document/api/266/31813)

新增数据结构：

* [SortBy](https://cloud.tencent.com/document/api/266/31773#SortBy)

### 第 1 次发布

发布时间：2018-12-19 11:08:45

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [ApplyUpload](https://cloud.tencent.com/document/api/266/31767)
* [CommitUpload](https://cloud.tencent.com/document/api/266/31766)
* [CreateClass](https://cloud.tencent.com/document/api/266/31772)
* [DeleteClass](https://cloud.tencent.com/document/api/266/31771)
* [DeleteMedia](https://cloud.tencent.com/document/api/266/31764)
* [DescribeAllClass](https://cloud.tencent.com/document/api/266/31770)
* [DescribeMediaInfos](https://cloud.tencent.com/document/api/266/31763)
* [ModifyClass](https://cloud.tencent.com/document/api/266/31769)
* [ModifyMediaInfo](https://cloud.tencent.com/document/api/266/31762)

新增数据结构：

* [MediaAnimatedGraphicsInfo](https://cloud.tencent.com/document/api/266/31773#MediaAnimatedGraphicsInfo)
* [MediaAnimatedGraphicsItem](https://cloud.tencent.com/document/api/266/31773#MediaAnimatedGraphicsItem)
* [MediaAudioStreamItem](https://cloud.tencent.com/document/api/266/31773#MediaAudioStreamItem)
* [MediaBasicInfo](https://cloud.tencent.com/document/api/266/31773#MediaBasicInfo)
* [MediaClassInfo](https://cloud.tencent.com/document/api/266/31773#MediaClassInfo)
* [MediaDeleteItem](https://cloud.tencent.com/document/api/266/31773#MediaDeleteItem)
* [MediaImageSpriteInfo](https://cloud.tencent.com/document/api/266/31773#MediaImageSpriteInfo)
* [MediaImageSpriteItem](https://cloud.tencent.com/document/api/266/31773#MediaImageSpriteItem)
* [MediaInfo](https://cloud.tencent.com/document/api/266/31773#MediaInfo)
* [MediaKeyFrameDescInfo](https://cloud.tencent.com/document/api/266/31773#MediaKeyFrameDescInfo)
* [MediaKeyFrameDescItem](https://cloud.tencent.com/document/api/266/31773#MediaKeyFrameDescItem)
* [MediaMetaData](https://cloud.tencent.com/document/api/266/31773#MediaMetaData)
* [MediaSampleSnapshotInfo](https://cloud.tencent.com/document/api/266/31773#MediaSampleSnapshotInfo)
* [MediaSampleSnapshotItem](https://cloud.tencent.com/document/api/266/31773#MediaSampleSnapshotItem)
* [MediaSnapshotByTimeOffsetInfo](https://cloud.tencent.com/document/api/266/31773#MediaSnapshotByTimeOffsetInfo)
* [MediaSnapshotByTimeOffsetItem](https://cloud.tencent.com/document/api/266/31773#MediaSnapshotByTimeOffsetItem)
* [MediaSnapshotByTimePicInfoItem](https://cloud.tencent.com/document/api/266/31773#MediaSnapshotByTimePicInfoItem)
* [MediaSourceData](https://cloud.tencent.com/document/api/266/31773#MediaSourceData)
* [MediaTranscodeInfo](https://cloud.tencent.com/document/api/266/31773#MediaTranscodeInfo)
* [MediaTranscodeItem](https://cloud.tencent.com/document/api/266/31773#MediaTranscodeItem)
* [MediaVideoStreamItem](https://cloud.tencent.com/document/api/266/31773#MediaVideoStreamItem)
* [TempCertificate](https://cloud.tencent.com/document/api/266/31773#TempCertificate)




## 私有网络(vpc) 版本：2017-03-12

### 第 198 次发布

发布时间：2024-08-06 02:28:26

本次发布包含了以下内容：

改善已有的文档。

新增数据结构：

* [[PrivateNatCrossDomainInfo](https://cloud.tencent.com/document/api/215/15824#PrivateNatCrossDomainInfo)](https://cloud.tencent.com/document/api/215/15824#[PrivateNatCrossDomainInfo](https://cloud.tencent.com/document/api/215/15824#PrivateNatCrossDomainInfo))

修改数据结构：

* [PrivateNatGateway](https://cloud.tencent.com/document/api/215/15824#PrivateNatGateway)

	* 新增成员：DirectConnectGatewayIds, NatType, CrossDomainInfo, VpcType, CcnId


### 第 197 次发布

发布时间：2024-07-24 02:26:47

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [ModifyVpnGatewayAttribute](https://cloud.tencent.com/document/api/215/17507)

	* 新增入参：MaxConnection


修改数据结构：

* [CCN](https://cloud.tencent.com/document/api/215/15824#CCN)

	* 新增成员：RouteECMPFlag, RouteOverlapFlag, TrafficMarkingPolicyFlag, RouteSelectPolicyFlag, DirectConnectAccelerateChannelFlag

	* <font color="#dd0000">**修改成员**：</font>CcnId, CcnName, CcnDescription, InstanceCount, CreateTime, State, QosLevel, InstanceChargeType, BandwidthLimitType, TagSet, RoutePriorityFlag, RouteTableCount, RouteTableFlag, IsSecurityLock, RouteBroadcastPolicyFlag


### 第 196 次发布

发布时间：2024-07-22 02:25:36

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [InstanceBind](https://cloud.tencent.com/document/api/215/15824#InstanceBind)

	* <font color="#dd0000">**修改成员**：</font>InstanceRegion


### 第 195 次发布

发布时间：2024-07-17 01:29:26

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateHaVip](https://cloud.tencent.com/document/api/215/30652)

	* 新增入参：CheckAssociate

	* <font color="#dd0000">**修改入参**：</font>SubnetId


新增数据结构：

* [HaVipAssociation](https://cloud.tencent.com/document/api/215/15824#HaVipAssociation)

修改数据结构：

* [CcnInstance](https://cloud.tencent.com/document/api/215/15824#CcnInstance)

	* 新增成员：OrderType

* [CrossBorderCompliance](https://cloud.tencent.com/document/api/215/15824#CrossBorderCompliance)

	* 新增成员：LegalPersonId, LegalPersonIdCard

* [HaVip](https://cloud.tencent.com/document/api/215/15824#HaVip)

	* 新增成员：HaVipAssociationSet, CheckAssociate, FlushedTime


### 第 194 次发布

发布时间：2024-07-16 01:29:31

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [AssociateInstancesToCcnRouteTable](https://cloud.tencent.com/document/api/215/108751)
* [ClearRouteTableSelectionPolicies](https://cloud.tencent.com/document/api/215/108750)
* [CreateCcnRouteTables](https://cloud.tencent.com/document/api/215/108749)
* [DeleteCcnRouteTables](https://cloud.tencent.com/document/api/215/108748)
* [DescribeCcnRouteTableBroadcastPolicys](https://cloud.tencent.com/document/api/215/108747)
* [DescribeCcnRouteTableInputPolicys](https://cloud.tencent.com/document/api/215/108746)
* [DescribeCcnRouteTables](https://cloud.tencent.com/document/api/215/108745)
* [DescribeRouteTableAssociatedInstances](https://cloud.tencent.com/document/api/215/108744)
* [DescribeRouteTableSelectionPolicies](https://cloud.tencent.com/document/api/215/108743)
* [ModifyCcnRouteTables](https://cloud.tencent.com/document/api/215/108742)
* [ModifyRouteTableSelectionPolicies](https://cloud.tencent.com/document/api/215/108741)
* [ReplaceCcnRouteTableBroadcastPolicys](https://cloud.tencent.com/document/api/215/108740)
* [ReplaceCcnRouteTableInputPolicys](https://cloud.tencent.com/document/api/215/108739)

新增数据结构：

* [CcnBatchRouteTable](https://cloud.tencent.com/document/api/215/15824#CcnBatchRouteTable)
* [CcnInstanceWithoutRegion](https://cloud.tencent.com/document/api/215/15824#CcnInstanceWithoutRegion)
* [CcnRouteBroadcastPolicyRouteCondition](https://cloud.tencent.com/document/api/215/15824#CcnRouteBroadcastPolicyRouteCondition)
* [CcnRouteTable](https://cloud.tencent.com/document/api/215/15824#CcnRouteTable)
* [CcnRouteTableBroadcastPolicy](https://cloud.tencent.com/document/api/215/15824#CcnRouteTableBroadcastPolicy)
* [CcnRouteTableBroadcastPolicys](https://cloud.tencent.com/document/api/215/15824#CcnRouteTableBroadcastPolicys)
* [CcnRouteTableInputPolicy](https://cloud.tencent.com/document/api/215/15824#CcnRouteTableInputPolicy)
* [CcnRouteTableInputPolicys](https://cloud.tencent.com/document/api/215/15824#CcnRouteTableInputPolicys)
* [CcnRouteTableSelectPolicy](https://cloud.tencent.com/document/api/215/15824#CcnRouteTableSelectPolicy)
* [InstanceBind](https://cloud.tencent.com/document/api/215/15824#InstanceBind)
* [ModifyRouteTableInfo](https://cloud.tencent.com/document/api/215/15824#ModifyRouteTableInfo)
* [RouteSelectionPolicy](https://cloud.tencent.com/document/api/215/15824#RouteSelectionPolicy)

### 第 193 次发布

发布时间：2024-07-10 01:29:16

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [ModifyVpnGatewaySslClientCert](https://cloud.tencent.com/document/api/215/108516)

新增数据结构：

* [PolicyStatistics](https://cloud.tencent.com/document/api/215/15824#PolicyStatistics)

修改数据结构：

* [SecurityGroupPolicySet](https://cloud.tencent.com/document/api/215/15824#SecurityGroupPolicySet)

	* 新增成员：PolicyStatistics


### 第 192 次发布

发布时间：2024-07-03 01:28:07

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateVpnConnection](https://cloud.tencent.com/document/api/215/17522)

	* 新增入参：HealthCheckConfig

* [ModifyVpnConnectionAttribute](https://cloud.tencent.com/document/api/215/17508)

	* 新增入参：HealthCheckConfig


新增数据结构：

* [HealthCheckConfig](https://cloud.tencent.com/document/api/215/15824#HealthCheckConfig)

修改数据结构：

* [VpnConnection](https://cloud.tencent.com/document/api/215/15824#VpnConnection)

	* 新增成员：HealthCheckConfig


### 第 191 次发布

发布时间：2024-07-02 01:27:15

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreatePrivateNatGateway](https://cloud.tencent.com/document/api/215/107904)
* [CreatePrivateNatGatewayDestinationIpPortTranslationNatRule](https://cloud.tencent.com/document/api/215/107903)
* [CreatePrivateNatGatewayTranslationAclRule](https://cloud.tencent.com/document/api/215/107902)
* [CreatePrivateNatGatewayTranslationNatRule](https://cloud.tencent.com/document/api/215/107901)
* [DeletePrivateNatGateway](https://cloud.tencent.com/document/api/215/107900)
* [DeletePrivateNatGatewayDestinationIpPortTranslationNatRule](https://cloud.tencent.com/document/api/215/107899)
* [DeletePrivateNatGatewayTranslationAclRule](https://cloud.tencent.com/document/api/215/107898)
* [DeletePrivateNatGatewayTranslationNatRule](https://cloud.tencent.com/document/api/215/107897)
* [DescribePrivateNatGatewayDestinationIpPortTranslationNatRules](https://cloud.tencent.com/document/api/215/107896)
* [DescribePrivateNatGatewayLimits](https://cloud.tencent.com/document/api/215/107895)
* [DescribePrivateNatGatewayRegions](https://cloud.tencent.com/document/api/215/107894)
* [DescribePrivateNatGatewayTranslationAclRules](https://cloud.tencent.com/document/api/215/107893)
* [DescribePrivateNatGatewayTranslationNatRules](https://cloud.tencent.com/document/api/215/107892)
* [DescribePrivateNatGateways](https://cloud.tencent.com/document/api/215/107891)
* [ModifyPrivateNatGatewayAttribute](https://cloud.tencent.com/document/api/215/107890)
* [ModifyPrivateNatGatewayDestinationIpPortTranslationNatRule](https://cloud.tencent.com/document/api/215/107889)
* [ModifyPrivateNatGatewayTranslationAclRule](https://cloud.tencent.com/document/api/215/107888)
* [ModifyPrivateNatGatewayTranslationNatRule](https://cloud.tencent.com/document/api/215/107887)

新增数据结构：

* [DestinationIpPortTranslationNatRuleDiff](https://cloud.tencent.com/document/api/215/15824#DestinationIpPortTranslationNatRuleDiff)
* [LocalDestinationIpPortTranslationNatRule](https://cloud.tencent.com/document/api/215/15824#LocalDestinationIpPortTranslationNatRule)
* [NatRegionInfoWithArea](https://cloud.tencent.com/document/api/215/15824#NatRegionInfoWithArea)
* [PrivateNatDestinationIpPortTranslationNatRule](https://cloud.tencent.com/document/api/215/15824#PrivateNatDestinationIpPortTranslationNatRule)
* [PrivateNatGateway](https://cloud.tencent.com/document/api/215/15824#PrivateNatGateway)
* [PrivateNatGatewayLimit](https://cloud.tencent.com/document/api/215/15824#PrivateNatGatewayLimit)
* [TranslationAclRule](https://cloud.tencent.com/document/api/215/15824#TranslationAclRule)
* [TranslationNatRule](https://cloud.tencent.com/document/api/215/15824#TranslationNatRule)
* [TranslationNatRuleDiff](https://cloud.tencent.com/document/api/215/15824#TranslationNatRuleDiff)
* [TranslationNatRuleInput](https://cloud.tencent.com/document/api/215/15824#TranslationNatRuleInput)

### 第 190 次发布

发布时间：2024-06-25 01:26:23

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [GatewayFlowMonitorDetail](https://cloud.tencent.com/document/api/215/15824#GatewayFlowMonitorDetail)

	* 新增成员：ConcurrentConnectionCount, NewConnectionRate


### 第 189 次发布

发布时间：2024-05-07 01:29:27

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [SslVpnSever](https://cloud.tencent.com/document/api/215/15824#SslVpnSever)

	* 新增成员：SpName


### 第 188 次发布

发布时间：2024-04-23 01:29:22

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeGatewayFlowMonitorDetail](https://cloud.tencent.com/document/api/215/33424)

	* 新增入参：PrivateIpAddress


### 第 187 次发布

发布时间：2024-04-08 01:27:01

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [Address](https://cloud.tencent.com/document/api/215/15824#Address)

	* 新增成员：BandwidthPackageId


### 第 186 次发布

发布时间：2024-01-17 01:26:10

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeUsedIpAddress](https://cloud.tencent.com/document/api/215/91061)

	* 新增入参：Filters


### 第 185 次发布

发布时间：2023-12-27 01:44:26

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [ModifyCcnAttribute](https://cloud.tencent.com/document/api/215/19195)

	* 新增入参：RouteECMPFlag, RouteOverlapFlag


### 第 184 次发布

发布时间：2023-12-26 01:32:32

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [AssignIpv6SubnetCidrBlock](https://cloud.tencent.com/document/api/215/34471)

	* 新增入参：ClientToken


### 第 183 次发布

发布时间：2023-12-01 01:28:57

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [IPSECOptionsSpecification](https://cloud.tencent.com/document/api/215/15824#IPSECOptionsSpecification)

	* 新增成员：IntegrityAlgorithm


### 第 182 次发布

发布时间：2023-11-29 02:08:37

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [Address](https://cloud.tencent.com/document/api/215/15824#Address)

	* 新增成员：RenewFlag


### 第 181 次发布

发布时间：2023-11-28 01:30:07

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [EndPointService](https://cloud.tencent.com/document/api/215/15824#EndPointService)

	* 新增成员：ServiceUin, BusinessIpType


### 第 180 次发布

发布时间：2023-11-15 02:39:18

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [ModifyCustomerGatewayAttribute](https://cloud.tencent.com/document/api/215/17509)

	* 新增入参：BgpAsn


### 第 179 次发布

发布时间：2023-11-09 01:29:06

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [ModifyVpnGatewayAttribute](https://cloud.tencent.com/document/api/215/17507)

	* 新增入参：BgpAsn


### 第 178 次发布

发布时间：2023-11-02 02:40:08

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [BandwidthPackage](https://cloud.tencent.com/document/api/215/15824#BandwidthPackage)

	* 新增成员：Deadline


### 第 177 次发布

发布时间：2023-10-31 02:45:47

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateCustomerGateway](https://cloud.tencent.com/document/api/215/17523)

	* 新增入参：BgpAsn

* [CreateVpnConnection](https://cloud.tencent.com/document/api/215/17522)

	* 新增入参：Route, BgpConfig


新增数据结构：

* [BgpConfig](https://cloud.tencent.com/document/api/215/15824#BgpConfig)
* [BgpConfigAndAsn](https://cloud.tencent.com/document/api/215/15824#BgpConfigAndAsn)
* [CreateVpnConnRoute](https://cloud.tencent.com/document/api/215/15824#CreateVpnConnRoute)

修改数据结构：

* [CustomerGateway](https://cloud.tencent.com/document/api/215/15824#CustomerGateway)

	* 新增成员：BgpAsn

* [VpnConnection](https://cloud.tencent.com/document/api/215/15824#VpnConnection)

	* 新增成员：BgpConfig


### 第 176 次发布

发布时间：2023-10-30 01:36:36

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [ModifyVpnGatewaySslServer](https://cloud.tencent.com/document/api/215/100955)

### 第 175 次发布

发布时间：2023-10-25 01:29:12

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeNetworkAcls](https://cloud.tencent.com/document/api/215/42160)

	* 新增入参：OrderField, OrderDirection


修改数据结构：

* [Subnet](https://cloud.tencent.com/document/api/215/15824#Subnet)

	* <font color="#dd0000">**修改成员**：</font>CreatedTime


### 第 174 次发布

发布时间：2023-09-28 01:25:40

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateVpcPeeringConnection](https://cloud.tencent.com/document/api/215/96025)

	* 新增入参：SourceVpcId, PeeringConnectionName, DestinationVpcId, DestinationUin, DestinationRegion, Bandwidth, Type, ChargeType, QosLevel

	* 新增出参：PeeringConnectionId

* [ModifyVpcPeeringConnection](https://cloud.tencent.com/document/api/215/96022)

	* 新增入参：PeeringConnectionId, PeeringConnectionName, Bandwidth, ChargeType

* [RejectVpcPeeringConnection](https://cloud.tencent.com/document/api/215/96021)

	* 新增入参：PeeringConnectionId


### 第 173 次发布

发布时间：2023-09-27 01:28:08

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeVpcPeeringConnections](https://cloud.tencent.com/document/api/215/96023)

	* 新增出参：TotalCount, PeerConnectionSet


新增数据结构：

* [PeerConnection](https://cloud.tencent.com/document/api/215/15824#PeerConnection)

### 第 172 次发布

发布时间：2023-09-25 01:30:02

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateBandwidthPackage](https://cloud.tencent.com/document/api/215/19212)

	* 新增入参：Egress


修改数据结构：

* [BandwidthPackage](https://cloud.tencent.com/document/api/215/15824#BandwidthPackage)

	* 新增成员：Egress


### 第 171 次发布

发布时间：2023-09-18 02:43:01

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateNatGateway](https://cloud.tencent.com/document/api/215/36721)

	* 新增入参：NatProductVersion


### 第 170 次发布

发布时间：2023-09-15 02:54:26

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [Address](https://cloud.tencent.com/document/api/215/15824#Address)

	* 新增成员：Egress

* [NatGateway](https://cloud.tencent.com/document/api/215/15824#NatGateway)

	* 新增成员：SmartScheduleMode, DedicatedClusterId

* [NatGatewayAddress](https://cloud.tencent.com/document/api/215/15824#NatGatewayAddress)

	* 新增成员：BlockType

	* <font color="#dd0000">**修改成员**：</font>AddressId, PublicIpAddress, IsBlocked


### 第 169 次发布

发布时间：2023-09-12 02:59:25

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeAddressTemplateGroups](https://cloud.tencent.com/document/api/215/16716)

	* 新增入参：NeedMemberInfo

* [DescribeAddressTemplates](https://cloud.tencent.com/document/api/215/16717)

	* 新增入参：NeedMemberInfo

* [DescribeServiceTemplateGroups](https://cloud.tencent.com/document/api/215/16718)

	* 新增入参：NeedMemberInfo

* [DescribeServiceTemplates](https://cloud.tencent.com/document/api/215/16719)

	* 新增入参：NeedMemberInfo


### 第 168 次发布

发布时间：2023-09-01 01:26:26

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [AssignPrivateIpAddresses](https://cloud.tencent.com/document/api/215/15813)

	* 新增入参：ClientToken

* [AttachNetworkInterface](https://cloud.tencent.com/document/api/215/15819)

	* 新增入参：ClientToken

* [CreateAndAttachNetworkInterface](https://cloud.tencent.com/document/api/215/43370)

	* 新增入参：ClientToken

* [CreateNetworkInterface](https://cloud.tencent.com/document/api/215/15818)

	* 新增入参：ClientToken

* [DetachNetworkInterface](https://cloud.tencent.com/document/api/215/15816)

	* 新增入参：ClientToken


修改数据结构：

* [RouteTable](https://cloud.tencent.com/document/api/215/15824#RouteTable)

	* <font color="#dd0000">**修改成员**：</font>CreatedTime


### 第 167 次发布

发布时间：2023-08-31 11:01:10

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateNetworkAclEntries](https://cloud.tencent.com/document/api/215/97652)
* [DeleteNetworkAclEntries](https://cloud.tencent.com/document/api/215/97651)

### 第 166 次发布

发布时间：2023-08-31 01:28:14

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [ModifyNetworkAclEntries](https://cloud.tencent.com/document/api/215/42107)

	* 新增入参：EnableUpdateAclEntries


修改数据结构：

* [NetworkAclEntry](https://cloud.tencent.com/document/api/215/15824#NetworkAclEntry)

	* 新增成员：Priority, NetworkAclIpv4EntryId, NetworkAclIpv6EntryId

	* <font color="#dd0000">**修改成员**：</font>ModifyTime


### 第 165 次发布

发布时间：2023-08-18 01:20:12

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeVpcEndPointServiceWhiteList](https://cloud.tencent.com/document/api/215/54677)

	* 新增出参：VpcEndPointServiceUserSet


### 第 164 次发布

发布时间：2023-08-09 01:58:05

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [AcceptVpcPeeringConnection](https://cloud.tencent.com/document/api/215/96026)

	* 新增入参：PeeringConnectionId

* [DeleteVpcPeeringConnection](https://cloud.tencent.com/document/api/215/96024)

	* 新增入参：PeeringConnectionId


### 第 163 次发布

发布时间：2023-08-07 01:19:59

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [AcceptVpcPeeringConnection](https://cloud.tencent.com/document/api/215/96026)
* [CreateVpcPeeringConnection](https://cloud.tencent.com/document/api/215/96025)
* [DeleteVpcPeeringConnection](https://cloud.tencent.com/document/api/215/96024)
* [DescribeVpcPeeringConnections](https://cloud.tencent.com/document/api/215/96023)
* [ModifyVpcPeeringConnection](https://cloud.tencent.com/document/api/215/96022)
* [RejectVpcPeeringConnection](https://cloud.tencent.com/document/api/215/96021)

### 第 162 次发布

发布时间：2023-07-28 01:57:59

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeSpecificTrafficPackageUsedDetails](https://cloud.tencent.com/document/api/215/95637)

修改接口：

* [DescribeVpcEndPointService](https://cloud.tencent.com/document/api/215/54678)

	* 新增入参：IsListAuthorizedEndPointService


新增数据结构：

* [TrafficFlow](https://cloud.tencent.com/document/api/215/15824#TrafficFlow)
* [UsedDetail](https://cloud.tencent.com/document/api/215/15824#UsedDetail)

### 第 161 次发布

发布时间：2023-07-12 01:51:01

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeSecurityGroups](https://cloud.tencent.com/document/api/215/15808)

	* 新增入参：OrderField, OrderDirection


### 第 160 次发布

发布时间：2023-07-07 01:59:12

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [ModifyVpcAttribute](https://cloud.tencent.com/document/api/215/15773)

	* 新增入参：EnableCdcPublish


修改数据结构：

* [Vpc](https://cloud.tencent.com/document/api/215/15824#Vpc)

	* <font color="#dd0000">**修改成员**：</font>IsDefault, CreatedTime


### 第 159 次发布

发布时间：2023-07-05 01:54:12

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [AllocateAddresses](https://cloud.tencent.com/document/api/215/16699)

	* 新增入参：AntiDDoSPackageId, ClientToken


修改数据结构：

* [Address](https://cloud.tencent.com/document/api/215/15824#Address)

	* 新增成员：AntiDDoSPackageId

	* <font color="#dd0000">**修改成员**：</font>AddressId, AddressName, AddressStatus, AddressIp, InstanceId, CreatedTime


### 第 158 次发布

发布时间：2023-06-15 01:43:49

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [NatGateway](https://cloud.tencent.com/document/api/215/15824#NatGateway)

	* 新增成员：NatProductVersion


### 第 157 次发布

发布时间：2023-05-26 02:10:55

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [AccessPolicy](https://cloud.tencent.com/document/api/215/15824#AccessPolicy)

	* 新增成员：Remark


### 第 156 次发布

发布时间：2023-05-19 02:14:41

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateVpnGatewaySslClient](https://cloud.tencent.com/document/api/215/70290)

	* 新增入参：SslVpnClientNames

	* <font color="#dd0000">**修改入参**：</font>SslVpnClientName

* [DeleteVpnGatewaySslClient](https://cloud.tencent.com/document/api/215/70288)

	* 新增入参：SslVpnClientIds

	* <font color="#dd0000">**修改入参**：</font>SslVpnClientId

* [DisableVpnGatewaySslClientCert](https://cloud.tencent.com/document/api/215/70284)

	* 新增入参：SslVpnClientIds

	* <font color="#dd0000">**修改入参**：</font>SslVpnClientId

* [DownloadVpnGatewaySslClientCert](https://cloud.tencent.com/document/api/215/70283)

	* 新增入参：SslVpnClientIds

	* <font color="#dd0000">**修改入参**：</font>SslVpnClientId

* [EnableVpnGatewaySslClientCert](https://cloud.tencent.com/document/api/215/70282)

	* 新增入参：SslVpnClientIds

	* <font color="#dd0000">**修改入参**：</font>SslVpnClientId


修改数据结构：

* [SslClientConfig](https://cloud.tencent.com/document/api/215/15824#SslClientConfig)

	* 新增成员：SslVpnClientId


### 第 155 次发布

发布时间：2023-05-17 02:12:18

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DeleteTrafficPackages](https://cloud.tencent.com/document/api/215/91087)
* [DescribeSubnetResourceDashboard](https://cloud.tencent.com/document/api/215/91088)

新增数据结构：

* [ResourceStatistics](https://cloud.tencent.com/document/api/215/15824#ResourceStatistics)
* [ResourceStatisticsItem](https://cloud.tencent.com/document/api/215/15824#ResourceStatisticsItem)

### 第 154 次发布

发布时间：2023-05-16 02:40:13

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeUsedIpAddress](https://cloud.tencent.com/document/api/215/91061)

修改接口：

* [DeleteRoutes](https://cloud.tencent.com/document/api/215/16725)

	* <font color="#dd0000">**修改入参**：</font>Routes


新增数据结构：

* [IpAddressStates](https://cloud.tencent.com/document/api/215/15824#IpAddressStates)

### 第 153 次发布

发布时间：2023-05-12 02:00:41

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [SecurityGroupLimitSet](https://cloud.tencent.com/document/api/215/15824#SecurityGroupLimitSet)

	* 新增成员：SecurityGroupExtendedPolicyLimit, SecurityGroupReferedCvmAndEniLimit, SecurityGroupReferedSvcLimit


### 第 152 次发布

发布时间：2023-05-01 01:46:16

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [AssignPrivateIpAddresses](https://cloud.tencent.com/document/api/215/15813)

	* 新增入参：QosLevel

* [CreateAndAttachNetworkInterface](https://cloud.tencent.com/document/api/215/43370)

	* 新增入参：QosLevel

* [CreateNetworkInterface](https://cloud.tencent.com/document/api/215/15818)

	* 新增入参：QosLevel


修改数据结构：

* [PrivateIpAddressSpecification](https://cloud.tencent.com/document/api/215/15824#PrivateIpAddressSpecification)

	* 新增成员：QosLevel


### 第 151 次发布

发布时间：2023-04-26 02:02:58

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [GenerateVpnConnectionDefaultHealthCheckIp](https://cloud.tencent.com/document/api/215/90654)

### 第 150 次发布

发布时间：2023-04-24 01:49:51

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [ModifyVpnConnectionAttribute](https://cloud.tencent.com/document/api/215/17508)

	* 新增入参：CustomerGatewayId


修改数据结构：

* [CcnRegionBandwidthLimitInfo](https://cloud.tencent.com/document/api/215/15824#CcnRegionBandwidthLimitInfo)

	* 新增成员：SourceRegion, DestinationRegion, BandwidthLimit


### 第 149 次发布

发布时间：2023-04-21 01:51:07

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [Address](https://cloud.tencent.com/document/api/215/15824#Address)

	* 新增成员：DeadlineDate, InstanceType


### 第 148 次发布

发布时间：2023-04-03 01:42:53

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [CcnBandwidthInfo](https://cloud.tencent.com/document/api/215/15824#CcnBandwidthInfo)

	* 新增成员：TagSet


### 第 147 次发布

发布时间：2023-03-31 02:06:58

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeCrossBorderCcnRegionBandwidthLimits](https://cloud.tencent.com/document/api/215/71325)

	* 新增入参：Filters, Offset, Limit

	* 新增出参：TotalCount, CcnBandwidthSet

* [DescribeVpnGatewayRoutes](https://cloud.tencent.com/document/api/215/57676)

	* 新增出参：TotalCount


新增数据结构：

* [CcnBandwidth](https://cloud.tencent.com/document/api/215/15824#CcnBandwidth)
* [CcnRegionBandwidthLimitInfo](https://cloud.tencent.com/document/api/215/15824#CcnRegionBandwidthLimitInfo)

### 第 146 次发布

发布时间：2023-03-16 02:29:21

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateHaVip](https://cloud.tencent.com/document/api/215/30652)

	* 新增入参：NetworkInterfaceId


### 第 145 次发布

发布时间：2023-03-14 02:17:29

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [ReplaceSecurityGroupPolicies](https://cloud.tencent.com/document/api/215/88451)

### 第 144 次发布

发布时间：2023-03-02 01:47:50

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [DefaultVpcSubnet](https://cloud.tencent.com/document/api/215/15824#DefaultVpcSubnet)

	* 新增成员：VpcName, SubnetName, CidrBlock


### 第 143 次发布

发布时间：2023-02-28 02:25:56

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [AddressTemplateItem](https://cloud.tencent.com/document/api/215/15824#AddressTemplateItem)

	* 新增成员：AddressTemplateId, AddressTemplateName

	* <font color="#dd0000">**修改成员**：</font>From, To


### 第 142 次发布

发布时间：2023-02-16 02:07:49

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateBandwidthPackage](https://cloud.tencent.com/document/api/215/19212)

	* 新增入参：TimeSpan


### 第 141 次发布

发布时间：2023-02-14 02:03:04

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeNetworkAccountType](https://cloud.tencent.com/document/api/215/86509)

修改接口：

* [CheckNetDetectState](https://cloud.tencent.com/document/api/215/38700)

	* <font color="#dd0000">**修改入参**：</font>NextHopType, NextHopDestination

* [DescribeVpcIpv6Addresses](https://cloud.tencent.com/document/api/215/34465)

	* 新增入参：SubnetId


### 第 140 次发布

发布时间：2023-02-13 02:21:03

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeTenantCcns](https://cloud.tencent.com/document/api/215/71324)

	* 新增入参：Filters, Offset, Limit

	* 新增出参：CcnSet, TotalCount


新增数据结构：

* [CcnInstanceInfo](https://cloud.tencent.com/document/api/215/15824#CcnInstanceInfo)

### 第 139 次发布

发布时间：2023-02-10 02:17:00

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [CCN](https://cloud.tencent.com/document/api/215/15824#CCN)

	* 新增成员：IsSecurityLock


### 第 138 次发布

发布时间：2023-02-08 02:24:44

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeVpcTaskResult](https://cloud.tencent.com/document/api/215/59037)

	* 新增出参：Result


新增数据结构：

* [VpcTaskResultDetailInfo](https://cloud.tencent.com/document/api/215/15824#VpcTaskResultDetailInfo)

### 第 137 次发布

发布时间：2023-02-06 02:53:59

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [VpngwCcnRoutes](https://cloud.tencent.com/document/api/215/15824#VpngwCcnRoutes)

	* 新增成员：DestinationCidrBlock


### 第 136 次发布

发布时间：2023-02-01 02:09:35

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [LockCcnBandwidths](https://cloud.tencent.com/document/api/215/71323)

	* 新增入参：Instances

* [UnlockCcnBandwidths](https://cloud.tencent.com/document/api/215/71321)

	* 新增入参：Instances


新增数据结构：

* [CcnFlowLock](https://cloud.tencent.com/document/api/215/15824#CcnFlowLock)

### 第 135 次发布

发布时间：2023-01-06 01:54:52

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateTrafficPackages](https://cloud.tencent.com/document/api/215/85309)

修改接口：

* [TransformAddress](https://cloud.tencent.com/document/api/215/16706)

	* 新增出参：TaskId, AddressId


修改数据结构：

* [BandwidthPackageBillBandwidth](https://cloud.tencent.com/document/api/215/15824#BandwidthPackageBillBandwidth)

	* <font color="#dd0000">**修改成员**：</font>BandwidthUsage


### 第 134 次发布

发布时间：2023-01-05 01:53:32

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [AttachSnapshotInstances](https://cloud.tencent.com/document/api/215/85159)
* [CreateSnapshotPolicies](https://cloud.tencent.com/document/api/215/85158)
* [DeleteSnapshotPolicies](https://cloud.tencent.com/document/api/215/85157)
* [DescribeSgSnapshotFileContent](https://cloud.tencent.com/document/api/215/85156)
* [DescribeSnapshotAttachedInstances](https://cloud.tencent.com/document/api/215/85155)
* [DescribeSnapshotFiles](https://cloud.tencent.com/document/api/215/85154)
* [DescribeSnapshotPolicies](https://cloud.tencent.com/document/api/215/85153)
* [DetachSnapshotInstances](https://cloud.tencent.com/document/api/215/85152)
* [DisableSnapshotPolicies](https://cloud.tencent.com/document/api/215/85151)
* [EnableSnapshotPolicies](https://cloud.tencent.com/document/api/215/85150)
* [ModifySnapshotPolicies](https://cloud.tencent.com/document/api/215/85149)
* [ResumeSnapshotInstance](https://cloud.tencent.com/document/api/215/85148)

新增数据结构：

* [BackupPolicy](https://cloud.tencent.com/document/api/215/15824#BackupPolicy)
* [BatchModifySnapshotPolicy](https://cloud.tencent.com/document/api/215/15824#BatchModifySnapshotPolicy)
* [SnapshotFileInfo](https://cloud.tencent.com/document/api/215/15824#SnapshotFileInfo)
* [SnapshotInstance](https://cloud.tencent.com/document/api/215/15824#SnapshotInstance)
* [SnapshotPolicy](https://cloud.tencent.com/document/api/215/15824#SnapshotPolicy)

### 第 133 次发布

发布时间：2022-12-29 11:09:38

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [CCN](https://cloud.tencent.com/document/api/215/15824#CCN)

	* 新增成员：RouteBroadcastPolicyFlag

	* <font color="#dd0000">**修改成员**：</font>CcnId, CcnName, CcnDescription, InstanceCount, CreateTime, State, QosLevel, InstanceChargeType, BandwidthLimitType, TagSet, RoutePriorityFlag, RouteTableCount, RouteTableFlag


### 第 132 次发布

发布时间：2022-12-16 18:54:14

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [AllocateAddresses](https://cloud.tencent.com/document/api/215/16699)

	* 新增入参：Egress

* [CreateVpcEndPointService](https://cloud.tencent.com/document/api/215/54684)

	* 新增入参：ServiceType

* [ModifyBandwidthPackageAttribute](https://cloud.tencent.com/document/api/215/19208)

	* <font color="#dd0000">**删除入参**：</font>MigrateOnRefund


### 第 131 次发布

发布时间：2022-12-14 01:57:08

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [EndPointService](https://cloud.tencent.com/document/api/215/15824#EndPointService)

	* 新增成员：ServiceType


### 第 130 次发布

发布时间：2022-12-12 01:57:43

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [ReturnNormalAddresses](https://cloud.tencent.com/document/api/215/83866)

### 第 129 次发布

发布时间：2022-11-22 07:10:00

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [ModifyNetworkInterfaceQos](https://cloud.tencent.com/document/api/215/55136)

	* 新增入参：DirectSendMaxPort


### 第 128 次发布

发布时间：2022-11-15 06:49:10

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [NetworkInterface](https://cloud.tencent.com/document/api/215/15824#NetworkInterface)

	* 新增成员：QosLevel


### 第 127 次发布

发布时间：2022-10-27 07:09:19

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [NetworkInterface](https://cloud.tencent.com/document/api/215/15824#NetworkInterface)

	* 新增成员：ResourceId

	* <font color="#dd0000">**修改成员**：</font>NetworkInterfaceId, NetworkInterfaceName, SubnetId, VpcId, MacAddress, State, PrivateIpAddressSet, Ipv6AddressSet, TagSet, EniType, Business, CdcId, AttachType


### 第 126 次发布

发布时间：2022-09-29 07:02:19

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [SetVpnGatewaysRenewFlag](https://cloud.tencent.com/document/api/215/81120)

### 第 125 次发布

发布时间：2022-09-16 06:49:40

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeCrossBorderFlowMonitor](https://cloud.tencent.com/document/api/215/80526)

新增数据结构：

* [CrossBorderFlowMonitorData](https://cloud.tencent.com/document/api/215/15824#CrossBorderFlowMonitorData)

### 第 124 次发布

发布时间：2022-09-14 06:43:15

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [NatGateway](https://cloud.tencent.com/document/api/215/15824#NatGateway)

	* 新增成员：RestrictState


### 第 123 次发布

发布时间：2022-09-05 06:59:01

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeTrafficPackages](https://cloud.tencent.com/document/api/215/80090)

新增数据结构：

* [TrafficPackage](https://cloud.tencent.com/document/api/215/15824#TrafficPackage)

### 第 122 次发布

发布时间：2022-08-10 06:57:28

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [VpnConnection](https://cloud.tencent.com/document/api/215/15824#VpnConnection)

	* 新增成员：DpdEnable, DpdTimeout, DpdAction, TagSet, NegotiationType


### 第 121 次发布

发布时间：2022-07-28 06:25:12

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeNetworkAclQuintupleEntries](https://cloud.tencent.com/document/api/215/77634)

	* 新增入参：NetworkAclId, Offset, Limit, Filters


### 第 120 次发布

发布时间：2022-07-22 06:16:48

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateNetworkAclQuintupleEntries](https://cloud.tencent.com/document/api/215/77636)
* [DeleteNetworkAclQuintupleEntries](https://cloud.tencent.com/document/api/215/77635)
* [DescribeNetworkAclQuintupleEntries](https://cloud.tencent.com/document/api/215/77634)
* [ModifyNetworkAclQuintupleEntries](https://cloud.tencent.com/document/api/215/77633)

### 第 119 次发布

发布时间：2022-07-21 06:20:44

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateNetworkAcl](https://cloud.tencent.com/document/api/215/42162)

	* 新增入参：NetworkAclType, Tags

* [ModifyNetworkAclEntries](https://cloud.tencent.com/document/api/215/42107)

	* 新增入参：NetworkAclQuintupleSet


新增数据结构：

* [NetworkAclQuintupleEntries](https://cloud.tencent.com/document/api/215/15824#NetworkAclQuintupleEntries)
* [NetworkAclQuintupleEntry](https://cloud.tencent.com/document/api/215/15824#NetworkAclQuintupleEntry)

### 第 118 次发布

发布时间：2022-07-20 06:15:28

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [NetworkAcl](https://cloud.tencent.com/document/api/215/15824#NetworkAcl)

	* 新增成员：NetworkAclType, TagSet


### 第 117 次发布

发布时间：2022-06-24 06:20:35

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [ModifyNetworkAclEntries](https://cloud.tencent.com/document/api/215/42107)

	* <font color="#dd0000">**修改入参**：</font>NetworkAclEntrySet


### 第 116 次发布

发布时间：2022-06-23 06:21:17

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeVpnGatewaySslClients](https://cloud.tencent.com/document/api/215/70286)

	* 新增入参：IsVpnPortal

* [DescribeVpnGatewaySslServers](https://cloud.tencent.com/document/api/215/70285)

	* 新增入参：IsVpnPortal

* [DownloadVpnGatewaySslClientCert](https://cloud.tencent.com/document/api/215/70283)

	* 新增入参：SamlToken, IsVpnPortal

	* 新增出参：SslClientConfig, Authenticated


新增数据结构：

* [AccessPolicy](https://cloud.tencent.com/document/api/215/15824#AccessPolicy)
* [SslClientConfig](https://cloud.tencent.com/document/api/215/15824#SslClientConfig)

修改数据结构：

* [SslVpnSever](https://cloud.tencent.com/document/api/215/15824#SslVpnSever)

	* 新增成员：SsoEnabled, EiamApplicationId, AccessPolicyEnabled, AccessPolicy


### 第 115 次发布

发布时间：2022-06-22 06:16:12

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [AdjustPublicAddress](https://cloud.tencent.com/document/api/215/75874)

修改接口：

* [CreateVpnGatewaySslServer](https://cloud.tencent.com/document/api/215/70289)

	* 新增入参：SsoEnabled, AccessPolicyEnabled, SamlData


### 第 114 次发布

发布时间：2022-06-10 06:16:31

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateFlowLog](https://cloud.tencent.com/document/api/215/35015)

	* 新增入参：CloudLogRegion

* [DescribeFlowLogs](https://cloud.tencent.com/document/api/215/35012)

	* 新增入参：CloudLogRegion


修改数据结构：

* [FlowLog](https://cloud.tencent.com/document/api/215/15824#FlowLog)

	* 新增成员：CloudLogRegion


### 第 113 次发布

发布时间：2022-05-31 06:20:06

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateNetworkInterface](https://cloud.tencent.com/document/api/215/15818)

	* 新增入参：TrunkingFlag

* [DescribeNetworkInterfaceLimit](https://cloud.tencent.com/document/api/215/38533)

	* 新增出参：SubEniQuantity, SubEniPrivateIpAddressQuantity

* [ModifyNetworkInterfaceAttribute](https://cloud.tencent.com/document/api/215/15815)

	* 新增入参：TrunkingFlag


### 第 112 次发布

发布时间：2022-05-18 06:20:08

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DisableFlowLogs](https://cloud.tencent.com/document/api/215/73922)
* [EnableFlowLogs](https://cloud.tencent.com/document/api/215/73921)

### 第 111 次发布

发布时间：2022-04-28 06:20:20

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateVpnGatewaySslClient](https://cloud.tencent.com/document/api/215/70290)

	* 新增出参：SslVpnClientId

* [CreateVpnGatewaySslServer](https://cloud.tencent.com/document/api/215/70289)

	* 新增出参：SslVpnServerId


### 第 110 次发布

发布时间：2022-03-29 08:18:27

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [AssociateNatGatewayAddress](https://cloud.tencent.com/document/api/215/36722)

	* 新增入参：PublicIpFromSameZone

* [CreateNatGateway](https://cloud.tencent.com/document/api/215/36721)

	* 新增入参：PublicIpFromSameZone

* [InquiryPriceCreateVpnGateway](https://cloud.tencent.com/document/api/215/17512)

	* 新增入参：MaxConnection, Type


### 第 109 次发布

发布时间：2022-03-23 08:14:50

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [AssociateNatGatewayAddress](https://cloud.tencent.com/document/api/215/36722)

	* 新增入参：StockPublicIpAddressesBandwidthOut, PublicIpAddressesBandwidthOut

* [CreateNatGateway](https://cloud.tencent.com/document/api/215/36721)

	* 新增入参：StockPublicIpAddressesBandwidthOut, PublicIpAddressesBandwidthOut


### 第 108 次发布

发布时间：2022-03-17 08:15:03

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeCrossBorderCcnRegionBandwidthLimits](https://cloud.tencent.com/document/api/215/71325)
* [DescribeTenantCcns](https://cloud.tencent.com/document/api/215/71324)
* [LockCcnBandwidths](https://cloud.tencent.com/document/api/215/71323)
* [LockCcns](https://cloud.tencent.com/document/api/215/71322)
* [UnlockCcnBandwidths](https://cloud.tencent.com/document/api/215/71321)
* [UnlockCcns](https://cloud.tencent.com/document/api/215/71320)

### 第 107 次发布

发布时间：2022-03-10 08:17:42

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [CcnBandwidthInfo](https://cloud.tencent.com/document/api/215/15824#CcnBandwidthInfo)

	* 新增成员：MarketId


### 第 106 次发布

发布时间：2022-02-24 08:15:58

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateVpnGatewaySslClient](https://cloud.tencent.com/document/api/215/70290)
* [CreateVpnGatewaySslServer](https://cloud.tencent.com/document/api/215/70289)
* [DeleteVpnGatewaySslClient](https://cloud.tencent.com/document/api/215/70288)
* [DeleteVpnGatewaySslServer](https://cloud.tencent.com/document/api/215/70287)
* [DescribeVpnGatewaySslClients](https://cloud.tencent.com/document/api/215/70286)
* [DescribeVpnGatewaySslServers](https://cloud.tencent.com/document/api/215/70285)
* [DisableVpnGatewaySslClientCert](https://cloud.tencent.com/document/api/215/70284)
* [DownloadVpnGatewaySslClientCert](https://cloud.tencent.com/document/api/215/70283)
* [EnableVpnGatewaySslClientCert](https://cloud.tencent.com/document/api/215/70282)

新增数据结构：

* [SslVpnClient](https://cloud.tencent.com/document/api/215/15824#SslVpnClient)
* [SslVpnSever](https://cloud.tencent.com/document/api/215/15824#SslVpnSever)

### 第 105 次发布

发布时间：2022-01-24 08:17:24

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateFlowLog](https://cloud.tencent.com/document/api/215/35015)

	* 新增入参：StorageType, FlowLogStorage

	* <font color="#dd0000">**修改入参**：</font>CloudLogId


新增数据结构：

* [FlowLogStorage](https://cloud.tencent.com/document/api/215/15824#FlowLogStorage)

修改数据结构：

* [FlowLog](https://cloud.tencent.com/document/api/215/15824#FlowLog)

	* 新增成员：Enable, StorageType, FlowLogStorage


### 第 104 次发布

发布时间：2021-12-20 08:15:01

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateVpnConnection](https://cloud.tencent.com/document/api/215/17522)

	* 新增入参：NegotiationType, DpdEnable, DpdTimeout, DpdAction

* [ModifyVpnConnectionAttribute](https://cloud.tencent.com/document/api/215/17508)

	* 新增入参：NegotiationType, DpdEnable, DpdTimeout, DpdAction


### 第 103 次发布

发布时间：2021-12-17 08:18:55

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateDirectConnectGateway](https://cloud.tencent.com/document/api/215/19192)

	* 新增入参：HaZoneGroupId


修改数据结构：

* [DirectConnectGateway](https://cloud.tencent.com/document/api/215/15824#DirectConnectGateway)

	* 新增成员：EnableFlowDetails, FlowDetailsUpdateTime, NewAfc, AccessNetworkType, HaZoneList

* [DirectConnectGatewayCcnRoute](https://cloud.tencent.com/document/api/215/15824#DirectConnectGatewayCcnRoute)

	* 新增成员：Description, UpdateTime


### 第 102 次发布

发布时间：2021-12-15 08:15:14

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeSecurityGroupPolicies](https://cloud.tencent.com/document/api/215/15804)

	* 新增入参：Filters


### 第 101 次发布

发布时间：2021-11-17 08:17:56

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateVpnGateway](https://cloud.tencent.com/document/api/215/17521)

	* 新增入参：CdcId, MaxConnection

* [ModifyIp6AddressesBandwidth](https://cloud.tencent.com/document/api/215/40088)

	* 新增出参：TaskId


修改数据结构：

* [VpnGateway](https://cloud.tencent.com/document/api/215/15824#VpnGateway)

	* 新增成员：CdcId, MaxConnection


### 第 100 次发布

发布时间：2021-10-26 08:14:56

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateAddressTemplate](https://cloud.tencent.com/document/api/215/16708)

	* 新增入参：AddressesExtra

	* <font color="#dd0000">**修改入参**：</font>Addresses

* [CreateServiceTemplate](https://cloud.tencent.com/document/api/215/16710)

	* 新增入参：ServicesExtra

	* <font color="#dd0000">**修改入参**：</font>Services

* [ModifyAddressTemplateAttribute](https://cloud.tencent.com/document/api/215/16720)

	* 新增入参：AddressesExtra

* [ModifyServiceTemplateAttribute](https://cloud.tencent.com/document/api/215/16722)

	* 新增入参：ServicesExtra


新增数据结构：

* [AddressInfo](https://cloud.tencent.com/document/api/215/15824#AddressInfo)
* [ServicesInfo](https://cloud.tencent.com/document/api/215/15824#ServicesInfo)

修改数据结构：

* [AddressTemplate](https://cloud.tencent.com/document/api/215/15824#AddressTemplate)

	* 新增成员：AddressExtraSet

* [ServiceTemplate](https://cloud.tencent.com/document/api/215/15824#ServiceTemplate)

	* 新增成员：ServiceExtraSet


### 第 99 次发布

发布时间：2021-10-15 08:16:52

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [AddTemplateMember](https://cloud.tencent.com/document/api/215/62762)
* [DeleteTemplateMember](https://cloud.tencent.com/document/api/215/62761)
* [ModifyTemplateMember](https://cloud.tencent.com/document/api/215/62760)

新增数据结构：

* [MemberInfo](https://cloud.tencent.com/document/api/215/15824#MemberInfo)

### 第 98 次发布

发布时间：2021-10-13 08:13:36

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeNatGatewayDirectConnectGatewayRoute](https://cloud.tencent.com/document/api/215/62616)
* [RefreshDirectConnectGatewayRouteToNatGateway](https://cloud.tencent.com/document/api/215/62615)

修改接口：

* [ModifyBandwidthPackageAttribute](https://cloud.tencent.com/document/api/215/19208)

	* 新增入参：MigrateOnRefund

* [UnassignPrivateIpAddresses](https://cloud.tencent.com/document/api/215/15814)

	* 新增入参：InstanceId


新增数据结构：

* [DirectConnectSubnet](https://cloud.tencent.com/document/api/215/15824#DirectConnectSubnet)
* [NatDirectConnectGatewayRoute](https://cloud.tencent.com/document/api/215/15824#NatDirectConnectGatewayRoute)

修改数据结构：

* [SecurityGroup](https://cloud.tencent.com/document/api/215/15824#SecurityGroup)

	* 新增成员：UpdateTime


### 第 97 次发布

发布时间：2021-09-07 08:09:15

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateVpnConnection](https://cloud.tencent.com/document/api/215/17522)

	* 新增入参：RouteType

	* <font color="#dd0000">**修改入参**：</font>VpcId, SecurityPolicyDatabases


### 第 96 次发布

发布时间：2021-08-24 08:10:38

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateFlowLog](https://cloud.tencent.com/document/api/215/35015)

	* <font color="#dd0000">**修改入参**：</font>VpcId

* [DeleteFlowLog](https://cloud.tencent.com/document/api/215/35014)

	* <font color="#dd0000">**修改入参**：</font>VpcId

* [ModifyFlowLogAttribute](https://cloud.tencent.com/document/api/215/35011)

	* <font color="#dd0000">**修改入参**：</font>VpcId


### 第 95 次发布

发布时间：2021-07-29 08:10:04

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [CCN](https://cloud.tencent.com/document/api/215/15824#CCN)

	* 新增成员：RouteTableCount, RouteTableFlag

* [CcnAttachedInstance](https://cloud.tencent.com/document/api/215/15824#CcnAttachedInstance)

	* 新增成员：RouteTableId, RouteTableName

* [CcnInstance](https://cloud.tencent.com/document/api/215/15824#CcnInstance)

	* 新增成员：RouteTableId


### 第 94 次发布

发布时间：2021-07-23 08:09:43

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [AssociateAddress](https://cloud.tencent.com/document/api/215/16700)

	* 新增入参：EipDirectConnection


### 第 93 次发布

发布时间：2021-07-22 08:09:27

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeVpcTaskResult](https://cloud.tencent.com/document/api/215/59037)

### 第 92 次发布

发布时间：2021-07-14 08:09:31

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [NatGateway](https://cloud.tencent.com/document/api/215/15824#NatGateway)

	* 新增成员：SourceIpTranslationNatRuleSet, IsExclusive, ExclusiveGatewayBandwidth


### 第 91 次发布

发布时间：2021-06-22 08:10:10

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateVpnGatewayRoutes](https://cloud.tencent.com/document/api/215/57678)
* [DeleteVpnGatewayRoutes](https://cloud.tencent.com/document/api/215/57677)
* [DescribeVpnGatewayRoutes](https://cloud.tencent.com/document/api/215/57676)
* [ModifyVpnGatewayRoutes](https://cloud.tencent.com/document/api/215/57675)

新增数据结构：

* [VpnGatewayRoute](https://cloud.tencent.com/document/api/215/15824#VpnGatewayRoute)
* [VpnGatewayRouteModify](https://cloud.tencent.com/document/api/215/15824#VpnGatewayRouteModify)

### 第 90 次发布

发布时间：2021-06-17 08:09:03

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeCrossBorderCompliance](https://cloud.tencent.com/document/api/215/47838)

	* 新增入参：Offset, Limit


### 第 89 次发布

发布时间：2021-05-24 08:08:44

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [SetCcnRegionBandwidthLimits](https://cloud.tencent.com/document/api/215/19194)

	* 新增入参：SetDefaultLimitFlag


### 第 88 次发布

发布时间：2021-05-21 08:08:53

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [AttachNetworkInterface](https://cloud.tencent.com/document/api/215/15819)

	* 新增入参：AttachType

* [CreateAndAttachNetworkInterface](https://cloud.tencent.com/document/api/215/43370)

	* 新增入参：AttachType

* [DescribeNetworkInterfaceLimit](https://cloud.tencent.com/document/api/215/38533)

	* 新增出参：ExtendEniQuantity, ExtendEniPrivateIpAddressQuantity

* [MigrateNetworkInterface](https://cloud.tencent.com/document/api/215/15821)

	* 新增入参：AttachType


修改数据结构：

* [Address](https://cloud.tencent.com/document/api/215/15824#Address)

	* 新增成员：TagSet

* [NetworkInterface](https://cloud.tencent.com/document/api/215/15824#NetworkInterface)

	* 新增成员：AttachType


### 第 87 次发布

发布时间：2021-05-11 08:09:25

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateDirectConnectGateway](https://cloud.tencent.com/document/api/215/19192)

	* 新增入参：Zone


修改数据结构：

* [DirectConnectGateway](https://cloud.tencent.com/document/api/215/15824#DirectConnectGateway)

	* 新增成员：LocalZone, Zone


### 第 86 次发布

发布时间：2021-04-26 08:08:37

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [ModifyNetworkInterfaceQos](https://cloud.tencent.com/document/api/215/55136)

### 第 85 次发布

发布时间：2021-04-14 08:08:09

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateVpcEndPoint](https://cloud.tencent.com/document/api/215/54685)
* [CreateVpcEndPointService](https://cloud.tencent.com/document/api/215/54684)
* [CreateVpcEndPointServiceWhiteList](https://cloud.tencent.com/document/api/215/54683)
* [DeleteVpcEndPoint](https://cloud.tencent.com/document/api/215/54682)
* [DeleteVpcEndPointService](https://cloud.tencent.com/document/api/215/54681)
* [DeleteVpcEndPointServiceWhiteList](https://cloud.tencent.com/document/api/215/54680)
* [DescribeVpcEndPoint](https://cloud.tencent.com/document/api/215/54679)
* [DescribeVpcEndPointService](https://cloud.tencent.com/document/api/215/54678)
* [DescribeVpcEndPointServiceWhiteList](https://cloud.tencent.com/document/api/215/54677)
* [DisassociateVpcEndPointSecurityGroups](https://cloud.tencent.com/document/api/215/54676)
* [EnableVpcEndPointConnect](https://cloud.tencent.com/document/api/215/54675)
* [ModifyVpcEndPointAttribute](https://cloud.tencent.com/document/api/215/54674)
* [ModifyVpcEndPointServiceAttribute](https://cloud.tencent.com/document/api/215/54673)
* [ModifyVpcEndPointServiceWhiteList](https://cloud.tencent.com/document/api/215/54672)

新增数据结构：

* [EndPoint](https://cloud.tencent.com/document/api/215/15824#EndPoint)
* [EndPointService](https://cloud.tencent.com/document/api/215/15824#EndPointService)
* [VpcEndPointServiceUser](https://cloud.tencent.com/document/api/215/15824#VpcEndPointServiceUser)

### 第 84 次发布

发布时间：2021-04-13 08:09:16

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateLocalGateway](https://cloud.tencent.com/document/api/215/54630)
* [DeleteLocalGateway](https://cloud.tencent.com/document/api/215/54629)
* [DescribeLocalGateway](https://cloud.tencent.com/document/api/215/54628)
* [ModifyLocalGateway](https://cloud.tencent.com/document/api/215/54627)

修改接口：

* [CreateSubnet](https://cloud.tencent.com/document/api/215/15782)

	* 新增入参：CdcId

* [CreateSubnets](https://cloud.tencent.com/document/api/215/31960)

	* 新增入参：CdcId

* [ReplaceRoutes](https://cloud.tencent.com/document/api/215/15764)

	* 新增出参：OldRouteSet, NewRouteSet


新增数据结构：

* [LocalGateway](https://cloud.tencent.com/document/api/215/15824#LocalGateway)

修改数据结构：

* [NetworkInterface](https://cloud.tencent.com/document/api/215/15824#NetworkInterface)

	* 新增成员：CdcId

* [Subnet](https://cloud.tencent.com/document/api/215/15824#Subnet)

	* 新增成员：CdcId, IsCdcSubnet


### 第 83 次发布

发布时间：2021-04-12 08:08:09

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [ModifyCcnAttachedInstancesAttribute](https://cloud.tencent.com/document/api/215/54517)

修改数据结构：

* [CcnAttachedInstance](https://cloud.tencent.com/document/api/215/15824#CcnAttachedInstance)

	* 新增成员：Description

* [CcnInstance](https://cloud.tencent.com/document/api/215/15824#CcnInstance)

	* 新增成员：Description


### 第 82 次发布

发布时间：2021-03-19 08:08:17

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [Route](https://cloud.tencent.com/document/api/215/15824#Route)

	* 新增成员：CreatedTime


### 第 81 次发布

发布时间：2021-03-10 08:10:37

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [AllocateAddresses](https://cloud.tencent.com/document/api/215/16699)

	* 新增入参：AddressName


### 第 80 次发布

发布时间：2021-02-02 08:09:22

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [NetworkInterface](https://cloud.tencent.com/document/api/215/15824#NetworkInterface)

	* 新增成员：Business


### 第 79 次发布

发布时间：2021-01-29 08:08:29

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateNatGatewaySourceIpTranslationNatRule](https://cloud.tencent.com/document/api/215/52622)
* [DeleteNatGatewaySourceIpTranslationNatRule](https://cloud.tencent.com/document/api/215/52621)
* [DescribeNatGatewaySourceIpTranslationNatRules](https://cloud.tencent.com/document/api/215/52620)
* [ModifyNatGatewaySourceIpTranslationNatRule](https://cloud.tencent.com/document/api/215/52619)
* [NotifyRoutes](https://cloud.tencent.com/document/api/215/52618)
* [WithdrawNotifyRoutes](https://cloud.tencent.com/document/api/215/52617)

修改接口：

* [DeleteRoutes](https://cloud.tencent.com/document/api/215/16725)

	* 新增出参：RouteSet


新增数据结构：

* [CidrForCcn](https://cloud.tencent.com/document/api/215/15824#CidrForCcn)
* [SourceIpTranslationNatRule](https://cloud.tencent.com/document/api/215/15824#SourceIpTranslationNatRule)

修改数据结构：

* [Route](https://cloud.tencent.com/document/api/215/15824#Route)

	* 新增成员：PublishedToVbc

* [RouteTable](https://cloud.tencent.com/document/api/215/15824#RouteTable)

	* 新增成员：LocalCidrForCcn


### 第 78 次发布

发布时间：2021-01-21 08:07:39

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [FlowLog](https://cloud.tencent.com/document/api/215/15824#FlowLog)

	* 新增成员：TagSet


### 第 77 次发布

发布时间：2021-01-20 08:07:38

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateVpnConnection](https://cloud.tencent.com/document/api/215/17522)

	* 新增入参：EnableHealthCheck, HealthCheckLocalIp, HealthCheckRemoteIp

* [ModifyVpnConnectionAttribute](https://cloud.tencent.com/document/api/215/17508)

	* 新增入参：EnableHealthCheck, HealthCheckLocalIp, HealthCheckRemoteIp


### 第 76 次发布

发布时间：2021-01-19 08:08:57

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [VpnConnection](https://cloud.tencent.com/document/api/215/15824#VpnConnection)

	* 新增成员：EnableHealthCheck, HealthCheckLocalIp, HealthCheckRemoteIp, HealthCheckStatus


### 第 75 次发布

发布时间：2020-12-21 08:08:07

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [ModifyNatGatewayAttribute](https://cloud.tencent.com/document/api/215/36715)

	* 新增入参：ModifySecurityGroup, SecurityGroupIds


修改数据结构：

* [NatGateway](https://cloud.tencent.com/document/api/215/15824#NatGateway)

	* 新增成员：SecurityGroupSet


### 第 74 次发布

发布时间：2020-12-17 08:07:53

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [AllocateIp6AddressesBandwidth](https://cloud.tencent.com/document/api/215/40090)

	* 新增入参：BandwidthPackageId


### 第 73 次发布

发布时间：2020-12-16 08:08:12

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CloneSecurityGroup](https://cloud.tencent.com/document/api/215/51025)

### 第 72 次发布

发布时间：2020-12-08 08:08:38

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateDirectConnectGateway](https://cloud.tencent.com/document/api/215/19192)

	* 新增入参：ModeType

* [ModifyDirectConnectGatewayAttribute](https://cloud.tencent.com/document/api/215/30643)

	* 新增入参：ModeType


修改数据结构：

* [DirectConnectGateway](https://cloud.tencent.com/document/api/215/15824#DirectConnectGateway)

	* 新增成员：VXLANSupport, ModeType


### 第 71 次发布

发布时间：2020-11-27 08:07:07

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [InquirePriceCreateDirectConnectGateway](https://cloud.tencent.com/document/api/215/50367)

### 第 70 次发布

发布时间：2020-11-24 08:08:57

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeIpGeolocationInfos](https://cloud.tencent.com/document/api/215/50234)

新增数据结构：

* [IpField](https://cloud.tencent.com/document/api/215/15824#IpField)
* [IpGeolocationInfo](https://cloud.tencent.com/document/api/215/15824#IpGeolocationInfo)

### 第 69 次发布

发布时间：2020-11-23 08:07:52

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [ReplaceSecurityGroupPolicy](https://cloud.tencent.com/document/api/215/15811)

	* 新增入参：OriginalSecurityGroupPolicySet


### 第 68 次发布

发布时间：2020-11-16 08:07:32

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeIpGeolocationDatabaseUrl](https://cloud.tencent.com/document/api/215/49899)

### 第 67 次发布

发布时间：2020-11-05 08:06:58

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateAndAttachNetworkInterface](https://cloud.tencent.com/document/api/215/43370)

	* 新增出参：NetworkInterface


### 第 66 次发布

发布时间：2020-11-04 08:06:58

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateAndAttachNetworkInterface](https://cloud.tencent.com/document/api/215/43370)

	* <font color="#dd0000">**删除出参**：</font>NetworkInterface


### 第 65 次发布

发布时间：2020-11-03 08:07:57

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeProductQuota](https://cloud.tencent.com/document/api/215/49629)

新增数据结构：

* [ProductQuota](https://cloud.tencent.com/document/api/215/15824#ProductQuota)

### 第 64 次发布

发布时间：2020-10-12 08:06:51

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [RenewAddresses](https://cloud.tencent.com/document/api/215/49015)

### 第 63 次发布

发布时间：2020-09-30 08:06:41

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeBandwidthPackageBillUsage](https://cloud.tencent.com/document/api/215/48945)
* [DescribeBandwidthPackageResources](https://cloud.tencent.com/document/api/215/48944)

新增数据结构：

* [BandwidthPackageBillBandwidth](https://cloud.tencent.com/document/api/215/15824#BandwidthPackageBillBandwidth)

### 第 62 次发布

发布时间：2020-09-25 08:06:55

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [AllocateAddresses](https://cloud.tencent.com/document/api/215/16699)

	* 新增入参：AddressChargePrepaid


修改数据结构：

* [AddressChargePrepaid](https://cloud.tencent.com/document/api/215/15824#AddressChargePrepaid)

	* 新增成员：AutoRenewFlag

	* <font color="#dd0000">**删除成员**：</font>RenewFlag


### 第 61 次发布

发布时间：2020-09-07 08:08:19

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateFlowLog](https://cloud.tencent.com/document/api/215/35015)

	* 新增入参：Tags


### 第 60 次发布

发布时间：2020-09-02 08:16:44

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [Address](https://cloud.tencent.com/document/api/215/15824#Address)

	* 新增成员：LocalBgp, Bandwidth, InternetChargeType


### 第 59 次发布

发布时间：2020-08-27 08:06:22

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [AuditCrossBorderCompliance](https://cloud.tencent.com/document/api/215/47839)
* [DescribeCrossBorderCompliance](https://cloud.tencent.com/document/api/215/47838)

新增数据结构：

* [CrossBorderCompliance](https://cloud.tencent.com/document/api/215/15824#CrossBorderCompliance)

### 第 58 次发布

发布时间：2020-08-19 08:20:41

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateCustomerGateway](https://cloud.tencent.com/document/api/215/17523)

	* 新增入参：Tags

* [CreateVpnConnection](https://cloud.tencent.com/document/api/215/17522)

	* 新增入参：Tags

* [CreateVpnGateway](https://cloud.tencent.com/document/api/215/17521)

	* 新增入参：Tags


### 第 57 次发布

发布时间：2020-08-14 08:20:29

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [NatGateway](https://cloud.tencent.com/document/api/215/15824#NatGateway)

	* 新增成员：TagSet


### 第 56 次发布

发布时间：2020-08-06 08:20:02

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [CCN](https://cloud.tencent.com/document/api/215/15824#CCN)

	* 新增成员：RoutePriorityFlag

* [CcnAttachedInstance](https://cloud.tencent.com/document/api/215/15824#CcnAttachedInstance)

	* 新增成员：InstanceArea

* [CcnRoute](https://cloud.tencent.com/document/api/215/15824#CcnRoute)

	* 新增成员：ExtraState, IsBgp, RoutePriority, InstanceExtraName


### 第 55 次发布

发布时间：2020-08-04 08:21:55

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [AssociateDirectConnectGatewayNatGateway](https://cloud.tencent.com/document/api/215/47109)
* [DisassociateDirectConnectGatewayNatGateway](https://cloud.tencent.com/document/api/215/47108)

修改接口：

* [CreateNatGateway](https://cloud.tencent.com/document/api/215/36721)

	* 新增入参：SubnetId


修改数据结构：

* [DirectConnectGateway](https://cloud.tencent.com/document/api/215/15824#DirectConnectGateway)

	* 新增成员：NatGatewayId

* [NatGateway](https://cloud.tencent.com/document/api/215/15824#NatGateway)

	* 新增成员：DirectConnectGatewayIds, SubnetId

* [Tag](https://cloud.tencent.com/document/api/215/15824#Tag)

	* <font color="#dd0000">**修改成员**：</font>Value


### 第 54 次发布

发布时间：2020-07-29 08:19:25

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateNetDetect](https://cloud.tencent.com/document/api/215/38699)

	* <font color="#dd0000">**修改入参**：</font>NextHopType, NextHopDestination


### 第 53 次发布

发布时间：2020-07-03 08:18:56

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DisableRoutes](https://cloud.tencent.com/document/api/215/19216)

	* 新增入参：RouteItemIds

	* <font color="#dd0000">**修改入参**：</font>RouteIds

* [EnableRoutes](https://cloud.tencent.com/document/api/215/19215)

	* 新增入参：RouteItemIds

	* <font color="#dd0000">**修改入参**：</font>RouteIds


修改数据结构：

* [Route](https://cloud.tencent.com/document/api/215/15824#Route)

	* 新增成员：DestinationIpv6CidrBlock, RouteItemId


### 第 52 次发布

发布时间：2020-06-11 08:18:40

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [GetCcnRegionBandwidthLimits](https://cloud.tencent.com/document/api/215/45482)

新增数据结构：

* [CcnBandwidthInfo](https://cloud.tencent.com/document/api/215/15824#CcnBandwidthInfo)

### 第 51 次发布

发布时间：2020-06-02 08:18:49

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [AssociateDhcpIpWithAddressIp](https://cloud.tencent.com/document/api/215/45093)
* [CreateDhcpIp](https://cloud.tencent.com/document/api/215/45092)
* [DeleteDhcpIp](https://cloud.tencent.com/document/api/215/45091)
* [DescribeDhcpIps](https://cloud.tencent.com/document/api/215/45090)
* [DisassociateDhcpIpWithAddressIp](https://cloud.tencent.com/document/api/215/45089)
* [ModifyDhcpIpAttribute](https://cloud.tencent.com/document/api/215/45088)

新增数据结构：

* [DhcpIp](https://cloud.tencent.com/document/api/215/15824#DhcpIp)

### 第 50 次发布

发布时间：2020-05-11 10:17:57

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [ModifyGatewayFlowQos](https://cloud.tencent.com/document/api/215/43268)

	* <font color="#dd0000">**修改入参**：</font>Bandwidth


修改数据结构：

* [GatewayQos](https://cloud.tencent.com/document/api/215/15824#GatewayQos)

	* <font color="#dd0000">**修改成员**：</font>Bandwidth


### 第 49 次发布

发布时间：2020-04-27 08:17:18

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [ModifyAddressInternetChargeType](https://cloud.tencent.com/document/api/215/43849)

新增数据结构：

* [AddressChargePrepaid](https://cloud.tencent.com/document/api/215/15824#AddressChargePrepaid)

修改数据结构：

* [SecurityGroupAssociationStatistics](https://cloud.tencent.com/document/api/215/15824#SecurityGroupAssociationStatistics)

	* 新增成员：TotalCount


### 第 48 次发布

发布时间：2020-04-23 08:17:22

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [Address](https://cloud.tencent.com/document/api/215/15824#Address)

	* 新增成员：InternetServiceProvider


### 第 47 次发布

发布时间：2020-04-20 08:16:59

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeVpnGatewayCcnRoutes](https://cloud.tencent.com/document/api/215/43514)

### 第 46 次发布

发布时间：2020-04-17 08:16:30

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [ModifyVpnGatewayCcnRoutes](https://cloud.tencent.com/document/api/215/43497)

修改接口：

* [CreateVpnGateway](https://cloud.tencent.com/document/api/215/17521)

	* 新增入参：Type


新增数据结构：

* [VpngwCcnRoutes](https://cloud.tencent.com/document/api/215/15824#VpngwCcnRoutes)

### 第 45 次发布

发布时间：2020-04-13 08:16:45

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateAndAttachNetworkInterface](https://cloud.tencent.com/document/api/215/43370)

### 第 44 次发布

发布时间：2020-04-10 08:16:25

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeVpcResourceDashboard](https://cloud.tencent.com/document/api/215/43355)

新增数据结构：

* [ResourceDashboard](https://cloud.tencent.com/document/api/215/15824#ResourceDashboard)

### 第 43 次发布

发布时间：2020-04-09 08:16:20

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CheckAssistantCidr](https://cloud.tencent.com/document/api/215/43277)
* [CreateAssistantCidr](https://cloud.tencent.com/document/api/215/43276)
* [CreateDefaultSecurityGroup](https://cloud.tencent.com/document/api/215/43280)
* [CreateSecurityGroupWithPolicies](https://cloud.tencent.com/document/api/215/43279)
* [DeleteAssistantCidr](https://cloud.tencent.com/document/api/215/43275)
* [DescribeAssistantCidr](https://cloud.tencent.com/document/api/215/43274)
* [DescribeGatewayFlowQos](https://cloud.tencent.com/document/api/215/43271)
* [DescribeSecurityGroupReferences](https://cloud.tencent.com/document/api/215/43278)
* [DescribeVpcInstances](https://cloud.tencent.com/document/api/215/43273)
* [DisableGatewayFlowMonitor](https://cloud.tencent.com/document/api/215/43270)
* [EnableGatewayFlowMonitor](https://cloud.tencent.com/document/api/215/43269)
* [ModifyAssistantCidr](https://cloud.tencent.com/document/api/215/43272)
* [ModifyGatewayFlowQos](https://cloud.tencent.com/document/api/215/43268)

新增数据结构：

* [ConflictItem](https://cloud.tencent.com/document/api/215/15824#ConflictItem)
* [ConflictSource](https://cloud.tencent.com/document/api/215/15824#ConflictSource)
* [CvmInstance](https://cloud.tencent.com/document/api/215/15824#CvmInstance)
* [GatewayQos](https://cloud.tencent.com/document/api/215/15824#GatewayQos)
* [ReferredSecurityGroup](https://cloud.tencent.com/document/api/215/15824#ReferredSecurityGroup)

### 第 42 次发布

发布时间：2020-04-08 08:15:45

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [AllocateAddresses](https://cloud.tencent.com/document/api/215/16699)

	* 新增入参：Tags


### 第 41 次发布

发布时间：2020-04-07 08:16:03

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [AssociateNetworkInterfaceSecurityGroups](https://cloud.tencent.com/document/api/215/43132)
* [DisassociateNetworkInterfaceSecurityGroups](https://cloud.tencent.com/document/api/215/43131)

### 第 40 次发布

发布时间：2020-03-27 08:14:59

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CheckDefaultSubnet](https://cloud.tencent.com/document/api/215/42943)
* [DescribeVpcLimits](https://cloud.tencent.com/document/api/215/42942)

<font color="#dd0000">**删除接口**：</font>

* DescribeAddressTemplateInstances

新增数据结构：

* [VpcLimit](https://cloud.tencent.com/document/api/215/15824#VpcLimit)

### 第 39 次发布

发布时间：2020-03-26 08:14:31

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [AllocateAddresses](https://cloud.tencent.com/document/api/215/16699)

	* 新增入参：BandwidthPackageId


### 第 38 次发布

发布时间：2020-03-24 08:14:43

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeAddressTemplateInstances](https://cloud.tencent.com/document/api/215/42837)
* [DescribeTemplateLimits](https://cloud.tencent.com/document/api/215/42836)

新增数据结构：

* [TemplateLimit](https://cloud.tencent.com/document/api/215/15824#TemplateLimit)

### 第 37 次发布

发布时间：2020-03-12 14:42:12

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [AssociateNetworkAclSubnets](https://cloud.tencent.com/document/api/215/42163)
* [CreateNetworkAcl](https://cloud.tencent.com/document/api/215/42162)
* [DeleteNetworkAcl](https://cloud.tencent.com/document/api/215/42161)
* [DescribeNetworkAcls](https://cloud.tencent.com/document/api/215/42160)
* [DisassociateNetworkAclSubnets](https://cloud.tencent.com/document/api/215/42159)
* [ModifyNetworkAclAttribute](https://cloud.tencent.com/document/api/215/42158)

新增数据结构：

* [NetworkAcl](https://cloud.tencent.com/document/api/215/15824#NetworkAcl)

### 第 36 次发布

发布时间：2020-03-10 00:50:44

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [ModifyNetworkAclEntries](https://cloud.tencent.com/document/api/215/42107)

修改接口：

* [CreateNatGateway](https://cloud.tencent.com/document/api/215/36721)

	* 新增入参：Tags


新增数据结构：

* [NetworkAclEntry](https://cloud.tencent.com/document/api/215/15824#NetworkAclEntry)
* [NetworkAclEntrySet](https://cloud.tencent.com/document/api/215/15824#NetworkAclEntrySet)

修改数据结构：

* [Route](https://cloud.tencent.com/document/api/215/15824#Route)

	* 新增成员：RouteTableId

* [VpnGateway](https://cloud.tencent.com/document/api/215/15824#VpnGateway)

	* 新增成员：NetworkInstanceId


### 第 35 次发布

发布时间：2020-02-25 11:20:11

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateCcn](https://cloud.tencent.com/document/api/215/19204)

	* 新增入参：Tags

* [CreateRouteTable](https://cloud.tencent.com/document/api/215/15768)

	* 新增入参：Tags

* [CreateSubnet](https://cloud.tencent.com/document/api/215/15782)

	* 新增入参：Tags

* [CreateSubnets](https://cloud.tencent.com/document/api/215/31960)

	* 新增入参：Tags

* [CreateVpc](https://cloud.tencent.com/document/api/215/15774)

	* 新增入参：Tags


### 第 34 次发布

发布时间：2020-02-21 12:12:39

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateSecurityGroup](https://cloud.tencent.com/document/api/215/15806)

	* 新增入参：Tags


### 第 33 次发布

发布时间：2020-02-21 11:57:14

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeSecurityGroupLimits](https://cloud.tencent.com/document/api/215/41428)

新增数据结构：

* [AddressTemplateItem](https://cloud.tencent.com/document/api/215/15824#AddressTemplateItem)
* [AlgType](https://cloud.tencent.com/document/api/215/15824#AlgType)
* [SecurityGroupLimitSet](https://cloud.tencent.com/document/api/215/15824#SecurityGroupLimitSet)

修改数据结构：

* [Address](https://cloud.tencent.com/document/api/215/15824#Address)

	* 新增成员：EipAlgType

* [AddressTemplateGroup](https://cloud.tencent.com/document/api/215/15824#AddressTemplateGroup)

	* 新增成员：AddressTemplateSet

* [CCN](https://cloud.tencent.com/document/api/215/15824#CCN)

	* 新增成员：TagSet

* [RouteTable](https://cloud.tencent.com/document/api/215/15824#RouteTable)

	* 新增成员：TagSet

* [ServiceTemplateGroup](https://cloud.tencent.com/document/api/215/15824#ServiceTemplateGroup)

	* 新增成员：ServiceTemplateSet

* [Subnet](https://cloud.tencent.com/document/api/215/15824#Subnet)

	* 新增成员：TotalIpAddressCount, TagSet


### 第 32 次发布

发布时间：2020-01-10 20:00:11

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeFlowLogs](https://cloud.tencent.com/document/api/215/35012)

	* 新增入参：Filters

* [ModifyBandwidthPackageAttribute](https://cloud.tencent.com/document/api/215/19208)

	* 新增入参：ChargeType


### 第 31 次发布

发布时间：2019-12-26 18:02:31

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [ModifyCcnRegionBandwidthLimitsType](https://cloud.tencent.com/document/api/215/40485)

修改数据结构：

* [HaVip](https://cloud.tencent.com/document/api/215/15824#HaVip)

	* 新增成员：Business

* [SecurityGroup](https://cloud.tencent.com/document/api/215/15824#SecurityGroup)

	* 新增成员：TagSet

* [VpnGateway](https://cloud.tencent.com/document/api/215/15824#VpnGateway)

	* 新增成员：Version


### 第 30 次发布

发布时间：2019-12-05 17:50:08

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [AllocateIp6AddressesBandwidth](https://cloud.tencent.com/document/api/215/40090)
* [DescribeIp6Addresses](https://cloud.tencent.com/document/api/215/40089)
* [ModifyIp6AddressesBandwidth](https://cloud.tencent.com/document/api/215/40088)
* [ReleaseIp6AddressesBandwidth](https://cloud.tencent.com/document/api/215/40087)

修改接口：

* [AddBandwidthPackageResources](https://cloud.tencent.com/document/api/215/19213)

	* 新增入参：Protocol

* [CreateBandwidthPackage](https://cloud.tencent.com/document/api/215/19212)

	* 新增入参：Tags, Protocol

* [CreateNetworkInterface](https://cloud.tencent.com/document/api/215/15818)

	* 新增入参：Tags

* [ModifySecurityGroupPolicies](https://cloud.tencent.com/document/api/215/15810)

	* 新增入参：SortPolicys


新增数据结构：

* [VpnGatewayQuota](https://cloud.tencent.com/document/api/215/15824#VpnGatewayQuota)

修改数据结构：

* [NetworkInterface](https://cloud.tencent.com/document/api/215/15824#NetworkInterface)

	* 新增成员：EniType

* [VpnGateway](https://cloud.tencent.com/document/api/215/15824#VpnGateway)

	* 新增成员：VpnGatewayQuotaSet


### 第 29 次发布

发布时间：2019-10-28 15:53:38

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CheckNetDetectState](https://cloud.tencent.com/document/api/215/38700)
* [CreateNetDetect](https://cloud.tencent.com/document/api/215/38699)
* [DeleteNetDetect](https://cloud.tencent.com/document/api/215/38698)
* [DescribeNetDetectStates](https://cloud.tencent.com/document/api/215/38697)
* [DescribeNetDetects](https://cloud.tencent.com/document/api/215/38696)
* [ModifyNetDetect](https://cloud.tencent.com/document/api/215/38695)

新增数据结构：

* [NetDetect](https://cloud.tencent.com/document/api/215/15824#NetDetect)
* [NetDetectIpState](https://cloud.tencent.com/document/api/215/15824#NetDetectIpState)
* [NetDetectState](https://cloud.tencent.com/document/api/215/15824#NetDetectState)

### 第 28 次发布

发布时间：2019-10-18 10:57:54

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeNetworkInterfaceLimit](https://cloud.tencent.com/document/api/215/38533)

修改数据结构：

* [SecurityGroupPolicy](https://cloud.tencent.com/document/api/215/15824#SecurityGroupPolicy)

	* 新增成员：Ipv6CidrBlock


### 第 27 次发布

发布时间：2019-10-10 19:35:20

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [AllocateAddresses](https://cloud.tencent.com/document/api/215/16699)

	* 新增出参：TaskId

* [AssociateAddress](https://cloud.tencent.com/document/api/215/16700)

	* 新增出参：TaskId

* [DisassociateAddress](https://cloud.tencent.com/document/api/215/16703)

	* 新增出参：TaskId

* [ModifyAddressesBandwidth](https://cloud.tencent.com/document/api/215/19214)

	* 新增出参：TaskId

* [ReleaseAddresses](https://cloud.tencent.com/document/api/215/16705)

	* <font color="#dd0000">**修改入参**：</font>AddressIds

	* 新增出参：TaskId


修改数据结构：

* [SecurityGroupPolicy](https://cloud.tencent.com/document/api/215/15824#SecurityGroupPolicy)

	* 新增成员：ModifyTime


### 第 26 次发布

发布时间：2019-09-26 20:32:20

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateCcn](https://cloud.tencent.com/document/api/215/19204)

	* 新增入参：InstanceChargeType, BandwidthLimitType


修改数据结构：

* [DirectConnectGateway](https://cloud.tencent.com/document/api/215/15824#DirectConnectGateway)

	* 新增成员：EnableBGPCommunity


### 第 25 次发布

发布时间：2019-08-29 20:56:58

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [AllocateAddresses](https://cloud.tencent.com/document/api/215/16699)

	* 新增入参：InternetChargeType, InternetMaxBandwidthOut, ApplicableForCLB


### 第 24 次发布

发布时间：2019-08-26 10:28:36

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [ModifyAddressAttribute](https://cloud.tencent.com/document/api/215/16704)

	* 新增入参：EipDirectConnection


新增数据结构：

* [AssistantCidr](https://cloud.tencent.com/document/api/215/15824#AssistantCidr)

修改数据结构：

* [Vpc](https://cloud.tencent.com/document/api/215/15824#Vpc)

	* 新增成员：AssistantCidrSet


### 第 23 次发布

发布时间：2019-08-01 17:24:55

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [AssociateNatGatewayAddress](https://cloud.tencent.com/document/api/215/36722)
* [CreateNatGateway](https://cloud.tencent.com/document/api/215/36721)
* [CreateNatGatewayDestinationIpPortTranslationNatRule](https://cloud.tencent.com/document/api/215/36720)
* [DeleteNatGateway](https://cloud.tencent.com/document/api/215/36719)
* [DeleteNatGatewayDestinationIpPortTranslationNatRule](https://cloud.tencent.com/document/api/215/36718)
* [DescribeNatGatewayDestinationIpPortTranslationNatRules](https://cloud.tencent.com/document/api/215/36717)
* [DisassociateNatGatewayAddress](https://cloud.tencent.com/document/api/215/36716)
* [ModifyNatGatewayAttribute](https://cloud.tencent.com/document/api/215/36715)
* [ModifyNatGatewayDestinationIpPortTranslationNatRule](https://cloud.tencent.com/document/api/215/36714)
* [ResetNatGatewayConnection](https://cloud.tencent.com/document/api/215/36713)

修改接口：

* [AllocateAddresses](https://cloud.tencent.com/document/api/215/16699)

	* 新增入参：InternetServiceProvider, AddressType, AnycastZone


新增数据结构：

* [NatGatewayDestinationIpPortTranslationNatRule](https://cloud.tencent.com/document/api/215/15824#NatGatewayDestinationIpPortTranslationNatRule)

### 第 22 次发布

发布时间：2019-07-18 11:22:10

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeTaskResult](https://cloud.tencent.com/document/api/215/36271)

修改数据结构：

* [NetworkInterface](https://cloud.tencent.com/document/api/215/15824#NetworkInterface)

	* 新增成员：TagSet


### 第 21 次发布

发布时间：2019-07-04 17:23:32

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeNatGateways](https://cloud.tencent.com/document/api/215/36034)

新增数据结构：

* [DestinationIpPortTranslationNatRule](https://cloud.tencent.com/document/api/215/15824#DestinationIpPortTranslationNatRule)
* [NatGateway](https://cloud.tencent.com/document/api/215/15824#NatGateway)
* [NatGatewayAddress](https://cloud.tencent.com/document/api/215/15824#NatGatewayAddress)

### 第 20 次发布

发布时间：2019-06-27 14:42:09

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateRoutes](https://cloud.tencent.com/document/api/215/16724)

	* 新增出参：TotalCount, RouteTableSet

* [DescribeCcns](https://cloud.tencent.com/document/api/215/19199)

	* 新增入参：OrderField, OrderDirection


新增数据结构：

* [Tag](https://cloud.tencent.com/document/api/215/15824#Tag)

修改数据结构：

* [Vpc](https://cloud.tencent.com/document/api/215/15824#Vpc)

	* 新增成员：TagSet


### 第 19 次发布

发布时间：2019-05-17 10:39:41

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateFlowLog](https://cloud.tencent.com/document/api/215/35015)
* [DeleteFlowLog](https://cloud.tencent.com/document/api/215/35014)
* [DescribeFlowLog](https://cloud.tencent.com/document/api/215/35013)
* [DescribeFlowLogs](https://cloud.tencent.com/document/api/215/35012)
* [ModifyFlowLogAttribute](https://cloud.tencent.com/document/api/215/35011)

新增数据结构：

* [FlowLog](https://cloud.tencent.com/document/api/215/15824#FlowLog)

### 第 18 次发布

发布时间：2019-04-25 19:53:12

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [AssignIpv6Addresses](https://cloud.tencent.com/document/api/215/34469)
* [AssignIpv6CidrBlock](https://cloud.tencent.com/document/api/215/34466)
* [AssignIpv6SubnetCidrBlock](https://cloud.tencent.com/document/api/215/34471)
* [DescribeVpcIpv6Addresses](https://cloud.tencent.com/document/api/215/34465)
* [ModifyIpv6AddressesAttribute](https://cloud.tencent.com/document/api/215/34468)
* [UnassignIpv6Addresses](https://cloud.tencent.com/document/api/215/34467)
* [UnassignIpv6CidrBlock](https://cloud.tencent.com/document/api/215/34464)
* [UnassignIpv6SubnetCidrBlock](https://cloud.tencent.com/document/api/215/34470)

新增数据结构：

* [Ipv6SubnetCidrBlock](https://cloud.tencent.com/document/api/215/15824#Ipv6SubnetCidrBlock)
* [VpcIpv6Address](https://cloud.tencent.com/document/api/215/15824#VpcIpv6Address)

修改数据结构：

* [Subnet](https://cloud.tencent.com/document/api/215/15824#Subnet)

	* 新增成员：NetworkAclId, IsRemoteVpcSnat


### 第 17 次发布

发布时间：2019-03-28 15:59:45

本次发布包含了以下内容：

改善已有的文档。

新增数据结构：

* [InstanceStatistic](https://cloud.tencent.com/document/api/215/15824#InstanceStatistic)

修改数据结构：

* [SecurityGroupAssociationStatistics](https://cloud.tencent.com/document/api/215/15824#SecurityGroupAssociationStatistics)

	* <font color="#dd0000">**修改成员**：</font>InstanceStatistics


### 第 16 次发布

发布时间：2019-03-01 16:03:19

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeGatewayFlowMonitorDetail](https://cloud.tencent.com/document/api/215/33424)

新增数据结构：

* [GatewayFlowMonitorDetail](https://cloud.tencent.com/document/api/215/15824#GatewayFlowMonitorDetail)
* [Ipv6Address](https://cloud.tencent.com/document/api/215/15824#Ipv6Address)

修改数据结构：

* [CCN](https://cloud.tencent.com/document/api/215/15824#CCN)

	* 新增成员：InstanceChargeType, BandwidthLimitType

* [NetworkInterface](https://cloud.tencent.com/document/api/215/15824#NetworkInterface)

	* 新增成员：Ipv6AddressSet

* [Subnet](https://cloud.tencent.com/document/api/215/15824#Subnet)

	* 新增成员：Ipv6CidrBlock

* [Vpc](https://cloud.tencent.com/document/api/215/15824#Vpc)

	* 新增成员：Ipv6CidrBlock


### 第 15 次发布

发布时间：2019-01-24 20:16:24

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [AddIp6Rules](https://cloud.tencent.com/document/api/215/32883)
* [CreateIp6Translators](https://cloud.tencent.com/document/api/215/32882)
* [DeleteIp6Translators](https://cloud.tencent.com/document/api/215/32881)
* [DescribeIp6TranslatorQuota](https://cloud.tencent.com/document/api/215/32880)
* [DescribeIp6Translators](https://cloud.tencent.com/document/api/215/32879)
* [DescribeVpcPrivateIpAddresses](https://cloud.tencent.com/document/api/215/32884)
* [ModifyIp6Rule](https://cloud.tencent.com/document/api/215/32878)
* [ModifyIp6Translator](https://cloud.tencent.com/document/api/215/32877)
* [RemoveIp6Rules](https://cloud.tencent.com/document/api/215/32876)

修改接口：

* [DescribeCcnAttachedInstances](https://cloud.tencent.com/document/api/215/19202)

	* 新增入参：OrderField, OrderDirection


新增数据结构：

* [Ip6Rule](https://cloud.tencent.com/document/api/215/15824#Ip6Rule)
* [Ip6RuleInfo](https://cloud.tencent.com/document/api/215/15824#Ip6RuleInfo)
* [Ip6Translator](https://cloud.tencent.com/document/api/215/15824#Ip6Translator)
* [VpcPrivateIpAddress](https://cloud.tencent.com/document/api/215/15824#VpcPrivateIpAddress)

### 第 14 次发布

发布时间：2019-01-10 20:02:38

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [CcnRegionBandwidthLimit](https://cloud.tencent.com/document/api/215/15824#CcnRegionBandwidthLimit)

	* 新增成员：DstRegion, DstIsBm


### 第 13 次发布

发布时间：2018-12-27 20:56:49

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateSubnets](https://cloud.tencent.com/document/api/215/31960)

修改接口：

* [CreateCcn](https://cloud.tencent.com/document/api/215/19204)

	* 新增入参：QosLevel


新增数据结构：

* [SubnetInput](https://cloud.tencent.com/document/api/215/15824#SubnetInput)

修改数据结构：

* [CcnRegionBandwidthLimit](https://cloud.tencent.com/document/api/215/15824#CcnRegionBandwidthLimit)

	* 新增成员：IsBm

* [SecurityGroupAssociationStatistics](https://cloud.tencent.com/document/api/215/15824#SecurityGroupAssociationStatistics)

	* 新增成员：InstanceStatistics

* [Vpc](https://cloud.tencent.com/document/api/215/15824#Vpc)

	* 新增成员：EnableDhcp


### 第 12 次发布

发布时间：2018-11-29 16:45:01

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [CCN](https://cloud.tencent.com/document/api/215/15824#CCN)

	* 新增成员：QosLevel


### 第 11 次发布

发布时间：2018-11-22 20:45:08

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateHaVip](https://cloud.tencent.com/document/api/215/30652)
* [DeleteDirectConnectGateway](https://cloud.tencent.com/document/api/215/30645)
* [DeleteHaVip](https://cloud.tencent.com/document/api/215/30651)
* [DescribeDirectConnectGateways](https://cloud.tencent.com/document/api/215/30644)
* [DescribeHaVips](https://cloud.tencent.com/document/api/215/30650)
* [HaVipAssociateAddressIp](https://cloud.tencent.com/document/api/215/30649)
* [HaVipDisassociateAddressIp](https://cloud.tencent.com/document/api/215/30648)
* [ModifyDirectConnectGatewayAttribute](https://cloud.tencent.com/document/api/215/30643)
* [ModifyHaVipAttribute](https://cloud.tencent.com/document/api/215/30647)

修改接口：

* [DescribeDirectConnectGatewayCcnRoutes](https://cloud.tencent.com/document/api/215/19189)

	* 新增入参：CcnRouteType, Offset, Limit


新增数据结构：

* [HaVip](https://cloud.tencent.com/document/api/215/15824#HaVip)

修改数据结构：

* [DirectConnectGateway](https://cloud.tencent.com/document/api/215/15824#DirectConnectGateway)

	* 新增成员：DirectConnectGatewayIp, CcnId, CcnRouteType, EnableBGP

	* <font color="#dd0000">**删除成员**：</font>DirectConnectTunnelCount

* [DirectConnectGatewayCcnRoute](https://cloud.tencent.com/document/api/215/15824#DirectConnectGatewayCcnRoute)

	* 新增成员：ASPath


### 第 10 次发布

发布时间：2018-10-26 14:41:33

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateBandwidthPackage](https://cloud.tencent.com/document/api/215/19212)

	* 新增入参：InternetMaxBandwidth


修改数据结构：

* [BandwidthPackage](https://cloud.tencent.com/document/api/215/15824#BandwidthPackage)

	* 新增成员：Bandwidth


### 第 9 次发布

发布时间：2018-09-27 19:38:50

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [AcceptAttachCcnInstances](https://cloud.tencent.com/document/api/215/20251)
* [RejectAttachCcnInstances](https://cloud.tencent.com/document/api/215/20250)
* [ResetAttachCcnInstances](https://cloud.tencent.com/document/api/215/20249)

修改接口：

* [AttachCcnInstances](https://cloud.tencent.com/document/api/215/19205)

	* 新增入参：CcnUin

* [CreateVpnGateway](https://cloud.tencent.com/document/api/215/17521)

	* 新增入参：Zone

* [DescribeCcnAttachedInstances](https://cloud.tencent.com/document/api/215/19202)

	* 新增入参：Filters

	* <font color="#dd0000">**修改入参**：</font>CcnId

	* <font color="#dd0000">**修改出参**：</font>InstanceSet

* [ModifyAddressAttribute](https://cloud.tencent.com/document/api/215/16704)

	* <font color="#dd0000">**修改入参**：</font>AddressName


新增数据结构：

* [CcnAttachedInstance](https://cloud.tencent.com/document/api/215/15824#CcnAttachedInstance)

修改数据结构：

* [Address](https://cloud.tencent.com/document/api/215/15824#Address)

	* 新增成员：CascadeRelease

* [CcnInstance](https://cloud.tencent.com/document/api/215/15824#CcnInstance)

	* <font color="#dd0000">**删除成员**：</font>CcnId, InstanceName, CidrBlock

* [CcnRoute](https://cloud.tencent.com/document/api/215/15824#CcnRoute)

	* 新增成员：InstanceUin

* [VpnGateway](https://cloud.tencent.com/document/api/215/15824#VpnGateway)

	* 新增成员：Zone


### 第 8 次发布

发布时间：2018-08-24 16:49:29

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [AddBandwidthPackageResources](https://cloud.tencent.com/document/api/215/19213)
* [AttachCcnInstances](https://cloud.tencent.com/document/api/215/19205)
* [CreateBandwidthPackage](https://cloud.tencent.com/document/api/215/19212)
* [CreateCcn](https://cloud.tencent.com/document/api/215/19204)
* [CreateDirectConnectGateway](https://cloud.tencent.com/document/api/215/19192)
* [CreateDirectConnectGatewayCcnRoutes](https://cloud.tencent.com/document/api/215/19191)
* [DeleteBandwidthPackage](https://cloud.tencent.com/document/api/215/19211)
* [DeleteCcn](https://cloud.tencent.com/document/api/215/19203)
* [DeleteDirectConnectGatewayCcnRoutes](https://cloud.tencent.com/document/api/215/19190)
* [DescribeBandwidthPackageQuota](https://cloud.tencent.com/document/api/215/19210)
* [DescribeBandwidthPackages](https://cloud.tencent.com/document/api/215/19209)
* [DescribeCcnAttachedInstances](https://cloud.tencent.com/document/api/215/19202)
* [DescribeCcnRegionBandwidthLimits](https://cloud.tencent.com/document/api/215/19201)
* [DescribeCcnRoutes](https://cloud.tencent.com/document/api/215/19200)
* [DescribeCcns](https://cloud.tencent.com/document/api/215/19199)
* [DescribeDirectConnectGatewayCcnRoutes](https://cloud.tencent.com/document/api/215/19189)
* [DescribeRouteConflicts](https://cloud.tencent.com/document/api/215/19217)
* [DetachCcnInstances](https://cloud.tencent.com/document/api/215/19198)
* [DisableCcnRoutes](https://cloud.tencent.com/document/api/215/19197)
* [DisableRoutes](https://cloud.tencent.com/document/api/215/19216)
* [EnableCcnRoutes](https://cloud.tencent.com/document/api/215/19196)
* [EnableRoutes](https://cloud.tencent.com/document/api/215/19215)
* [ModifyAddressesBandwidth](https://cloud.tencent.com/document/api/215/19214)
* [ModifyBandwidthPackageAttribute](https://cloud.tencent.com/document/api/215/19208)
* [ModifyCcnAttribute](https://cloud.tencent.com/document/api/215/19195)
* [RemoveBandwidthPackageResources](https://cloud.tencent.com/document/api/215/19207)
* [ReplaceDirectConnectGatewayCcnRoutes](https://cloud.tencent.com/document/api/215/19188)
* [SetCcnRegionBandwidthLimits](https://cloud.tencent.com/document/api/215/19194)

新增数据结构：

* [AddressTemplateSpecification](https://cloud.tencent.com/document/api/215/15824#AddressTemplateSpecification)
* [BandwidthPackage](https://cloud.tencent.com/document/api/215/15824#BandwidthPackage)
* [CCN](https://cloud.tencent.com/document/api/215/15824#CCN)
* [CcnInstance](https://cloud.tencent.com/document/api/215/15824#CcnInstance)
* [CcnRegionBandwidthLimit](https://cloud.tencent.com/document/api/215/15824#CcnRegionBandwidthLimit)
* [CcnRoute](https://cloud.tencent.com/document/api/215/15824#CcnRoute)
* [DirectConnectGateway](https://cloud.tencent.com/document/api/215/15824#DirectConnectGateway)
* [DirectConnectGatewayCcnRoute](https://cloud.tencent.com/document/api/215/15824#DirectConnectGatewayCcnRoute)
* [Resource](https://cloud.tencent.com/document/api/215/15824#Resource)
* [RouteConflict](https://cloud.tencent.com/document/api/215/15824#RouteConflict)
* [ServiceTemplateSpecification](https://cloud.tencent.com/document/api/215/15824#ServiceTemplateSpecification)

修改数据结构：

* [Address](https://cloud.tencent.com/document/api/215/15824#Address)

	* 新增成员：InstanceId, NetworkInterfaceId, PrivateAddressIp, IsArrears, IsBlocked, IsEipDirectConnection, AddressType

	* <font color="#dd0000">**删除成员**：</font>BindedResourceId

* [PrivateIpAddressSpecification](https://cloud.tencent.com/document/api/215/15824#PrivateIpAddressSpecification)

	* 新增成员：State

* [Route](https://cloud.tencent.com/document/api/215/15824#Route)

	* 新增成员：RouteType

* [SecurityGroupPolicy](https://cloud.tencent.com/document/api/215/15824#SecurityGroupPolicy)

	* <font color="#dd0000">**修改成员**：</font>ServiceTemplate, AddressTemplate


### 第 7 次发布

发布时间：2018-07-26 17:08:14

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateRoutes](https://cloud.tencent.com/document/api/215/16724)

	* <font color="#dd0000">**修改入参**：</font>Routes

* [DeleteRoutes](https://cloud.tencent.com/document/api/215/16725)

	* <font color="#dd0000">**修改入参**：</font>Routes


修改数据结构：

* [Route](https://cloud.tencent.com/document/api/215/15824#Route)

	* 新增成员：Enabled

* [Vpc](https://cloud.tencent.com/document/api/215/15824#Vpc)

	* 新增成员：DnsServerSet, DomainName, DhcpOptionsId


### 第 6 次发布

发布时间：2018-06-14 12:15:42

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateDefaultVpc](https://cloud.tencent.com/document/api/215/17876)
* [DescribeAccountAttributes](https://cloud.tencent.com/document/api/215/17875)

新增数据结构：

* [AccountAttribute](https://cloud.tencent.com/document/api/215/15824#AccountAttribute)
* [DefaultVpcSubnet](https://cloud.tencent.com/document/api/215/15824#DefaultVpcSubnet)
* [NetworkInterfaceAttachment](https://cloud.tencent.com/document/api/215/15824#NetworkInterfaceAttachment)

修改数据结构：

* [NetworkInterface](https://cloud.tencent.com/document/api/215/15824#NetworkInterface)

	* <font color="#dd0000">**修改成员**：</font>Attachment

* [SecurityGroupAssociationStatistics](https://cloud.tencent.com/document/api/215/15824#SecurityGroupAssociationStatistics)

	* 新增成员：CLB


### 第 5 次发布

发布时间：2018-06-07 15:01:42

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeSecurityGroupAssociationStatistics](https://cloud.tencent.com/document/api/215/17799)

新增数据结构：

* [SecurityGroupAssociationStatistics](https://cloud.tencent.com/document/api/215/15824#SecurityGroupAssociationStatistics)

### 第 4 次发布

发布时间：2018-05-31 14:45:36

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateCustomerGateway](https://cloud.tencent.com/document/api/215/17523)
* [CreateVpnConnection](https://cloud.tencent.com/document/api/215/17522)
* [CreateVpnGateway](https://cloud.tencent.com/document/api/215/17521)
* [DeleteCustomerGateway](https://cloud.tencent.com/document/api/215/17520)
* [DeleteVpnConnection](https://cloud.tencent.com/document/api/215/17519)
* [DeleteVpnGateway](https://cloud.tencent.com/document/api/215/17518)
* [DescribeCustomerGatewayVendors](https://cloud.tencent.com/document/api/215/17517)
* [DescribeCustomerGateways](https://cloud.tencent.com/document/api/215/17516)
* [DescribeVpnConnections](https://cloud.tencent.com/document/api/215/17515)
* [DescribeVpnGateways](https://cloud.tencent.com/document/api/215/17514)
* [DownloadCustomerGatewayConfiguration](https://cloud.tencent.com/document/api/215/17513)
* [InquiryPriceCreateVpnGateway](https://cloud.tencent.com/document/api/215/17512)
* [InquiryPriceRenewVpnGateway](https://cloud.tencent.com/document/api/215/17511)
* [InquiryPriceResetVpnGatewayInternetMaxBandwidth](https://cloud.tencent.com/document/api/215/17510)
* [ModifyCustomerGatewayAttribute](https://cloud.tencent.com/document/api/215/17509)
* [ModifyVpnConnectionAttribute](https://cloud.tencent.com/document/api/215/17508)
* [ModifyVpnGatewayAttribute](https://cloud.tencent.com/document/api/215/17507)
* [RenewVpnGateway](https://cloud.tencent.com/document/api/215/17506)
* [ResetVpnConnection](https://cloud.tencent.com/document/api/215/17505)
* [ResetVpnGatewayInternetMaxBandwidth](https://cloud.tencent.com/document/api/215/17504)

修改接口：

* [DescribeAddressTemplateGroups](https://cloud.tencent.com/document/api/215/16716)

	* 新增出参：TotalCount, AddressTemplateGroupSet

* [ReplaceRoutes](https://cloud.tencent.com/document/api/215/15764)

	* <font color="#dd0000">**修改入参**：</font>Routes

* [ResetRoutes](https://cloud.tencent.com/document/api/215/15769)

	* <font color="#dd0000">**修改入参**：</font>Routes


新增数据结构：

* [CustomerGateway](https://cloud.tencent.com/document/api/215/15824#CustomerGateway)
* [CustomerGatewayVendor](https://cloud.tencent.com/document/api/215/15824#CustomerGatewayVendor)
* [IKEOptionsSpecification](https://cloud.tencent.com/document/api/215/15824#IKEOptionsSpecification)
* [IPSECOptionsSpecification](https://cloud.tencent.com/document/api/215/15824#IPSECOptionsSpecification)
* [ItemPrice](https://cloud.tencent.com/document/api/215/15824#ItemPrice)
* [Price](https://cloud.tencent.com/document/api/215/15824#Price)
* [SecurityPolicyDatabase](https://cloud.tencent.com/document/api/215/15824#SecurityPolicyDatabase)
* [VpnConnection](https://cloud.tencent.com/document/api/215/15824#VpnConnection)
* [VpnGateway](https://cloud.tencent.com/document/api/215/15824#VpnGateway)

修改数据结构：

* [Route](https://cloud.tencent.com/document/api/215/15824#Route)

	* <font color="#dd0000">**修改成员**：</font>RouteId

* [Subnet](https://cloud.tencent.com/document/api/215/15824#Subnet)

	* 新增成员：AvailableIpAddressCount


### 第 3 次发布

发布时间：2018-05-24 17:08:50

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [Address](https://cloud.tencent.com/document/api/215/15824#Address)

	* 新增成员：AddressStatus

	* <font color="#dd0000">**删除成员**：</font>AddressState


### 第 2 次发布

发布时间：2018-05-11 10:47:37

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateSecurityGroup](https://cloud.tencent.com/document/api/215/15806)

	* 新增出参：SecurityGroup

* [CreateVpc](https://cloud.tencent.com/document/api/215/15774)

	* 新增入参：DnsServers, DomainName

* [DescribeSecurityGroupPolicies](https://cloud.tencent.com/document/api/215/15804)

	* 新增出参：SecurityGroupPolicySet

* [DescribeSecurityGroups](https://cloud.tencent.com/document/api/215/15808)

	* 新增出参：SecurityGroupSet, TotalCount

* [DescribeSubnets](https://cloud.tencent.com/document/api/215/15784)

	* 新增出参：SubnetSet

	* <font color="#dd0000">**删除出参**：</font>DescribeSubnets

* [ModifyVpcAttribute](https://cloud.tencent.com/document/api/215/15773)

	* 新增入参：DnsServers, DomainName


新增数据结构：

* [SecurityGroup](https://cloud.tencent.com/document/api/215/15824#SecurityGroup)

### 第 1 次发布

发布时间：2018-04-24

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [AllocateAddresses](https://cloud.tencent.com/document/api/215/16699)
* [AssignPrivateIpAddresses](https://cloud.tencent.com/document/api/215/15813)
* [AssociateAddress](https://cloud.tencent.com/document/api/215/16700)
* [AttachClassicLinkVpc](https://cloud.tencent.com/document/api/215/15779)
* [AttachNetworkInterface](https://cloud.tencent.com/document/api/215/15819)
* [CreateAddressTemplate](https://cloud.tencent.com/document/api/215/16708)
* [CreateAddressTemplateGroup](https://cloud.tencent.com/document/api/215/16709)
* [CreateNetworkInterface](https://cloud.tencent.com/document/api/215/15818)
* [CreateRouteTable](https://cloud.tencent.com/document/api/215/15768)
* [CreateRoutes](https://cloud.tencent.com/document/api/215/16724)
* [CreateSecurityGroup](https://cloud.tencent.com/document/api/215/15806)
* [CreateSecurityGroupPolicies](https://cloud.tencent.com/document/api/215/15807)
* [CreateServiceTemplate](https://cloud.tencent.com/document/api/215/16710)
* [CreateServiceTemplateGroup](https://cloud.tencent.com/document/api/215/16711)
* [CreateSubnet](https://cloud.tencent.com/document/api/215/15782)
* [CreateVpc](https://cloud.tencent.com/document/api/215/15774)
* [DeleteAddressTemplate](https://cloud.tencent.com/document/api/215/16712)
* [DeleteAddressTemplateGroup](https://cloud.tencent.com/document/api/215/16713)
* [DeleteNetworkInterface](https://cloud.tencent.com/document/api/215/15822)
* [DeleteRouteTable](https://cloud.tencent.com/document/api/215/15771)
* [DeleteRoutes](https://cloud.tencent.com/document/api/215/16725)
* [DeleteSecurityGroup](https://cloud.tencent.com/document/api/215/15803)
* [DeleteSecurityGroupPolicies](https://cloud.tencent.com/document/api/215/15809)
* [DeleteServiceTemplate](https://cloud.tencent.com/document/api/215/16714)
* [DeleteServiceTemplateGroup](https://cloud.tencent.com/document/api/215/16715)
* [DeleteSubnet](https://cloud.tencent.com/document/api/215/15783)
* [DeleteVpc](https://cloud.tencent.com/document/api/215/15775)
* [DescribeAddressQuota](https://cloud.tencent.com/document/api/215/16701)
* [DescribeAddressTemplateGroups](https://cloud.tencent.com/document/api/215/16716)
* [DescribeAddressTemplates](https://cloud.tencent.com/document/api/215/16717)
* [DescribeAddresses](https://cloud.tencent.com/document/api/215/16702)
* [DescribeClassicLinkInstances](https://cloud.tencent.com/document/api/215/15776)
* [DescribeNetworkInterfaces](https://cloud.tencent.com/document/api/215/15817)
* [DescribeRouteTables](https://cloud.tencent.com/document/api/215/15763)
* [DescribeSecurityGroupPolicies](https://cloud.tencent.com/document/api/215/15804)
* [DescribeSecurityGroups](https://cloud.tencent.com/document/api/215/15808)
* [DescribeServiceTemplateGroups](https://cloud.tencent.com/document/api/215/16718)
* [DescribeServiceTemplates](https://cloud.tencent.com/document/api/215/16719)
* [DescribeSubnets](https://cloud.tencent.com/document/api/215/15784)
* [DescribeVpcs](https://cloud.tencent.com/document/api/215/15778)
* [DetachClassicLinkVpc](https://cloud.tencent.com/document/api/215/15777)
* [DetachNetworkInterface](https://cloud.tencent.com/document/api/215/15816)
* [DisassociateAddress](https://cloud.tencent.com/document/api/215/16703)
* [MigrateNetworkInterface](https://cloud.tencent.com/document/api/215/15821)
* [MigratePrivateIpAddress](https://cloud.tencent.com/document/api/215/15820)
* [ModifyAddressAttribute](https://cloud.tencent.com/document/api/215/16704)
* [ModifyAddressTemplateAttribute](https://cloud.tencent.com/document/api/215/16720)
* [ModifyAddressTemplateGroupAttribute](https://cloud.tencent.com/document/api/215/16721)
* [ModifyNetworkInterfaceAttribute](https://cloud.tencent.com/document/api/215/15815)
* [ModifyPrivateIpAddressesAttribute](https://cloud.tencent.com/document/api/215/15823)
* [ModifyRouteTableAttribute](https://cloud.tencent.com/document/api/215/15766)
* [ModifySecurityGroupAttribute](https://cloud.tencent.com/document/api/215/15805)
* [ModifySecurityGroupPolicies](https://cloud.tencent.com/document/api/215/15810)
* [ModifyServiceTemplateAttribute](https://cloud.tencent.com/document/api/215/16722)
* [ModifyServiceTemplateGroupAttribute](https://cloud.tencent.com/document/api/215/16723)
* [ModifySubnetAttribute](https://cloud.tencent.com/document/api/215/15781)
* [ModifyVpcAttribute](https://cloud.tencent.com/document/api/215/15773)
* [ReleaseAddresses](https://cloud.tencent.com/document/api/215/16705)
* [ReplaceRouteTableAssociation](https://cloud.tencent.com/document/api/215/15767)
* [ReplaceRoutes](https://cloud.tencent.com/document/api/215/15764)
* [ReplaceSecurityGroupPolicy](https://cloud.tencent.com/document/api/215/15811)
* [ResetRoutes](https://cloud.tencent.com/document/api/215/15769)
* [TransformAddress](https://cloud.tencent.com/document/api/215/16706)
* [UnassignPrivateIpAddresses](https://cloud.tencent.com/document/api/215/15814)

新增数据结构：

* [Address](https://cloud.tencent.com/document/api/215/15824#Address)
* [AddressTemplate](https://cloud.tencent.com/document/api/215/15824#AddressTemplate)
* [AddressTemplateGroup](https://cloud.tencent.com/document/api/215/15824#AddressTemplateGroup)
* [ClassicLinkInstance](https://cloud.tencent.com/document/api/215/15824#ClassicLinkInstance)
* [Filter](https://cloud.tencent.com/document/api/215/15824#Filter)
* [FilterObject](https://cloud.tencent.com/document/api/215/15824#FilterObject)
* [InstanceChargePrepaid](https://cloud.tencent.com/document/api/215/15824#InstanceChargePrepaid)
* [NetworkInterface](https://cloud.tencent.com/document/api/215/15824#NetworkInterface)
* [PrivateIpAddressSpecification](https://cloud.tencent.com/document/api/215/15824#PrivateIpAddressSpecification)
* [Quota](https://cloud.tencent.com/document/api/215/15824#Quota)
* [Route](https://cloud.tencent.com/document/api/215/15824#Route)
* [RouteTable](https://cloud.tencent.com/document/api/215/15824#RouteTable)
* [RouteTableAssociation](https://cloud.tencent.com/document/api/215/15824#RouteTableAssociation)
* [SecurityGroupPolicy](https://cloud.tencent.com/document/api/215/15824#SecurityGroupPolicy)
* [SecurityGroupPolicySet](https://cloud.tencent.com/document/api/215/15824#SecurityGroupPolicySet)
* [ServiceTemplate](https://cloud.tencent.com/document/api/215/15824#ServiceTemplate)
* [ServiceTemplateGroup](https://cloud.tencent.com/document/api/215/15824#ServiceTemplateGroup)
* [Subnet](https://cloud.tencent.com/document/api/215/15824#Subnet)
* [Vpc](https://cloud.tencent.com/document/api/215/15824#Vpc)




## 声音复刻(vrs) 版本：2020-08-24

### 第 6 次发布

发布时间：2024-04-02 01:27:45

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateVRSTask](https://cloud.tencent.com/document/api/1283/90064)

	* <font color="#dd0000">**修改入参**：</font>SampleRate, Codec

* [DetectEnvAndSoundQuality](https://cloud.tencent.com/document/api/1283/90062)

	* <font color="#dd0000">**修改入参**：</font>Codec


修改数据结构：

* [DescribeVRSTaskStatusRespData](https://cloud.tencent.com/document/api/1283/90065#DescribeVRSTaskStatusRespData)

	* <font color="#dd0000">**修改成员**：</font>TaskId, Status, StatusStr, VoiceType, ErrorMsg


### 第 5 次发布

发布时间：2023-11-21 01:41:45

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [VoiceTypeInfo](https://cloud.tencent.com/document/api/1283/90065#VoiceTypeInfo)

	* 新增成员：IsDeployed


### 第 4 次发布

发布时间：2023-11-16 01:37:19

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [GetVRSVoiceTypes](https://cloud.tencent.com/document/api/1283/101623)

新增数据结构：

* [VoiceTypeInfo](https://cloud.tencent.com/document/api/1283/90065#VoiceTypeInfo)
* [VoiceTypeListData](https://cloud.tencent.com/document/api/1283/90065#VoiceTypeListData)

### 第 3 次发布

发布时间：2023-11-03 01:27:03

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateVRSTask](https://cloud.tencent.com/document/api/1283/90064)

	* 新增入参：TaskType, VPRAudioId


### 第 2 次发布

发布时间：2023-07-18 01:58:58

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CancelVRSTask](https://cloud.tencent.com/document/api/1283/95078)
* [DownloadVRSModel](https://cloud.tencent.com/document/api/1283/95077)

修改接口：

* [CreateVRSTask](https://cloud.tencent.com/document/api/1283/90064)

	* 新增入参：ModelType


新增数据结构：

* [CancelVRSTaskRsp](https://cloud.tencent.com/document/api/1283/90065#CancelVRSTaskRsp)
* [DownloadVRSModelRsp](https://cloud.tencent.com/document/api/1283/90065#DownloadVRSModelRsp)

### 第 1 次发布

发布时间：2023-04-11 09:31:00

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateVRSTask](https://cloud.tencent.com/document/api/1283/90064)
* [DescribeVRSTaskStatus](https://cloud.tencent.com/document/api/1283/90063)
* [DetectEnvAndSoundQuality](https://cloud.tencent.com/document/api/1283/90062)
* [GetTrainingText](https://cloud.tencent.com/document/api/1283/90061)

新增数据结构：

* [CreateVRSTaskRespData](https://cloud.tencent.com/document/api/1283/90065#CreateVRSTaskRespData)
* [DescribeVRSTaskStatusRespData](https://cloud.tencent.com/document/api/1283/90065#DescribeVRSTaskStatusRespData)
* [DetectionEnvAndSoundQualityRespData](https://cloud.tencent.com/document/api/1283/90065#DetectionEnvAndSoundQualityRespData)
* [TrainingText](https://cloud.tencent.com/document/api/1283/90065#TrainingText)
* [TrainingTexts](https://cloud.tencent.com/document/api/1283/90065#TrainingTexts)
* [Words](https://cloud.tencent.com/document/api/1283/90065#Words)




## 视频转译(vtc) 版本：2024-02-23

### 第 2 次发布

发布时间：2024-06-07 02:52:58

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [ConfirmVideoTranslateJob](https://cloud.tencent.com/document/api/1769/106275)

	* 新增出参：Status, Message


### 第 1 次发布

发布时间：2024-05-16 16:17:26

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [ConfirmVideoTranslateJob](https://cloud.tencent.com/document/api/1769/106275)
* [DescribeVideoTranslateJob](https://cloud.tencent.com/document/api/1769/106274)
* [SubmitVideoTranslateJob](https://cloud.tencent.com/document/api/1769/106273)

新增数据结构：

* [AsrTimestamps](https://cloud.tencent.com/document/api/1769/106276#AsrTimestamps)
* [AudioTranslateResult](https://cloud.tencent.com/document/api/1769/106276#AudioTranslateResult)
* [TranslateResult](https://cloud.tencent.com/document/api/1769/106276#TranslateResult)




## Web 应用防火墙(waf) 版本：2018-01-25

### 第 94 次发布

发布时间：2024-07-23 02:21:00

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [AddAttackWhiteRule](https://cloud.tencent.com/document/api/627/100203)

	* 新增入参：TypeIds, Mode, Name

* [CreateIpAccessControl](https://cloud.tencent.com/document/api/627/105915)

	* 新增入参：JobType, JobDateTime

* [DescribeInstances](https://cloud.tencent.com/document/api/627/75922)

	* 新增入参：FreeDelayFlag

* [DescribeIpAccessControl](https://cloud.tencent.com/document/api/627/72645)

	* 新增入参：TimerType

* [ModifyAttackWhiteRule](https://cloud.tencent.com/document/api/627/100200)

	* 新增入参：TypeIds, Mode, Name

* [ModifyIpAccessControl](https://cloud.tencent.com/document/api/627/105912)

	* 新增入参：JobType, JobDateTime

* [UpsertCCRule](https://cloud.tencent.com/document/api/627/97646)

	* 新增入参：Length


修改数据结构：

* [BatchIpAccessControlItem](https://cloud.tencent.com/document/api/627/53609#BatchIpAccessControlItem)

	* 新增成员：JobType, CronType, JobDateTime, ValidStatus

* [CCRuleItem](https://cloud.tencent.com/document/api/627/53609#CCRuleItem)

	* 新增成员：Length, RuleId, EventId, SessionApplied, CreateTime

* [InstanceInfo](https://cloud.tencent.com/document/api/627/53609#InstanceInfo)

	* 新增成员：FreeDelayFlag

* [IpAccessControlItem](https://cloud.tencent.com/document/api/627/53609#IpAccessControlItem)

	* 新增成员：JobType, CronType, JobDateTime

* [UserSignatureRule](https://cloud.tencent.com/document/api/627/53609#UserSignatureRule)

	* 新增成员：RiskLevel

* [UserWhiteRule](https://cloud.tencent.com/document/api/627/53609#UserWhiteRule)

	* 新增成员：MatchParams, SignatureIds, TypeIds, TypeId, Mode, Name, MatchInfo, MatchInfoStr

* [UserWhiteRuleItem](https://cloud.tencent.com/document/api/627/53609#UserWhiteRuleItem)

	* 新增成员：MatchParams


### 第 93 次发布

发布时间：2024-07-04 01:27:42

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DeleteDomainWhiteRules](https://cloud.tencent.com/document/api/627/72649)

	* <font color="#dd0000">**修改出参**：</font>Data


修改数据结构：

* [ClbObject](https://cloud.tencent.com/document/api/627/53609#ClbObject)

	* 新增成员：Proxy, IpHeaders, BotStatus, ApiStatus, ObjectFlowMode


### 第 92 次发布

发布时间：2024-07-03 01:28:45

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeDomainRules](https://cloud.tencent.com/document/api/627/99701)

	* <font color="#dd0000">**修改出参**：</font>Rules


### 第 91 次发布

发布时间：2024-07-02 01:27:59

本次发布包含了以下内容：

改善已有的文档。

<font color="#dd0000">**删除接口**：</font>

* ModifyAccessPeriod

### 第 90 次发布

发布时间：2024-06-25 01:27:00

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [AddAreaBanAreas](https://cloud.tencent.com/document/api/627/107677)

### 第 89 次发布

发布时间：2024-06-20 02:34:10

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeAccessFastAnalysis](https://cloud.tencent.com/document/api/627/60014)

	* <font color="#dd0000">**修改入参**：</font>TopicId

	* 新增出参：FieldValueRatioInfos, TotalCount


新增数据结构：

* [AccessFieldValueRatioInfo](https://cloud.tencent.com/document/api/627/53609#AccessFieldValueRatioInfo)

### 第 88 次发布

发布时间：2024-06-17 02:33:30

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeAreaBanAreas](https://cloud.tencent.com/document/api/627/107303)

新增数据结构：

* [DescribeAreaBanAreasRsp](https://cloud.tencent.com/document/api/627/53609#DescribeAreaBanAreasRsp)

### 第 87 次发布

发布时间：2024-06-13 02:48:34

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeAreaBanSupportAreas](https://cloud.tencent.com/document/api/627/107228)
* [ModifyAreaBanAreas](https://cloud.tencent.com/document/api/627/107229)

### 第 86 次发布

发布时间：2024-06-06 02:53:14

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeAntiFakeRules](https://cloud.tencent.com/document/api/627/97641)

	* 新增出参：Total


### 第 85 次发布

发布时间：2024-06-04 02:34:05

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [ModifyApiSecEventChange](https://cloud.tencent.com/document/api/627/106776)

新增数据结构：

* [ApiSecKey](https://cloud.tencent.com/document/api/627/53609#ApiSecKey)

### 第 84 次发布

发布时间：2024-05-31 02:29:01

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [AddCustomRule](https://cloud.tencent.com/document/api/627/53608)

	* 新增入参：JobType, JobDateTime, Source, Label, Status, PageId

	* <font color="#dd0000">**修改入参**：</font>ExpireTime

* [AddCustomWhiteRule](https://cloud.tencent.com/document/api/627/90325)

	* 新增入参：JobType, JobDateTime

* [AddSpartaProtection](https://cloud.tencent.com/document/api/627/72689)

	* 新增入参：ProbeStatus

* [DeleteCustomRule](https://cloud.tencent.com/document/api/627/97444)

	* 新增入参：DomainRuleIdList

	* 新增出参：Success

* [DescribeCustomRuleList](https://cloud.tencent.com/document/api/627/97443)

	* 新增入参：DomainList

* [ModifyCustomRule](https://cloud.tencent.com/document/api/627/97442)

	* 新增入参：JobType, JobDateTime, Source, Status, PageId

	* 新增出参：Success

* [ModifyCustomRuleStatus](https://cloud.tencent.com/document/api/627/53599)

	* 新增入参：DomainRuleIdList

* [ModifyCustomWhiteRule](https://cloud.tencent.com/document/api/627/90323)

	* 新增入参：JobType, JobDateTime

* [ModifySpartaProtection](https://cloud.tencent.com/document/api/627/94309)

	* 新增入参：ProbeStatus

* [UpsertCCRule](https://cloud.tencent.com/document/api/627/97646)

	* 新增入参：CreateTime


新增数据结构：

* [CronJob](https://cloud.tencent.com/document/api/627/53609#CronJob)
* [DomainRuleId](https://cloud.tencent.com/document/api/627/53609#DomainRuleId)
* [JobDateTime](https://cloud.tencent.com/document/api/627/53609#JobDateTime)
* [MiniExtendPkg](https://cloud.tencent.com/document/api/627/53609#MiniExtendPkg)
* [TimedJob](https://cloud.tencent.com/document/api/627/53609#TimedJob)

修改数据结构：

* [BatchIpAccessControlItem](https://cloud.tencent.com/document/api/627/53609#BatchIpAccessControlItem)

	* 新增成员：CreateTime

* [CCRuleItems](https://cloud.tencent.com/document/api/627/53609#CCRuleItems)

	* 新增成员：CreateTime

* [CacheUrlItems](https://cloud.tencent.com/document/api/627/53609#CacheUrlItems)

	* 新增成员：ModifyTime, CreateTime

* [DescribeAntiLeakageItem](https://cloud.tencent.com/document/api/627/53609#DescribeAntiLeakageItem)

	* 新增成员：ModifyTime

* [DescribeCustomRulesRspRuleListItem](https://cloud.tencent.com/document/api/627/53609#DescribeCustomRulesRspRuleListItem)

	* 新增成员：JobType, JobDateTime, CronType, Label, PageId, Domain

* [InstanceInfo](https://cloud.tencent.com/document/api/627/53609#InstanceInfo)

	* 新增成员：MiniExtendPkg, BillingItem

* [IpAccessControlItem](https://cloud.tencent.com/document/api/627/53609#IpAccessControlItem)

	* 新增成员：CreateTime

* [RuleList](https://cloud.tencent.com/document/api/627/53609#RuleList)

	* 新增成员：CreateTime

* [UserDomainInfo](https://cloud.tencent.com/document/api/627/53609#UserDomainInfo)

	* 新增成员：AlbType, BotStatus, ApiStatus


### 第 83 次发布

发布时间：2024-05-08 19:38:01

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateIpAccessControl](https://cloud.tencent.com/document/api/627/105915)
* [DeleteIpAccessControlV2](https://cloud.tencent.com/document/api/627/105914)
* [ImportIpAccessControl](https://cloud.tencent.com/document/api/627/105913)
* [ModifyIpAccessControl](https://cloud.tencent.com/document/api/627/105912)

新增数据结构：

* [IpAccessControlParam](https://cloud.tencent.com/document/api/627/53609#IpAccessControlParam)

### 第 82 次发布

发布时间：2024-03-20 01:31:28

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [AddSpartaProtection](https://cloud.tencent.com/document/api/627/72689)

	* 新增入参：ProxyBuffer

	* <font color="#dd0000">**修改入参**：</font>Ports, IsKeepAlive, InstanceID

* [DescribeAttackOverview](https://cloud.tencent.com/document/api/627/87744)

	* 新增出参：ApiRiskEventCircleCount

* [DescribeIpAccessControl](https://cloud.tencent.com/document/api/627/72645)

	* 新增入参：RuleId

	* 新增出参：UsedTotal

* [ModifyAccessPeriod](https://cloud.tencent.com/document/api/#/#)

	* <font color="#dd0000">**修改入参**：</font>TopicId

* [ModifySpartaProtection](https://cloud.tencent.com/document/api/627/94309)

	* 新增入参：ProxyBuffer

	* <font color="#dd0000">**修改入参**：</font>DomainId, InstanceID


修改数据结构：

* [BatchIpAccessControlItem](https://cloud.tencent.com/document/api/627/53609#BatchIpAccessControlItem)

	* 新增成员：RuleId, IpList

* [DomainInfo](https://cloud.tencent.com/document/api/627/53609#DomainInfo)

	* 新增成员：AccessStatus

* [DomainsPartInfo](https://cloud.tencent.com/document/api/627/53609#DomainsPartInfo)

	* 新增成员：ProxyBuffer

* [IpAccessControlItem](https://cloud.tencent.com/document/api/627/53609#IpAccessControlItem)

	* 新增成员：RuleId, IpList


### 第 81 次发布

发布时间：2024-03-18 01:26:30

本次发布包含了以下内容：

改善已有的文档。

<font color="#dd0000">**删除接口**：</font>

* DescribeWafInfo

<font color="#dd0000">**删除数据结构**：</font>

* ClbHostResult
* ClbHostsParams

### 第 80 次发布

发布时间：2024-03-01 01:29:13

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateDeals](https://cloud.tencent.com/document/api/627/104041)

新增数据结构：

* [CreateDealsGoods](https://cloud.tencent.com/document/api/627/53609#CreateDealsGoods)
* [CreateDealsGoodsDetail](https://cloud.tencent.com/document/api/627/53609#CreateDealsGoodsDetail)

### 第 79 次发布

发布时间：2024-01-26 01:25:28

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [ModifyDomainPostAction](https://cloud.tencent.com/document/api/627/103434)

### 第 78 次发布

发布时间：2024-01-24 17:54:43

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [AddAttackWhiteRule](https://cloud.tencent.com/document/api/627/100203)

	* 新增入参：SignatureIds

	* <font color="#dd0000">**修改入参**：</font>SignatureId

* [AddSpartaProtection](https://cloud.tencent.com/document/api/627/72689)

	* 新增入参：Note, UpstreamHost

* [DeleteIpAccessControl](https://cloud.tencent.com/document/api/627/72648)

	* 新增入参：ActionType

* [DescribeWafAutoDenyRules](https://cloud.tencent.com/document/api/627/72643)

	* 新增出参：Source

* [ModifyAttackWhiteRule](https://cloud.tencent.com/document/api/627/100200)

	* 新增入参：SignatureIds

	* <font color="#dd0000">**修改入参**：</font>SignatureId

* [ModifyBotStatus](https://cloud.tencent.com/document/api/627/97281)

	* 新增入参：DomainList

	* <font color="#dd0000">**修改入参**：</font>Domain

	* 新增出参：UnSupportedList, FailDomainList, Count

* [ModifyObject](https://cloud.tencent.com/document/api/627/100164)

	* 新增入参：Proxy, IpHeaders

* [ModifySpartaProtection](https://cloud.tencent.com/document/api/627/94309)

	* 新增入参：Note, UpstreamHost


修改数据结构：

* [ClbDomainsInfo](https://cloud.tencent.com/document/api/627/53609#ClbDomainsInfo)

	* 新增成员：Note

* [DomainInfo](https://cloud.tencent.com/document/api/627/53609#DomainInfo)

	* 新增成员：Note, SrcList, UpstreamDomainList, SgID

* [DomainsPartInfo](https://cloud.tencent.com/document/api/627/53609#DomainsPartInfo)

	* 新增成员：Note, UpstreamHost, Level

* [HostRecord](https://cloud.tencent.com/document/api/627/53609#HostRecord)

	* 新增成员：Note

* [PeakPointsItem](https://cloud.tencent.com/document/api/627/53609#PeakPointsItem)

	* 新增成员：WxCount, WxUp, WxDown


### 第 77 次发布

发布时间：2023-12-26 02:05:35

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [InstanceInfo](https://cloud.tencent.com/document/api/627/53609#InstanceInfo)

	* 新增成员：LastQpsExceedTime


### 第 76 次发布

发布时间：2023-12-07 02:50:53

本次发布包含了以下内容：

改善已有的文档。

新增数据结构：

* [MiniPkg](https://cloud.tencent.com/document/api/627/53609#MiniPkg)

修改数据结构：

* [BotQPS](https://cloud.tencent.com/document/api/627/53609#BotQPS)

	* <font color="#dd0000">**修改成员**：</font>RenewFlag

* [InstanceInfo](https://cloud.tencent.com/document/api/627/53609#InstanceInfo)

	* 新增成员：MiniPkg, MiniQpsStandard, MiniMaxQPS


### 第 75 次发布

发布时间：2023-11-21 01:41:48

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeIpAccessControl](https://cloud.tencent.com/document/api/627/72645)

	* 新增入参：ValidTimeStampMin, ValidTimeStampMax

* [DescribeIpHitItems](https://cloud.tencent.com/document/api/627/72644)

	* 新增入参：ValidTimeStampMin, ValidTimeStampMax

* [DescribeModuleStatus](https://cloud.tencent.com/document/api/627/101340)

	* 新增出参：RateLimit

* [ModifyModuleStatus](https://cloud.tencent.com/document/api/627/99699)

	* 新增入参：RateLimit

* [UpsertIpAccessControl](https://cloud.tencent.com/document/api/627/72636)

	* 新增出参：Ids

* [UpsertSession](https://cloud.tencent.com/document/api/627/97645)

	* 新增出参：SessionID


修改数据结构：

* [AccessHistogramItem](https://cloud.tencent.com/document/api/627/53609#AccessHistogramItem)

	* 新增成员：BeginTime

* [ClbObject](https://cloud.tencent.com/document/api/627/53609#ClbObject)

	* 新增成员：Type, Region

* [DescribeCustomRulesRspRuleListItem](https://cloud.tencent.com/document/api/627/53609#DescribeCustomRulesRspRuleListItem)

	* 新增成员：ModifyTime, ValidStatus, Source

* [PeakPointsItem](https://cloud.tencent.com/document/api/627/53609#PeakPointsItem)

	* 新增成员：WxAccess


### 第 74 次发布

发布时间：2023-11-16 17:58:08

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [SessionItem](https://cloud.tencent.com/document/api/627/53609#SessionItem)

	* 新增成员：SessionId, SessionName, SessionInUsed, RelatedRuleID


### 第 73 次发布

发布时间：2023-11-14 15:28:58

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeCCAutoStatus](https://cloud.tencent.com/document/api/627/101568)
* [UpsertCCAutoStatus](https://cloud.tencent.com/document/api/627/101567)

<font color="#dd0000">**删除接口**：</font>

* ModifyWafAutoDenyStatus

修改接口：

* [DescribeCCRuleList](https://cloud.tencent.com/document/api/627/97636)

	* 新增出参：Data


新增数据结构：

* [CCRuleItems](https://cloud.tencent.com/document/api/627/53609#CCRuleItems)
* [CCRuleLists](https://cloud.tencent.com/document/api/627/53609#CCRuleLists)

修改数据结构：

* [ApiPkg](https://cloud.tencent.com/document/api/627/53609#ApiPkg)

	* <font color="#dd0000">**删除成员**：</font>APICPWaf, APINPWaf


### 第 72 次发布

发布时间：2023-11-08 10:49:05

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeModuleStatus](https://cloud.tencent.com/document/api/627/101340)

	* 新增入参：Domain

	* 新增出参：WebSecurity, AccessControl, CcProtection, AntiTamper, AntiLeakage, ApiProtection

* [ModifyModuleStatus](https://cloud.tencent.com/document/api/627/99699)

	* 新增入参：Domain, WebSecurity, AccessControl, CcProtection, ApiProtection, AntiTamper, AntiLeakage


### 第 71 次发布

发布时间：2023-11-08 02:29:51

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeCCRuleList](https://cloud.tencent.com/document/api/627/97636)

	* 新增入参：Domain, Offset, Limit, By, Filters, Order


### 第 70 次发布

发布时间：2023-11-07 02:47:21

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeModuleStatus](https://cloud.tencent.com/document/api/627/101340)

新增数据结构：

* [ApiPkg](https://cloud.tencent.com/document/api/627/53609#ApiPkg)

修改数据结构：

* [BotPkg](https://cloud.tencent.com/document/api/627/53609#BotPkg)

	* 新增成员：IsBotTrial

* [InstanceInfo](https://cloud.tencent.com/document/api/627/53609#InstanceInfo)

	* 新增成员：ApiPkg


### 第 69 次发布

发布时间：2023-11-03 01:27:06

本次发布包含了以下内容：

改善已有的文档。

<font color="#dd0000">**预下线接口**：</font>

* DescribeAntiFakeUrl
* DescribeCCRule

### 第 68 次发布

发布时间：2023-11-01 01:26:18

本次发布包含了以下内容：

改善已有的文档。

<font color="#dd0000">**预下线接口**：</font>

* DeleteDownloadRecord

### 第 67 次发布

发布时间：2023-10-27 02:33:14

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeAntiInfoLeakageRules](https://cloud.tencent.com/document/api/627/97638)

	* 新增入参：Offset, Limit, Order, Filters


### 第 66 次发布

发布时间：2023-10-26 01:28:51

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [ModifyGenerateDeals](https://cloud.tencent.com/document/api/627/100753)

新增数据结构：

* [Goods](https://cloud.tencent.com/document/api/627/53609#Goods)
* [GoodsDetail](https://cloud.tencent.com/document/api/627/53609#GoodsDetail)
* [ProductInfo](https://cloud.tencent.com/document/api/627/53609#ProductInfo)

### 第 65 次发布

发布时间：2023-10-19 16:23:29

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeSpartaProtectionInfo](https://cloud.tencent.com/document/api/627/100463)
* [DescribeUserLevel](https://cloud.tencent.com/document/api/627/100462)
* [DescribeWebshellStatus](https://cloud.tencent.com/document/api/627/100464)

修改接口：

* [DescribeUserClbWafRegions](https://cloud.tencent.com/document/api/627/53600)

	* 新增出参：RichDatas


新增数据结构：

* [ClbWafRegionItem](https://cloud.tencent.com/document/api/627/53609#ClbWafRegionItem)

修改数据结构：

* [DomainURI](https://cloud.tencent.com/document/api/627/53609#DomainURI)

	* 新增成员：InstanceID


### 第 64 次发布

发布时间：2023-10-17 01:32:14

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeAttackType](https://cloud.tencent.com/document/api/627/100324)
* [DescribeHistogram](https://cloud.tencent.com/document/api/627/100323)
* [DescribeTopAttackDomain](https://cloud.tencent.com/document/api/627/100322)

新增数据结构：

* [KVInt](https://cloud.tencent.com/document/api/627/53609#KVInt)
* [PiechartItem](https://cloud.tencent.com/document/api/627/53609#PiechartItem)

### 第 63 次发布

发布时间：2023-10-13 01:29:06

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [AddAttackWhiteRule](https://cloud.tencent.com/document/api/627/100203)
* [DeleteAttackWhiteRule](https://cloud.tencent.com/document/api/627/100202)
* [DescribeAttackWhiteRule](https://cloud.tencent.com/document/api/627/100201)
* [ModifyAttackWhiteRule](https://cloud.tencent.com/document/api/627/100200)

新增数据结构：

* [UserWhiteRule](https://cloud.tencent.com/document/api/627/53609#UserWhiteRule)
* [UserWhiteRuleItem](https://cloud.tencent.com/document/api/627/53609#UserWhiteRuleItem)

### 第 62 次发布

发布时间：2023-10-12 02:58:37

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeObjects](https://cloud.tencent.com/document/api/627/100165)
* [ModifyObject](https://cloud.tencent.com/document/api/627/100164)

新增数据结构：

* [ClbObject](https://cloud.tencent.com/document/api/627/53609#ClbObject)

### 第 61 次发布

发布时间：2023-10-10 01:56:43

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeDomainRules](https://cloud.tencent.com/document/api/627/99701)
* [DescribeUserSignatureRule](https://cloud.tencent.com/document/api/627/99700)
* [ModifyModuleStatus](https://cloud.tencent.com/document/api/627/99699)
* [ModifyUserLevel](https://cloud.tencent.com/document/api/627/99698)
* [ModifyUserSignatureRule](https://cloud.tencent.com/document/api/627/99697)
* [ModifyWebshellStatus](https://cloud.tencent.com/document/api/627/99702)

新增数据结构：

* [ReqUserRule](https://cloud.tencent.com/document/api/627/53609#ReqUserRule)
* [Rule](https://cloud.tencent.com/document/api/627/53609#Rule)
* [UserSignatureRule](https://cloud.tencent.com/document/api/627/53609#UserSignatureRule)
* [WebshellStatus](https://cloud.tencent.com/document/api/627/53609#WebshellStatus)

### 第 60 次发布

发布时间：2023-10-09 01:28:10

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeCertificateVerifyResult](https://cloud.tencent.com/document/api/627/99281)

### 第 59 次发布

发布时间：2023-09-29 01:25:00

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [GoodsDetailNew](https://cloud.tencent.com/document/api/627/53609#GoodsDetailNew)

	* 新增成员：ResourceId


### 第 58 次发布

发布时间：2023-09-27 01:28:58

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [BotPkg](https://cloud.tencent.com/document/api/627/53609#BotPkg)

	* 新增成员：BotCPWaf, BotNPWaf


### 第 57 次发布

发布时间：2023-09-26 01:36:12

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [AddAntiFakeUrl](https://cloud.tencent.com/document/api/627/97644)

	* 新增出参：Id

* [AddAntiInfoLeakRules](https://cloud.tencent.com/document/api/627/97643)

	* 新增出参：RuleId

* [DeleteCCRule](https://cloud.tencent.com/document/api/627/97648)

	* 新增入参：RuleId

	* 新增出参：RuleId

* [DeleteIpAccessControl](https://cloud.tencent.com/document/api/627/72648)

	* 新增入参：IsId

* [DeleteSession](https://cloud.tencent.com/document/api/627/53602)

	* 新增入参：SessionID

* [DescribeAccessFastAnalysis](https://cloud.tencent.com/document/api/627/60014)

	* 新增入参：Sort, Count

* [DescribeAttackOverview](https://cloud.tencent.com/document/api/627/87744)

	* 新增出参：IPBlackCount, TamperCount, LeakCount

* [DescribeIpAccessControl](https://cloud.tencent.com/document/api/627/72645)

	* 新增入参：ValidStatus

* [DescribeRuleLimit](https://cloud.tencent.com/document/api/627/88452)

	* 新增入参：InstanceId

* [DescribeWafAutoDenyRules](https://cloud.tencent.com/document/api/627/72643)

	* 新增入参：InstanceId

	* 新增出参：HWState

* [UpsertCCRule](https://cloud.tencent.com/document/api/627/97646)

	* 新增入参：SessionApplied, RuleId

	* 新增出参：RuleId

* [UpsertIpAccessControl](https://cloud.tencent.com/document/api/627/72636)

	* 新增入参：InstanceId

* [UpsertSession](https://cloud.tencent.com/document/api/627/97645)

	* 新增入参：SessionName, SessionID


新增数据结构：

* [HybridPkg](https://cloud.tencent.com/document/api/627/53609#HybridPkg)
* [MajorEventsPkg](https://cloud.tencent.com/document/api/627/53609#MajorEventsPkg)

修改数据结构：

* [BatchIpAccessControlItem](https://cloud.tencent.com/document/api/627/53609#BatchIpAccessControlItem)

	* 新增成员：Id

* [InstanceInfo](https://cloud.tencent.com/document/api/627/53609#InstanceInfo)

	* 新增成员：MajorEventsPkg, HybridPkg

* [IpAccessControlItem](https://cloud.tencent.com/document/api/627/53609#IpAccessControlItem)

	* 新增成员：Id, ValidStatus

* [PeakPointsItem](https://cloud.tencent.com/document/api/627/53609#PeakPointsItem)

	* 新增成员：BlackIP, Tamper, Leak, ACL


### 第 56 次发布

发布时间：2023-09-25 01:30:53

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [DomainInfo](https://cloud.tencent.com/document/api/627/53609#DomainInfo)

	* 新增成员：CloudType


### 第 55 次发布

发布时间：2023-09-20 01:52:55

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [SwitchElasticMode](https://cloud.tencent.com/document/api/627/98703)

### 第 54 次发布

发布时间：2023-09-19 01:30:35

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [ModifyInstanceName](https://cloud.tencent.com/document/api/627/98581)

	* 新增入参：InstanceName


修改数据结构：

* [ClbDomainsInfo](https://cloud.tencent.com/document/api/627/53609#ClbDomainsInfo)

	* 新增成员：CloudType

* [HostRecord](https://cloud.tencent.com/document/api/627/53609#HostRecord)

	* 新增成员：CloudType

* [LoadBalancer](https://cloud.tencent.com/document/api/627/53609#LoadBalancer)

	* 新增成员：LoadBalancerDomain

* [LoadBalancerPackageNew](https://cloud.tencent.com/document/api/627/53609#LoadBalancerPackageNew)

	* 新增成员：LoadBalancerDomain

* [UserDomainInfo](https://cloud.tencent.com/document/api/627/53609#UserDomainInfo)

	* 新增成员：CloudType


### 第 53 次发布

发布时间：2023-09-15 18:00:58

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [ModifyInstanceElasticMode](https://cloud.tencent.com/document/api/627/98582)
* [ModifyInstanceName](https://cloud.tencent.com/document/api/627/98581)
* [ModifyInstanceQpsLimit](https://cloud.tencent.com/document/api/627/98580)
* [ModifyInstanceRenewFlag](https://cloud.tencent.com/document/api/627/98579)

### 第 52 次发布

发布时间：2023-09-14 14:35:46

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [GenerateDealsAndPayNew](https://cloud.tencent.com/document/api/627/98468)

新增数据结构：

* [DealData](https://cloud.tencent.com/document/api/627/53609#DealData)
* [GoodNews](https://cloud.tencent.com/document/api/627/53609#GoodNews)
* [GoodsDetailNew](https://cloud.tencent.com/document/api/627/53609#GoodsDetailNew)

### 第 51 次发布

发布时间：2023-09-14 02:44:37

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [GetInstanceQpsLimit](https://cloud.tencent.com/document/api/627/98204)

新增数据结构：

* [QpsData](https://cloud.tencent.com/document/api/627/53609#QpsData)

修改数据结构：

* [DomainsPartInfo](https://cloud.tencent.com/document/api/627/53609#DomainsPartInfo)

	* 新增成员：Domain, DomainId, InstanceId, Edition, InstanceName, Cert, CreateTime, Engine


### 第 50 次发布

发布时间：2023-09-13 02:45:23

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribePorts](https://cloud.tencent.com/document/api/627/98033)

### 第 49 次发布

发布时间：2023-09-08 03:00:07

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeDomainVerifyResult](https://cloud.tencent.com/document/api/627/97869)

<font color="#dd0000">**删除接口**：</font>

* AddSpartaProtectionAuto
* AddSpartaProtectionsAuto

<font color="#dd0000">**删除数据结构**：</font>

* FailedInfo

### 第 48 次发布

发布时间：2023-09-07 02:51:23

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [FreshAntiFakeUrl](https://cloud.tencent.com/document/api/627/97829)

### 第 47 次发布

发布时间：2023-08-31 10:55:43

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [AddAntiFakeUrl](https://cloud.tencent.com/document/api/627/97644)
* [AddAntiInfoLeakRules](https://cloud.tencent.com/document/api/627/97643)
* [DeleteAntiFakeUrl](https://cloud.tencent.com/document/api/627/97642)
* [DeleteAntiInfoLeakRule](https://cloud.tencent.com/document/api/627/97649)
* [DeleteCCRule](https://cloud.tencent.com/document/api/627/97648)
* [DescribeAntiFakeRules](https://cloud.tencent.com/document/api/627/97641)
* [DescribeAntiFakeUrl](https://cloud.tencent.com/document/api/627/97640)
* [DescribeAntiInfoLeakRules](https://cloud.tencent.com/document/api/627/97639)
* [DescribeAntiInfoLeakageRules](https://cloud.tencent.com/document/api/627/97638)
* [DescribeBatchIpAccessControl](https://cloud.tencent.com/document/api/627/97650)
* [DescribeCCRule](https://cloud.tencent.com/document/api/627/97637)
* [DescribeCCRuleList](https://cloud.tencent.com/document/api/627/97636)
* [DescribeSession](https://cloud.tencent.com/document/api/627/97635)
* [ModifyAntiFakeUrl](https://cloud.tencent.com/document/api/627/97634)
* [ModifyAntiFakeUrlStatus](https://cloud.tencent.com/document/api/627/97647)
* [ModifyAntiInfoLeakRuleStatus](https://cloud.tencent.com/document/api/627/97633)
* [ModifyAntiInfoLeakRules](https://cloud.tencent.com/document/api/627/97632)
* [ModifyCustomWhiteRuleStatus](https://cloud.tencent.com/document/api/627/97631)
* [UpsertCCRule](https://cloud.tencent.com/document/api/627/97646)
* [UpsertSession](https://cloud.tencent.com/document/api/627/97645)

新增数据结构：

* [BatchIpAccessControlData](https://cloud.tencent.com/document/api/627/53609#BatchIpAccessControlData)
* [BatchIpAccessControlItem](https://cloud.tencent.com/document/api/627/53609#BatchIpAccessControlItem)
* [CCRuleData](https://cloud.tencent.com/document/api/627/53609#CCRuleData)
* [CCRuleItem](https://cloud.tencent.com/document/api/627/53609#CCRuleItem)
* [CacheUrlItem](https://cloud.tencent.com/document/api/627/53609#CacheUrlItem)
* [CacheUrlItems](https://cloud.tencent.com/document/api/627/53609#CacheUrlItems)
* [DescribeAntiInfoLeakRulesRuleItem](https://cloud.tencent.com/document/api/627/53609#DescribeAntiInfoLeakRulesRuleItem)
* [DescribeAntiInfoLeakRulesStrategyItem](https://cloud.tencent.com/document/api/627/53609#DescribeAntiInfoLeakRulesStrategyItem)
* [DescribeAntiLeakageItem](https://cloud.tencent.com/document/api/627/53609#DescribeAntiLeakageItem)
* [PageInfo](https://cloud.tencent.com/document/api/627/53609#PageInfo)
* [SessionData](https://cloud.tencent.com/document/api/627/53609#SessionData)
* [SessionItem](https://cloud.tencent.com/document/api/627/53609#SessionItem)
* [StrategyForAntiInfoLeak](https://cloud.tencent.com/document/api/627/53609#StrategyForAntiInfoLeak)

### 第 46 次发布

发布时间：2023-08-28 02:53:45

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DeleteCustomRule](https://cloud.tencent.com/document/api/627/97444)
* [DescribeCustomRuleList](https://cloud.tencent.com/document/api/627/97443)
* [ModifyCustomRule](https://cloud.tencent.com/document/api/627/97442)

### 第 45 次发布

发布时间：2023-08-25 02:26:20

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [ModifyApiAnalyzeStatus](https://cloud.tencent.com/document/api/627/97282)
* [ModifyBotStatus](https://cloud.tencent.com/document/api/627/97281)

修改接口：

* [DescribeAttackOverview](https://cloud.tencent.com/document/api/627/87744)

	* 新增出参：ApiRiskEventCount


新增数据结构：

* [TargetEntity](https://cloud.tencent.com/document/api/627/53609#TargetEntity)

### 第 44 次发布

发布时间：2023-08-24 01:31:57

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [AddSpartaProtectionAuto](https://cloud.tencent.com/document/api/627/96951)
* [AddSpartaProtectionsAuto](https://cloud.tencent.com/document/api/627/96932)
* [DeleteHost](https://cloud.tencent.com/document/api/627/96950)
* [DeleteSpartaProtection](https://cloud.tencent.com/document/api/627/96949)
* [DescribeCiphersDetail](https://cloud.tencent.com/document/api/627/96948)
* [DescribeDomainCountInfo](https://cloud.tencent.com/document/api/627/96947)
* [DescribeDomainDetailsClb](https://cloud.tencent.com/document/api/627/96946)
* [DescribeFindDomainList](https://cloud.tencent.com/document/api/627/96945)
* [DescribeHost](https://cloud.tencent.com/document/api/627/96944)
* [DescribeHostLimit](https://cloud.tencent.com/document/api/627/96943)
* [DescribeHosts](https://cloud.tencent.com/document/api/627/96942)
* [DescribeTlsVersion](https://cloud.tencent.com/document/api/627/96941)
* [DescribeUserDomainInfo](https://cloud.tencent.com/document/api/627/96940)
* [DescribeWafInfo](https://cloud.tencent.com/document/api/627/96939)
* [ModifyDomainIpv6Status](https://cloud.tencent.com/document/api/627/96938)
* [ModifyDomainsCLSStatus](https://cloud.tencent.com/document/api/627/96937)
* [ModifyHost](https://cloud.tencent.com/document/api/627/96936)
* [ModifyHostFlowMode](https://cloud.tencent.com/document/api/627/96935)
* [ModifyHostMode](https://cloud.tencent.com/document/api/627/96934)
* [ModifyHostStatus](https://cloud.tencent.com/document/api/627/96933)
* [ModifyProtectionStatus](https://cloud.tencent.com/document/api/627/96931)
* [ModifySpartaProtectionMode](https://cloud.tencent.com/document/api/627/96930)
* [RefreshAccessCheckResult](https://cloud.tencent.com/document/api/627/96929)

新增数据结构：

* [ClbDomainsInfo](https://cloud.tencent.com/document/api/627/53609#ClbDomainsInfo)
* [ClbHostResult](https://cloud.tencent.com/document/api/627/53609#ClbHostResult)
* [ClbHostsParams](https://cloud.tencent.com/document/api/627/53609#ClbHostsParams)
* [DomainURI](https://cloud.tencent.com/document/api/627/53609#DomainURI)
* [FailedInfo](https://cloud.tencent.com/document/api/627/53609#FailedInfo)
* [FindAllDomainDetail](https://cloud.tencent.com/document/api/627/53609#FindAllDomainDetail)
* [HostDel](https://cloud.tencent.com/document/api/627/53609#HostDel)
* [HostStatus](https://cloud.tencent.com/document/api/627/53609#HostStatus)
* [SearchItem](https://cloud.tencent.com/document/api/627/53609#SearchItem)
* [TLSCiphers](https://cloud.tencent.com/document/api/627/53609#TLSCiphers)
* [TLSVersion](https://cloud.tencent.com/document/api/627/53609#TLSVersion)
* [UserDomainInfo](https://cloud.tencent.com/document/api/627/53609#UserDomainInfo)

### 第 43 次发布

发布时间：2023-08-22 01:23:21

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [GetAttackTotalCount](https://cloud.tencent.com/document/api/627/96829)

修改数据结构：

* [DomainsPartInfo](https://cloud.tencent.com/document/api/627/53609#DomainsPartInfo)

	* <font color="#dd0000">**修改成员**：</font>Weights, XFFReset


### 第 42 次发布

发布时间：2023-08-15 01:49:42

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [AddSpartaProtection](https://cloud.tencent.com/document/api/627/72689)

	* 新增入参：XFFReset

* [ModifySpartaProtection](https://cloud.tencent.com/document/api/627/94309)

	* 新增入参：XFFReset


修改数据结构：

* [DomainsPartInfo](https://cloud.tencent.com/document/api/627/53609#DomainsPartInfo)

	* 新增成员：XFFReset

* [InstanceInfo](https://cloud.tencent.com/document/api/627/53609#InstanceInfo)

	* 新增成员：IsAPISecurityTrial


### 第 41 次发布

发布时间：2023-07-31 01:50:43

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [GetAttackHistogram](https://cloud.tencent.com/document/api/627/95692)

新增数据结构：

* [LogHistogramInfo](https://cloud.tencent.com/document/api/627/53609#LogHistogramInfo)

### 第 40 次发布

发布时间：2023-07-28 01:59:57

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeAccessHistogram](https://cloud.tencent.com/document/api/627/95638)

新增数据结构：

* [AccessHistogramItem](https://cloud.tencent.com/document/api/627/53609#AccessHistogramItem)

### 第 39 次发布

发布时间：2023-07-25 11:27:24

本次发布包含了以下内容：

改善已有的文档。

<font color="#dd0000">**预下线接口**：</font>

* DescribeAutoDenyIP

### 第 38 次发布

发布时间：2023-07-21 01:50:55

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [AddDomainWhiteRule](https://cloud.tencent.com/document/api/627/72650)

	* <font color="#dd0000">**修改出参**：</font>Id


### 第 37 次发布

发布时间：2023-07-05 01:56:06

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [DomainInfo](https://cloud.tencent.com/document/api/627/53609#DomainInfo)

	* 新增成员：CdcClusters, ApiStatus, SgState, SgDetail


### 第 36 次发布

发布时间：2023-06-27 01:53:24

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [ModifySpartaProtection](https://cloud.tencent.com/document/api/627/94309)

新增数据结构：

* [SpartaProtectionPort](https://cloud.tencent.com/document/api/627/53609#SpartaProtectionPort)

### 第 35 次发布

发布时间：2023-05-30 01:43:58

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [PostAttackDownloadTask](https://cloud.tencent.com/document/api/627/77524)

	* 新增入参：Count

* [SearchAccessLog](https://cloud.tencent.com/document/api/627/60012)

	* 新增入参：Page

* [SearchAttackLog](https://cloud.tencent.com/document/api/627/86118)

	* 新增入参：Page


修改数据结构：

* [QPSPackageNew](https://cloud.tencent.com/document/api/627/53609#QPSPackageNew)

	* 新增成员：BillingItem


### 第 34 次发布

发布时间：2023-05-08 02:03:46

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [AddDomainWhiteRule](https://cloud.tencent.com/document/api/627/72650)

	* <font color="#dd0000">**修改入参**：</font>Domain, Rules, Url, Function, Status

	* <font color="#dd0000">**修改出参**：</font>Id

* [DeleteDomainWhiteRules](https://cloud.tencent.com/document/api/627/72649)

	* <font color="#dd0000">**修改入参**：</font>Domain, Ids

	* <font color="#dd0000">**修改出参**：</font>Data

* [ModifyDomainWhiteRule](https://cloud.tencent.com/document/api/627/72640)

	* <font color="#dd0000">**修改入参**：</font>Domain, Id, Rules, Url, Function, Status

* [SwitchDomainRules](https://cloud.tencent.com/document/api/627/86120)

	* <font color="#dd0000">**修改入参**：</font>Domain, Ids, Status


### 第 33 次发布

发布时间：2023-04-28 01:48:31

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [ModifyWafThreatenIntelligence](https://cloud.tencent.com/document/api/627/72637)

	* <font color="#dd0000">**修改入参**：</font>WafThreatenIntelligenceDetails

	* <font color="#dd0000">**修改出参**：</font>WafThreatenIntelligenceDetails


修改数据结构：

* [BotPkg](https://cloud.tencent.com/document/api/627/53609#BotPkg)

	* 新增成员：RenewFlag

* [BotQPS](https://cloud.tencent.com/document/api/627/53609#BotQPS)

	* 新增成员：RenewFlag

* [FraudPkg](https://cloud.tencent.com/document/api/627/53609#FraudPkg)

	* 新增成员：RenewFlag

* [WafThreatenIntelligenceDetails](https://cloud.tencent.com/document/api/627/53609#WafThreatenIntelligenceDetails)

	* <font color="#dd0000">**修改成员**：</font>DefenseStatus


### 第 32 次发布

发布时间：2023-04-24 01:51:56

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeAttackOverview](https://cloud.tencent.com/document/api/627/87744)

	* 新增出参：ApiAssetsCount


修改数据结构：

* [DescribeCustomRulesRspRuleListItem](https://cloud.tencent.com/document/api/627/53609#DescribeCustomRulesRspRuleListItem)

	* 新增成员：EventId

* [InstanceInfo](https://cloud.tencent.com/document/api/627/53609#InstanceInfo)

	* 新增成员：APISecurity, QpsStandard, BandwidthStandard, Status, SandboxQps


### 第 31 次发布

发布时间：2023-04-20 01:59:38

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [AddCustomWhiteRule](https://cloud.tencent.com/document/api/627/90325)
* [DeleteCustomWhiteRule](https://cloud.tencent.com/document/api/627/90324)
* [ModifyCustomWhiteRule](https://cloud.tencent.com/document/api/627/90323)

### 第 30 次发布

发布时间：2023-04-19 02:01:49

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [AddSpartaProtection](https://cloud.tencent.com/document/api/627/72689)

	* 新增入参：SniType, SniHost, IpHeaders


修改数据结构：

* [DomainsPartInfo](https://cloud.tencent.com/document/api/627/53609#DomainsPartInfo)

	* 新增成员：SniType, SniHost, Weights, IpHeaders

* [HostRecord](https://cloud.tencent.com/document/api/627/53609#HostRecord)

	* 新增成员：IpHeaders, EngineType

* [PeakPointsItem](https://cloud.tencent.com/document/api/627/53609#PeakPointsItem)

	* 新增成员：StatusServerError, StatusClientError, StatusRedirect, StatusOk, UpstreamServerError, UpstreamClientError, UpstreamRedirect

* [PortInfo](https://cloud.tencent.com/document/api/627/53609#PortInfo)

	* 新增成员：NginxServerId, Port, Protocol, UpstreamPort, UpstreamProtocol


### 第 29 次发布

发布时间：2023-04-18 01:52:40

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribePeakPoints](https://cloud.tencent.com/document/api/627/90250)
* [DescribePeakValue](https://cloud.tencent.com/document/api/627/90249)

新增数据结构：

* [PeakPointsItem](https://cloud.tencent.com/document/api/627/53609#PeakPointsItem)

### 第 28 次发布

发布时间：2023-04-05 02:09:55

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateHost](https://cloud.tencent.com/document/api/627/89906)

新增数据结构：

* [HostRecord](https://cloud.tencent.com/document/api/627/53609#HostRecord)
* [LoadBalancer](https://cloud.tencent.com/document/api/627/53609#LoadBalancer)

### 第 27 次发布

发布时间：2023-04-04 02:20:33

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeVipInfo](https://cloud.tencent.com/document/api/627/89806)

新增数据结构：

* [VipInfo](https://cloud.tencent.com/document/api/627/53609#VipInfo)

### 第 26 次发布

发布时间：2023-03-27 03:03:12

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeAttackOverview](https://cloud.tencent.com/document/api/627/87744)

	* 新增入参：FromTime, ToTime, Appid, Domain, Edition, InstanceID


### 第 25 次发布

发布时间：2023-03-14 02:20:08

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeCustomWhiteRule](https://cloud.tencent.com/document/api/627/88453)
* [DescribePolicyStatus](https://cloud.tencent.com/document/api/627/88454)
* [DescribeRuleLimit](https://cloud.tencent.com/document/api/627/88452)

新增数据结构：

* [DescribeCustomRulesRspRuleListItem](https://cloud.tencent.com/document/api/627/53609#DescribeCustomRulesRspRuleListItem)
* [WafRuleLimit](https://cloud.tencent.com/document/api/627/53609#WafRuleLimit)

### 第 24 次发布

发布时间：2023-03-03 02:02:13

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeAttackOverview](https://cloud.tencent.com/document/api/627/87744)

### 第 23 次发布

发布时间：2023-02-06 02:56:05

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [ModifyAreaBanStatus](https://cloud.tencent.com/document/api/627/86121)
* [SearchAttackLog](https://cloud.tencent.com/document/api/627/86118)
* [SwitchDomainRules](https://cloud.tencent.com/document/api/627/86120)

新增数据结构：

* [AttackLogInfo](https://cloud.tencent.com/document/api/627/53609#AttackLogInfo)

### 第 22 次发布

发布时间：2023-01-31 02:14:03

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [AddCustomRule](https://cloud.tencent.com/document/api/627/53608)

	* 新增入参：EventId


### 第 21 次发布

发布时间：2023-01-04 01:53:21

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [DomainInfo](https://cloud.tencent.com/document/api/627/53609#DomainInfo)

	* 新增成员：AlbType


### 第 20 次发布

发布时间：2022-12-21 02:20:11

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [LoadBalancerPackageNew](https://cloud.tencent.com/document/api/627/53609#LoadBalancerPackageNew)

	* 新增成员：ListenerId, ListenerName, LoadBalancerId, LoadBalancerName, Protocol, Region, Vip, Vport, Zone, NumericalVpcId, LoadBalancerType


### 第 19 次发布

发布时间：2022-12-09 02:16:48

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [AddSpartaProtection](https://cloud.tencent.com/document/api/627/72689)

	* 新增入参：ProxyReadTimeout, ProxySendTimeout


修改数据结构：

* [DomainsPartInfo](https://cloud.tencent.com/document/api/627/53609#DomainsPartInfo)

	* 新增成员：ProxyReadTimeout, ProxySendTimeout

* [InstanceInfo](https://cloud.tencent.com/document/api/627/53609#InstanceInfo)

	* 新增成员：AttackLogPost, MaxBandwidth


### 第 18 次发布

发布时间：2022-11-16 06:48:54

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeDomainDetailsSaas](https://cloud.tencent.com/document/api/627/82938)

新增数据结构：

* [DomainsPartInfo](https://cloud.tencent.com/document/api/627/53609#DomainsPartInfo)
* [LoadBalancerPackageNew](https://cloud.tencent.com/document/api/627/53609#LoadBalancerPackageNew)
* [PortInfo](https://cloud.tencent.com/document/api/627/53609#PortInfo)

修改数据结构：

* [DomainInfo](https://cloud.tencent.com/document/api/627/53609#DomainInfo)

	* 新增成员：Domain, DomainId, InstanceId, Cname, Edition, Region, InstanceName, ClsStatus, FlowMode, Status, Mode, Engine, CCList, RsList, Ports, LoadBalancerSet, AppId, State, CreateTime, Ipv6Status, BotStatus, Level, PostCLSStatus, PostCKafkaStatus


### 第 17 次发布

发布时间：2022-09-15 06:49:04

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [AddSpartaProtection](https://cloud.tencent.com/document/api/627/72689)

	* 新增入参：ActiveCheck, TLSVersion, Ciphers, CipherTemplate

* [DeleteIpAccessControl](https://cloud.tencent.com/document/api/627/72648)

	* 新增入参：SourceType

* [UpsertIpAccessControl](https://cloud.tencent.com/document/api/627/72636)

	* 新增入参：SourceType


修改数据结构：

* [InstanceInfo](https://cloud.tencent.com/document/api/627/53609#InstanceInfo)

	* 新增成员：ElasticBilling


### 第 16 次发布

发布时间：2022-09-02 07:06:31

本次发布包含了以下内容：

改善已有的文档。

新增数据结构：

* [BotQPS](https://cloud.tencent.com/document/api/627/53609#BotQPS)

修改数据结构：

* [BotPkg](https://cloud.tencent.com/document/api/627/53609#BotPkg)

	* 新增成员：Type

* [InstanceInfo](https://cloud.tencent.com/document/api/627/53609#InstanceInfo)

	* 新增成员：BotQPS


### 第 15 次发布

发布时间：2022-07-29 06:18:30

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeUserCdcClbWafRegions](https://cloud.tencent.com/document/api/627/78031)

新增数据结构：

* [CdcCluster](https://cloud.tencent.com/document/api/627/53609#CdcCluster)
* [CdcRegion](https://cloud.tencent.com/document/api/627/53609#CdcRegion)

### 第 14 次发布

发布时间：2022-07-25 06:17:49

本次发布包含了以下内容：

改善已有的文档。

<font color="#dd0000">**删除接口**：</font>

* CreateAttackDownloadTask

### 第 13 次发布

发布时间：2022-07-19 19:05:38

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [PostAttackDownloadTask](https://cloud.tencent.com/document/api/627/77524)

### 第 12 次发布

发布时间：2022-07-19 15:39:43

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [GetAttackDownloadRecords](https://cloud.tencent.com/document/api/627/77337)

	* 新增出参：Records


新增数据结构：

* [DownloadAttackRecordInfo](https://cloud.tencent.com/document/api/627/53609#DownloadAttackRecordInfo)

### 第 11 次发布

发布时间：2022-07-18 06:19:58

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [GetAttackDownloadRecords](https://cloud.tencent.com/document/api/627/77337)

### 第 10 次发布

发布时间：2022-07-14 06:19:27

本次发布包含了以下内容：

改善已有的文档。

<font color="#dd0000">**删除接口**：</font>

* DescribeCustomRules

<font color="#dd0000">**删除数据结构**：</font>

* DescribeCustomRulesPagingInfo
* DescribeCustomRulesRspRuleListItem

### 第 9 次发布

发布时间：2022-06-23 06:22:00

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeInstances](https://cloud.tencent.com/document/api/627/75922)

新增数据结构：

* [BotPkg](https://cloud.tencent.com/document/api/627/53609#BotPkg)
* [DomainPackageNew](https://cloud.tencent.com/document/api/627/53609#DomainPackageNew)
* [FraudPkg](https://cloud.tencent.com/document/api/627/53609#FraudPkg)
* [InstanceInfo](https://cloud.tencent.com/document/api/627/53609#InstanceInfo)
* [QPSPackageNew](https://cloud.tencent.com/document/api/627/53609#QPSPackageNew)

### 第 8 次发布

发布时间：2022-04-21 06:21:00

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeDomains](https://cloud.tencent.com/document/api/627/72840)

修改接口：

* [AddSpartaProtection](https://cloud.tencent.com/document/api/627/72689)

	* 新增入参：Weights


新增数据结构：

* [DomainInfo](https://cloud.tencent.com/document/api/627/53609#DomainInfo)
* [FiltersItemNew](https://cloud.tencent.com/document/api/627/53609#FiltersItemNew)

### 第 7 次发布

发布时间：2022-04-19 06:20:51

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [AddSpartaProtection](https://cloud.tencent.com/document/api/627/72689)

新增数据结构：

* [PortItem](https://cloud.tencent.com/document/api/627/53609#PortItem)

### 第 6 次发布

发布时间：2022-04-18 06:22:13

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [AddDomainWhiteRule](https://cloud.tencent.com/document/api/627/72650)
* [DeleteDomainWhiteRules](https://cloud.tencent.com/document/api/627/72649)
* [DeleteIpAccessControl](https://cloud.tencent.com/document/api/627/72648)
* [DescribeAutoDenyIP](https://cloud.tencent.com/document/api/627/72647)
* [DescribeDomainWhiteRules](https://cloud.tencent.com/document/api/627/72646)
* [DescribeIpAccessControl](https://cloud.tencent.com/document/api/627/72645)
* [DescribeIpHitItems](https://cloud.tencent.com/document/api/627/72644)
* [DescribeWafAutoDenyRules](https://cloud.tencent.com/document/api/627/72643)
* [DescribeWafAutoDenyStatus](https://cloud.tencent.com/document/api/627/72642)
* [DescribeWafThreatenIntelligence](https://cloud.tencent.com/document/api/627/72641)
* [ModifyDomainWhiteRule](https://cloud.tencent.com/document/api/627/72640)
* [ModifyWafAutoDenyRules](https://cloud.tencent.com/document/api/627/72639)
* [ModifyWafAutoDenyStatus](https://cloud.tencent.com/document/api/627/72638)
* [ModifyWafThreatenIntelligence](https://cloud.tencent.com/document/api/627/72637)
* [UpsertIpAccessControl](https://cloud.tencent.com/document/api/627/72636)

新增数据结构：

* [AutoDenyDetail](https://cloud.tencent.com/document/api/627/53609#AutoDenyDetail)
* [IpAccessControlData](https://cloud.tencent.com/document/api/627/53609#IpAccessControlData)
* [IpAccessControlItem](https://cloud.tencent.com/document/api/627/53609#IpAccessControlItem)
* [IpHitItem](https://cloud.tencent.com/document/api/627/53609#IpHitItem)
* [IpHitItemsData](https://cloud.tencent.com/document/api/627/53609#IpHitItemsData)
* [RuleList](https://cloud.tencent.com/document/api/627/53609#RuleList)
* [WafThreatenIntelligenceDetails](https://cloud.tencent.com/document/api/627/53609#WafThreatenIntelligenceDetails)

### 第 5 次发布

发布时间：2021-12-02 08:14:23

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeAccessFastAnalysis](https://cloud.tencent.com/document/api/627/60014)

	* 新增入参：TopicId, From, To, Query, FieldName


### 第 4 次发布

发布时间：2021-08-10 08:14:12

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateAccessExport](https://cloud.tencent.com/document/api/627/60017)
* [DeleteAccessExport](https://cloud.tencent.com/document/api/627/60016)
* [DescribeAccessExports](https://cloud.tencent.com/document/api/627/60015)
* [DescribeAccessFastAnalysis](https://cloud.tencent.com/document/api/627/60014)
* [DescribeAccessIndex](https://cloud.tencent.com/document/api/627/60013)
* [SearchAccessLog](https://cloud.tencent.com/document/api/627/60012)

新增数据结构：

* [AccessFullTextInfo](https://cloud.tencent.com/document/api/627/53609#AccessFullTextInfo)
* [AccessKeyValueInfo](https://cloud.tencent.com/document/api/627/53609#AccessKeyValueInfo)
* [AccessLogInfo](https://cloud.tencent.com/document/api/627/53609#AccessLogInfo)
* [AccessLogItem](https://cloud.tencent.com/document/api/627/53609#AccessLogItem)
* [AccessLogItems](https://cloud.tencent.com/document/api/627/53609#AccessLogItems)
* [AccessRuleInfo](https://cloud.tencent.com/document/api/627/53609#AccessRuleInfo)
* [AccessRuleKeyValueInfo](https://cloud.tencent.com/document/api/627/53609#AccessRuleKeyValueInfo)
* [AccessRuleTagInfo](https://cloud.tencent.com/document/api/627/53609#AccessRuleTagInfo)
* [AccessValueInfo](https://cloud.tencent.com/document/api/627/53609#AccessValueInfo)
* [ExportAccessInfo](https://cloud.tencent.com/document/api/627/53609#ExportAccessInfo)

### 第 3 次发布

发布时间：2021-07-21 08:12:02

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [ModifyAccessPeriod](https://cloud.tencent.com/document/api/#/#)

### 第 2 次发布

发布时间：2021-06-03 08:11:25

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeFlowTrend](https://cloud.tencent.com/document/api/627/56620)

新增数据结构：

* [BotStatPointItem](https://cloud.tencent.com/document/api/627/53609#BotStatPointItem)

### 第 1 次发布

发布时间：2021-03-15 11:00:34

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [AddCustomRule](https://cloud.tencent.com/document/api/627/53608)
* [CreateAttackDownloadTask](https://cloud.tencent.com/document/api/627/53606)
* [DeleteAttackDownloadRecord](https://cloud.tencent.com/document/api/627/53605)
* [DeleteDownloadRecord](https://cloud.tencent.com/document/api/627/53604)
* [DeleteSession](https://cloud.tencent.com/document/api/627/53602)
* [DescribeCustomRules](https://cloud.tencent.com/document/api/627/53601)
* [DescribeUserClbWafRegions](https://cloud.tencent.com/document/api/627/53600)
* [ModifyCustomRuleStatus](https://cloud.tencent.com/document/api/627/53599)

新增数据结构：

* [DescribeCustomRulesPagingInfo](https://cloud.tencent.com/document/api/627/53609#DescribeCustomRulesPagingInfo)
* [DescribeCustomRulesRspRuleListItem](https://cloud.tencent.com/document/api/627/53609#DescribeCustomRulesRspRuleListItem)
* [ResponseCode](https://cloud.tencent.com/document/api/627/53609#ResponseCode)
* [Strategy](https://cloud.tencent.com/document/api/627/53609#Strategy)




## 企业微信汽车行业版(wav) 版本：2021-01-29

### 第 17 次发布

发布时间：2023-07-18 01:59:28

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [ClueInfoDetail](https://cloud.tencent.com/document/api/1318/56791#ClueInfoDetail)

	* 新增成员：UpdateTime


### 第 16 次发布

发布时间：2023-07-14 01:46:29

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [CustomerProfile](https://cloud.tencent.com/document/api/1318/56791#CustomerProfile)

	* 新增成员：LeadId, WxId, Position, IsBindWx, IsInvalid, InvalidType, InvalidTypeName, InvalidTime, InvalidRemark, IsLose, LoseType, LoseTypeName, LoseRemark

	* <font color="#dd0000">**修改成员**：</font>CustomerId, DealerCode, UnionId, CreateTime, UserName, Gender, Phone, AgeRangeName, JobTypeName, Address, LeadsProcessStatus, LeadType, SourceName, LeadsLevelCode, VehicleBrandCode, VehicleSeriesCode, VehicleTypeCode, VehiclePurpose, PurchaseConcern, SalesName, SalesPhone, RealArrivalTime, CompleteTestDriveTime, OrderTime, DeliveryTime, InvoiceTime, LoseTime, CreatedAtTime, ImportAtTime, DistributeTime, LeadCreateTime, Nickname, OrgIdList, Introducer, IntroducerPhone, FollowTime, NextFollowTime, EnterpriseTags, ChannelTags


### 第 15 次发布

发布时间：2023-07-11 01:55:43

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [ClueInfoDetail](https://cloud.tencent.com/document/api/1318/56791#ClueInfoDetail)

	* 新增成员：CorpShopId


### 第 14 次发布

发布时间：2023-06-30 12:15:39

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [QueryArrivalList](https://cloud.tencent.com/document/api/1318/94396)
* [QueryFollowList](https://cloud.tencent.com/document/api/1318/94395)

新增数据结构：

* [ArrivalInfo](https://cloud.tencent.com/document/api/1318/56791#ArrivalInfo)
* [FollowInfo](https://cloud.tencent.com/document/api/1318/56791#FollowInfo)

修改数据结构：

* [ClueInfoDetail](https://cloud.tencent.com/document/api/1318/56791#ClueInfoDetail)

	* 新增成员：WxId, BrandCode, BuildTime, OrderTime, ArrivalTime, DeliveryTime, FollowTime, NextFollowTime, OrgId, OrgName, Introducer, IntroducerPhone, IsBindWx, IsMerge, IsInvalid, InvalidType, InvalidTypeName, InvalidRemark, InvalidTime, DealerName, ShopId, ShopName, Position

	* <font color="#dd0000">**修改成员**：</font>LeadUserType, LeadType, ChannelId, ChannelName, SourceChannelName, Gender, CreateTime, LeadStatus, LevelCode, ImportAtTime, DistributeTime, CreateAtTime

* [CorpUserInfo](https://cloud.tencent.com/document/api/1318/56791#CorpUserInfo)

	* 新增成员：JobNumber


### 第 13 次发布

发布时间：2023-03-14 12:01:08

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [QueryCustomerProfileList](https://cloud.tencent.com/document/api/1318/88474)
* [QueryExternalContactDetailByDate](https://cloud.tencent.com/document/api/1318/88473)

新增数据结构：

* [ChannelTag](https://cloud.tencent.com/document/api/1318/56791#ChannelTag)
* [CustomerProfile](https://cloud.tencent.com/document/api/1318/56791#CustomerProfile)
* [EnterpriseTag](https://cloud.tencent.com/document/api/1318/56791#EnterpriseTag)
* [ExternalContactDetailPro](https://cloud.tencent.com/document/api/1318/56791#ExternalContactDetailPro)
* [FollowUserPro](https://cloud.tencent.com/document/api/1318/56791#FollowUserPro)
* [PurchaseConcern](https://cloud.tencent.com/document/api/1318/56791#PurchaseConcern)
* [VehiclePurpose](https://cloud.tencent.com/document/api/1318/56791#VehiclePurpose)

### 第 12 次发布

发布时间：2023-03-14 10:50:42

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [QueryClueInfoList](https://cloud.tencent.com/document/api/1318/62149)

	* 新增入参：BeginTime, EndTime


修改数据结构：

* [ClueInfoDetail](https://cloud.tencent.com/document/api/1318/56791#ClueInfoDetail)

	* 新增成员：LeadUserType, LeadType, ChannelId, ChannelName, SourceChannelName, Gender, CreateTime, LeadStatus, LevelCode, ImportAtTime, DistributeTime, CreateAtTime

* [DealerInfo](https://cloud.tencent.com/document/api/1318/56791#DealerInfo)

	* 新增成员：ProvinceCode, CityCodeList, BrandIdList


### 第 11 次发布

发布时间：2022-10-12 07:10:28

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [ClueInfoDetail](https://cloud.tencent.com/document/api/1318/56791#ClueInfoDetail)

	* 新增成员：UserName


### 第 10 次发布

发布时间：2022-04-04 07:39:05

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [QueryCrmStatistics](https://cloud.tencent.com/document/api/1318/72098)
* [QueryCustomerEventDetailStatistics](https://cloud.tencent.com/document/api/1318/72097)
* [QueryExternalUserEventList](https://cloud.tencent.com/document/api/1318/72096)
* [QueryMaterialList](https://cloud.tencent.com/document/api/1318/72095)
* [QueryStaffEventDetailStatistics](https://cloud.tencent.com/document/api/1318/72094)
* [QueryUserInfoList](https://cloud.tencent.com/document/api/1318/72093)

新增数据结构：

* [CorpUserInfo](https://cloud.tencent.com/document/api/1318/56791#CorpUserInfo)
* [CrmStatisticsData](https://cloud.tencent.com/document/api/1318/56791#CrmStatisticsData)
* [CustomerActionEventDetail](https://cloud.tencent.com/document/api/1318/56791#CustomerActionEventDetail)
* [ExternalUserEventInfo](https://cloud.tencent.com/document/api/1318/56791#ExternalUserEventInfo)
* [MaterialInfo](https://cloud.tencent.com/document/api/1318/56791#MaterialInfo)
* [SalesActionEventDetail](https://cloud.tencent.com/document/api/1318/56791#SalesActionEventDetail)

### 第 9 次发布

发布时间：2021-12-21 08:13:33

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateLead](https://cloud.tencent.com/document/api/1318/66374)
* [QueryDealerInfoList](https://cloud.tencent.com/document/api/1318/66373)
* [QueryVehicleInfoList](https://cloud.tencent.com/document/api/1318/66372)

新增数据结构：

* [DealerInfo](https://cloud.tencent.com/document/api/1318/56791#DealerInfo)
* [VehicleInfo](https://cloud.tencent.com/document/api/1318/56791#VehicleInfo)

### 第 8 次发布

发布时间：2021-09-30 08:11:50

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [QueryClueInfoList](https://cloud.tencent.com/document/api/1318/62149)

新增数据结构：

* [ClueInfoDetail](https://cloud.tencent.com/document/api/1318/56791#ClueInfoDetail)

### 第 7 次发布

发布时间：2021-09-27 08:19:04

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [ExternalContactSimpleInfo](https://cloud.tencent.com/document/api/1318/56791#ExternalContactSimpleInfo)

	* 新增成员：DepartmentIdList


### 第 6 次发布

发布时间：2021-07-29 08:00:14

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [QueryLicenseInfo](https://cloud.tencent.com/document/api/1318/59273)

新增数据结构：

* [LicenseInfo](https://cloud.tencent.com/document/api/1318/56791#LicenseInfo)

### 第 5 次发布

发布时间：2021-06-29 08:00:12

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [QueryExternalUserMappingInfo](https://cloud.tencent.com/document/api/1318/58032)

新增数据结构：

* [ExternalUserMappingInfo](https://cloud.tencent.com/document/api/1318/56791#ExternalUserMappingInfo)

### 第 4 次发布

发布时间：2021-06-21 08:00:09

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [ExternalContact](https://cloud.tencent.com/document/api/1318/56791#ExternalContact)

	* 新增成员：Phone

* [ExternalContactSimpleInfo](https://cloud.tencent.com/document/api/1318/56791#ExternalContactSimpleInfo)

	* 新增成员：SalesName


### 第 3 次发布

发布时间：2021-06-17 08:00:11

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [ChatArchivingDetail](https://cloud.tencent.com/document/api/1318/56791#ChatArchivingDetail)

	* 新增成员：BodyJson


### 第 2 次发布

发布时间：2021-06-15 08:00:03

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateChannelCode](https://cloud.tencent.com/document/api/1318/57315)
* [CreateCorpTag](https://cloud.tencent.com/document/api/1318/57314)
* [QueryActivityJoinList](https://cloud.tencent.com/document/api/1318/57313)
* [QueryActivityList](https://cloud.tencent.com/document/api/1318/57312)
* [QueryChannelCodeList](https://cloud.tencent.com/document/api/1318/57311)
* [QueryChatArchivingList](https://cloud.tencent.com/document/api/1318/57310)
* [QueryExternalContactDetail](https://cloud.tencent.com/document/api/1318/57309)
* [QueryExternalContactList](https://cloud.tencent.com/document/api/1318/57308)
* [QueryMiniAppCodeList](https://cloud.tencent.com/document/api/1318/57307)

新增数据结构：

* [ActivityDetail](https://cloud.tencent.com/document/api/1318/56791#ActivityDetail)
* [ActivityJoinDetail](https://cloud.tencent.com/document/api/1318/56791#ActivityJoinDetail)
* [ChannelCodeInnerDetail](https://cloud.tencent.com/document/api/1318/56791#ChannelCodeInnerDetail)
* [ChatArchivingDetail](https://cloud.tencent.com/document/api/1318/56791#ChatArchivingDetail)
* [ChatArchivingMsgTypeVideo](https://cloud.tencent.com/document/api/1318/56791#ChatArchivingMsgTypeVideo)
* [ExternalContact](https://cloud.tencent.com/document/api/1318/56791#ExternalContact)
* [ExternalContactSimpleInfo](https://cloud.tencent.com/document/api/1318/56791#ExternalContactSimpleInfo)
* [ExternalContactTag](https://cloud.tencent.com/document/api/1318/56791#ExternalContactTag)
* [FollowUser](https://cloud.tencent.com/document/api/1318/56791#FollowUser)
* [MiniAppCodeInfo](https://cloud.tencent.com/document/api/1318/56791#MiniAppCodeInfo)
* [TagDetailInfo](https://cloud.tencent.com/document/api/1318/56791#TagDetailInfo)
* [TagGroup](https://cloud.tencent.com/document/api/1318/56791#TagGroup)
* [TagInfo](https://cloud.tencent.com/document/api/1318/56791#TagInfo)
* [WeComTagDetail](https://cloud.tencent.com/document/api/1318/56791#WeComTagDetail)

### 第 1 次发布

发布时间：2021-06-07 14:33:31

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [QueryActivityLiveCodeList](https://cloud.tencent.com/document/api/1318/56790)

新增数据结构：

* [LiveCodeDetail](https://cloud.tencent.com/document/api/1318/56791#LiveCodeDetail)




## 数据开发治理平台 WeData(wedata) 版本：2021-08-20

### 第 101 次发布

发布时间：2024-07-25 02:32:09

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [OrganizationalFunction](https://cloud.tencent.com/document/api/1267/76336#OrganizationalFunction)

	* 新增成员：EnvType


### 第 100 次发布

发布时间：2024-07-24 02:30:53

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeOrganizationalFunctions](https://cloud.tencent.com/document/api/1267/81482)

	* 新增入参：Filters, OrderFields

* [DescribeTableSchemaInfo](https://cloud.tencent.com/document/api/1267/82542)

	* 新增入参：ProjectId


修改数据结构：

* [RuleGroupExecStrategy](https://cloud.tencent.com/document/api/1267/76336#RuleGroupExecStrategy)

	* 新增成员：DlcGroupName


### 第 99 次发布

发布时间：2024-07-02 01:28:21

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeDutyScheduleDetails](https://cloud.tencent.com/document/api/1267/107907)
* [DescribeDutyScheduleList](https://cloud.tencent.com/document/api/1267/107906)

新增数据结构：

* [Duty](https://cloud.tencent.com/document/api/1267/76336#Duty)
* [DutyPerson](https://cloud.tencent.com/document/api/1267/76336#DutyPerson)
* [DutySchedule](https://cloud.tencent.com/document/api/1267/76336#DutySchedule)
* [DutyScheduleData](https://cloud.tencent.com/document/api/1267/76336#DutyScheduleData)
* [DutyScheduleDetailsInfo](https://cloud.tencent.com/document/api/1267/76336#DutyScheduleDetailsInfo)

### 第 98 次发布

发布时间：2024-06-26 01:28:35

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [UploadResource](https://cloud.tencent.com/document/api/1267/107737)

新增数据结构：

* [UploadResourceRequestInfo](https://cloud.tencent.com/document/api/1267/76336#UploadResourceRequestInfo)
* [UserFileDTONew](https://cloud.tencent.com/document/api/1267/76336#UserFileDTONew)

### 第 97 次发布

发布时间：2024-06-20 02:35:45

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DiagnosePro](https://cloud.tencent.com/document/api/1267/105332)

	* <font color="#dd0000">**修改入参**：</font>SearchCondition, ProjectId


修改数据结构：

* [TaskAlarmInfo](https://cloud.tencent.com/document/api/1267/76336#TaskAlarmInfo)

	* 新增成员：DingDingWebHooks


### 第 96 次发布

发布时间：2024-06-19 02:35:11

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [MoveTasksToFolder](https://cloud.tencent.com/document/api/1267/107484)

修改数据结构：

* [OpsTaskCanvasInfoList](https://cloud.tencent.com/document/api/1267/76336#OpsTaskCanvasInfoList)

	* <font color="#dd0000">**修改成员**：</font>CirculateTaskList


### 第 95 次发布

发布时间：2024-06-17 02:35:04

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateTaskFolder](https://cloud.tencent.com/document/api/1267/107304)

### 第 94 次发布

发布时间：2024-06-14 03:00:16

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeTableMeta](https://cloud.tencent.com/document/api/1267/102541)

	* 新增入参：TableNameFilter, TableFilterType


新增数据结构：

* [TableMetaProperty](https://cloud.tencent.com/document/api/1267/76336#TableMetaProperty)
* [TableNameFilter](https://cloud.tencent.com/document/api/1267/76336#TableNameFilter)

修改数据结构：

* [TableMeta](https://cloud.tencent.com/document/api/1267/76336#TableMeta)

	* 新增成员：TableProperties


### 第 93 次发布

发布时间：2024-06-07 02:54:55

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [OrganizationalFunction](https://cloud.tencent.com/document/api/1267/76336#OrganizationalFunction)

	* 新增成员：OperatorUserIdsStr, OwnerUserIdsStr


### 第 92 次发布

发布时间：2024-06-06 02:55:04

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [DimensionScoreInfo](https://cloud.tencent.com/document/api/1267/76336#DimensionScoreInfo)

	* 新增成员：UserIdStr

* [RuleTemplate](https://cloud.tencent.com/document/api/1267/76336#RuleTemplate)

	* 新增成员：UserIdStr

* [SubscribeReceiver](https://cloud.tencent.com/document/api/1267/76336#SubscribeReceiver)

	* 新增成员：ReceiverUserIdStr


### 第 91 次发布

发布时间：2024-06-04 02:35:39

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [UploadContent](https://cloud.tencent.com/document/api/1267/93282)

	* 新增入参：ProjectId


### 第 90 次发布

发布时间：2024-05-29 02:30:31

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [BatchStopOpsTasks](https://cloud.tencent.com/document/api/1267/95257)

	* 新增入参：KillInstance

* [BatchStopWorkflowsByIds](https://cloud.tencent.com/document/api/1267/95232)

	* 新增入参：KillInstance

* [CreateHiveTableByDDL](https://cloud.tencent.com/document/api/1267/82524)

	* 新增入参：SchemaName

* [DescribeOperateOpsTasks](https://cloud.tencent.com/document/api/1267/95254)

	* 新增入参：InitStrategy, RequestResourceTypes

* [FreezeOpsTasks](https://cloud.tencent.com/document/api/1267/95252)

	* 新增入参：KillInstance

* [FreezeTasksByWorkflowIds](https://cloud.tencent.com/document/api/1267/95179)

	* 新增入参：KillInstance


修改数据结构：

* [DatasourceBaseInfo](https://cloud.tencent.com/document/api/1267/76336#DatasourceBaseInfo)

	* 新增成员：Category

* [InstanceOpsDto](https://cloud.tencent.com/document/api/1267/76336#InstanceOpsDto)

	* 新增成员：DeletedFatherList, CirculateInstanceList

* [OpsTaskCanvasInfoList](https://cloud.tencent.com/document/api/1267/76336#OpsTaskCanvasInfoList)

	* 新增成员：CirculateTaskList

* [OpsTaskLinkInfoDto](https://cloud.tencent.com/document/api/1267/76336#OpsTaskLinkInfoDto)

	* 新增成员：LinkStyle


### 第 89 次发布

发布时间：2024-05-07 01:30:27

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeProject](https://cloud.tencent.com/document/api/1267/76377)

	* 新增出参：Data


新增数据结构：

* [BaseClusterInfo](https://cloud.tencent.com/document/api/1267/76336#BaseClusterInfo)
* [BaseTenant](https://cloud.tencent.com/document/api/1267/76336#BaseTenant)
* [BaseUser](https://cloud.tencent.com/document/api/1267/76336#BaseUser)
* [Project](https://cloud.tencent.com/document/api/1267/76336#Project)

### 第 88 次发布

发布时间：2024-04-18 15:07:41

本次发布包含了以下内容：

改善已有的文档。

<font color="#dd0000">**删除接口**：</font>

* DescribeInstanceByCycleReport
* DescribeTaskDetail
* DescribeTasksByPage

<font color="#dd0000">**删除数据结构**：</font>

* TaskInfoData
* TaskInfoDataPage

### 第 87 次发布

发布时间：2024-04-18 01:35:09

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateWorkflowDs](https://cloud.tencent.com/document/api/1267/105331)
* [DiagnosePro](https://cloud.tencent.com/document/api/1267/105332)

新增数据结构：

* [ColumnData](https://cloud.tencent.com/document/api/1267/76336#ColumnData)
* [ColumnItem](https://cloud.tencent.com/document/api/1267/76336#ColumnItem)
* [Content](https://cloud.tencent.com/document/api/1267/76336#Content)
* [DiagnoseRep](https://cloud.tencent.com/document/api/1267/76336#DiagnoseRep)
* [Table](https://cloud.tencent.com/document/api/1267/76336#Table)

### 第 86 次发布

发布时间：2024-04-16 17:50:29

本次发布包含了以下内容：

改善已有的文档。

<font color="#dd0000">**删除接口**：</font>

* BatchCreateTaskVersionDs
* BatchDeleteTasksDs
* BatchDeleteTasksNew
* BatchModifyOwnersNew
* BatchStopTasksNew
* CheckDuplicateRuleName
* CheckDuplicateTemplateName
* CommitExportTask
* CommitRuleGroupExecResult
* CreateBaseline
* CreateFolder
* CreateOrUpdateResource
* CreateResourcePath
* CreateWorkflow
* DeleteBaseline
* DeleteFolder
* DeleteWorkflowNew
* DescribeAllTaskType
* DescribeAllUsedVersionSon
* DescribeBaselineAllTaskDag
* DescribeBaselineById
* DescribeBaselineInstanceDag
* DescribeBaselineInstanceGantt
* DescribeBaselineInstances
* DescribeBaselines
* DescribeBelongTo
* DescribeDataBases
* DescribeDataObjects
* DescribeDataSourceWithoutInfo
* DescribeDataTypes
* DescribeDependOpsTaskList
* DescribeDependTasksNew
* DescribeDiagnosticInfoByBaselineId
* DescribeDrInstanceScriptContent
* DescribeDrSonInstance
* DescribeEventDetail
* DescribeEventIsAlarmTypes
* DescribeEventTypes
* DescribeEvents
* DescribeFathers
* DescribeFolderList
* DescribeInstanceLogs
* DescribeInstances
* DescribeInstancesInfoWithTaskInfo
* DescribeMonitorsByPage
* DescribeOperateOpsTaskDatasource
* DescribeOperateOpsTaskDatasourceType
* DescribeOperateTasks
* DescribeProdTasks
* DescribeRelatedInstances
* DescribeRuleDataSources
* DescribeRuleExecExportResult
* DescribeRuleExecHistory
* DescribeRuleExecResultsByPage
* DescribeRuleGroupExecResultsByPageWithoutAuth
* DescribeRuleHistoryByPage
* DescribeRuleTablesByPage
* DescribeScheduleInstance
* DescribeSonInstances
* DescribeTaskInstance
* DescribeTaskInstanceReportDetail
* DescribeTaskInstances
* DescribeTaskReport
* DescribeTaskReportDetailList
* DescribeTemplateHistory
* DescribeWorkflowOpsCanvasInfo
* DiagnosePlus
* EditBaseline
* ForceSucInstances
* ForceSucScheduleInstances
* FreezeTasks
* FreezeTasksByMultiWorkflow
* KillInstances
* MakeUpOpsTasks
* MakeUpTasksByWorkflow
* MakeUpTasksNew
* MakeUpWorkflowNew
* ModifyBaselineAlarmStatus
* ModifyBaselineTaskAlarmStatus
* ModifyFolder
* RerunInstances
* RerunOpsMakePlanInstances
* RerunScheduleInstances
* RunTask
* StopBaseline
* SubmitBaseline

修改接口：

* [CreateTaskVersionDs](https://cloud.tencent.com/document/api/1267/101692)

	* 新增入参：EnableCheckTaskCycleLink

* [DeleteProjectUsers](https://cloud.tencent.com/document/api/1267/103141)

	* 新增入参：ProjectId, UserIds

* [DescribeDatasource](https://cloud.tencent.com/document/api/1267/80759)

	* 新增入参：Env

* [DescribeOperateOpsTasks](https://cloud.tencent.com/document/api/1267/95254)

	* 新增入参：KeyWord

* [DescribeOrganizationalFunctions](https://cloud.tencent.com/document/api/1267/81482)

	* 新增入参：EnvType

* [GenHiveTableDDLSql](https://cloud.tencent.com/document/api/1267/82483)

	* 新增入参：SinkSchemaName

* [ModifyExecStrategy](https://cloud.tencent.com/document/api/1267/82794)

	* 新增入参：TriggerTypes

* [SaveCustomFunction](https://cloud.tencent.com/document/api/1267/81481)

	* 新增入参：ProjectId, DbName, Name


<font color="#dd0000">**删除数据结构**：</font>

* AlarmDsVO
* AlarmExtDsVO
* AlarmRuleDto
* AttributeItemDsVO
* BaselineDetailResponse
* BaselineDto
* BaselineInstanceVo
* BaselineTaskDto
* BaselineTaskInfo
* BaselineTaskInstanceDto
* BatchCreateTaskVersionDsDTOLite
* BatchOperateResultDs
* BooleanResponse
* CandidateDsDTo
* CanvasInfo
* CollectionTaskOpsDto
* CreateAlarmRuleRequest
* DatasourceTypeByTaskType
* DependencyConfigDsDTONoRecurV2
* DependencyStrategyDs
* DescribeBaselineResponse
* DescribeBaselineTaskDagResponse
* DescribeDiagnosticInfoResponse
* DescribeFolderListData
* DescribeTaskInstancesData
* EventDto
* EventPage
* ExportTaskInfo
* Folder
* InstanceInfo
* InstanceLog
* InstanceReportReadNode
* InstanceReportSummary
* InstanceReportWriteNode
* Label
* ModifyAlarmRuleRequest
* OperateResult
* ParamInfoDs
* ParameterTaskDsDto
* ParameterTaskInDsDto
* ParameterTaskOutDsDto
* RuleExecExportResult
* RuleGroupMonitor
* RuleGroupMonitorPage
* RuleHistory
* RuleHistoryPage
* RuleTemplateHistory
* RuleTemplateHistoryPage
* RunnerRuleExecResult
* SearchConditionInstance
* SimpleDataSourceInfo
* SourceObject
* StringListNode
* TaskCanvasInfo
* TaskDsDTOLiteV2
* TaskDsDTONoRecurV2
* TaskExtDsVO
* TaskInfoPage
* TaskInstanceDetail
* TaskInstanceInfo
* TaskLinkDsDTO
* TaskLinkInfo
* TaskReportDetail
* TaskTypeDsVO
* TaskTypeExtDsVO
* TaskTypeExtParamDsVO
* UserFileDTO

修改数据结构：

* [CommonIdOpsDto](https://cloud.tencent.com/document/api/1267/76336#CommonIdOpsDto)

	* <font color="#dd0000">**修改成员**：</font>Id

* [DatabaseInfo](https://cloud.tencent.com/document/api/1267/76336#DatabaseInfo)

	* 新增成员：DsEnvType

* [DatasourceBaseInfo](https://cloud.tencent.com/document/api/1267/76336#DatasourceBaseInfo)

	* 新增成员：ParamsString

	* <font color="#dd0000">**修改成员**：</font>Version

* [EventCaseConsumeLogOptDto](https://cloud.tencent.com/document/api/1267/76336#EventCaseConsumeLogOptDto)

	* <font color="#dd0000">**修改成员**：</font>ConsumeLogId, EventCaseId, ConsumerId, CreationTimestamp, ConsumerDetail

* [EventCaseConsumeLogOptDtoCollection](https://cloud.tencent.com/document/api/1267/76336#EventCaseConsumeLogOptDtoCollection)

	* <font color="#dd0000">**修改成员**：</font>TotalCount, TotalPage, PageCount, PageNumber, PageSize, Items

* [EventCaseOpsDto](https://cloud.tencent.com/document/api/1267/76336#EventCaseOpsDto)

	* <font color="#dd0000">**修改成员**：</font>CaseId, Name, Dimension, CreationTimestamp, ConsumerId, Description

* [EventListenerOpsDto](https://cloud.tencent.com/document/api/1267/76336#EventListenerOpsDto)

	* <font color="#dd0000">**修改成员**：</font>EventName, Key, Type, Properties, CreationTimestamp

* [EventOpsDto](https://cloud.tencent.com/document/api/1267/76336#EventOpsDto)

	* <font color="#dd0000">**修改成员**：</font>Name, EventType, EventSubType, EventBroadcastType, DimensionFormat, TimeToLive, TimeUnit, CreationTimestamp, Owner, Properties, Description, Listeners, EventCases

* [MakePlanTaskOpsDtoCollection](https://cloud.tencent.com/document/api/1267/76336#MakePlanTaskOpsDtoCollection)

	* <font color="#dd0000">**修改成员**：</font>TotalCount, TotalPage, PageCount, PageNumber, PageSize, Items

* [OrganizationalFunction](https://cloud.tencent.com/document/api/1267/76336#OrganizationalFunction)

	* 新增成员：Tag

* [ProdSchedulerTask](https://cloud.tencent.com/document/api/1267/76336#ProdSchedulerTask)

	* 新增成员：CycleType

* [Rule](https://cloud.tencent.com/document/api/1267/76336#Rule)

	* 新增成员：DsEnvType

* [RuleExecResult](https://cloud.tencent.com/document/api/1267/76336#RuleExecResult)

	* <font color="#dd0000">**修改成员**：</font>RuleExecId, RuleGroupExecId, RuleGroupId, RuleId, RuleName, RuleType, SourceObjectDataTypeName, SourceObjectValue, ConditionExpression, ExecResultStatus, TriggerResult, CompareResult, TemplateName, QualityDim, TargetDBTableName, TargetObjectValue, TargetObjectDataType, FieldConfig, RelConditionExpr, StartTime, AlarmLevel

* [RuleGroup](https://cloud.tencent.com/document/api/1267/76336#RuleGroup)

	* 新增成员：DsEnvType

* [RuleGroupExecStrategy](https://cloud.tencent.com/document/api/1267/76336#RuleGroupExecStrategy)

	* 新增成员：TriggerTypes

* [SearchCondition](https://cloud.tencent.com/document/api/1267/76336#SearchCondition)

	* <font color="#dd0000">**修改成员**：</font>Instance

* [TableQualityDetail](https://cloud.tencent.com/document/api/1267/76336#TableQualityDetail)

	* 新增成员：DsEnvType


### 第 85 次发布

发布时间：2024-04-12 01:28:34

本次发布包含了以下内容：

改善已有的文档。

<font color="#dd0000">**删除接口**：</font>

* CreateInLongAgent
* DeleteInLongAgent
* DescribeClusterNamespaceList
* DescribeInLongAgentList
* DescribeInLongAgentTaskList
* DescribeInLongAgentVpcList
* DescribeInLongTkeClusterList
* DescribeIntegrationStatisticsAgentStatus
* DescribeStandardRuleDetailInfoList
* RestartInLongAgent
* UpdateInLongAgent

<font color="#dd0000">**删除数据结构**：</font>

* CvmAgentStatus
* InLongAgentDetail
* InLongAgentTask
* InLongTkeDetail
* Namespace

修改数据结构：

* [InstanceList](https://cloud.tencent.com/document/api/1267/76336#InstanceList)

	* <font color="#dd0000">**修改成员**：</font>CostTime, CurRunDate, CycleType, DoFlag, InCharge, LastLog, SchedulerDesc, StartTime, State, TaskId, TaskName, TryLimit

* [InstanceLogList](https://cloud.tencent.com/document/api/1267/76336#InstanceLogList)

	* <font color="#dd0000">**修改成员**：</font>TaskId, CurRunDate, Tries, LastUpdate, BrokerIp, FileSize, OriginFileName, CreateTime, InstanceLogType, TaskName, CostTime

* [IntegrationInstanceLog](https://cloud.tencent.com/document/api/1267/76336#IntegrationInstanceLog)

	* <font color="#dd0000">**修改成员**：</font>LogInfo


### 第 84 次发布

发布时间：2024-04-01 01:31:06

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateOrUpdateResource](https://cloud.tencent.com/document/api/#/#)

	* 新增入参：FileMd5


### 第 83 次发布

发布时间：2024-03-29 01:32:12

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [ExportTaskInfo](https://cloud.tencent.com/document/api/1267/76336#ExportTaskInfo)

	* 新增成员：Expire, DatasourceName, DbTableName, RuleName, RuleExecId

* [Rule](https://cloud.tencent.com/document/api/1267/76336#Rule)

	* 新增成员：TriggerCondition

* [RuleExecResult](https://cloud.tencent.com/document/api/1267/76336#RuleExecResult)

	* <font color="#dd0000">**修改成员**：</font>RuleExecId, RuleGroupExecId, RuleGroupId, RuleId, RuleName, RuleType, SourceObjectDataTypeName, SourceObjectValue, ConditionExpression, ExecResultStatus, TriggerResult, CompareResult, StartTime, AlarmLevel

* [RuleGroupExecResult](https://cloud.tencent.com/document/api/1267/76336#RuleGroupExecResult)

	* 新增成员：RuleExecResultVOList


### 第 82 次发布

发布时间：2024-03-28 01:32:09

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [TaskCanvasInfo](https://cloud.tencent.com/document/api/1267/76336#TaskCanvasInfo)

	* 新增成员：SelfDepend, ExecutorGroupId, ExecutorGroupName, RunPriority, TryLimit, RetryAble, RetryWait, LastSchedulerCommitTime, Notes, Creator, UpdateUser, UpdateUserId, YarnQueue, ExecutionTTL

	* <font color="#dd0000">**修改成员**：</font>ExecutionStartTime, ExecutionEndTime, Layer, SourceServiceId, SourceServiceType, TargetServiceId, TargetServiceType, AlarmType, CreateTime, UserId, OwnerId, TenantId


### 第 81 次发布

发布时间：2024-03-27 01:31:32

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [BatchKillIntegrationTaskInstances](https://cloud.tencent.com/document/api/1267/82538)

	* 新增出参：TaskNames

* [BatchRerunIntegrationTaskInstances](https://cloud.tencent.com/document/api/1267/82536)

	* 新增出参：TaskNames

* [CreateDataSource](https://cloud.tencent.com/document/api/1267/80762)

	* 新增入参：DevelopmentParams

* [DescribeAlarmReceiver](https://cloud.tencent.com/document/api/1267/82512)

	* 新增入参：RecordId

	* <font color="#dd0000">**修改入参**：</font>MessageId

* [ModifyDataSource](https://cloud.tencent.com/document/api/1267/80760)

	* 新增入参：DevelopmentParams


新增数据结构：

* [QuietPeriod](https://cloud.tencent.com/document/api/1267/76336#QuietPeriod)

修改数据结构：

* [AlarmEventInfo](https://cloud.tencent.com/document/api/1267/76336#AlarmEventInfo)

	* 新增成员：InQuitePeriods, RecordId

* [DataSourceInfo](https://cloud.tencent.com/document/api/1267/76336#DataSourceInfo)

	* 新增成员：ProductId, DevelopmentId, DevelopmentParams

* [MakePlanTaskOpsDto](https://cloud.tencent.com/document/api/1267/76336#MakePlanTaskOpsDto)

	* 新增成员：InstanceTotalCount

	* <font color="#dd0000">**修改成员**：</font>TaskBaseInfo, InstanceCount, CompletePercent, SuccessPercent

* [TaskAlarmInfo](https://cloud.tencent.com/document/api/1267/76336#TaskAlarmInfo)

	* 新增成员：QuietPeriods


### 第 80 次发布

发布时间：2024-03-26 01:30:25

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [ModifyTaskInfo](https://cloud.tencent.com/document/api/1267/78692)

	* 新增入参：ExecutionTTL, ScriptChange, InChargeIds


### 第 79 次发布

发布时间：2024-03-14 01:29:38

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [TableLineageInfo](https://cloud.tencent.com/document/api/1267/76336#TableLineageInfo)

	* 新增成员：DatasourceName, DatabaseName, DatabaseId

* [TableMeta](https://cloud.tencent.com/document/api/1267/76336#TableMeta)

	* 新增成员：IsPartitionTable, PartitionColumns, PartitionExpireDays


### 第 78 次发布

发布时间：2024-03-13 01:28:24

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [InstanceLifeCycleOpsDto](https://cloud.tencent.com/document/api/1267/76336#InstanceLifeCycleOpsDto)

	* 新增成员：InstanceState

	* <font color="#dd0000">**修改成员**：</font>TaskId, CurRunDate, LifeRound, RunType, Tries, InstanceLifeDetailDtoList, RunnerState, ErrorDesc, ErrorCodeLevel, InstanceLogListOpsDto

* [InstanceLifeDetailDto](https://cloud.tencent.com/document/api/1267/76336#InstanceLifeDetailDto)

	* 新增成员：DetailState, EndTime

	* <font color="#dd0000">**修改成员**：</font>State, StartTime


### 第 77 次发布

发布时间：2024-03-01 01:29:38

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [BatchDeleteIntegrationTasks](https://cloud.tencent.com/document/api/1267/82540)

	* 新增入参：Name, TaskNames

* [BatchResumeIntegrationTasks](https://cloud.tencent.com/document/api/1267/82535)

	* 新增出参：TaskNames

* [BatchStartIntegrationTasks](https://cloud.tencent.com/document/api/1267/82534)

	* 新增入参：StartTaskInfoSet

	* <font color="#dd0000">**修改入参**：</font>TaskIds

	* 新增出参：TaskNames

* [BatchStopIntegrationTasks](https://cloud.tencent.com/document/api/1267/82533)

	* 新增出参：TaskNames

* [BatchSuspendIntegrationTasks](https://cloud.tencent.com/document/api/1267/82532)

	* 新增入参：TaskNames

* [BatchUpdateIntegrationTasks](https://cloud.tencent.com/document/api/1267/82531)

	* 新增入参：TaskNames


新增数据结构：

* [StartTaskInfo](https://cloud.tencent.com/document/api/1267/76336#StartTaskInfo)

### 第 76 次发布

发布时间：2024-02-29 01:29:13

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeColumnsMeta](https://cloud.tencent.com/document/api/1267/101829)

	* 新增入参：ComplianceId

* [DescribeInstanceLogDetail](https://cloud.tencent.com/document/api/1267/95235)

	* 新增入参：StartCount, LineCount


修改数据结构：

* [ColumnBasicInfo](https://cloud.tencent.com/document/api/1267/76336#ColumnBasicInfo)

	* 新增成员：Scale

* [ColumnLineageInfo](https://cloud.tencent.com/document/api/1267/76336#ColumnLineageInfo)

	* <font color="#dd0000">**修改成员**：</font>TableId

* [ColumnMeta](https://cloud.tencent.com/document/api/1267/76336#ColumnMeta)

	* 新增成员：LevelName, LevelRank

* [CompareRule](https://cloud.tencent.com/document/api/1267/76336#CompareRule)

	* 新增成员：ComputeExpression

* [InstanceLogInfoOpsDto](https://cloud.tencent.com/document/api/1267/76336#InstanceLogInfoOpsDto)

	* 新增成员：LineCount

* [RuleGroup](https://cloud.tencent.com/document/api/1267/76336#RuleGroup)

	* 新增成员：StrategyConfig, SubscribeConfig

* [TableBasicInfo](https://cloud.tencent.com/document/api/1267/76336#TableBasicInfo)

	* 新增成员：Location

* [TableLineageInfo](https://cloud.tencent.com/document/api/1267/76336#TableLineageInfo)

	* 新增成员：DisplayType, EngineType, TableType

* [TableMeta](https://cloud.tencent.com/document/api/1267/76336#TableMeta)

	* 新增成员：MetaCrawlType, IsView, Location

	* <font color="#dd0000">**修改成员**：</font>DataSourceCategory, Columns


### 第 75 次发布

发布时间：2024-02-23 01:28:34

本次发布包含了以下内容：

改善已有的文档。

新增数据结构：

* [AttributeItemDTO](https://cloud.tencent.com/document/api/1267/76336#AttributeItemDTO)
* [InstanceLifeCycleOpsDto](https://cloud.tencent.com/document/api/1267/76336#InstanceLifeCycleOpsDto)
* [InstanceLifeDetailDto](https://cloud.tencent.com/document/api/1267/76336#InstanceLifeDetailDto)

修改数据结构：

* [InstanceLogInfo](https://cloud.tencent.com/document/api/1267/76336#InstanceLogInfo)

	* 新增成员：ExtensionInfo

	* <font color="#dd0000">**修改成员**：</font>TaskId, CurRunDate, Tries, LastUpdate, BrokerIp, FileSize, OriginFileName, CreateTime, InstanceLogType, TaskName, CostTime, InstanceStatus, CodeFileName

* [InstanceOpsDto](https://cloud.tencent.com/document/api/1267/76336#InstanceOpsDto)

	* 新增成员：RelatedInstanceList, RelatedInstanceSize, OwnerId, UserId, InstanceLifeCycleOpsDto, RetryAttempts


### 第 74 次发布

发布时间：2024-01-30 01:28:12

本次发布包含了以下内容：

改善已有的文档。

<font color="#dd0000">**删除接口**：</font>

* AcquireLock
* AnalyzeDependentTasks
* BatchCreateTaskVersionAsync
* BatchCreateVirtualTaskDs
* BatchDeleteTasksDsAsync
* BatchRunTasksDs
* BatchUpdateTasksDs
* CheckCustomFunctionPremise
* CheckTaskNameExistDs
* CheckTaskPriorityDs
* ClearRecycleTask
* CommitWorkflow
* CompareDsTaskVersionInfo
* CopyTaskDs
* CopyWorkflowDs
* CreateBrowsingHistory
* CreateFileVersion
* CreateLink
* CreatePath
* CreateProjectParamDs
* CreateResourceDirectory
* CreateScriptsImportTasksDs
* CreateTaskDs
* CreateTaskFolder
* CreateTaskInParamDs
* CreateTaskOutParamDs
* CreateTaskOutputRegistries
* CreateTaskOutputRegistry
* CreateTaskParamDs
* CreateWorkflowDs
* DeleteBatchWorkflowDs
* DeleteDsEvent
* DeleteDsEventListener
* DeleteDsEventPublisher
* DeleteEventListenerByTaskId
* DeleteLink
* DeleteProjectParamVersionDs
* DeleteRecordList
* DeleteRecycleTask
* DeleteResourcePath
* DeleteTaskFolder
* DeleteTaskInParamDs
* DeleteTaskOutParamDs
* DeleteTaskOutputRegistry
* DescribeAllParamDs
* DescribeBatchTestRun
* DescribeBrowsingHistories
* DescribeChildrenDs
* DescribeChildrenPathTrees
* DescribeCodeDetail
* DescribeCodeDetailV2
* DescribeCodeSearchAuditInfo
* DescribeCodeSearchAuditInfoV2
* DescribeCodeSearchCount
* DescribeCodeSearchInfo
* DescribeCodeSearchInfoV2
* DescribeCrontabTopNDs
* DescribeCustomFunctionVersionList
* DescribeDataDevelopTaskType
* DescribeDataTableImportProgress
* DescribeDependTasksDevDs
* DescribeDependencyTasksForProjectClone
* DescribeDependencyWorkflowForProjectClone
* DescribeDevelopmentSpaceSupportType
* DescribeDsEvent
* DescribeDsEventDetail
* DescribeDsEventListener
* DescribeDsEventListenerList
* DescribeDsEventPublisher
* DescribeDsEventPublisherList
* DescribeDsKettleServerFolderTree
* DescribeDsLatestTaskVersionInfo
* DescribeDsNotSubmitTasksAndCanRunByWorkflow
* DescribeDsTaskVersionInfo
* DescribeDsTaskVersionList
* DescribeEtlTaskType
* DescribeEventListenerByTaskId
* DescribeEventListenerTask
* DescribeExecutionLog
* DescribeFatherDatasourceInfoDs
* DescribeFileVersions
* DescribeGlobalWorkflowDs
* DescribeImportableOfflineTask
* DescribeInfoTransByTypeIdDs
* DescribeLock
* DescribeNewSqlTaskResult
* DescribeParentTask
* DescribePathTrees
* DescribeProdWorkflowCanvasInfoDs
* DescribeProjectParamDs
* DescribeProjectParamDsPage
* DescribeProjectParamVersionDs
* DescribeProjectParamVersionInfoDs
* DescribeRecordList
* DescribeRecycleTaskDetail
* DescribeRecycleTaskList
* DescribeScriptsImportTaskType
* DescribeSqlTaskResult
* DescribeTaskBindVirtualTask
* DescribeTaskDetailDs
* DescribeTaskInParamDs
* DescribeTaskLatestRunTime
* DescribeTaskListByConditionDs
* DescribeTaskOutParamDs
* DescribeTaskOutputRegistries
* DescribeTaskParamDs
* DescribeTaskParentRunTime
* DescribeTaskTypeByScriptType
* DescribeTasksForProjectClone
* DescribeTestRun
* DescribeToken
* DescribeWorkflowByFordIds
* DescribeWorkflowCanvasInfoDs
* DescribeWorkflowCanvasOpLogs
* DescribeWorkflowCanvasOperators
* DescribeWorkflowForProjectClone
* DescribeWorkflowParamDs
* DescribeWorkflowSchedulerInfoDs
* DescribeWorkflowTasksForProjectClone
* DownloadNewSqlResult
* DownloadSqlResult
* ExportDsEvent
* ExportFiles
* ExportProjectParamDs
* ExportWorkflowXml
* ExportWorkflowZip
* FindDependTaskListDs
* FindDependTaskListsDs
* FindFuzzyTasksDs
* FindTaskByRemotePath
* GetAdvanceRunParams
* GetBatchDetailErrorLog
* GetCosToken
* GetLatestAnalyseInfo
* GetLatestTestRunInfo
* GetPathTrees
* GetResourceCosPath
* GetResourcePathTree
* GetRunSonListDs
* GetTestRunTaskInstancesStatusInfo
* HeartBeat
* ImportDsEvent
* ImportFiles
* ImportOfflineTask
* ImportProjectParamDs
* ImportTableData
* ImportWorkflowXml
* ImportWorkflowZip
* JudgeResourceFile
* JudgeTaskListenEvent
* KillTasksTestRun
* ListBatchDetail
* ListBatchJob
* ModifyTaskFolder
* ModifyTaskInfoDs
* ModifyTaskLinksDs
* ModifyTaskScriptDs
* MoveFile
* MoveTasksToFolder
* PreviewDataTableCsv
* QueryWorkflowVersion
* RegisterDsEvent
* RegisterDsEventListener
* RegisterDsEventPublisher
* ReleaseLock
* RenameFile
* RenameResource
* RenameResourceFile
* RenameResourcePath
* RenameTaskDs
* RenewWorkflowDs
* RenewWorkflowFolderDs
* RenewWorkflowOwnerDs
* RenewWorkflowSchedulerInfoDs
* ReplaceProjectParamVersionDs
* RestoreRecycleTask
* RollbackCustomFunctionVersion
* SavePositionsDs
* ScriptUsedByOtherTaskDs
* StopAdhocTask
* StopTestRun
* SubmitBatchTestRun
* SubmitIntegrationTask
* SubmitPySparkTask
* SubmitPythonTask
* SubmitShellTask
* SubmitTestRun
* UpdateBatchTaskAdvancedSettings
* UpdateBatchTaskDatasource
* UpdateBatchTaskInCharge
* UpdateBatchTaskParameter
* UpdateBatchTaskParams
* UpdateBatchTaskResourceGroup
* UpdateBatchTaskSchedule
* UpdateDsEvent
* UpdateEventListener
* UpdateTaskDs
* UpdateWorkflowInfo
* UploadAdvanceRunParams
* UploadFilesDs
* UploadResource

<font color="#dd0000">**删除数据结构**：</font>

* AdhocRecordInfoDto
* AdhocSubTaskDto
* AlarmExtVO
* AlarmVO
* AnalyzeDependentTask
* AsyncResourceVO
* AttributeItemVO
* BatchCreateVirtualTaskDTO
* BatchJobVO
* BatchResultDs
* BatchTaskOperateNew
* BizParams
* BrowsingHistory
* CheckTaskNameExistResult
* CheckTaskPriorityTaskDTO
* CloneObjectDTO
* CloneTaskModeInfo
* CloneTaskModePageInfoInfo
* CodeDetailResult
* CodeMatchInfo
* CodeSearchAuditDTO
* CodeSearchAuditInfo
* CodeSearchAuditResult
* CodeSearchCountInfo
* CodeSearchInfo
* CodeSearchInfoPage
* CodeSearchResult
* CollectionEventDTO
* CollectionEventListenerTaskDTO
* CollectionParamDTO
* Columns
* CosTokenResponse
* CreateTaskOutputRegistry
* CsvReadDTO
* CsvRow
* CustomizeBusinessEntityDTO
* DeleteUserFileDTO
* DependencyConfigDsDTO
* DependencyConfigDsDTONoRecur
* DependencyConfigDsDTONoRecurV3
* DependencyStrategy
* DependencyTaskDTO
* DependencyWorkflowDTO
* DescribeLockResp
* DescribeTestRunBatchItem
* DescribeWorkflowCanvasOplogRequestFilter
* DsKettleServerFolderTreeNodeDto
* EventDsDto
* EventListenerDTO
* EventListenerNewDTO
* EventListenerTaskInfo
* EventPublisherDTO
* ExportEventDTO
* ExportFile
* ExportRequestInfo
* ImportRequestInfo
* ImportTableDTO
* KillTestRunTasksResponseResult
* LatestAnalyseInfoTask
* LatestTestRunInfoTask
* ListBatchJobPages
* NewPathDTO
* ParamDsRequest
* ParamGetTaskInstancesStatusInfoResponseInstance
* ParamGetTestRunTaskInstancesStatusInfoTask
* ParamMapDsDto
* ParamTaskDsRequest
* ParameterInfoDsDto
* ParameterVersionDsDto
* Params
* PathTreeNode
* PathTreeNodeParams
* ProjectCloneTaskInfo
* ProjectCloneTaskInfoPageNew
* ProjectCloneWorkflowInfo
* ProjectCloneWorkflowInfoPageNew
* RecycleFilePageInfo
* RecycleTaskInfo
* RecycleTaskPageInfo
* RenameResourceDTO
* RowColumn
* ScriptTypeInfo
* ShareStorageFileDTO
* ShareStorageFileMappingDTO
* SparkParameterDTO
* SubCloneObjectDTO
* TCHouseXTaskParameter
* TableHybrisReq
* TaskBaseInfo
* TaskDataRegistry
* TaskDataRegistryDTO
* TaskDatasourceDTO
* TaskDatasourceDTOPage
* TaskDsDTO
* TaskDsDTOLite
* TaskDsDTOLiteV3
* TaskDsDTONoRecur
* TaskDsDTONoRecurV3
* TaskDsDTOPage
* TaskExtVO
* TaskInfoWithInstance
* TaskParentSchedulerDependency
* TaskTypeExtParamVO
* TaskTypeExtVO
* TaskTypeVO
* TaskVersionDsDTO
* TestRunBatchItem
* UpdateBatchTaskParameterDTO
* UploadResourceRequestInfo
* UserFileDTONew
* UserFileVersionDto
* VirtualTaskInfo
* VirtualTaskInfoPage
* WorkflowCanvasOpLogResult
* WorkflowCanvasOperatorsDs
* WorkflowCanvasOplog
* WorkflowDsDTO
* WorkflowDsDTOPage
* WorkflowScheduleDtoDs
* WorkflowVersionInfo

### 第 73 次发布

发布时间：2024-01-26 01:25:54

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CheckCustomFunctionPremise](https://cloud.tencent.com/document/api/#/#)
* [ClearRecycleTask](https://cloud.tencent.com/document/api/#/#)
* [CommitWorkflow](https://cloud.tencent.com/document/api/#/#)
* [CompareDsTaskVersionInfo](https://cloud.tencent.com/document/api/#/#)
* [CopyWorkflowDs](https://cloud.tencent.com/document/api/#/#)
* [CreateBrowsingHistory](https://cloud.tencent.com/document/api/#/#)
* [CreateLink](https://cloud.tencent.com/document/api/#/#)
* [CreateResourceDirectory](https://cloud.tencent.com/document/api/#/#)
* [CreateWorkflowDs](https://cloud.tencent.com/document/api/1267/105331)
* [DeleteBatchWorkflowDs](https://cloud.tencent.com/document/api/#/#)
* [DeleteDsEvent](https://cloud.tencent.com/document/api/#/#)
* [DeleteEventListenerByTaskId](https://cloud.tencent.com/document/api/#/#)
* [DeleteRecordList](https://cloud.tencent.com/document/api/#/#)
* [DeleteRecycleTask](https://cloud.tencent.com/document/api/#/#)
* [DeleteResourcePath](https://cloud.tencent.com/document/api/#/#)
* [DescribeAllParamDs](https://cloud.tencent.com/document/api/#/#)
* [DescribeBatchTestRun](https://cloud.tencent.com/document/api/#/#)
* [DescribeCustomFunctionVersionList](https://cloud.tencent.com/document/api/#/#)
* [DescribeDataTableImportProgress](https://cloud.tencent.com/document/api/#/#)
* [DescribeDsEventDetail](https://cloud.tencent.com/document/api/#/#)
* [DescribeDsEventListener](https://cloud.tencent.com/document/api/#/#)
* [DescribeDsEventListenerList](https://cloud.tencent.com/document/api/#/#)
* [DescribeDsEventPublisher](https://cloud.tencent.com/document/api/#/#)
* [DescribeDsEventPublisherList](https://cloud.tencent.com/document/api/#/#)
* [DescribeDsLatestTaskVersionInfo](https://cloud.tencent.com/document/api/#/#)
* [DescribeDsNotSubmitTasksAndCanRunByWorkflow](https://cloud.tencent.com/document/api/#/#)
* [DescribeDsTaskVersionInfo](https://cloud.tencent.com/document/api/#/#)
* [DescribeDsTaskVersionList](https://cloud.tencent.com/document/api/#/#)
* [DescribeExecutionLog](https://cloud.tencent.com/document/api/#/#)
* [DescribeFileVersions](https://cloud.tencent.com/document/api/#/#)
* [DescribeGlobalWorkflowDs](https://cloud.tencent.com/document/api/#/#)
* [DescribeNewSqlTaskResult](https://cloud.tencent.com/document/api/#/#)
* [DescribeProdWorkflowCanvasInfoDs](https://cloud.tencent.com/document/api/#/#)
* [DescribeProjectParamDs](https://cloud.tencent.com/document/api/#/#)
* [DescribeProjectParamVersionDs](https://cloud.tencent.com/document/api/#/#)
* [DescribeRecordList](https://cloud.tencent.com/document/api/#/#)
* [DescribeRecycleTaskDetail](https://cloud.tencent.com/document/api/#/#)
* [DescribeRecycleTaskList](https://cloud.tencent.com/document/api/#/#)
* [DescribeSqlTaskResult](https://cloud.tencent.com/document/api/#/#)
* [DescribeTaskInParamDs](https://cloud.tencent.com/document/api/#/#)
* [DescribeTaskOutParamDs](https://cloud.tencent.com/document/api/#/#)
* [DescribeTaskParamDs](https://cloud.tencent.com/document/api/#/#)
* [DescribeTestRun](https://cloud.tencent.com/document/api/#/#)
* [DescribeToken](https://cloud.tencent.com/document/api/#/#)
* [DescribeWorkflowByFordIds](https://cloud.tencent.com/document/api/#/#)
* [DescribeWorkflowCanvasOperators](https://cloud.tencent.com/document/api/#/#)
* [DescribeWorkflowParamDs](https://cloud.tencent.com/document/api/#/#)
* [DownloadNewSqlResult](https://cloud.tencent.com/document/api/#/#)
* [DownloadSqlResult](https://cloud.tencent.com/document/api/#/#)
* [FindTaskByRemotePath](https://cloud.tencent.com/document/api/#/#)
* [GetLatestAnalyseInfo](https://cloud.tencent.com/document/api/#/#)
* [GetLatestTestRunInfo](https://cloud.tencent.com/document/api/#/#)
* [GetResourceCosPath](https://cloud.tencent.com/document/api/#/#)
* [ImportTableData](https://cloud.tencent.com/document/api/#/#)
* [ImportWorkflowXml](https://cloud.tencent.com/document/api/#/#)
* [ImportWorkflowZip](https://cloud.tencent.com/document/api/#/#)
* [JudgeResourceFile](https://cloud.tencent.com/document/api/#/#)
* [KillTasksTestRun](https://cloud.tencent.com/document/api/#/#)
* [PreviewDataTableCsv](https://cloud.tencent.com/document/api/#/#)
* [QueryWorkflowVersion](https://cloud.tencent.com/document/api/#/#)
* [RenameResourcePath](https://cloud.tencent.com/document/api/#/#)
* [ReplaceProjectParamVersionDs](https://cloud.tencent.com/document/api/#/#)
* [RestoreRecycleTask](https://cloud.tencent.com/document/api/#/#)
* [RollbackCustomFunctionVersion](https://cloud.tencent.com/document/api/#/#)
* [StopAdhocTask](https://cloud.tencent.com/document/api/#/#)
* [StopTestRun](https://cloud.tencent.com/document/api/#/#)
* [SubmitBatchTestRun](https://cloud.tencent.com/document/api/#/#)
* [SubmitIntegrationTask](https://cloud.tencent.com/document/api/#/#)
* [SubmitTestRun](https://cloud.tencent.com/document/api/#/#)
* [UpdateWorkflowInfo](https://cloud.tencent.com/document/api/#/#)

修改接口：

* [DeleteProjectParamDs](https://cloud.tencent.com/document/api/1267/95142)

	* <font color="#dd0000">**修改入参**：</font>ParamKey, ProjectId

* [DeleteResource](https://cloud.tencent.com/document/api/1267/81749)

	* <font color="#dd0000">**修改入参**：</font>ProjectId, ResourceId

* [DeleteTaskDs](https://cloud.tencent.com/document/api/1267/95141)

	* <font color="#dd0000">**修改入参**：</font>ProjectId


新增数据结构：

* [AdhocRecordInfoDto](https://cloud.tencent.com/document/api/1267/76336#AdhocRecordInfoDto)
* [AdhocSubTaskDto](https://cloud.tencent.com/document/api/1267/76336#AdhocSubTaskDto)
* [BizParams](https://cloud.tencent.com/document/api/1267/76336#BizParams)
* [Columns](https://cloud.tencent.com/document/api/1267/76336#Columns)
* [CsvReadDTO](https://cloud.tencent.com/document/api/1267/76336#CsvReadDTO)
* [CsvRow](https://cloud.tencent.com/document/api/1267/76336#CsvRow)
* [DescribeTestRunBatchItem](https://cloud.tencent.com/document/api/1267/76336#DescribeTestRunBatchItem)
* [ImportTableDTO](https://cloud.tencent.com/document/api/1267/76336#ImportTableDTO)
* [KillTestRunTasksResponseResult](https://cloud.tencent.com/document/api/1267/76336#KillTestRunTasksResponseResult)
* [LatestAnalyseInfoTask](https://cloud.tencent.com/document/api/1267/76336#LatestAnalyseInfoTask)
* [LatestTestRunInfoTask](https://cloud.tencent.com/document/api/1267/76336#LatestTestRunInfoTask)
* [ParameterVersionDsDto](https://cloud.tencent.com/document/api/1267/76336#ParameterVersionDsDto)
* [RecycleTaskInfo](https://cloud.tencent.com/document/api/1267/76336#RecycleTaskInfo)
* [RecycleTaskPageInfo](https://cloud.tencent.com/document/api/1267/76336#RecycleTaskPageInfo)
* [RowColumn](https://cloud.tencent.com/document/api/1267/76336#RowColumn)
* [TableHybrisReq](https://cloud.tencent.com/document/api/1267/76336#TableHybrisReq)
* [TaskVersionDsDTO](https://cloud.tencent.com/document/api/1267/76336#TaskVersionDsDTO)
* [TestRunBatchItem](https://cloud.tencent.com/document/api/1267/76336#TestRunBatchItem)
* [UserFileVersionDto](https://cloud.tencent.com/document/api/1267/76336#UserFileVersionDto)
* [WorkflowCanvasOperatorsDs](https://cloud.tencent.com/document/api/1267/76336#WorkflowCanvasOperatorsDs)
* [WorkflowDsDTOPage](https://cloud.tencent.com/document/api/1267/76336#WorkflowDsDTOPage)
* [WorkflowVersionInfo](https://cloud.tencent.com/document/api/1267/76336#WorkflowVersionInfo)

### 第 72 次发布

发布时间：2024-01-25 01:27:19

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [BatchCreateTaskVersionDs](https://cloud.tencent.com/document/api/#/#)

	* 新增入参：NeedCheckParentSubmitted

* [DescribeCodeSearchInfo](https://cloud.tencent.com/document/api/#/#)

	* 新增入参：WorkflowIds, FolderIds, DatasourceIds, FolderPaths, TaskStatus

	* <font color="#dd0000">**修改入参**：</font>SearchScopes

* [RemoveWorkflowDs](https://cloud.tencent.com/document/api/1267/95140)

	* 新增入参：DeleteScript, OperateIsInform, DeleteMode


修改数据结构：

* [OrganizationalFunction](https://cloud.tencent.com/document/api/1267/76336#OrganizationalFunction)

	* 新增成员：SchemaName, CommandFormat, OwnerName, SubmitTimestamp


### 第 71 次发布

发布时间：2024-01-24 01:40:11

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [AcquireLock](https://cloud.tencent.com/document/api/#/#)
* [AnalyzeDependentTasks](https://cloud.tencent.com/document/api/#/#)
* [BatchCreateTaskVersionAsync](https://cloud.tencent.com/document/api/#/#)
* [BatchCreateVirtualTaskDs](https://cloud.tencent.com/document/api/#/#)
* [BatchDeleteTasksDsAsync](https://cloud.tencent.com/document/api/#/#)
* [BatchRunTasksDs](https://cloud.tencent.com/document/api/#/#)
* [BatchUpdateTasksDs](https://cloud.tencent.com/document/api/#/#)
* [CheckTaskNameExistDs](https://cloud.tencent.com/document/api/#/#)
* [CheckTaskPriorityDs](https://cloud.tencent.com/document/api/#/#)
* [CopyTaskDs](https://cloud.tencent.com/document/api/#/#)
* [CreateFileVersion](https://cloud.tencent.com/document/api/#/#)
* [CreatePath](https://cloud.tencent.com/document/api/#/#)
* [CreateProjectParamDs](https://cloud.tencent.com/document/api/#/#)
* [CreateScriptsImportTasksDs](https://cloud.tencent.com/document/api/#/#)
* [CreateTaskDs](https://cloud.tencent.com/document/api/#/#)
* [CreateTaskFolder](https://cloud.tencent.com/document/api/1267/107304)
* [CreateTaskInParamDs](https://cloud.tencent.com/document/api/#/#)
* [CreateTaskOutParamDs](https://cloud.tencent.com/document/api/#/#)
* [CreateTaskOutputRegistries](https://cloud.tencent.com/document/api/#/#)
* [CreateTaskOutputRegistry](https://cloud.tencent.com/document/api/#/#)
* [CreateTaskParamDs](https://cloud.tencent.com/document/api/#/#)
* [DeleteDsEventListener](https://cloud.tencent.com/document/api/#/#)
* [DeleteDsEventPublisher](https://cloud.tencent.com/document/api/#/#)
* [DeleteLink](https://cloud.tencent.com/document/api/#/#)
* [DeleteProjectParamVersionDs](https://cloud.tencent.com/document/api/#/#)
* [DeleteTaskFolder](https://cloud.tencent.com/document/api/#/#)
* [DeleteTaskInParamDs](https://cloud.tencent.com/document/api/#/#)
* [DeleteTaskOutParamDs](https://cloud.tencent.com/document/api/#/#)
* [DeleteTaskOutputRegistry](https://cloud.tencent.com/document/api/#/#)
* [DescribeBrowsingHistories](https://cloud.tencent.com/document/api/#/#)
* [DescribeChildrenDs](https://cloud.tencent.com/document/api/#/#)
* [DescribeChildrenPathTrees](https://cloud.tencent.com/document/api/#/#)
* [DescribeCodeDetail](https://cloud.tencent.com/document/api/#/#)
* [DescribeCodeDetailV2](https://cloud.tencent.com/document/api/#/#)
* [DescribeCodeSearchAuditInfo](https://cloud.tencent.com/document/api/#/#)
* [DescribeCodeSearchAuditInfoV2](https://cloud.tencent.com/document/api/#/#)
* [DescribeCodeSearchCount](https://cloud.tencent.com/document/api/#/#)
* [DescribeCodeSearchInfo](https://cloud.tencent.com/document/api/#/#)
* [DescribeCodeSearchInfoV2](https://cloud.tencent.com/document/api/#/#)
* [DescribeCrontabTopNDs](https://cloud.tencent.com/document/api/#/#)
* [DescribeDataDevelopTaskType](https://cloud.tencent.com/document/api/#/#)
* [DescribeDependTasksDevDs](https://cloud.tencent.com/document/api/#/#)
* [DescribeDependencyTasksForProjectClone](https://cloud.tencent.com/document/api/#/#)
* [DescribeDependencyWorkflowForProjectClone](https://cloud.tencent.com/document/api/#/#)
* [DescribeDevelopmentSpaceSupportType](https://cloud.tencent.com/document/api/#/#)
* [DescribeDsEvent](https://cloud.tencent.com/document/api/#/#)
* [DescribeDsKettleServerFolderTree](https://cloud.tencent.com/document/api/#/#)
* [DescribeEtlTaskType](https://cloud.tencent.com/document/api/#/#)
* [DescribeEventListenerByTaskId](https://cloud.tencent.com/document/api/#/#)
* [DescribeEventListenerTask](https://cloud.tencent.com/document/api/#/#)
* [DescribeFatherDatasourceInfoDs](https://cloud.tencent.com/document/api/#/#)
* [DescribeImportableOfflineTask](https://cloud.tencent.com/document/api/#/#)
* [DescribeInfoTransByTypeIdDs](https://cloud.tencent.com/document/api/#/#)
* [DescribeLock](https://cloud.tencent.com/document/api/#/#)
* [DescribeParentTask](https://cloud.tencent.com/document/api/#/#)
* [DescribePathTrees](https://cloud.tencent.com/document/api/#/#)
* [DescribeProjectParamDsPage](https://cloud.tencent.com/document/api/#/#)
* [DescribeProjectParamVersionInfoDs](https://cloud.tencent.com/document/api/#/#)
* [DescribeScriptsImportTaskType](https://cloud.tencent.com/document/api/#/#)
* [DescribeTaskBindVirtualTask](https://cloud.tencent.com/document/api/#/#)
* [DescribeTaskDetailDs](https://cloud.tencent.com/document/api/#/#)
* [DescribeTaskLatestRunTime](https://cloud.tencent.com/document/api/#/#)
* [DescribeTaskListByConditionDs](https://cloud.tencent.com/document/api/#/#)
* [DescribeTaskOutputRegistries](https://cloud.tencent.com/document/api/#/#)
* [DescribeTaskParentRunTime](https://cloud.tencent.com/document/api/#/#)
* [DescribeTaskTypeByScriptType](https://cloud.tencent.com/document/api/#/#)
* [DescribeTasksForProjectClone](https://cloud.tencent.com/document/api/#/#)
* [DescribeWorkflowCanvasInfoDs](https://cloud.tencent.com/document/api/#/#)
* [DescribeWorkflowCanvasOpLogs](https://cloud.tencent.com/document/api/#/#)
* [DescribeWorkflowForProjectClone](https://cloud.tencent.com/document/api/#/#)
* [DescribeWorkflowSchedulerInfoDs](https://cloud.tencent.com/document/api/#/#)
* [DescribeWorkflowTasksForProjectClone](https://cloud.tencent.com/document/api/#/#)
* [ExportDsEvent](https://cloud.tencent.com/document/api/#/#)
* [ExportFiles](https://cloud.tencent.com/document/api/#/#)
* [ExportProjectParamDs](https://cloud.tencent.com/document/api/#/#)
* [ExportWorkflowXml](https://cloud.tencent.com/document/api/#/#)
* [ExportWorkflowZip](https://cloud.tencent.com/document/api/#/#)
* [FindDependTaskListDs](https://cloud.tencent.com/document/api/#/#)
* [FindDependTaskListsDs](https://cloud.tencent.com/document/api/#/#)
* [FindFuzzyTasksDs](https://cloud.tencent.com/document/api/#/#)
* [GetAdvanceRunParams](https://cloud.tencent.com/document/api/#/#)
* [GetBatchDetailErrorLog](https://cloud.tencent.com/document/api/#/#)
* [GetCosToken](https://cloud.tencent.com/document/api/#/#)
* [GetPathTrees](https://cloud.tencent.com/document/api/#/#)
* [GetResourcePathTree](https://cloud.tencent.com/document/api/#/#)
* [GetRunSonListDs](https://cloud.tencent.com/document/api/#/#)
* [GetTestRunTaskInstancesStatusInfo](https://cloud.tencent.com/document/api/#/#)
* [HeartBeat](https://cloud.tencent.com/document/api/#/#)
* [ImportDsEvent](https://cloud.tencent.com/document/api/#/#)
* [ImportFiles](https://cloud.tencent.com/document/api/#/#)
* [ImportOfflineTask](https://cloud.tencent.com/document/api/#/#)
* [ImportProjectParamDs](https://cloud.tencent.com/document/api/#/#)
* [JudgeTaskListenEvent](https://cloud.tencent.com/document/api/#/#)
* [ListBatchDetail](https://cloud.tencent.com/document/api/#/#)
* [ListBatchJob](https://cloud.tencent.com/document/api/#/#)
* [ModifyTaskFolder](https://cloud.tencent.com/document/api/#/#)
* [ModifyTaskInfoDs](https://cloud.tencent.com/document/api/#/#)
* [ModifyTaskLinksDs](https://cloud.tencent.com/document/api/#/#)
* [ModifyTaskScriptDs](https://cloud.tencent.com/document/api/#/#)
* [MoveFile](https://cloud.tencent.com/document/api/#/#)
* [MoveTasksToFolder](https://cloud.tencent.com/document/api/1267/107484)
* [RegisterDsEvent](https://cloud.tencent.com/document/api/#/#)
* [RegisterDsEventListener](https://cloud.tencent.com/document/api/#/#)
* [RegisterDsEventPublisher](https://cloud.tencent.com/document/api/#/#)
* [ReleaseLock](https://cloud.tencent.com/document/api/#/#)
* [RenameFile](https://cloud.tencent.com/document/api/#/#)
* [RenameResource](https://cloud.tencent.com/document/api/#/#)
* [RenameResourceFile](https://cloud.tencent.com/document/api/#/#)
* [RenameTaskDs](https://cloud.tencent.com/document/api/#/#)
* [RenewWorkflowDs](https://cloud.tencent.com/document/api/#/#)
* [RenewWorkflowFolderDs](https://cloud.tencent.com/document/api/#/#)
* [RenewWorkflowOwnerDs](https://cloud.tencent.com/document/api/#/#)
* [RenewWorkflowSchedulerInfoDs](https://cloud.tencent.com/document/api/#/#)
* [SavePositionsDs](https://cloud.tencent.com/document/api/#/#)
* [ScriptUsedByOtherTaskDs](https://cloud.tencent.com/document/api/#/#)
* [SubmitPySparkTask](https://cloud.tencent.com/document/api/#/#)
* [SubmitPythonTask](https://cloud.tencent.com/document/api/#/#)
* [SubmitShellTask](https://cloud.tencent.com/document/api/#/#)
* [UpdateBatchTaskAdvancedSettings](https://cloud.tencent.com/document/api/#/#)
* [UpdateBatchTaskDatasource](https://cloud.tencent.com/document/api/#/#)
* [UpdateBatchTaskInCharge](https://cloud.tencent.com/document/api/#/#)
* [UpdateBatchTaskParameter](https://cloud.tencent.com/document/api/#/#)
* [UpdateBatchTaskParams](https://cloud.tencent.com/document/api/#/#)
* [UpdateBatchTaskResourceGroup](https://cloud.tencent.com/document/api/#/#)
* [UpdateBatchTaskSchedule](https://cloud.tencent.com/document/api/#/#)
* [UpdateDsEvent](https://cloud.tencent.com/document/api/#/#)
* [UpdateEventListener](https://cloud.tencent.com/document/api/#/#)
* [UpdateTaskDs](https://cloud.tencent.com/document/api/#/#)
* [UploadAdvanceRunParams](https://cloud.tencent.com/document/api/#/#)
* [UploadFilesDs](https://cloud.tencent.com/document/api/#/#)
* [UploadResource](https://cloud.tencent.com/document/api/1267/107737)

新增数据结构：

* [AlarmExtVO](https://cloud.tencent.com/document/api/1267/76336#AlarmExtVO)
* [AlarmVO](https://cloud.tencent.com/document/api/1267/76336#AlarmVO)
* [AnalyzeDependentTask](https://cloud.tencent.com/document/api/1267/76336#AnalyzeDependentTask)
* [AsyncResourceVO](https://cloud.tencent.com/document/api/1267/76336#AsyncResourceVO)
* [AttributeItemVO](https://cloud.tencent.com/document/api/1267/76336#AttributeItemVO)
* [BatchCreateVirtualTaskDTO](https://cloud.tencent.com/document/api/1267/76336#BatchCreateVirtualTaskDTO)
* [BatchJobVO](https://cloud.tencent.com/document/api/1267/76336#BatchJobVO)
* [BatchResultDs](https://cloud.tencent.com/document/api/1267/76336#BatchResultDs)
* [BatchTaskOperateNew](https://cloud.tencent.com/document/api/1267/76336#BatchTaskOperateNew)
* [BrowsingHistory](https://cloud.tencent.com/document/api/1267/76336#BrowsingHistory)
* [CheckTaskNameExistResult](https://cloud.tencent.com/document/api/1267/76336#CheckTaskNameExistResult)
* [CheckTaskPriorityTaskDTO](https://cloud.tencent.com/document/api/1267/76336#CheckTaskPriorityTaskDTO)
* [CloneObjectDTO](https://cloud.tencent.com/document/api/1267/76336#CloneObjectDTO)
* [CloneTaskModeInfo](https://cloud.tencent.com/document/api/1267/76336#CloneTaskModeInfo)
* [CloneTaskModePageInfoInfo](https://cloud.tencent.com/document/api/1267/76336#CloneTaskModePageInfoInfo)
* [CodeDetailResult](https://cloud.tencent.com/document/api/1267/76336#CodeDetailResult)
* [CodeMatchInfo](https://cloud.tencent.com/document/api/1267/76336#CodeMatchInfo)
* [CodeSearchAuditDTO](https://cloud.tencent.com/document/api/1267/76336#CodeSearchAuditDTO)
* [CodeSearchAuditInfo](https://cloud.tencent.com/document/api/1267/76336#CodeSearchAuditInfo)
* [CodeSearchAuditResult](https://cloud.tencent.com/document/api/1267/76336#CodeSearchAuditResult)
* [CodeSearchCountInfo](https://cloud.tencent.com/document/api/1267/76336#CodeSearchCountInfo)
* [CodeSearchInfo](https://cloud.tencent.com/document/api/1267/76336#CodeSearchInfo)
* [CodeSearchInfoPage](https://cloud.tencent.com/document/api/1267/76336#CodeSearchInfoPage)
* [CodeSearchResult](https://cloud.tencent.com/document/api/1267/76336#CodeSearchResult)
* [CollectionEventDTO](https://cloud.tencent.com/document/api/1267/76336#CollectionEventDTO)
* [CollectionEventListenerTaskDTO](https://cloud.tencent.com/document/api/1267/76336#CollectionEventListenerTaskDTO)
* [CollectionParamDTO](https://cloud.tencent.com/document/api/1267/76336#CollectionParamDTO)
* [CosTokenResponse](https://cloud.tencent.com/document/api/1267/76336#CosTokenResponse)
* [CreateTaskOutputRegistry](https://cloud.tencent.com/document/api/1267/76336#CreateTaskOutputRegistry)
* [CustomizeBusinessEntityDTO](https://cloud.tencent.com/document/api/1267/76336#CustomizeBusinessEntityDTO)
* [DeleteUserFileDTO](https://cloud.tencent.com/document/api/1267/76336#DeleteUserFileDTO)
* [DependencyConfigDsDTO](https://cloud.tencent.com/document/api/1267/76336#DependencyConfigDsDTO)
* [DependencyConfigDsDTONoRecur](https://cloud.tencent.com/document/api/1267/76336#DependencyConfigDsDTONoRecur)
* [DependencyConfigDsDTONoRecurV3](https://cloud.tencent.com/document/api/1267/76336#DependencyConfigDsDTONoRecurV3)
* [DependencyStrategy](https://cloud.tencent.com/document/api/1267/76336#DependencyStrategy)
* [DependencyTaskDTO](https://cloud.tencent.com/document/api/1267/76336#DependencyTaskDTO)
* [DependencyWorkflowDTO](https://cloud.tencent.com/document/api/1267/76336#DependencyWorkflowDTO)
* [DescribeLockResp](https://cloud.tencent.com/document/api/1267/76336#DescribeLockResp)
* [DescribeWorkflowCanvasOplogRequestFilter](https://cloud.tencent.com/document/api/1267/76336#DescribeWorkflowCanvasOplogRequestFilter)
* [DsKettleServerFolderTreeNodeDto](https://cloud.tencent.com/document/api/1267/76336#DsKettleServerFolderTreeNodeDto)
* [EventDsDto](https://cloud.tencent.com/document/api/1267/76336#EventDsDto)
* [EventListenerDTO](https://cloud.tencent.com/document/api/1267/76336#EventListenerDTO)
* [EventListenerNewDTO](https://cloud.tencent.com/document/api/1267/76336#EventListenerNewDTO)
* [EventListenerTaskInfo](https://cloud.tencent.com/document/api/1267/76336#EventListenerTaskInfo)
* [EventPublisherDTO](https://cloud.tencent.com/document/api/1267/76336#EventPublisherDTO)
* [ExportEventDTO](https://cloud.tencent.com/document/api/1267/76336#ExportEventDTO)
* [ExportFile](https://cloud.tencent.com/document/api/1267/76336#ExportFile)
* [ExportRequestInfo](https://cloud.tencent.com/document/api/1267/76336#ExportRequestInfo)
* [ImportRequestInfo](https://cloud.tencent.com/document/api/1267/76336#ImportRequestInfo)
* [ListBatchJobPages](https://cloud.tencent.com/document/api/1267/76336#ListBatchJobPages)
* [NewPathDTO](https://cloud.tencent.com/document/api/1267/76336#NewPathDTO)
* [ParamDsRequest](https://cloud.tencent.com/document/api/1267/76336#ParamDsRequest)
* [ParamGetTaskInstancesStatusInfoResponseInstance](https://cloud.tencent.com/document/api/1267/76336#ParamGetTaskInstancesStatusInfoResponseInstance)
* [ParamGetTestRunTaskInstancesStatusInfoTask](https://cloud.tencent.com/document/api/1267/76336#ParamGetTestRunTaskInstancesStatusInfoTask)
* [ParamMapDsDto](https://cloud.tencent.com/document/api/1267/76336#ParamMapDsDto)
* [ParamTaskDsRequest](https://cloud.tencent.com/document/api/1267/76336#ParamTaskDsRequest)
* [ParameterInfoDsDto](https://cloud.tencent.com/document/api/1267/76336#ParameterInfoDsDto)
* [Params](https://cloud.tencent.com/document/api/1267/76336#Params)
* [PathTreeNode](https://cloud.tencent.com/document/api/1267/76336#PathTreeNode)
* [PathTreeNodeParams](https://cloud.tencent.com/document/api/1267/76336#PathTreeNodeParams)
* [ProjectCloneTaskInfo](https://cloud.tencent.com/document/api/1267/76336#ProjectCloneTaskInfo)
* [ProjectCloneTaskInfoPageNew](https://cloud.tencent.com/document/api/1267/76336#ProjectCloneTaskInfoPageNew)
* [ProjectCloneWorkflowInfo](https://cloud.tencent.com/document/api/1267/76336#ProjectCloneWorkflowInfo)
* [ProjectCloneWorkflowInfoPageNew](https://cloud.tencent.com/document/api/1267/76336#ProjectCloneWorkflowInfoPageNew)
* [RecycleFilePageInfo](https://cloud.tencent.com/document/api/1267/76336#RecycleFilePageInfo)
* [RenameResourceDTO](https://cloud.tencent.com/document/api/1267/76336#RenameResourceDTO)
* [ScriptTypeInfo](https://cloud.tencent.com/document/api/1267/76336#ScriptTypeInfo)
* [ShareStorageFileDTO](https://cloud.tencent.com/document/api/1267/76336#ShareStorageFileDTO)
* [ShareStorageFileMappingDTO](https://cloud.tencent.com/document/api/1267/76336#ShareStorageFileMappingDTO)
* [SparkParameterDTO](https://cloud.tencent.com/document/api/1267/76336#SparkParameterDTO)
* [SubCloneObjectDTO](https://cloud.tencent.com/document/api/1267/76336#SubCloneObjectDTO)
* [TCHouseXTaskParameter](https://cloud.tencent.com/document/api/1267/76336#TCHouseXTaskParameter)
* [TaskBaseInfo](https://cloud.tencent.com/document/api/1267/76336#TaskBaseInfo)
* [TaskDataRegistry](https://cloud.tencent.com/document/api/1267/76336#TaskDataRegistry)
* [TaskDataRegistryDTO](https://cloud.tencent.com/document/api/1267/76336#TaskDataRegistryDTO)
* [TaskDatasourceDTO](https://cloud.tencent.com/document/api/1267/76336#TaskDatasourceDTO)
* [TaskDatasourceDTOPage](https://cloud.tencent.com/document/api/1267/76336#TaskDatasourceDTOPage)
* [TaskDsDTO](https://cloud.tencent.com/document/api/1267/76336#TaskDsDTO)
* [TaskDsDTOLite](https://cloud.tencent.com/document/api/1267/76336#TaskDsDTOLite)
* [TaskDsDTOLiteV3](https://cloud.tencent.com/document/api/1267/76336#TaskDsDTOLiteV3)
* [TaskDsDTONoRecur](https://cloud.tencent.com/document/api/1267/76336#TaskDsDTONoRecur)
* [TaskDsDTONoRecurV3](https://cloud.tencent.com/document/api/1267/76336#TaskDsDTONoRecurV3)
* [TaskDsDTOPage](https://cloud.tencent.com/document/api/1267/76336#TaskDsDTOPage)
* [TaskExtVO](https://cloud.tencent.com/document/api/1267/76336#TaskExtVO)
* [TaskInfoWithInstance](https://cloud.tencent.com/document/api/1267/76336#TaskInfoWithInstance)
* [TaskParentSchedulerDependency](https://cloud.tencent.com/document/api/1267/76336#TaskParentSchedulerDependency)
* [TaskTypeExtParamVO](https://cloud.tencent.com/document/api/1267/76336#TaskTypeExtParamVO)
* [TaskTypeExtVO](https://cloud.tencent.com/document/api/1267/76336#TaskTypeExtVO)
* [TaskTypeVO](https://cloud.tencent.com/document/api/1267/76336#TaskTypeVO)
* [UpdateBatchTaskParameterDTO](https://cloud.tencent.com/document/api/1267/76336#UpdateBatchTaskParameterDTO)
* [UploadResourceRequestInfo](https://cloud.tencent.com/document/api/1267/76336#UploadResourceRequestInfo)
* [UserFileDTONew](https://cloud.tencent.com/document/api/1267/76336#UserFileDTONew)
* [VirtualTaskInfo](https://cloud.tencent.com/document/api/1267/76336#VirtualTaskInfo)
* [VirtualTaskInfoPage](https://cloud.tencent.com/document/api/1267/76336#VirtualTaskInfoPage)
* [WorkflowCanvasOpLogResult](https://cloud.tencent.com/document/api/1267/76336#WorkflowCanvasOpLogResult)
* [WorkflowCanvasOplog](https://cloud.tencent.com/document/api/1267/76336#WorkflowCanvasOplog)
* [WorkflowDsDTO](https://cloud.tencent.com/document/api/1267/76336#WorkflowDsDTO)
* [WorkflowScheduleDtoDs](https://cloud.tencent.com/document/api/1267/76336#WorkflowScheduleDtoDs)

### 第 70 次发布

发布时间：2024-01-22 01:25:42

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DeleteProjectUsers](https://cloud.tencent.com/document/api/1267/103141)

### 第 69 次发布

发布时间：2024-01-18 01:27:50

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DeleteCustomFunction](https://cloud.tencent.com/document/api/1267/81485)

	* 新增入参：FunctionName, FunctionType, DatabaseName, SchemaName, CommandFormat

	* <font color="#dd0000">**修改入参**：</font>ClusterIdentifier, FunctionId


新增数据结构：

* [SqlExpression](https://cloud.tencent.com/document/api/1267/76336#SqlExpression)
* [SqlExpressionTable](https://cloud.tencent.com/document/api/1267/76336#SqlExpressionTable)

修改数据结构：

* [BooleanResponse](https://cloud.tencent.com/document/api/1267/76336#BooleanResponse)

	* 新增成员：Code

* [InstanceReportReadNode](https://cloud.tencent.com/document/api/1267/76336#InstanceReportReadNode)

	* 新增成员：WaitWriterTime

* [InstanceReportWriteNode](https://cloud.tencent.com/document/api/1267/76336#InstanceReportWriteNode)

	* 新增成员：WaitReaderTime

* [IntegrationTaskInfo](https://cloud.tencent.com/document/api/1267/76336#IntegrationTaskInfo)

	* 新增成员：ArrangeSpaceTaskId, OfflineTaskStatus

* [Rule](https://cloud.tencent.com/document/api/1267/76336#Rule)

	* 新增成员：TableName, TableOwnerName, ExecStrategy, Subscription, CreateTime, DatasourceId, DatabaseId, MonitorStatus

* [RuleGroupExecStrategy](https://cloud.tencent.com/document/api/1267/76336#RuleGroupExecStrategy)

	* 新增成员：RuleId, RuleName

	* <font color="#dd0000">**修改成员**：</font>RuleGroupId, MonitorType, ExecQueue, ExecutorGroupId, ExecutorGroupName, Tasks, StartTime, EndTime, CycleType, DelayTime, CycleStep, TaskAction

* [RuleGroupSubscribe](https://cloud.tencent.com/document/api/1267/76336#RuleGroupSubscribe)

	* 新增成员：RuleId, RuleName

* [RuleTemplate](https://cloud.tencent.com/document/api/1267/76336#RuleTemplate)

	* 新增成员：ResolvedSqlExpression, DatasourceTypes


### 第 68 次发布

发布时间：2024-01-17 01:27:06

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateDataSource](https://cloud.tencent.com/document/api/1267/80762)

	* 新增入参：ConnectResult

* [DescribeBaselineAllTaskDag](https://cloud.tencent.com/document/api/#/#)

	* 新增入参：BaselineTaskId

* [DescribeBaselineInstanceDag](https://cloud.tencent.com/document/api/#/#)

	* 新增入参：PromiseTaskId

* [DescribeBaselineInstanceGantt](https://cloud.tencent.com/document/api/#/#)

	* 新增入参：PromiseTaskId

* [DescribeSchedulerInstanceStatus](https://cloud.tencent.com/document/api/1267/95198)

	* 新增入参：WorkflowId

* [DescribeSchedulerRunTimeInstanceCntByStatus](https://cloud.tencent.com/document/api/1267/95197)

	* 新增入参：WorkflowId, SortItem, SortType

* [DescribeSchedulerTaskCntByStatus](https://cloud.tencent.com/document/api/1267/95196)

	* 新增入参：WorkflowId

* [DescribeStatisticInstanceStatusTrendOps](https://cloud.tencent.com/document/api/1267/95193)

	* 新增入参：WorkflowId

* [DescribeTaskByCycle](https://cloud.tencent.com/document/api/1267/95192)

	* 新增入参：WorkflowId

* [DescribeTaskByStatusReport](https://cloud.tencent.com/document/api/1267/95190)

	* 新增入参：WorkflowId


修改数据结构：

* [BaselineTaskInstanceDto](https://cloud.tencent.com/document/api/1267/76336#BaselineTaskInstanceDto)

	* 新增成员：CriticalDependency

	* <font color="#dd0000">**修改成员**：</font>Id, BaselineInstanceId, BaselineType, BaselineDataTime, UpstreamInstanceIds, DownstreamInstanceIds, IsPromiseTask, TaskId, CurRunDate, TaskName, InCriticalPath, InFirstLevel, EstimatedCostTime, ActualCostTime, LatestStartTime, ActualStartTime, EstimatedEndTime, LatestEndTime, ActualEndTime, TaskInstanceStatus, ProjectId, ShardKey, CreateTime, UpdateTime, UserUin, OwnerUin, AppId

* [ColumnLineageInfo](https://cloud.tencent.com/document/api/1267/76336#ColumnLineageInfo)

	* <font color="#dd0000">**修改成员**：</font>PrefixPath

* [RuntimeInstanceCntTop](https://cloud.tencent.com/document/api/1267/76336#RuntimeInstanceCntTop)

	* 新增成员：WaitScheduleTime

	* <font color="#dd0000">**修改成员**：</font>TaskId, TaskName, InCharge, CycleUnit, State, RunTime, CurRunTime

* [TableLineageInfo](https://cloud.tencent.com/document/api/1267/76336#TableLineageInfo)

	* 新增成员：ChannelType

	* <font color="#dd0000">**修改成员**：</font>PrefixPath


### 第 67 次发布

发布时间：2024-01-16 01:27:38

本次发布包含了以下内容：

改善已有的文档。

<font color="#dd0000">**删除接口**：</font>

* DescribeKafkaTopicInfo

### 第 66 次发布

发布时间：2023-12-28 01:29:55

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeFieldBasicInfo](https://cloud.tencent.com/document/api/1267/102705)
* [DescribeTableBasicInfo](https://cloud.tencent.com/document/api/1267/102704)
* [DescribeTableLineageInfo](https://cloud.tencent.com/document/api/1267/102703)

新增数据结构：

* [ColumnBasicInfo](https://cloud.tencent.com/document/api/1267/76336#ColumnBasicInfo)
* [TableBasicInfo](https://cloud.tencent.com/document/api/1267/76336#TableBasicInfo)
* [TableLineageBaseInfo](https://cloud.tencent.com/document/api/1267/76336#TableLineageBaseInfo)

### 第 65 次发布

发布时间：2023-12-20 02:28:42

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [InstanceLogInfo](https://cloud.tencent.com/document/api/1267/76336#InstanceLogInfo)

	* 新增成员：CodeFileName

	* <font color="#dd0000">**修改成员**：</font>TaskId, CurRunDate, Tries, LastUpdate, BrokerIp, FileSize, OriginFileName, CreateTime, InstanceLogType, TaskName, CostTime, InstanceStatus


### 第 64 次发布

发布时间：2023-12-19 02:31:16

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeTableMeta](https://cloud.tencent.com/document/api/1267/102541)

修改接口：

* [BatchSuspendIntegrationTasks](https://cloud.tencent.com/document/api/1267/82532)

	* 新增入参：Event

* [CommitIntegrationTask](https://cloud.tencent.com/document/api/1267/82526)

	* 新增入参：EventDesc

* [ResumeIntegrationTask](https://cloud.tencent.com/document/api/1267/82473)

	* 新增入参：EventDesc

* [StartIntegrationTask](https://cloud.tencent.com/document/api/1267/82471)

	* 新增入参：EventDesc

* [SuspendIntegrationTask](https://cloud.tencent.com/document/api/1267/82469)

	* 新增入参：Event


修改数据结构：

* [AlarmReceiverInfo](https://cloud.tencent.com/document/api/1267/76336#AlarmReceiverInfo)

	* 新增成员：LarkGroup

* [TaskAlarmInfo](https://cloud.tencent.com/document/api/1267/76336#TaskAlarmInfo)

	* 新增成员：LarkWebHooks


### 第 63 次发布

发布时间：2023-12-15 20:46:29

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateTaskVersionDs](https://cloud.tencent.com/document/api/1267/101692)

	* 新增入参：RequestFromSource

* [UploadContent](https://cloud.tencent.com/document/api/1267/93282)

	* 新增入参：RequestFromSource


修改数据结构：

* [ColumnMeta](https://cloud.tencent.com/document/api/1267/76336#ColumnMeta)

	* 新增成员：DictionaryId, DictionaryName


### 第 62 次发布

发布时间：2023-12-07 02:52:47

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeDsFolderTree](https://cloud.tencent.com/document/api/1267/100212)

	* 新增入参：TaskFolderId, DisplayType, IncludeTaskFolder

* [DescribeDsParentFolderTree](https://cloud.tencent.com/document/api/1267/100211)

	* 新增入参：DisplayType


### 第 61 次发布

发布时间：2023-12-01 01:30:04

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [BatchUpdateIntegrationTasks](https://cloud.tencent.com/document/api/1267/82531)

	* 新增入参：InchargeIds

* [CheckAlarmRegularNameExist](https://cloud.tencent.com/document/api/1267/82530)

	* 新增入参：MonitorType

* [DescribeAlarmEvents](https://cloud.tencent.com/document/api/1267/82513)

	* 新增入参：MonitorType

	* <font color="#dd0000">**修改入参**：</font>Filters, OrderFields, TaskType, StartTime, EndTime

* [DescribeAlarmReceiver](https://cloud.tencent.com/document/api/1267/82512)

	* 新增入参：MonitorType

* [DescribeEventCases](https://cloud.tencent.com/document/api/1267/95217)

	* 新增入参：TimeToLive, SortItem, SortType

* [TriggerDsEvent](https://cloud.tencent.com/document/api/1267/102051)

	* 新增入参：EventBatchCaseList

	* <font color="#dd0000">**修改入参**：</font>EventCaseList


新增数据结构：

* [EventBatchCaseDTO](https://cloud.tencent.com/document/api/1267/76336#EventBatchCaseDTO)

修改数据结构：

* [AlarmEventInfo](https://cloud.tencent.com/document/api/1267/76336#AlarmEventInfo)

	* 新增成员：MonitorObjectId, MonitorObjectName, Threshold

* [AlarmIndicatorInfo](https://cloud.tencent.com/document/api/1267/76336#AlarmIndicatorInfo)

	* 新增成员：Threshold


### 第 60 次发布

发布时间：2023-11-30 08:21:21

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [TriggerDsEvent](https://cloud.tencent.com/document/api/1267/102051)

新增数据结构：

* [BatchOpsDTO](https://cloud.tencent.com/document/api/1267/76336#BatchOpsDTO)
* [EventCaseDTO](https://cloud.tencent.com/document/api/1267/76336#EventCaseDTO)
* [FailMessage](https://cloud.tencent.com/document/api/1267/76336#FailMessage)

### 第 59 次发布

发布时间：2023-11-23 01:33:33

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeColumnsMeta](https://cloud.tencent.com/document/api/1267/101829)

新增数据结构：

* [ColumnMeta](https://cloud.tencent.com/document/api/1267/76336#ColumnMeta)
* [Pair](https://cloud.tencent.com/document/api/1267/76336#Pair)

### 第 58 次发布

发布时间：2023-11-21 01:42:45

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeApproveTypeList](https://cloud.tencent.com/document/api/1267/101771)

新增数据结构：

* [ApproveType](https://cloud.tencent.com/document/api/1267/76336#ApproveType)

修改数据结构：

* [Apply](https://cloud.tencent.com/document/api/1267/76336#Apply)

	* 新增成员：ErrorMessage, ApplyName, ApproverId, ApproverName, ApproveProjectName

	* <font color="#dd0000">**修改成员**：</font>ApplicantName, ApproveId


### 第 57 次发布

发布时间：2023-11-20 00:24:26

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [BatchCreateTaskVersionDs](https://cloud.tencent.com/document/api/#/#)
* [CreateTaskVersionDs](https://cloud.tencent.com/document/api/1267/101692)
* [DescribeApproveList](https://cloud.tencent.com/document/api/1267/101695)
* [ModifyApproveStatus](https://cloud.tencent.com/document/api/1267/101694)

新增数据结构：

* [AlarmDsVO](https://cloud.tencent.com/document/api/1267/76336#AlarmDsVO)
* [AlarmExtDsVO](https://cloud.tencent.com/document/api/1267/76336#AlarmExtDsVO)
* [Apply](https://cloud.tencent.com/document/api/1267/76336#Apply)
* [ApproveModify](https://cloud.tencent.com/document/api/1267/76336#ApproveModify)
* [AttributeItemDsVO](https://cloud.tencent.com/document/api/1267/76336#AttributeItemDsVO)
* [BatchCreateTaskVersionDTO](https://cloud.tencent.com/document/api/1267/76336#BatchCreateTaskVersionDTO)
* [BatchCreateTaskVersionDsDTOLite](https://cloud.tencent.com/document/api/1267/76336#BatchCreateTaskVersionDsDTOLite)
* [BatchOperateResultDs](https://cloud.tencent.com/document/api/1267/76336#BatchOperateResultDs)
* [CandidateDsDTo](https://cloud.tencent.com/document/api/1267/76336#CandidateDsDTo)
* [DependencyConfigDsDTONoRecurV2](https://cloud.tencent.com/document/api/1267/76336#DependencyConfigDsDTONoRecurV2)
* [DependencyStrategyDs](https://cloud.tencent.com/document/api/1267/76336#DependencyStrategyDs)
* [DescribeApply](https://cloud.tencent.com/document/api/1267/76336#DescribeApply)
* [FilterOptional](https://cloud.tencent.com/document/api/1267/76336#FilterOptional)
* [OrderFieldOptional](https://cloud.tencent.com/document/api/1267/76336#OrderFieldOptional)
* [ParamInfoDs](https://cloud.tencent.com/document/api/1267/76336#ParamInfoDs)
* [ParameterTaskDsDto](https://cloud.tencent.com/document/api/1267/76336#ParameterTaskDsDto)
* [ParameterTaskInDsDto](https://cloud.tencent.com/document/api/1267/76336#ParameterTaskInDsDto)
* [ParameterTaskOutDsDto](https://cloud.tencent.com/document/api/1267/76336#ParameterTaskOutDsDto)
* [TaskDsDTOLiteV2](https://cloud.tencent.com/document/api/1267/76336#TaskDsDTOLiteV2)
* [TaskDsDTONoRecurV2](https://cloud.tencent.com/document/api/1267/76336#TaskDsDTONoRecurV2)
* [TaskExtDsVO](https://cloud.tencent.com/document/api/1267/76336#TaskExtDsVO)
* [TaskLinkDsDTO](https://cloud.tencent.com/document/api/1267/76336#TaskLinkDsDTO)
* [TaskTypeDsVO](https://cloud.tencent.com/document/api/1267/76336#TaskTypeDsVO)
* [TaskTypeExtDsVO](https://cloud.tencent.com/document/api/1267/76336#TaskTypeExtDsVO)
* [TaskTypeExtParamDsVO](https://cloud.tencent.com/document/api/1267/76336#TaskTypeExtParamDsVO)

### 第 56 次发布

发布时间：2023-11-14 01:33:54

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeTableMetas](https://cloud.tencent.com/document/api/1267/101563)

新增数据结构：

* [SearchColumnDocVO](https://cloud.tencent.com/document/api/1267/76336#SearchColumnDocVO)
* [TableHeat](https://cloud.tencent.com/document/api/1267/76336#TableHeat)
* [TableMeta](https://cloud.tencent.com/document/api/1267/76336#TableMeta)
* [TablePropertyScore](https://cloud.tencent.com/document/api/1267/76336#TablePropertyScore)

### 第 55 次发布

发布时间：2023-11-07 02:48:57

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DeleteDataSources](https://cloud.tencent.com/document/api/1267/80761)

	* 新增入参：ProjectId

* [DescribeDsFolderTree](https://cloud.tencent.com/document/api/1267/100212)

	* 新增入参：IncludeVirtualTask

* [ModifyDataSource](https://cloud.tencent.com/document/api/1267/80760)

	* 新增入参：ProjectId


### 第 54 次发布

发布时间：2023-11-01 01:26:43

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeDatabaseMetas](https://cloud.tencent.com/document/api/1267/101009)

新增数据结构：

* [DatabaseMeta](https://cloud.tencent.com/document/api/1267/76336#DatabaseMeta)

### 第 53 次发布

发布时间：2023-10-31 02:51:22

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [SubmitSqlTask](https://cloud.tencent.com/document/api/1267/95149)

	* 新增入参：ScriptEncryption


### 第 52 次发布

发布时间：2023-10-27 02:35:29

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeOperateOpsTasks](https://cloud.tencent.com/document/api/1267/95254)

	* 新增入参：TaskTags


新增数据结构：

* [TaskTag](https://cloud.tencent.com/document/api/1267/76336#TaskTag)

### 第 51 次发布

发布时间：2023-10-19 16:24:08

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [BooleanResponse](https://cloud.tencent.com/document/api/1267/76336#BooleanResponse)

	* 新增成员：BaselineId

	* <font color="#dd0000">**修改成员**：</font>Success, Message


### 第 50 次发布

发布时间：2023-10-18 03:15:04

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [GetFileInfo](https://cloud.tencent.com/document/api/1267/100430)

### 第 49 次发布

发布时间：2023-10-17 01:32:55

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [OfflineTaskAddParam](https://cloud.tencent.com/document/api/1267/76336#OfflineTaskAddParam)

	* 新增成员：TaskAutoSubmit, InstanceInitStrategy


### 第 48 次发布

发布时间：2023-10-16 01:29:53

本次发布包含了以下内容：

改善已有的文档。

<font color="#dd0000">**预下线接口**：</font>

* DescribeKafkaTopicInfo

### 第 47 次发布

发布时间：2023-10-13 11:16:14

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateDsFolder](https://cloud.tencent.com/document/api/1267/100214)
* [DeleteDsFolder](https://cloud.tencent.com/document/api/1267/100213)
* [DescribeDsFolderTree](https://cloud.tencent.com/document/api/1267/100212)
* [DescribeDsParentFolderTree](https://cloud.tencent.com/document/api/1267/100211)
* [FindAllFolder](https://cloud.tencent.com/document/api/1267/100209)
* [ModifyDsFolder](https://cloud.tencent.com/document/api/1267/100210)
* [RunForceSucScheduleInstances](https://cloud.tencent.com/document/api/1267/100208)
* [RunRerunScheduleInstances](https://cloud.tencent.com/document/api/1267/100207)

修改接口：

* [DescribeOperateOpsTasks](https://cloud.tencent.com/document/api/1267/95254)

	* 新增入参：ExecutorGroupIdList

* [DescribeStreamTaskLogList](https://cloud.tencent.com/document/api/1267/82487)

	* 新增入参：Keyword


新增数据结构：

* [FolderDsDto](https://cloud.tencent.com/document/api/1267/76336#FolderDsDto)
* [PathNodeDsVO](https://cloud.tencent.com/document/api/1267/76336#PathNodeDsVO)

修改数据结构：

* [AlarmEventInfo](https://cloud.tencent.com/document/api/1267/76336#AlarmEventInfo)

	* 新增成员：AlarmRecipientName, TaskType, SendResult

* [InLongAgentDetail](https://cloud.tencent.com/document/api/1267/76336#InLongAgentDetail)

	* 新增成员：ClusterId, AgentRegion

	* <font color="#dd0000">**修改成员**：</font>LifeDays

* [InstanceApiOpsRequest](https://cloud.tencent.com/document/api/1267/76336#InstanceApiOpsRequest)

	* 新增成员：ExecutorGroupIdList

* [InstanceOpsDto](https://cloud.tencent.com/document/api/1267/76336#InstanceOpsDto)

	* 新增成员：ExecutorGroupId, ExecutorGroupName

* [TaskOpsDto](https://cloud.tencent.com/document/api/1267/76336#TaskOpsDto)

	* 新增成员：ExecutorGroupId, ExecutorGroupName


### 第 46 次发布

发布时间：2023-08-31 01:29:16

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [DataSourceInfo](https://cloud.tencent.com/document/api/1267/76336#DataSourceInfo)

	* 新增成员：ShowType

	* <font color="#dd0000">**修改成员**：</font>ModifiedTime


### 第 45 次发布

发布时间：2023-08-30 01:28:20

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeTaskRunHistory](https://cloud.tencent.com/document/api/1267/95189)

	* <font color="#dd0000">**修改入参**：</font>PageNumber


修改数据结构：

* [LinkOpsDto](https://cloud.tencent.com/document/api/1267/76336#LinkOpsDto)

	* <font color="#dd0000">**修改成员**：</font>Id, LinkKey, TaskFrom, TaskTo, InCharge, LinkDependencyType, Offset, LinkType, WorkflowId

* [TaskOpsDto](https://cloud.tencent.com/document/api/1267/76336#TaskOpsDto)

	* <font color="#dd0000">**修改成员**：</font>TaskId, VirtualTaskId, VirtualFlag, TaskName, WorkflowId, RealWorkflowId, WorkflowName, FolderId, FolderName, CreateTime, LastUpdate, Status, InCharge, InChargeId, StartTime, EndTime, ExecutionStartTime, ExecutionEndTime, CycleType, CycleStep, CrontabExpression, DelayTime, StartupTime, RetryWait, RetryAble, TaskAction, TryLimit, RunPriority, TaskType, BrokerIp, ClusterId, MinDateTime, MaxDateTime, ExecutionTTL, SelfDepend, LeftCoordinate, TopCoordinate, Notes, InstanceInitStrategy, YarnQueue, LastSchedulerCommitTime, NormalizedJobStartTime, SchedulerDesc, ResourceGroup, Creator, DependencyRel, DependencyWorkflow, EventListenerConfig, EventPublisherConfig, VirtualTaskStatus, TaskLinkInfo, ProductName, ProjectId, ProjectIdent, ProjectName, OwnId, UserId, TenantId, UpdateUser, UpdateTime, UpdateUserId, TaskTypeId, TaskTypeDesc, ShowWorkflow, FirstSubmitTime, FirstRunTime, ScheduleDesc, CycleNum, Crontab, StartDate, EndDate, CycleUnit, InitStrategy, Layer, SourceServiceId, SourceServiceType, TargetServiceId, TargetServiceType, TasksStr, Submit


### 第 44 次发布

发布时间：2023-08-25 02:27:36

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [IntegrationNodeSchema](https://cloud.tencent.com/document/api/1267/76336#IntegrationNodeSchema)

	* 新增成员：Comment


### 第 43 次发布

发布时间：2023-08-23 01:51:51

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [UserFileDTO](https://cloud.tencent.com/document/api/1267/76336#UserFileDTO)

	* <font color="#dd0000">**修改成员**：</font>CreateTime, UpdateTime


### 第 42 次发布

发布时间：2023-08-22 01:23:51

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [RuleGroup](https://cloud.tencent.com/document/api/1267/76336#RuleGroup)

	* 新增成员：CreateTime


### 第 41 次发布

发布时间：2023-08-17 06:34:07

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeTableLineage](https://cloud.tencent.com/document/api/1267/94987)

	* 新增入参：RecursiveSecond


### 第 40 次发布

发布时间：2023-08-09 02:00:26

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeSchedulerInstanceStatus](https://cloud.tencent.com/document/api/1267/95198)

	* 新增入参：StartTime, EndTime, InCharge

* [DescribeSchedulerRunTimeInstanceCntByStatus](https://cloud.tencent.com/document/api/1267/95197)

	* 新增入参：TaskType, InCharge

* [DescribeSchedulerTaskCntByStatus](https://cloud.tencent.com/document/api/1267/95196)

	* 新增入参：InCharge

* [DescribeSchedulerTaskTypeCnt](https://cloud.tencent.com/document/api/1267/95195)

	* 新增入参：InCharge

* [DescribeStatisticInstanceStatusTrendOps](https://cloud.tencent.com/document/api/1267/95193)

	* 新增入参：InCharge, TaskType, StateList, AggregationUnit, AverageWindowSize

* [DescribeTaskByCycle](https://cloud.tencent.com/document/api/1267/95192)

	* 新增入参：InCharge

* [DescribeTaskByStatusReport](https://cloud.tencent.com/document/api/1267/95190)

	* 新增入参：AggregationUnit, CycleUnit, Status, InCharge


修改数据结构：

* [InstanceStatisticInfo](https://cloud.tencent.com/document/api/1267/76336#InstanceStatisticInfo)

	* 新增成员：ReportTime, Count

* [TaskByStatus](https://cloud.tencent.com/document/api/1267/76336#TaskByStatus)

	* 新增成员：ReportTime, Count


### 第 39 次发布

发布时间：2023-08-08 01:27:52

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeBatchOperateTask](https://cloud.tencent.com/document/api/1267/94610)

	* 新增入参：DatasourceIdList, DatasourceTypeList, CycleUnitList, CanSubmit


修改数据结构：

* [DescribeBatchOperateTaskDTO](https://cloud.tencent.com/document/api/1267/76336#DescribeBatchOperateTaskDTO)

	* 新增成员：CycleUnit, ScheduleDesc, DatasourceId, DatasourceType


### 第 38 次发布

发布时间：2023-08-04 01:21:15

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [BatchDeleteIntegrationTasks](https://cloud.tencent.com/document/api/1267/82540)

	* 新增入参：DeleteKFFlag

* [CommitIntegrationTask](https://cloud.tencent.com/document/api/1267/82526)

	* 新增入参：VersionDesc, InstanceVersion

* [DeleteIntegrationTask](https://cloud.tencent.com/document/api/1267/82516)

	* 新增出参：DeleteFlag, DeleteErrInfo

* [DescribeIntegrationTask](https://cloud.tencent.com/document/api/1267/82495)

	* 新增入参：InstanceVersion

	* 新增出参：AgentStatus, TaskVersion


新增数据结构：

* [AgentStatus](https://cloud.tencent.com/document/api/1267/76336#AgentStatus)
* [TaskVersionInstance](https://cloud.tencent.com/document/api/1267/76336#TaskVersionInstance)

修改数据结构：

* [IntegrationTaskInfo](https://cloud.tencent.com/document/api/1267/76336#IntegrationTaskInfo)

	* 新增成员：SwitchResource, ReadPhase, InstanceVersion


### 第 37 次发布

发布时间：2023-07-20 01:54:12

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [BatchDeleteOpsTasks](https://cloud.tencent.com/document/api/1267/95234)
* [BatchModifyOpsOwners](https://cloud.tencent.com/document/api/1267/95258)
* [BatchRunOpsTask](https://cloud.tencent.com/document/api/1267/95233)
* [BatchStopOpsTasks](https://cloud.tencent.com/document/api/1267/95257)
* [BatchStopWorkflowsByIds](https://cloud.tencent.com/document/api/1267/95232)
* [CountOpsInstanceState](https://cloud.tencent.com/document/api/1267/95256)
* [CreateBaseline](https://cloud.tencent.com/document/api/#/#)
* [CreateOpsMakePlan](https://cloud.tencent.com/document/api/1267/95231)
* [DagInstances](https://cloud.tencent.com/document/api/1267/95230)
* [DeleteBaseline](https://cloud.tencent.com/document/api/#/#)
* [DeleteFile](https://cloud.tencent.com/document/api/1267/95250)
* [DeleteResourceFile](https://cloud.tencent.com/document/api/1267/95236)
* [DeleteWorkflowById](https://cloud.tencent.com/document/api/1267/95228)
* [DescribeAllByFolderNew](https://cloud.tencent.com/document/api/1267/95227)
* [DescribeAllTaskType](https://cloud.tencent.com/document/api/#/#)
* [DescribeAllUsedVersionSon](https://cloud.tencent.com/document/api/#/#)
* [DescribeBaselineAllTaskDag](https://cloud.tencent.com/document/api/#/#)
* [DescribeBaselineById](https://cloud.tencent.com/document/api/#/#)
* [DescribeBaselineInstanceDag](https://cloud.tencent.com/document/api/#/#)
* [DescribeBaselineInstanceGantt](https://cloud.tencent.com/document/api/#/#)
* [DescribeBaselineInstances](https://cloud.tencent.com/document/api/#/#)
* [DescribeBaselines](https://cloud.tencent.com/document/api/#/#)
* [DescribeBelongTo](https://cloud.tencent.com/document/api/#/#)
* [DescribeDependOpsTaskList](https://cloud.tencent.com/document/api/#/#)
* [DescribeDependOpsTasks](https://cloud.tencent.com/document/api/1267/95255)
* [DescribeDependTaskLists](https://cloud.tencent.com/document/api/1267/95222)
* [DescribeDiagnosticInfoByBaselineId](https://cloud.tencent.com/document/api/#/#)
* [DescribeDrInstancePage](https://cloud.tencent.com/document/api/1267/95221)
* [DescribeDrInstanceScriptContent](https://cloud.tencent.com/document/api/#/#)
* [DescribeDrSonInstance](https://cloud.tencent.com/document/api/#/#)
* [DescribeEvent](https://cloud.tencent.com/document/api/1267/95218)
* [DescribeEventCases](https://cloud.tencent.com/document/api/1267/95217)
* [DescribeEventConsumeTasks](https://cloud.tencent.com/document/api/1267/95216)
* [DescribeEventDetail](https://cloud.tencent.com/document/api/#/#)
* [DescribeEventIsAlarmTypes](https://cloud.tencent.com/document/api/#/#)
* [DescribeEventTypes](https://cloud.tencent.com/document/api/#/#)
* [DescribeEvents](https://cloud.tencent.com/document/api/#/#)
* [DescribeFathers](https://cloud.tencent.com/document/api/#/#)
* [DescribeInstanceByCycle](https://cloud.tencent.com/document/api/1267/95210)
* [DescribeInstanceByCycleReport](https://cloud.tencent.com/document/api/#/#)
* [DescribeInstanceLogDetail](https://cloud.tencent.com/document/api/1267/95235)
* [DescribeInstanceLogFile](https://cloud.tencent.com/document/api/1267/95208)
* [DescribeInstancesInfoWithTaskInfo](https://cloud.tencent.com/document/api/#/#)
* [DescribeOperateOpsTaskDatasource](https://cloud.tencent.com/document/api/#/#)
* [DescribeOperateOpsTaskDatasourceType](https://cloud.tencent.com/document/api/#/#)
* [DescribeOperateOpsTasks](https://cloud.tencent.com/document/api/1267/95254)
* [DescribeOpsInstanceLogList](https://cloud.tencent.com/document/api/1267/95204)
* [DescribeOpsMakePlanInstances](https://cloud.tencent.com/document/api/1267/95203)
* [DescribeOpsMakePlanTasks](https://cloud.tencent.com/document/api/1267/95202)
* [DescribeOpsMakePlans](https://cloud.tencent.com/document/api/1267/95201)
* [DescribeOpsWorkflows](https://cloud.tencent.com/document/api/1267/95200)
* [DescribeScheduleInstance](https://cloud.tencent.com/document/api/#/#)
* [DescribeScheduleInstances](https://cloud.tencent.com/document/api/1267/95199)
* [DescribeSchedulerInstanceStatus](https://cloud.tencent.com/document/api/1267/95198)
* [DescribeSchedulerRunTimeInstanceCntByStatus](https://cloud.tencent.com/document/api/1267/95197)
* [DescribeSchedulerTaskCntByStatus](https://cloud.tencent.com/document/api/1267/95196)
* [DescribeSchedulerTaskTypeCnt](https://cloud.tencent.com/document/api/1267/95195)
* [DescribeSonInstances](https://cloud.tencent.com/document/api/#/#)
* [DescribeStatisticInstanceStatusTrendOps](https://cloud.tencent.com/document/api/1267/95193)
* [DescribeSuccessorOpsTaskInfos](https://cloud.tencent.com/document/api/1267/95253)
* [DescribeTaskByCycle](https://cloud.tencent.com/document/api/1267/95192)
* [DescribeTaskByCycleReport](https://cloud.tencent.com/document/api/1267/95191)
* [DescribeTaskByStatusReport](https://cloud.tencent.com/document/api/1267/95190)
* [DescribeTaskRunHistory](https://cloud.tencent.com/document/api/1267/95189)
* [DescribeThirdTaskRunLog](https://cloud.tencent.com/document/api/1267/95188)
* [DescribeWorkflowCanvasInfo](https://cloud.tencent.com/document/api/1267/95187)
* [DescribeWorkflowExecuteById](https://cloud.tencent.com/document/api/1267/95186)
* [DescribeWorkflowInfoById](https://cloud.tencent.com/document/api/1267/95185)
* [DescribeWorkflowListByProjectId](https://cloud.tencent.com/document/api/1267/95184)
* [DescribeWorkflowOpsCanvasInfo](https://cloud.tencent.com/document/api/#/#)
* [DescribeWorkflowTaskCount](https://cloud.tencent.com/document/api/1267/95182)
* [DiagnosePlus](https://cloud.tencent.com/document/api/#/#)
* [EditBaseline](https://cloud.tencent.com/document/api/#/#)
* [ForceSucScheduleInstances](https://cloud.tencent.com/document/api/#/#)
* [FreezeOpsTasks](https://cloud.tencent.com/document/api/1267/95252)
* [FreezeTasksByWorkflowIds](https://cloud.tencent.com/document/api/1267/95179)
* [KillOpsMakePlanInstances](https://cloud.tencent.com/document/api/1267/95178)
* [KillScheduleInstances](https://cloud.tencent.com/document/api/1267/95177)
* [MakeUpOpsTasks](https://cloud.tencent.com/document/api/#/#)
* [MakeUpTasksByWorkflow](https://cloud.tencent.com/document/api/#/#)
* [ModifyBaselineAlarmStatus](https://cloud.tencent.com/document/api/#/#)
* [ModifyBaselineTaskAlarmStatus](https://cloud.tencent.com/document/api/#/#)
* [RerunOpsMakePlanInstances](https://cloud.tencent.com/document/api/#/#)
* [RerunScheduleInstances](https://cloud.tencent.com/document/api/#/#)
* [RunTasksByMultiWorkflow](https://cloud.tencent.com/document/api/1267/95171)
* [StopBaseline](https://cloud.tencent.com/document/api/#/#)
* [SubmitBaseline](https://cloud.tencent.com/document/api/#/#)
* [UpdateWorkflowOwner](https://cloud.tencent.com/document/api/1267/95170)

新增数据结构：

* [AlarmRuleDto](https://cloud.tencent.com/document/api/1267/76336#AlarmRuleDto)
* [BaselineDetailResponse](https://cloud.tencent.com/document/api/1267/76336#BaselineDetailResponse)
* [BaselineDto](https://cloud.tencent.com/document/api/1267/76336#BaselineDto)
* [BaselineInstanceVo](https://cloud.tencent.com/document/api/1267/76336#BaselineInstanceVo)
* [BaselineTaskDto](https://cloud.tencent.com/document/api/1267/76336#BaselineTaskDto)
* [BaselineTaskInfo](https://cloud.tencent.com/document/api/1267/76336#BaselineTaskInfo)
* [BaselineTaskInstanceDto](https://cloud.tencent.com/document/api/1267/76336#BaselineTaskInstanceDto)
* [BatchOperateResultOpsDto](https://cloud.tencent.com/document/api/1267/76336#BatchOperateResultOpsDto)
* [BatchOperationOpsDto](https://cloud.tencent.com/document/api/1267/76336#BatchOperationOpsDto)
* [BooleanResponse](https://cloud.tencent.com/document/api/1267/76336#BooleanResponse)
* [CollectionFolderOpsDto](https://cloud.tencent.com/document/api/1267/76336#CollectionFolderOpsDto)
* [CollectionInstanceOpsDto](https://cloud.tencent.com/document/api/1267/76336#CollectionInstanceOpsDto)
* [CollectionTaskOpsDto](https://cloud.tencent.com/document/api/1267/76336#CollectionTaskOpsDto)
* [CommonIdOpsDto](https://cloud.tencent.com/document/api/1267/76336#CommonIdOpsDto)
* [CreateAlarmRuleRequest](https://cloud.tencent.com/document/api/1267/76336#CreateAlarmRuleRequest)
* [CreateMakeDatetimeInfo](https://cloud.tencent.com/document/api/1267/76336#CreateMakeDatetimeInfo)
* [DatasourceTypeByTaskType](https://cloud.tencent.com/document/api/1267/76336#DatasourceTypeByTaskType)
* [DescribeBaselineResponse](https://cloud.tencent.com/document/api/1267/76336#DescribeBaselineResponse)
* [DescribeBaselineTaskDagResponse](https://cloud.tencent.com/document/api/1267/76336#DescribeBaselineTaskDagResponse)
* [DescribeDiagnosticInfoResponse](https://cloud.tencent.com/document/api/1267/76336#DescribeDiagnosticInfoResponse)
* [DrInstanceOpsDto](https://cloud.tencent.com/document/api/1267/76336#DrInstanceOpsDto)
* [DrInstanceOpsDtoPage](https://cloud.tencent.com/document/api/1267/76336#DrInstanceOpsDtoPage)
* [EventCaseAuditLogOptDto](https://cloud.tencent.com/document/api/1267/76336#EventCaseAuditLogOptDto)
* [EventCaseAuditLogVOCollection](https://cloud.tencent.com/document/api/1267/76336#EventCaseAuditLogVOCollection)
* [EventCaseConsumeLogOptDto](https://cloud.tencent.com/document/api/1267/76336#EventCaseConsumeLogOptDto)
* [EventCaseConsumeLogOptDtoCollection](https://cloud.tencent.com/document/api/1267/76336#EventCaseConsumeLogOptDtoCollection)
* [EventCaseOpsDto](https://cloud.tencent.com/document/api/1267/76336#EventCaseOpsDto)
* [EventDto](https://cloud.tencent.com/document/api/1267/76336#EventDto)
* [EventListenerOpsDto](https://cloud.tencent.com/document/api/1267/76336#EventListenerOpsDto)
* [EventOpsDto](https://cloud.tencent.com/document/api/1267/76336#EventOpsDto)
* [EventPage](https://cloud.tencent.com/document/api/1267/76336#EventPage)
* [FolderOpsDto](https://cloud.tencent.com/document/api/1267/76336#FolderOpsDto)
* [InstanceApiOpsRequest](https://cloud.tencent.com/document/api/1267/76336#InstanceApiOpsRequest)
* [InstanceCondition](https://cloud.tencent.com/document/api/1267/76336#InstanceCondition)
* [InstanceDownloadLogInfo](https://cloud.tencent.com/document/api/1267/76336#InstanceDownloadLogInfo)
* [InstanceLogInfo](https://cloud.tencent.com/document/api/1267/76336#InstanceLogInfo)
* [InstanceLogInfoOpsDto](https://cloud.tencent.com/document/api/1267/76336#InstanceLogInfoOpsDto)
* [InstanceOpsDto](https://cloud.tencent.com/document/api/1267/76336#InstanceOpsDto)
* [InstanceOpsInfoPage](https://cloud.tencent.com/document/api/1267/76336#InstanceOpsInfoPage)
* [InstanceSearchCondition](https://cloud.tencent.com/document/api/1267/76336#InstanceSearchCondition)
* [InstanceStatisticInfo](https://cloud.tencent.com/document/api/1267/76336#InstanceStatisticInfo)
* [LinkOpsDto](https://cloud.tencent.com/document/api/1267/76336#LinkOpsDto)
* [MakePlanInstanceOpsDtoCollection](https://cloud.tencent.com/document/api/1267/76336#MakePlanInstanceOpsDtoCollection)
* [MakePlanOpsDto](https://cloud.tencent.com/document/api/1267/76336#MakePlanOpsDto)
* [MakePlanOpsDtoCollection](https://cloud.tencent.com/document/api/1267/76336#MakePlanOpsDtoCollection)
* [MakePlanTaskOpsDto](https://cloud.tencent.com/document/api/1267/76336#MakePlanTaskOpsDto)
* [MakePlanTaskOpsDtoCollection](https://cloud.tencent.com/document/api/1267/76336#MakePlanTaskOpsDtoCollection)
* [ModifyAlarmRuleRequest](https://cloud.tencent.com/document/api/1267/76336#ModifyAlarmRuleRequest)
* [OperationOpsDto](https://cloud.tencent.com/document/api/1267/76336#OperationOpsDto)
* [OpsTaskCanvasDto](https://cloud.tencent.com/document/api/1267/76336#OpsTaskCanvasDto)
* [OpsTaskCanvasInfoList](https://cloud.tencent.com/document/api/1267/76336#OpsTaskCanvasInfoList)
* [OpsTaskInfoPage](https://cloud.tencent.com/document/api/1267/76336#OpsTaskInfoPage)
* [OpsTaskLinkInfoDto](https://cloud.tencent.com/document/api/1267/76336#OpsTaskLinkInfoDto)
* [PairDto](https://cloud.tencent.com/document/api/1267/76336#PairDto)
* [ProjectBaseInfoOpsRequest](https://cloud.tencent.com/document/api/1267/76336#ProjectBaseInfoOpsRequest)
* [RuntimeInstanceCntTop](https://cloud.tencent.com/document/api/1267/76336#RuntimeInstanceCntTop)
* [ScreenInstanceInfo](https://cloud.tencent.com/document/api/1267/76336#ScreenInstanceInfo)
* [ScreenTaskInfo](https://cloud.tencent.com/document/api/1267/76336#ScreenTaskInfo)
* [SimpleDataSourceInfo](https://cloud.tencent.com/document/api/1267/76336#SimpleDataSourceInfo)
* [StrToStrMap](https://cloud.tencent.com/document/api/1267/76336#StrToStrMap)
* [StringListNode](https://cloud.tencent.com/document/api/1267/76336#StringListNode)
* [TaskByCycle](https://cloud.tencent.com/document/api/1267/76336#TaskByCycle)
* [TaskByStatus](https://cloud.tencent.com/document/api/1267/76336#TaskByStatus)
* [TaskInstanceCountDto](https://cloud.tencent.com/document/api/1267/76336#TaskInstanceCountDto)
* [TaskOpsDto](https://cloud.tencent.com/document/api/1267/76336#TaskOpsDto)
* [TaskTypeCnt](https://cloud.tencent.com/document/api/1267/76336#TaskTypeCnt)
* [TaskTypeMap](https://cloud.tencent.com/document/api/1267/76336#TaskTypeMap)
* [TaskTypeOpsDto](https://cloud.tencent.com/document/api/1267/76336#TaskTypeOpsDto)
* [WorkFlowExecuteDto](https://cloud.tencent.com/document/api/1267/76336#WorkFlowExecuteDto)
* [WorkFlowExecuteDtoByPage](https://cloud.tencent.com/document/api/1267/76336#WorkFlowExecuteDtoByPage)
* [WorkflowCanvasOpsDto](https://cloud.tencent.com/document/api/1267/76336#WorkflowCanvasOpsDto)
* [WorkflowExtOpsDto](https://cloud.tencent.com/document/api/1267/76336#WorkflowExtOpsDto)
* [WorkflowExtOpsDtoPage](https://cloud.tencent.com/document/api/1267/76336#WorkflowExtOpsDtoPage)
* [WorkflowSchedulerOpsDto](https://cloud.tencent.com/document/api/1267/76336#WorkflowSchedulerOpsDto)
* [WorkflowTaskCountOpsDto](https://cloud.tencent.com/document/api/1267/76336#WorkflowTaskCountOpsDto)

### 第 36 次发布

发布时间：2023-07-19 01:51:22

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [BatchDeleteTasksDs](https://cloud.tencent.com/document/api/#/#)
* [DeleteFilePath](https://cloud.tencent.com/document/api/1267/95143)
* [DeleteProjectParamDs](https://cloud.tencent.com/document/api/1267/95142)
* [DeleteResourceFiles](https://cloud.tencent.com/document/api/1267/95145)
* [DeleteTaskDs](https://cloud.tencent.com/document/api/1267/95141)
* [RemoveWorkflowDs](https://cloud.tencent.com/document/api/1267/95140)
* [SubmitSqlTask](https://cloud.tencent.com/document/api/1267/95149)
* [SubmitTaskTestRun](https://cloud.tencent.com/document/api/1267/95147)

新增数据结构：

* [AdhocDetail](https://cloud.tencent.com/document/api/1267/76336#AdhocDetail)
* [AdhocRecord](https://cloud.tencent.com/document/api/1267/76336#AdhocRecord)
* [StageCloudApiRequest](https://cloud.tencent.com/document/api/1267/76336#StageCloudApiRequest)
* [UserFileInfo](https://cloud.tencent.com/document/api/1267/76336#UserFileInfo)

修改数据结构：

* [TaskCanvasInfo](https://cloud.tencent.com/document/api/1267/76336#TaskCanvasInfo)

	* 新增成员：UserId, OwnerId, TenantId


### 第 35 次发布

发布时间：2023-07-12 01:53:01

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeColumnLineage](https://cloud.tencent.com/document/api/1267/94988)
* [DescribeTableLineage](https://cloud.tencent.com/document/api/1267/94987)

新增数据结构：

* [ColumnAggregationLineage](https://cloud.tencent.com/document/api/1267/76336#ColumnAggregationLineage)
* [ColumnLineageInfo](https://cloud.tencent.com/document/api/1267/76336#ColumnLineageInfo)
* [LineageParamRecord](https://cloud.tencent.com/document/api/1267/76336#LineageParamRecord)
* [SimpleColumnInfo](https://cloud.tencent.com/document/api/1267/76336#SimpleColumnInfo)
* [TableLineageInfo](https://cloud.tencent.com/document/api/1267/76336#TableLineageInfo)

### 第 34 次发布

发布时间：2023-07-07 02:01:57

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeBatchOperateTask](https://cloud.tencent.com/document/api/1267/94610)

新增数据结构：

* [DescribeBatchOperateTaskDTO](https://cloud.tencent.com/document/api/1267/76336#DescribeBatchOperateTaskDTO)
* [DescribeBatchOperateTaskPage](https://cloud.tencent.com/document/api/1267/76336#DescribeBatchOperateTaskPage)

### 第 33 次发布

发布时间：2023-07-05 01:56:36

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CommitIntegrationTask](https://cloud.tencent.com/document/api/1267/82526)

	* 新增入参：ExtConfig

* [GenHiveTableDDLSql](https://cloud.tencent.com/document/api/1267/82483)

	* 新增入参：UpsertKeys, TableBaseInfo

* [ResumeIntegrationTask](https://cloud.tencent.com/document/api/1267/82473)

	* 新增入参：Event, ExtConfig

* [StartIntegrationTask](https://cloud.tencent.com/document/api/1267/82471)

	* 新增入参：Event, ExtConfig


新增数据结构：

* [DlcDataGovernPolicy](https://cloud.tencent.com/document/api/1267/76336#DlcDataGovernPolicy)
* [DlcExpiredSnapshotsInfo](https://cloud.tencent.com/document/api/1267/76336#DlcExpiredSnapshotsInfo)
* [DlcMergeManifestsInfo](https://cloud.tencent.com/document/api/1267/76336#DlcMergeManifestsInfo)
* [DlcRemoveOrphanFilesInfo](https://cloud.tencent.com/document/api/1267/76336#DlcRemoveOrphanFilesInfo)
* [DlcRewriteDataInfo](https://cloud.tencent.com/document/api/1267/76336#DlcRewriteDataInfo)
* [TableBaseInfo](https://cloud.tencent.com/document/api/1267/76336#TableBaseInfo)

修改数据结构：

* [AlarmIndicatorInfo](https://cloud.tencent.com/document/api/1267/76336#AlarmIndicatorInfo)

	* 新增成员：Duration, DurationUnit, MaxTimes

* [RecordField](https://cloud.tencent.com/document/api/1267/76336#RecordField)

	* <font color="#dd0000">**修改成员**：</font>Name, Value

* [SourceFieldInfo](https://cloud.tencent.com/document/api/1267/76336#SourceFieldInfo)

	* 新增成员：Comment


### 第 32 次发布

发布时间：2023-06-27 01:54:02

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeDimensionScore](https://cloud.tencent.com/document/api/1267/82830)

	* 新增入参：Filters

* [DescribeQualityScore](https://cloud.tencent.com/document/api/1267/82825)

	* 新增入参：ScoreType, Filters

* [DescribeQualityScoreTrend](https://cloud.tencent.com/document/api/1267/82824)

	* 新增入参：ScoreType, Filters

* [DescribeTableQualityDetails](https://cloud.tencent.com/document/api/1267/82801)

	* 新增入参：ScoreType

* [DescribeTableScoreTrend](https://cloud.tencent.com/document/api/1267/82800)

	* 新增入参：ScoreType


修改数据结构：

* [DimensionCount](https://cloud.tencent.com/document/api/1267/76336#DimensionCount)

	* 新增成员：QualityDim

* [RuleExecResult](https://cloud.tencent.com/document/api/1267/76336#RuleExecResult)

	* 新增成员：StartTime, AlarmLevel

* [RuleExecResultDetail](https://cloud.tencent.com/document/api/1267/76336#RuleExecResultDetail)

	* 新增成员：DatasourceType

* [RuleGroup](https://cloud.tencent.com/document/api/1267/76336#RuleGroup)

	* 新增成员：InstanceId

* [SourceObject](https://cloud.tencent.com/document/api/1267/76336#SourceObject)

	* 新增成员：ObjectDataTypeName, ObjectValue, ObjectType


### 第 31 次发布

发布时间：2023-06-08 02:14:41

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [UploadContent](https://cloud.tencent.com/document/api/1267/93282)

新增数据结构：

* [ScriptInfoResponse](https://cloud.tencent.com/document/api/1267/76336#ScriptInfoResponse)
* [ScriptRequestInfo](https://cloud.tencent.com/document/api/1267/76336#ScriptRequestInfo)

### 第 30 次发布

发布时间：2023-06-07 02:00:11

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DeleteTaskAlarmRegular](https://cloud.tencent.com/document/api/1267/82514)

	* <font color="#dd0000">**修改入参**：</font>TaskId, TaskType


### 第 29 次发布

发布时间：2023-06-06 02:12:11

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CheckAlarmRegularNameExist](https://cloud.tencent.com/document/api/1267/82530)

	* 新增入参：TaskType

	* <font color="#dd0000">**修改入参**：</font>TaskId

* [DescribeInstanceList](https://cloud.tencent.com/document/api/1267/82505)

	* 新增出参：InstanceList, TotalCount

* [DescribeInstanceLog](https://cloud.tencent.com/document/api/1267/82504)

	* 新增出参：InstanceLogInfo

* [DescribeInstanceLogList](https://cloud.tencent.com/document/api/1267/82503)

	* 新增出参：InstanceLogList

* [DescribeIntegrationTasks](https://cloud.tencent.com/document/api/1267/82494)

	* 新增出参：TotalCount

* [DescribeTaskAlarmRegulations](https://cloud.tencent.com/document/api/1267/82486)

	* <font color="#dd0000">**修改入参**：</font>TaskId, TaskType


新增数据结构：

* [InstanceList](https://cloud.tencent.com/document/api/1267/76336#InstanceList)
* [InstanceLogList](https://cloud.tencent.com/document/api/1267/76336#InstanceLogList)
* [IntegrationInstanceLog](https://cloud.tencent.com/document/api/1267/76336#IntegrationInstanceLog)

修改数据结构：

* [AlarmEventInfo](https://cloud.tencent.com/document/api/1267/76336#AlarmEventInfo)

	* 新增成员：RegularId

* [IntegrationTaskInfo](https://cloud.tencent.com/document/api/1267/76336#IntegrationTaskInfo)

	* 新增成员：InputDatasourceType, OutputDatasourceType, NumRecordsIn, NumRecordsOut, ReaderDelay, NumRestarts, CreateTime, UpdateTime, LastRunTime, StopTime, HasVersion, Locked, Locker, RunningCu, TaskAlarmRegularList

* [TaskAlarmInfo](https://cloud.tencent.com/document/api/1267/76336#TaskAlarmInfo)

	* 新增成员：UpdateTime, OperatorUin, TaskCount, MonitorType, MonitorObjectIds, LatestAlarmInstanceId, LatestAlarmTime, Description


### 第 28 次发布

发布时间：2023-05-31 01:52:47

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeOperateTasks](https://cloud.tencent.com/document/api/#/#)

	* 新增入参：SourceServiceId, SourceServiceType, TargetServiceId, TargetServiceType, AlarmType


修改数据结构：

* [TaskCanvasInfo](https://cloud.tencent.com/document/api/1267/76336#TaskCanvasInfo)

	* 新增成员：ExecutionStartTime, ExecutionEndTime, Layer, SourceServiceId, SourceServiceType, TargetServiceId, TargetServiceType, AlarmType, CreateTime

* [TaskInfoPage](https://cloud.tencent.com/document/api/1267/76336#TaskInfoPage)

	* 新增成员：PageCount, TotalCount


### 第 27 次发布

发布时间：2023-05-24 02:08:07

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CommitRuleGroupTask](https://cloud.tencent.com/document/api/1267/82838)

	* 新增入参：EngineType

* [CreateRule](https://cloud.tencent.com/document/api/1267/82837)

	* 新增入参：SourceEngineTypes

* [DescribeRules](https://cloud.tencent.com/document/api/1267/82803)

	* 新增入参：EngineType

* [ModifyExecStrategy](https://cloud.tencent.com/document/api/1267/82794)

	* 新增入参：ExecEngineType

* [ModifyRule](https://cloud.tencent.com/document/api/1267/82792)

	* 新增入参：SourceEngineTypes


修改数据结构：

* [Rule](https://cloud.tencent.com/document/api/1267/76336#Rule)

	* 新增成员：SourceEngineTypes

* [RuleExecConfig](https://cloud.tencent.com/document/api/1267/76336#RuleExecConfig)

	* 新增成员：EngineType

* [RuleGroupExecResult](https://cloud.tencent.com/document/api/1267/76336#RuleGroupExecResult)

	* 新增成员：EngineType

* [RuleGroupExecStrategy](https://cloud.tencent.com/document/api/1267/76336#RuleGroupExecStrategy)

	* 新增成员：ExecEngineType, ExecPlan


### 第 26 次发布

发布时间：2023-05-15 02:15:00

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [DatasourceBaseInfo](https://cloud.tencent.com/document/api/1267/76336#DatasourceBaseInfo)

	* 新增成员：Version


### 第 25 次发布

发布时间：2023-05-08 02:04:21

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeDatabaseInfoList](https://cloud.tencent.com/document/api/1267/82545)

	* 新增出参：DatabaseInfo


### 第 24 次发布

发布时间：2023-04-27 13:15:51

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeOperateTasks](https://cloud.tencent.com/document/api/#/#)

修改接口：

* [DescribeDatabaseInfoList](https://cloud.tencent.com/document/api/1267/82545)

	* 新增入参：Filters

* [DescribeRealTimeTaskMetricOverview](https://cloud.tencent.com/document/api/1267/82490)

	* 新增入参：StartTime, EndTime

* [GenHiveTableDDLSql](https://cloud.tencent.com/document/api/1267/82483)

	* 新增入参：TargetDatasourceId


新增数据结构：

* [TaskInfoPage](https://cloud.tencent.com/document/api/1267/76336#TaskInfoPage)

修改数据结构：

* [AlarmIndicatorInfo](https://cloud.tencent.com/document/api/1267/76336#AlarmIndicatorInfo)

	* 新增成员：AlarmIndicatorUnit

* [DataSourceInfo](https://cloud.tencent.com/document/api/1267/76336#DataSourceInfo)

	* 新增成员：ModifiedTime


### 第 23 次发布

发布时间：2023-03-31 02:11:48

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [InLongAgentDetail](https://cloud.tencent.com/document/api/1267/76336#InLongAgentDetail)

	* 新增成员：LifeDays


### 第 22 次发布

发布时间：2023-03-22 02:53:10

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [CreateOfflineTask](https://cloud.tencent.com/document/api/1267/82520)

	* 新增出参：TaskId


### 第 21 次发布

发布时间：2023-03-16 02:33:23

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [Rule](https://cloud.tencent.com/document/api/1267/76336#Rule)

	* 新增成员：TemplateSql, SubQualityDim, TargetObjectType, TargetObjectDataType, TargetObjectDataTypeName, TargetObjectValue


### 第 20 次发布

发布时间：2023-03-08 02:25:19

本次发布包含了以下内容：

改善已有的文档。

新增数据结构：

* [AlarmIndicatorInfo](https://cloud.tencent.com/document/api/1267/76336#AlarmIndicatorInfo)

修改数据结构：

* [AlarmEventInfo](https://cloud.tencent.com/document/api/1267/76336#AlarmEventInfo)

	* <font color="#dd0000">**修改成员**：</font>AlarmIndicator

* [AlarmReceiverInfo](https://cloud.tencent.com/document/api/1267/76336#AlarmReceiverInfo)

	* 新增成员：WecomGroup

* [IntegrationTaskInfo](https://cloud.tencent.com/document/api/1267/76336#IntegrationTaskInfo)

	* 新增成员：DataProxyUrl, Submit

* [TableInfo](https://cloud.tencent.com/document/api/1267/76336#TableInfo)

	* 新增成员：OriginDatabaseName, OriginSchemaName

* [TaskAlarmInfo](https://cloud.tencent.com/document/api/1267/76336#TaskAlarmInfo)

	* 新增成员：AlarmIndicatorInfos, AlarmRecipientType, WeComHook

	* <font color="#dd0000">**修改成员**：</font>AlarmIndicator, AlarmRecipientId, AlarmRecipientName


### 第 19 次发布

发布时间：2023-02-22 02:17:42

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeOfflineTaskToken](https://cloud.tencent.com/document/api/1267/82492)

	* 新增出参：Data

* [DescribeRealTimeTaskSpeed](https://cloud.tencent.com/document/api/1267/82489)

	* 新增出参：Data

* [DescribeTaskInstance](https://cloud.tencent.com/document/api/#/#)

	* 新增出参：Data

* [GenHiveTableDDLSql](https://cloud.tencent.com/document/api/1267/82483)

	* 新增出参：Data


新增数据结构：

* [RealTimeTaskSpeed](https://cloud.tencent.com/document/api/1267/76336#RealTimeTaskSpeed)

### 第 18 次发布

发布时间：2023-02-15 02:14:22

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [GenHiveTableDDLSql](https://cloud.tencent.com/document/api/1267/82483)

	* 新增入参：Partitions, Properties, TableMode, TableVersion, UpsertFlag, TableComment, AddDataFiles, AddEqualityDeletes, AddPositionDeletes, AddDeleteFiles


新增数据结构：

* [Partition](https://cloud.tencent.com/document/api/1267/76336#Partition)
* [Property](https://cloud.tencent.com/document/api/1267/76336#Property)

### 第 17 次发布

发布时间：2023-01-12 01:49:24

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [CompareRule](https://cloud.tencent.com/document/api/1267/76336#CompareRule)

	* 新增成员：CycleStep


### 第 16 次发布

发布时间：2022-12-30 01:58:31

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeInLongAgentList](https://cloud.tencent.com/document/api/#/#)

	* 新增入参：AgentTypes


新增数据结构：

* [CvmAgentStatus](https://cloud.tencent.com/document/api/1267/76336#CvmAgentStatus)

修改数据结构：

* [InLongAgentDetail](https://cloud.tencent.com/document/api/1267/76336#InLongAgentDetail)

	* 新增成员：AgentGroupId, CvmAgentStatusList, AgentTotal


### 第 15 次发布

发布时间：2022-12-07 07:21:53

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [ModifyRuleGroupSubscription](https://cloud.tencent.com/document/api/1267/82791)

	* 新增入参：WebHooks


新增数据结构：

* [SubscribeWebHook](https://cloud.tencent.com/document/api/1267/76336#SubscribeWebHook)

修改数据结构：

* [RuleGroupSubscribe](https://cloud.tencent.com/document/api/1267/76336#RuleGroupSubscribe)

	* 新增成员：WebHooks


### 第 14 次发布

发布时间：2022-11-23 07:08:01

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateResourcePath](https://cloud.tencent.com/document/api/#/#)

修改接口：

* [GenHiveTableDDLSql](https://cloud.tencent.com/document/api/1267/82483)

	* 新增入参：SourceFieldInfoList


新增数据结构：

* [SourceFieldInfo](https://cloud.tencent.com/document/api/1267/76336#SourceFieldInfo)

修改数据结构：

* [IntegrationNodeSchema](https://cloud.tencent.com/document/api/1267/76336#IntegrationNodeSchema)

	* 新增成员：Alias


### 第 13 次发布

发布时间：2022-11-16 06:49:20

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeDataBases](https://cloud.tencent.com/document/api/#/#)

	* 新增入参：DsTypes

* [DescribeRuleDataSources](https://cloud.tencent.com/document/api/#/#)

	* 新增入参：DsTypes

* [DescribeRuleTemplates](https://cloud.tencent.com/document/api/1267/82804)

	* 新增入参：SourceEngineTypes


修改数据结构：

* [DatabaseInfo](https://cloud.tencent.com/document/api/1267/76336#DatabaseInfo)

	* 新增成员：OriginDatabaseName, OriginSchemaName


### 第 12 次发布

发布时间：2022-11-15 06:51:30

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CheckDuplicateRuleName](https://cloud.tencent.com/document/api/#/#)
* [CheckDuplicateTemplateName](https://cloud.tencent.com/document/api/#/#)
* [CommitExportTask](https://cloud.tencent.com/document/api/#/#)
* [CommitRuleGroupExecResult](https://cloud.tencent.com/document/api/#/#)
* [CommitRuleGroupTask](https://cloud.tencent.com/document/api/1267/82838)
* [CreateRule](https://cloud.tencent.com/document/api/1267/82837)
* [CreateRuleTemplate](https://cloud.tencent.com/document/api/1267/82836)
* [DeleteRule](https://cloud.tencent.com/document/api/1267/82835)
* [DeleteRuleTemplate](https://cloud.tencent.com/document/api/1267/82834)
* [DescribeDataBases](https://cloud.tencent.com/document/api/#/#)
* [DescribeDataCheckStat](https://cloud.tencent.com/document/api/1267/82832)
* [DescribeDataObjects](https://cloud.tencent.com/document/api/#/#)
* [DescribeDimensionScore](https://cloud.tencent.com/document/api/1267/82830)
* [DescribeExecStrategy](https://cloud.tencent.com/document/api/1267/82829)
* [DescribeInstances](https://cloud.tencent.com/document/api/#/#)
* [DescribeMonitorsByPage](https://cloud.tencent.com/document/api/#/#)
* [DescribeProdTasks](https://cloud.tencent.com/document/api/#/#)
* [DescribeQualityScore](https://cloud.tencent.com/document/api/1267/82825)
* [DescribeQualityScoreTrend](https://cloud.tencent.com/document/api/1267/82824)
* [DescribeRule](https://cloud.tencent.com/document/api/1267/82823)
* [DescribeRuleDataSources](https://cloud.tencent.com/document/api/#/#)
* [DescribeRuleDimStat](https://cloud.tencent.com/document/api/1267/82821)
* [DescribeRuleExecDetail](https://cloud.tencent.com/document/api/1267/82820)
* [DescribeRuleExecExportResult](https://cloud.tencent.com/document/api/#/#)
* [DescribeRuleExecHistory](https://cloud.tencent.com/document/api/#/#)
* [DescribeRuleExecLog](https://cloud.tencent.com/document/api/1267/82817)
* [DescribeRuleExecResults](https://cloud.tencent.com/document/api/1267/82816)
* [DescribeRuleExecResultsByPage](https://cloud.tencent.com/document/api/#/#)
* [DescribeRuleExecStat](https://cloud.tencent.com/document/api/1267/82814)
* [DescribeRuleGroup](https://cloud.tencent.com/document/api/1267/82813)
* [DescribeRuleGroupExecResultsByPage](https://cloud.tencent.com/document/api/1267/82812)
* [DescribeRuleGroupExecResultsByPageWithoutAuth](https://cloud.tencent.com/document/api/#/#)
* [DescribeRuleGroupSubscription](https://cloud.tencent.com/document/api/1267/82810)
* [DescribeRuleGroupTable](https://cloud.tencent.com/document/api/1267/82809)
* [DescribeRuleGroupsByPage](https://cloud.tencent.com/document/api/1267/82808)
* [DescribeRuleHistoryByPage](https://cloud.tencent.com/document/api/#/#)
* [DescribeRuleTablesByPage](https://cloud.tencent.com/document/api/#/#)
* [DescribeRuleTemplate](https://cloud.tencent.com/document/api/1267/82805)
* [DescribeRuleTemplates](https://cloud.tencent.com/document/api/1267/82804)
* [DescribeRuleTemplatesByPage](https://cloud.tencent.com/document/api/1267/82788)
* [DescribeRules](https://cloud.tencent.com/document/api/1267/82803)
* [DescribeRulesByPage](https://cloud.tencent.com/document/api/1267/82802)
* [DescribeTableQualityDetails](https://cloud.tencent.com/document/api/1267/82801)
* [DescribeTableScoreTrend](https://cloud.tencent.com/document/api/1267/82800)
* [DescribeTemplateDimCount](https://cloud.tencent.com/document/api/1267/82799)
* [DescribeTemplateHistory](https://cloud.tencent.com/document/api/#/#)
* [DescribeTopTableStat](https://cloud.tencent.com/document/api/1267/82797)
* [DescribeTrendStat](https://cloud.tencent.com/document/api/1267/82796)
* [ModifyDimensionWeight](https://cloud.tencent.com/document/api/1267/82795)
* [ModifyExecStrategy](https://cloud.tencent.com/document/api/1267/82794)
* [ModifyMonitorStatus](https://cloud.tencent.com/document/api/1267/82793)
* [ModifyRule](https://cloud.tencent.com/document/api/1267/82792)
* [ModifyRuleGroupSubscription](https://cloud.tencent.com/document/api/1267/82791)
* [ModifyRuleTemplate](https://cloud.tencent.com/document/api/1267/82790)

新增数据结构：

* [CompareResult](https://cloud.tencent.com/document/api/1267/76336#CompareResult)
* [CompareResultItem](https://cloud.tencent.com/document/api/1267/76336#CompareResultItem)
* [CompareRule](https://cloud.tencent.com/document/api/1267/76336#CompareRule)
* [CompareRuleItem](https://cloud.tencent.com/document/api/1267/76336#CompareRuleItem)
* [DailyScoreInfo](https://cloud.tencent.com/document/api/1267/76336#DailyScoreInfo)
* [DataCheckStat](https://cloud.tencent.com/document/api/1267/76336#DataCheckStat)
* [DatabaseInfo](https://cloud.tencent.com/document/api/1267/76336#DatabaseInfo)
* [DimensionCount](https://cloud.tencent.com/document/api/1267/76336#DimensionCount)
* [DimensionScore](https://cloud.tencent.com/document/api/1267/76336#DimensionScore)
* [DimensionScoreInfo](https://cloud.tencent.com/document/api/1267/76336#DimensionScoreInfo)
* [ExportTaskInfo](https://cloud.tencent.com/document/api/1267/76336#ExportTaskInfo)
* [FieldConfig](https://cloud.tencent.com/document/api/1267/76336#FieldConfig)
* [ProdSchedulerTask](https://cloud.tencent.com/document/api/1267/76336#ProdSchedulerTask)
* [QualityScore](https://cloud.tencent.com/document/api/1267/76336#QualityScore)
* [QualityScoreTrend](https://cloud.tencent.com/document/api/1267/76336#QualityScoreTrend)
* [Rule](https://cloud.tencent.com/document/api/1267/76336#Rule)
* [RuleConfig](https://cloud.tencent.com/document/api/1267/76336#RuleConfig)
* [RuleDimCnt](https://cloud.tencent.com/document/api/1267/76336#RuleDimCnt)
* [RuleDimStat](https://cloud.tencent.com/document/api/1267/76336#RuleDimStat)
* [RuleExecConfig](https://cloud.tencent.com/document/api/1267/76336#RuleExecConfig)
* [RuleExecDateStat](https://cloud.tencent.com/document/api/1267/76336#RuleExecDateStat)
* [RuleExecExportResult](https://cloud.tencent.com/document/api/1267/76336#RuleExecExportResult)
* [RuleExecLog](https://cloud.tencent.com/document/api/1267/76336#RuleExecLog)
* [RuleExecResult](https://cloud.tencent.com/document/api/1267/76336#RuleExecResult)
* [RuleExecResultDetail](https://cloud.tencent.com/document/api/1267/76336#RuleExecResultDetail)
* [RuleExecResultPage](https://cloud.tencent.com/document/api/1267/76336#RuleExecResultPage)
* [RuleExecStat](https://cloud.tencent.com/document/api/1267/76336#RuleExecStat)
* [RuleFieldConfig](https://cloud.tencent.com/document/api/1267/76336#RuleFieldConfig)
* [RuleGroup](https://cloud.tencent.com/document/api/1267/76336#RuleGroup)
* [RuleGroupExecResult](https://cloud.tencent.com/document/api/1267/76336#RuleGroupExecResult)
* [RuleGroupExecResultPage](https://cloud.tencent.com/document/api/1267/76336#RuleGroupExecResultPage)
* [RuleGroupExecStrategy](https://cloud.tencent.com/document/api/1267/76336#RuleGroupExecStrategy)
* [RuleGroupMonitor](https://cloud.tencent.com/document/api/1267/76336#RuleGroupMonitor)
* [RuleGroupMonitorPage](https://cloud.tencent.com/document/api/1267/76336#RuleGroupMonitorPage)
* [RuleGroupPage](https://cloud.tencent.com/document/api/1267/76336#RuleGroupPage)
* [RuleGroupSchedulerInfo](https://cloud.tencent.com/document/api/1267/76336#RuleGroupSchedulerInfo)
* [RuleGroupSubscribe](https://cloud.tencent.com/document/api/1267/76336#RuleGroupSubscribe)
* [RuleGroupTable](https://cloud.tencent.com/document/api/1267/76336#RuleGroupTable)
* [RuleGroupTableInnerInfo](https://cloud.tencent.com/document/api/1267/76336#RuleGroupTableInnerInfo)
* [RuleHistory](https://cloud.tencent.com/document/api/1267/76336#RuleHistory)
* [RuleHistoryPage](https://cloud.tencent.com/document/api/1267/76336#RuleHistoryPage)
* [RulePage](https://cloud.tencent.com/document/api/1267/76336#RulePage)
* [RuleTemplate](https://cloud.tencent.com/document/api/1267/76336#RuleTemplate)
* [RuleTemplateHistory](https://cloud.tencent.com/document/api/1267/76336#RuleTemplateHistory)
* [RuleTemplateHistoryPage](https://cloud.tencent.com/document/api/1267/76336#RuleTemplateHistoryPage)
* [RuleTemplatePage](https://cloud.tencent.com/document/api/1267/76336#RuleTemplatePage)
* [RunnerRuleExecResult](https://cloud.tencent.com/document/api/1267/76336#RunnerRuleExecResult)
* [SourceObject](https://cloud.tencent.com/document/api/1267/76336#SourceObject)
* [SubscribeReceiver](https://cloud.tencent.com/document/api/1267/76336#SubscribeReceiver)
* [TableConfig](https://cloud.tencent.com/document/api/1267/76336#TableConfig)
* [TableQualityDetail](https://cloud.tencent.com/document/api/1267/76336#TableQualityDetail)
* [TableQualityDetailPage](https://cloud.tencent.com/document/api/1267/76336#TableQualityDetailPage)
* [TableScoreStatisticsInfo](https://cloud.tencent.com/document/api/1267/76336#TableScoreStatisticsInfo)
* [ThresholdValue](https://cloud.tencent.com/document/api/1267/76336#ThresholdValue)
* [TopTableStat](https://cloud.tencent.com/document/api/1267/76336#TopTableStat)
* [TopTableStatItem](https://cloud.tencent.com/document/api/1267/76336#TopTableStatItem)
* [WeightInfo](https://cloud.tencent.com/document/api/1267/76336#WeightInfo)

### 第 11 次发布

发布时间：2022-11-07 15:46:29

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [BatchCreateIntegrationTaskAlarms](https://cloud.tencent.com/document/api/1267/82541)
* [BatchDeleteIntegrationTasks](https://cloud.tencent.com/document/api/1267/82540)
* [BatchForceSuccessIntegrationTaskInstances](https://cloud.tencent.com/document/api/1267/82539)
* [BatchKillIntegrationTaskInstances](https://cloud.tencent.com/document/api/1267/82538)
* [BatchMakeUpIntegrationTasks](https://cloud.tencent.com/document/api/1267/82537)
* [BatchRerunIntegrationTaskInstances](https://cloud.tencent.com/document/api/1267/82536)
* [BatchResumeIntegrationTasks](https://cloud.tencent.com/document/api/1267/82535)
* [BatchStartIntegrationTasks](https://cloud.tencent.com/document/api/1267/82534)
* [BatchStopIntegrationTasks](https://cloud.tencent.com/document/api/1267/82533)
* [BatchSuspendIntegrationTasks](https://cloud.tencent.com/document/api/1267/82532)
* [BatchUpdateIntegrationTasks](https://cloud.tencent.com/document/api/1267/82531)
* [CheckAlarmRegularNameExist](https://cloud.tencent.com/document/api/1267/82530)
* [CheckIntegrationNodeNameExists](https://cloud.tencent.com/document/api/1267/82529)
* [CheckIntegrationTaskNameExists](https://cloud.tencent.com/document/api/1267/82528)
* [CheckTaskNameExist](https://cloud.tencent.com/document/api/1267/82527)
* [CommitIntegrationTask](https://cloud.tencent.com/document/api/1267/82526)
* [CreateHiveTable](https://cloud.tencent.com/document/api/1267/82525)
* [CreateHiveTableByDDL](https://cloud.tencent.com/document/api/1267/82524)
* [CreateInLongAgent](https://cloud.tencent.com/document/api/#/#)
* [CreateIntegrationNode](https://cloud.tencent.com/document/api/1267/82522)
* [CreateIntegrationTask](https://cloud.tencent.com/document/api/1267/82521)
* [CreateOfflineTask](https://cloud.tencent.com/document/api/1267/82520)
* [CreateTaskAlarmRegular](https://cloud.tencent.com/document/api/1267/82519)
* [DeleteInLongAgent](https://cloud.tencent.com/document/api/#/#)
* [DeleteIntegrationNode](https://cloud.tencent.com/document/api/1267/82517)
* [DeleteIntegrationTask](https://cloud.tencent.com/document/api/1267/82516)
* [DeleteOfflineTask](https://cloud.tencent.com/document/api/1267/82515)
* [DeleteTaskAlarmRegular](https://cloud.tencent.com/document/api/1267/82514)
* [DescribeAlarmEvents](https://cloud.tencent.com/document/api/1267/82513)
* [DescribeAlarmReceiver](https://cloud.tencent.com/document/api/1267/82512)
* [DescribeClusterNamespaceList](https://cloud.tencent.com/document/api/#/#)
* [DescribeDataSourceInfoList](https://cloud.tencent.com/document/api/1267/82546)
* [DescribeDataTypes](https://cloud.tencent.com/document/api/#/#)
* [DescribeDatabaseInfoList](https://cloud.tencent.com/document/api/1267/82545)
* [DescribeInLongAgentList](https://cloud.tencent.com/document/api/#/#)
* [DescribeInLongAgentTaskList](https://cloud.tencent.com/document/api/#/#)
* [DescribeInLongAgentVpcList](https://cloud.tencent.com/document/api/#/#)
* [DescribeInLongTkeClusterList](https://cloud.tencent.com/document/api/#/#)
* [DescribeInstanceLastLog](https://cloud.tencent.com/document/api/1267/82506)
* [DescribeInstanceList](https://cloud.tencent.com/document/api/1267/82505)
* [DescribeInstanceLog](https://cloud.tencent.com/document/api/1267/82504)
* [DescribeInstanceLogList](https://cloud.tencent.com/document/api/1267/82503)
* [DescribeIntegrationNode](https://cloud.tencent.com/document/api/1267/82502)
* [DescribeIntegrationStatistics](https://cloud.tencent.com/document/api/1267/82501)
* [DescribeIntegrationStatisticsAgentStatus](https://cloud.tencent.com/document/api/#/#)
* [DescribeIntegrationStatisticsInstanceTrend](https://cloud.tencent.com/document/api/1267/82499)
* [DescribeIntegrationStatisticsRecordsTrend](https://cloud.tencent.com/document/api/1267/82498)
* [DescribeIntegrationStatisticsTaskStatus](https://cloud.tencent.com/document/api/1267/82497)
* [DescribeIntegrationStatisticsTaskStatusTrend](https://cloud.tencent.com/document/api/1267/82496)
* [DescribeIntegrationTask](https://cloud.tencent.com/document/api/1267/82495)
* [DescribeIntegrationTasks](https://cloud.tencent.com/document/api/1267/82494)
* [DescribeIntegrationVersionNodesInfo](https://cloud.tencent.com/document/api/1267/82493)
* [DescribeKafkaTopicInfo](https://cloud.tencent.com/document/api/1267/82544)
* [DescribeOfflineTaskToken](https://cloud.tencent.com/document/api/1267/82492)
* [DescribeRealTimeTaskInstanceNodeInfo](https://cloud.tencent.com/document/api/1267/82491)
* [DescribeRealTimeTaskMetricOverview](https://cloud.tencent.com/document/api/1267/82490)
* [DescribeRealTimeTaskSpeed](https://cloud.tencent.com/document/api/1267/82489)
* [DescribeStandardRuleDetailInfoList](https://cloud.tencent.com/document/api/#/#)
* [DescribeStreamTaskLogList](https://cloud.tencent.com/document/api/1267/82487)
* [DescribeTableInfoList](https://cloud.tencent.com/document/api/1267/82543)
* [DescribeTableSchemaInfo](https://cloud.tencent.com/document/api/1267/82542)
* [DescribeTaskAlarmRegulations](https://cloud.tencent.com/document/api/1267/82486)
* [DescribeTaskInstance](https://cloud.tencent.com/document/api/#/#)
* [DescribeTaskInstanceReportDetail](https://cloud.tencent.com/document/api/#/#)
* [DescribeTaskLockStatus](https://cloud.tencent.com/document/api/1267/82485)
* [DescribeTaskReport](https://cloud.tencent.com/document/api/#/#)
* [DescribeTaskReportDetailList](https://cloud.tencent.com/document/api/#/#)
* [DryRunDIOfflineTask](https://cloud.tencent.com/document/api/1267/82484)
* [GenHiveTableDDLSql](https://cloud.tencent.com/document/api/1267/82483)
* [GetIntegrationNodeColumnSchema](https://cloud.tencent.com/document/api/1267/82482)
* [GetOfflineDIInstanceList](https://cloud.tencent.com/document/api/1267/82481)
* [GetOfflineInstanceList](https://cloud.tencent.com/document/api/1267/82480)
* [LockIntegrationTask](https://cloud.tencent.com/document/api/1267/82479)
* [ModifyIntegrationNode](https://cloud.tencent.com/document/api/1267/82478)
* [ModifyIntegrationTask](https://cloud.tencent.com/document/api/1267/82477)
* [ModifyTaskAlarmRegular](https://cloud.tencent.com/document/api/1267/82476)
* [ModifyTaskName](https://cloud.tencent.com/document/api/1267/82475)
* [RestartInLongAgent](https://cloud.tencent.com/document/api/#/#)
* [ResumeIntegrationTask](https://cloud.tencent.com/document/api/1267/82473)
* [RobAndLockIntegrationTask](https://cloud.tencent.com/document/api/1267/82472)
* [StartIntegrationTask](https://cloud.tencent.com/document/api/1267/82471)
* [StopIntegrationTask](https://cloud.tencent.com/document/api/1267/82470)
* [SuspendIntegrationTask](https://cloud.tencent.com/document/api/1267/82469)
* [TaskLog](https://cloud.tencent.com/document/api/1267/82468)
* [UnlockIntegrationTask](https://cloud.tencent.com/document/api/1267/82467)
* [UpdateInLongAgent](https://cloud.tencent.com/document/api/#/#)

新增数据结构：

* [AlarmEventInfo](https://cloud.tencent.com/document/api/1267/76336#AlarmEventInfo)
* [AlarmReceiverInfo](https://cloud.tencent.com/document/api/1267/76336#AlarmReceiverInfo)
* [BytesSpeed](https://cloud.tencent.com/document/api/1267/76336#BytesSpeed)
* [DatasourceBaseInfo](https://cloud.tencent.com/document/api/1267/76336#DatasourceBaseInfo)
* [InLongAgentDetail](https://cloud.tencent.com/document/api/1267/76336#InLongAgentDetail)
* [InLongAgentTask](https://cloud.tencent.com/document/api/1267/76336#InLongAgentTask)
* [InLongTkeDetail](https://cloud.tencent.com/document/api/1267/76336#InLongTkeDetail)
* [InstanceNodeInfo](https://cloud.tencent.com/document/api/1267/76336#InstanceNodeInfo)
* [InstanceReportReadNode](https://cloud.tencent.com/document/api/1267/76336#InstanceReportReadNode)
* [InstanceReportSummary](https://cloud.tencent.com/document/api/1267/76336#InstanceReportSummary)
* [InstanceReportWriteNode](https://cloud.tencent.com/document/api/1267/76336#InstanceReportWriteNode)
* [IntegrationNodeInfo](https://cloud.tencent.com/document/api/1267/76336#IntegrationNodeInfo)
* [IntegrationStatisticsTrendResult](https://cloud.tencent.com/document/api/1267/76336#IntegrationStatisticsTrendResult)
* [IntegrationTaskInfo](https://cloud.tencent.com/document/api/1267/76336#IntegrationTaskInfo)
* [Label](https://cloud.tencent.com/document/api/1267/76336#Label)
* [LogContent](https://cloud.tencent.com/document/api/1267/76336#LogContent)
* [LogContentInfo](https://cloud.tencent.com/document/api/1267/76336#LogContentInfo)
* [Namespace](https://cloud.tencent.com/document/api/1267/76336#Namespace)
* [OfflineInstance](https://cloud.tencent.com/document/api/1267/76336#OfflineInstance)
* [OfflineTaskAddParam](https://cloud.tencent.com/document/api/1267/76336#OfflineTaskAddParam)
* [RealTimeTaskInstanceNodeInfo](https://cloud.tencent.com/document/api/1267/76336#RealTimeTaskInstanceNodeInfo)
* [RecordsSpeed](https://cloud.tencent.com/document/api/1267/76336#RecordsSpeed)
* [RobLockState](https://cloud.tencent.com/document/api/1267/76336#RobLockState)
* [SchedulerTaskInstanceInfo](https://cloud.tencent.com/document/api/1267/76336#SchedulerTaskInstanceInfo)
* [SchemaDetail](https://cloud.tencent.com/document/api/1267/76336#SchemaDetail)
* [SearchCondition](https://cloud.tencent.com/document/api/1267/76336#SearchCondition)
* [SearchConditionInstance](https://cloud.tencent.com/document/api/1267/76336#SearchConditionInstance)
* [SearchConditionInstanceNew](https://cloud.tencent.com/document/api/1267/76336#SearchConditionInstanceNew)
* [SearchConditionNew](https://cloud.tencent.com/document/api/1267/76336#SearchConditionNew)
* [SpeedValue](https://cloud.tencent.com/document/api/1267/76336#SpeedValue)
* [TableInfo](https://cloud.tencent.com/document/api/1267/76336#TableInfo)
* [TaskAlarmInfo](https://cloud.tencent.com/document/api/1267/76336#TaskAlarmInfo)
* [TaskInstanceDetail](https://cloud.tencent.com/document/api/1267/76336#TaskInstanceDetail)
* [TaskLockStatus](https://cloud.tencent.com/document/api/1267/76336#TaskLockStatus)
* [TaskReportDetail](https://cloud.tencent.com/document/api/1267/76336#TaskReportDetail)

### 第 10 次发布

发布时间：2022-10-28 07:02:18

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DeleteCustomFunction](https://cloud.tencent.com/document/api/1267/81485)

	* 新增入参：ProjectId

* [SubmitCustomFunction](https://cloud.tencent.com/document/api/1267/81480)

	* 新增入参：ProjectId


### 第 9 次发布

发布时间：2022-10-20 07:01:15

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateOrUpdateResource](https://cloud.tencent.com/document/api/#/#)
* [DeleteResource](https://cloud.tencent.com/document/api/1267/81749)
* [DescribeResourceManagePathTrees](https://cloud.tencent.com/document/api/1267/81748)

新增数据结构：

* [ResourcePathTree](https://cloud.tencent.com/document/api/1267/76336#ResourcePathTree)
* [UserFileDTO](https://cloud.tencent.com/document/api/1267/76336#UserFileDTO)

### 第 8 次发布

发布时间：2022-10-17 06:55:30

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DeleteCustomFunction](https://cloud.tencent.com/document/api/1267/81485)
* [DescribeFunctionKinds](https://cloud.tencent.com/document/api/1267/81484)
* [DescribeFunctionTypes](https://cloud.tencent.com/document/api/1267/81483)
* [DescribeOrganizationalFunctions](https://cloud.tencent.com/document/api/1267/81482)
* [SaveCustomFunction](https://cloud.tencent.com/document/api/1267/81481)
* [SubmitCustomFunction](https://cloud.tencent.com/document/api/1267/81480)

新增数据结构：

* [FunctionResource](https://cloud.tencent.com/document/api/1267/76336#FunctionResource)
* [FunctionTypeOrKind](https://cloud.tencent.com/document/api/1267/76336#FunctionTypeOrKind)
* [FunctionVersion](https://cloud.tencent.com/document/api/1267/76336#FunctionVersion)
* [OrganizationalFunction](https://cloud.tencent.com/document/api/1267/76336#OrganizationalFunction)

### 第 7 次发布

发布时间：2022-10-12 07:10:44

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateCustomFunction](https://cloud.tencent.com/document/api/1267/81354)

### 第 6 次发布

发布时间：2022-09-21 17:26:55

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeDataSourceList](https://cloud.tencent.com/document/api/1267/80897)
* [DescribeDataSourceWithoutInfo](https://cloud.tencent.com/document/api/#/#)

新增数据结构：

* [DataSourceInfoPage](https://cloud.tencent.com/document/api/1267/76336#DataSourceInfoPage)
* [Filter](https://cloud.tencent.com/document/api/1267/76336#Filter)

### 第 5 次发布

发布时间：2022-09-19 21:02:53

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateDataSource](https://cloud.tencent.com/document/api/1267/80762)
* [DeleteDataSources](https://cloud.tencent.com/document/api/1267/80761)
* [ModifyDataSource](https://cloud.tencent.com/document/api/1267/80760)

### 第 4 次发布

发布时间：2022-09-19 19:36:37

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeDatasource](https://cloud.tencent.com/document/api/1267/80759)

新增数据结构：

* [DataSourceInfo](https://cloud.tencent.com/document/api/1267/76336#DataSourceInfo)

### 第 3 次发布

发布时间：2022-08-05 15:51:29

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [BatchDeleteTasksNew](https://cloud.tencent.com/document/api/#/#)
* [BatchModifyOwnersNew](https://cloud.tencent.com/document/api/#/#)
* [BatchStopTasksNew](https://cloud.tencent.com/document/api/#/#)
* [CreateFolder](https://cloud.tencent.com/document/api/#/#)
* [CreateTask](https://cloud.tencent.com/document/api/1267/78710)
* [CreateWorkflow](https://cloud.tencent.com/document/api/#/#)
* [DeleteFolder](https://cloud.tencent.com/document/api/#/#)
* [DeleteWorkflowNew](https://cloud.tencent.com/document/api/#/#)
* [DescribeDependTasksNew](https://cloud.tencent.com/document/api/#/#)
* [DescribeFolderList](https://cloud.tencent.com/document/api/#/#)
* [DescribeFolderWorkflowList](https://cloud.tencent.com/document/api/1267/78704)
* [DescribeInstanceLogs](https://cloud.tencent.com/document/api/#/#)
* [DescribeTaskDetail](https://cloud.tencent.com/document/api/#/#)
* [DescribeTaskScript](https://cloud.tencent.com/document/api/1267/78701)
* [DescribeTasksByPage](https://cloud.tencent.com/document/api/#/#)
* [ForceSucInstances](https://cloud.tencent.com/document/api/#/#)
* [FreezeTasks](https://cloud.tencent.com/document/api/#/#)
* [FreezeTasksByMultiWorkflow](https://cloud.tencent.com/document/api/#/#)
* [KillInstances](https://cloud.tencent.com/document/api/#/#)
* [MakeUpTasksNew](https://cloud.tencent.com/document/api/#/#)
* [MakeUpWorkflowNew](https://cloud.tencent.com/document/api/#/#)
* [ModifyFolder](https://cloud.tencent.com/document/api/#/#)
* [ModifyTaskInfo](https://cloud.tencent.com/document/api/1267/78692)
* [ModifyTaskLinks](https://cloud.tencent.com/document/api/1267/78691)
* [ModifyTaskScript](https://cloud.tencent.com/document/api/1267/78690)
* [ModifyWorkflowInfo](https://cloud.tencent.com/document/api/1267/78689)
* [ModifyWorkflowSchedule](https://cloud.tencent.com/document/api/1267/78688)
* [RegisterEvent](https://cloud.tencent.com/document/api/1267/78687)
* [RegisterEventListener](https://cloud.tencent.com/document/api/1267/78686)
* [RerunInstances](https://cloud.tencent.com/document/api/#/#)
* [RunTask](https://cloud.tencent.com/document/api/#/#)
* [SetTaskAlarmNew](https://cloud.tencent.com/document/api/1267/78683)
* [SubmitTask](https://cloud.tencent.com/document/api/1267/78682)
* [SubmitWorkflow](https://cloud.tencent.com/document/api/1267/78681)
* [TriggerEvent](https://cloud.tencent.com/document/api/1267/78680)

新增数据结构：

* [AlarmInfo](https://cloud.tencent.com/document/api/1267/76336#AlarmInfo)
* [BatchOperateResult](https://cloud.tencent.com/document/api/1267/76336#BatchOperateResult)
* [BatchResult](https://cloud.tencent.com/document/api/1267/76336#BatchResult)
* [BatchReturn](https://cloud.tencent.com/document/api/1267/76336#BatchReturn)
* [CanvasInfo](https://cloud.tencent.com/document/api/1267/76336#CanvasInfo)
* [CommonContent](https://cloud.tencent.com/document/api/1267/76336#CommonContent)
* [CommonId](https://cloud.tencent.com/document/api/1267/76336#CommonId)
* [DependencyConfig](https://cloud.tencent.com/document/api/1267/76336#DependencyConfig)
* [DescribeFolderListData](https://cloud.tencent.com/document/api/1267/76336#DescribeFolderListData)
* [DescribeFolderWorkflowListData](https://cloud.tencent.com/document/api/1267/76336#DescribeFolderWorkflowListData)
* [Folder](https://cloud.tencent.com/document/api/1267/76336#Folder)
* [GeneralTaskParam](https://cloud.tencent.com/document/api/1267/76336#GeneralTaskParam)
* [InstanceInfo](https://cloud.tencent.com/document/api/1267/76336#InstanceInfo)
* [InstanceLog](https://cloud.tencent.com/document/api/1267/76336#InstanceLog)
* [IntegrationNodeDetail](https://cloud.tencent.com/document/api/1267/76336#IntegrationNodeDetail)
* [IntegrationNodeMapping](https://cloud.tencent.com/document/api/1267/76336#IntegrationNodeMapping)
* [IntegrationNodeSchema](https://cloud.tencent.com/document/api/1267/76336#IntegrationNodeSchema)
* [IntegrationNodeSchemaMapping](https://cloud.tencent.com/document/api/1267/76336#IntegrationNodeSchemaMapping)
* [OperateResult](https://cloud.tencent.com/document/api/1267/76336#OperateResult)
* [ParamInfo](https://cloud.tencent.com/document/api/1267/76336#ParamInfo)
* [RecordField](https://cloud.tencent.com/document/api/1267/76336#RecordField)
* [SimpleTaskInfo](https://cloud.tencent.com/document/api/1267/76336#SimpleTaskInfo)
* [SubmitWorkflow](https://cloud.tencent.com/document/api/1267/76336#SubmitWorkflow)
* [TaskCanvasInfo](https://cloud.tencent.com/document/api/1267/76336#TaskCanvasInfo)
* [TaskExtInfo](https://cloud.tencent.com/document/api/1267/76336#TaskExtInfo)
* [TaskInfoData](https://cloud.tencent.com/document/api/1267/76336#TaskInfoData)
* [TaskInfoDataPage](https://cloud.tencent.com/document/api/1267/76336#TaskInfoDataPage)
* [TaskInnerInfo](https://cloud.tencent.com/document/api/1267/76336#TaskInnerInfo)
* [TaskLinkInfo](https://cloud.tencent.com/document/api/1267/76336#TaskLinkInfo)
* [TaskScriptContent](https://cloud.tencent.com/document/api/1267/76336#TaskScriptContent)
* [Workflow](https://cloud.tencent.com/document/api/1267/76336#Workflow)

### 第 2 次发布

发布时间：2022-07-04 06:20:00

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeProject](https://cloud.tencent.com/document/api/1267/76377)

### 第 1 次发布

发布时间：2022-07-01 10:43:09

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeRelatedInstances](https://cloud.tencent.com/document/api/#/#)
* [DescribeTaskInstances](https://cloud.tencent.com/document/api/#/#)

新增数据结构：

* [DescribeTaskInstancesData](https://cloud.tencent.com/document/api/1267/76336#DescribeTaskInstancesData)
* [OrderField](https://cloud.tencent.com/document/api/1267/76336#OrderField)
* [TaskInstanceInfo](https://cloud.tencent.com/document/api/1267/76336#TaskInstanceInfo)




## 微瓴同业开放平台(weilingwith) 版本：2023-04-27

### 第 8 次发布

发布时间：2024-04-03 11:34:07

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [BatchDeleteDevice](https://cloud.tencent.com/document/api/1693/104841)
* [DeleteDeviceGroup](https://cloud.tencent.com/document/api/1693/104840)
* [DescribeDeviceGroupList](https://cloud.tencent.com/document/api/1693/104839)
* [ModifyDeviceField](https://cloud.tencent.com/document/api/1693/104838)
* [ModifyDeviceGroup](https://cloud.tencent.com/document/api/1693/104837)
* [ModifyDeviceTag](https://cloud.tencent.com/document/api/1693/104836)
* [SaveDeviceGroup](https://cloud.tencent.com/document/api/1693/104835)

新增数据结构：

* [DescribeDeviceGroupListRes](https://cloud.tencent.com/document/api/1693/97961#DescribeDeviceGroupListRes)
* [DescribeGroupInfo](https://cloud.tencent.com/document/api/1693/97961#DescribeGroupInfo)
* [ModifyDeviceFieldInfo](https://cloud.tencent.com/document/api/1693/97961#ModifyDeviceFieldInfo)
* [ModifyDeviceGroupInfo](https://cloud.tencent.com/document/api/1693/97961#ModifyDeviceGroupInfo)
* [ModifyDeviceTagInfo](https://cloud.tencent.com/document/api/1693/97961#ModifyDeviceTagInfo)
* [SaveDeviceGroupRes](https://cloud.tencent.com/document/api/1693/97961#SaveDeviceGroupRes)

### 第 7 次发布

发布时间：2024-01-31 01:28:56

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeDeviceList](https://cloud.tencent.com/document/api/1693/101482)

	* 新增入参：IsActive, IsCamera


修改数据结构：

* [DeviceDataInfo](https://cloud.tencent.com/document/api/1693/97961#DeviceDataInfo)

	* 新增成员：DeviceStatus, Status


### 第 6 次发布

发布时间：2024-01-17 01:27:53

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [ControlDevice](https://cloud.tencent.com/document/api/1693/101487)

	* 新增入参：IsSynchronized


### 第 5 次发布

发布时间：2023-12-01 01:31:31

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeAlarmStatusList](https://cloud.tencent.com/document/api/1693/101460)

	* 新增入参：ApplicationToken, WorkspaceId

	* 新增出参：Result


新增数据结构：

* [AlarmStatusData](https://cloud.tencent.com/document/api/1693/97961#AlarmStatusData)
* [DescribeAlarmStatusListRes](https://cloud.tencent.com/document/api/1693/97961#DescribeAlarmStatusListRes)

### 第 4 次发布

发布时间：2023-11-15 02:45:47

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [AddAlarmProcessRecord](https://cloud.tencent.com/document/api/1693/101492)

	* 新增入参：RecordSet, WorkspaceId, ApplicationToken, ApplicationId, ExtendOne

	* 新增出参：Result

* [BatchCreateDevice](https://cloud.tencent.com/document/api/1693/101491)

	* 新增入参：WorkspaceId, AddDeviceSet, ApplicationToken

	* 新增出参：Result

* [BatchKillAlarm](https://cloud.tencent.com/document/api/1693/101490)

	* 新增入参：BeginTime, EndTime, StatusSet, WorkspaceId, UserId, UserName, ApplicationToken, ProcessorId, AlarmTypeSet, LevelSet, WIDSet, IdSet, Desc

	* 新增出参：Result

* [BatchReportAppMessage](https://cloud.tencent.com/document/api/1693/101489)

	* 新增入参：WorkspaceId, ApplicationToken, ReportSet

	* 新增出参：Result

* [ChangeAlarmStatus](https://cloud.tencent.com/document/api/1693/101488)

	* 新增入参：Id, Status, ProcessTime, ProcessType, WorkspaceId, UserId, UserName, ApplicationToken, Processor, ProcessDescription, ProcessExtend, ExtendOne, ApplicationId

	* 新增出参：Result

* [ControlCameraPTZ](https://cloud.tencent.com/document/api/1693/101468)

	* 新增入参：WID, CMD, WorkspaceId, ApplicationToken

	* 新增出参：Result

* [ControlDevice](https://cloud.tencent.com/document/api/1693/101487)

	* 新增入参：WorkspaceId, WIDSet, ControlData, ApplicationToken

	* 新增出参：Result

* [CreateApplicationToken](https://cloud.tencent.com/document/api/1693/101495)

	* 新增入参：ApplicationId, Nonce, TenantId, RequestTime, Signature

	* 新增出参：Result

* [DescribeActionList](https://cloud.tencent.com/document/api/1693/101486)

	* 新增入参：WorkspaceId, PageNumber, PageSize, ApplicationToken, ActionType, IdSet

	* 新增出参：Result

* [DescribeAdministrationByTag](https://cloud.tencent.com/document/api/1693/101461)

	* 新增入参：ApplicationToken, WorkspaceId, Tag

	* 新增出参：Result

* [DescribeAlarmLevelList](https://cloud.tencent.com/document/api/1693/101485)

	* 新增入参：WorkspaceId, ApplicationToken

	* 新增出参：Result

* [DescribeAlarmList](https://cloud.tencent.com/document/api/1693/101484)

	* 新增入参：BeginTime, EndTime, PageNumber, PageSize, WorkspaceId, ApplicationToken, Statuses, AlarmTypeSet, LevelSet, IdSet, AppIdSet, WIDSet, SpaceCodeSet, ExtendOne, ExtendTwo, ProcessorSet, GroupIdSet

	* 新增出参：Result

* [DescribeAlarmTypeList](https://cloud.tencent.com/document/api/1693/101483)

	* 新增入参：WorkspaceId, ApplicationToken, ParentType

	* 新增出参：Result

* [DescribeBuildingList](https://cloud.tencent.com/document/api/1693/101512)

	* 新增入参：WorkspaceId, ApplicationToken, HasModel, SpaceCodes

	* 新增出参：Result

* [DescribeBuildingModel](https://cloud.tencent.com/document/api/1693/101511)

	* 新增入参：BuildingId, WorkspaceId, ApplicationToken

	* 新增出参：Result

* [DescribeBuildingProfile](https://cloud.tencent.com/document/api/1693/101510)

	* 新增入参：BuildingId, WorkspaceId, ApplicationToken

	* 新增出参：Result

* [DescribeCameraExtendInfo](https://cloud.tencent.com/document/api/1693/101467)

	* 新增入参：WID, WorkspaceId, ApplicationToken

	* 新增出参：Result

* [DescribeCityWorkspaceList](https://cloud.tencent.com/document/api/1693/101459)

	* 新增入参：AdministrativeCodeSet, ApplicationToken

	* 新增出参：Result

* [DescribeDeviceList](https://cloud.tencent.com/document/api/1693/101482)

	* 新增入参：WorkspaceId, PageNumber, PageSize, ApplicationToken, DeviceTypeSet, ProductIdSet, TagIdSet, SpaceCodeSet, DeviceTagSet, WIDSet, Field, GroupIdSet

	* 新增出参：Result

* [DescribeDeviceShadowList](https://cloud.tencent.com/document/api/1693/101481)

	* 新增入参：TagIdSet

* [DescribeDeviceStatusList](https://cloud.tencent.com/document/api/1693/101480)

	* 新增入参：WorkspaceId, ApplicationToken, PageNumber, PageSize, DeviceTypeSet, ProductIdSet, TagIdSet, SpaceCodeSet, WIDSet, DeviceTagSet, DeviceStatusSet, StatusSet, IsAlive

	* 新增出参：Result

* [DescribeDeviceStatusStat](https://cloud.tencent.com/document/api/1693/101479)

	* 新增入参：Level, WorkspaceId, ApplicationToken, SpaceCodeSet, DeviceTypeSet

	* 新增出参：Result

* [DescribeDeviceTagList](https://cloud.tencent.com/document/api/1693/101478)

	* 新增入参：WorkspaceId, PageNumber, PageSize, ApplicationToken

	* 新增出参：Result

* [DescribeDeviceTypeList](https://cloud.tencent.com/document/api/1693/101477)

	* 新增入参：WorkspaceId, ApplicationToken, Flag

	* 新增出参：Result

* [DescribeEdgeApplicationToken](https://cloud.tencent.com/document/api/1693/97957)

	* 新增入参：ApplicationToken, Refresh

	* 新增出参：Result

* [DescribeElementProfilePage](https://cloud.tencent.com/document/api/1693/101509)

	* 新增入参：BuildingId, PageNumber, PageSize, WorkspaceId, ApplicationToken, ParentElementIds, Level, SpaceTypeCode, EntityTypes, IncludeDelete, StartTime, EndTime

	* 新增出参：Result

* [DescribeElementProfileTree](https://cloud.tencent.com/document/api/1693/101508)

	* 新增入参：BuildingId, WorkspaceId, ApplicationToken, ElementId, Level, SpaceTypeCode

	* 新增出参：Result

* [DescribeEventList](https://cloud.tencent.com/document/api/1693/101476)

	* 新增入参：WorkspaceId, PageNumber, PageSize, ApplicationToken, TriggerType, IdSet

	* 新增出参：Result

* [DescribeFileDownloadURL](https://cloud.tencent.com/document/api/1693/101494)

	* 新增入参：WorkspaceId, FileId, ApplicationToken

	* 新增出参：Result

* [DescribeFileUploadURL](https://cloud.tencent.com/document/api/1693/101493)

	* 新增入参：WorkspaceId, FileName, FileSize, ApplicationToken, FileMD5, SaveType, FileExpireTime, NoExpireFlag

	* 新增出参：Result

* [DescribeInterfaceList](https://cloud.tencent.com/document/api/1693/97956)

	* 新增入参：ApplicationToken, PageNumber, PageSize, Keyword, Style, Type

	* 新增出参：Result

* [DescribeLinkRuleList](https://cloud.tencent.com/document/api/1693/101475)

	* 新增入参：WorkspaceId, PageNumber, PageSize, ApplicationToken, TriggerType, IdSet

	* 新增出参：Result

* [DescribeModelList](https://cloud.tencent.com/document/api/1693/101474)

	* 新增入参：WorkspaceId, PageNumber, PageSize, ApplicationToken, DeviceTypeSet, ProductIdSet, ModelIdSet

	* 新增出参：Result

* [DescribeProductList](https://cloud.tencent.com/document/api/1693/101473)

	* 新增入参：WorkspaceId, PageNumber, PageSize, ApplicationToken, DeviceTypeSet, ProductIdSet, ModelIdSet

	* 新增出参：Result

* [DescribePropertyList](https://cloud.tencent.com/document/api/1693/101507)

	* 新增入参：BuildingId, ElementId, WorkspaceId, ApplicationToken

	* 新增出参：Result

* [DescribeRuleDetail](https://cloud.tencent.com/document/api/1693/101472)

	* 新增入参：WorkspaceId, Id, ApplicationToken

	* 新增出参：Result

* [DescribeSceneList](https://cloud.tencent.com/document/api/1693/101506)

	* 新增入参：WorkspaceId, ApplicationToken

	* 新增出参：Result

* [DescribeSpaceDeviceIdList](https://cloud.tencent.com/document/api/1693/101505)

	* 新增入参：ElementIds, IsCascade, WorkspaceId, PageNumber, PageSize, ApplicationToken

	* 新增出参：Result

* [DescribeSpaceDeviceRelationList](https://cloud.tencent.com/document/api/1693/101504)

	* 新增入参：ElementIds, IsCascade, WorkspaceId, PageNumber, PageSize, ApplicationToken

	* 新增出参：Result

* [DescribeSpaceInfoByDeviceId](https://cloud.tencent.com/document/api/1693/101503)

	* 新增入参：DeviceId, WorkspaceId, ApplicationToken

	* 新增出参：Result

* [DescribeSpaceRelationByDeviceId](https://cloud.tencent.com/document/api/1693/101502)

	* 新增入参：DeviceId, WorkspaceId, ApplicationToken

	* 新增出参：Result

* [DescribeSpaceTypeList](https://cloud.tencent.com/document/api/1693/101501)

	* 新增入参：WorkspaceId, PageNumber, PageSize, ApplicationToken

	* 新增出参：Result

* [DescribeTenantBuildingCountAndArea](https://cloud.tencent.com/document/api/1693/101500)

	* 新增入参：WorkspaceIdList, ApplicationToken

	* 新增出参：Result

* [DescribeVideoCloudRecord](https://cloud.tencent.com/document/api/1693/101466)

	* 新增入参：WID, StartTime, EndTime, WorkspaceId, ApplicationToken

	* 新增出参：Result

* [DescribeVideoLiveStream](https://cloud.tencent.com/document/api/1693/101465)

	* 新增入参：WID, Protocol, WorkspaceId, ApplicationToken, StreamId, Env

	* 新增出参：Result

* [DescribeWorkSpaceBuildingCountAndArea](https://cloud.tencent.com/document/api/1693/101499)

	* 新增入参：WorkspaceIdList, ApplicationToken

	* 新增出参：Result

* [DescribeWorkspaceList](https://cloud.tencent.com/document/api/1693/97955)

	* 新增入参：ApplicationToken, WorkspaceId

	* 新增出参：Result

* [ModifyDeviceName](https://cloud.tencent.com/document/api/1693/101471)

	* 新增入参：WorkspaceId, Set, ApplicationToken

	* 新增出参：Result

* [ReportAppMessage](https://cloud.tencent.com/document/api/1693/101470)

	* 新增入参：WorkspaceId, Profile, ReportTs, Properties, ApplicationToken, EventSet, ServiceSet, ExtendTwo, Echo

	* 新增出参：Result

* [StopVideoStreaming](https://cloud.tencent.com/document/api/1693/101463)

	* 新增入参：Stream, WID, WorkspaceId, ApplicationToken

	* 新增出参：Result

* [UpdateWorkspaceParkAttributes](https://cloud.tencent.com/document/api/1693/101458)

	* 新增入参：WorkspaceId, ApplicationToken, ParkName, ParkNum

	* 新增出参：Result


新增数据结构：

* [Action](https://cloud.tencent.com/document/api/1693/97961#Action)
* [ActionDetail](https://cloud.tencent.com/document/api/1693/97961#ActionDetail)
* [ActionObj](https://cloud.tencent.com/document/api/1693/97961#ActionObj)
* [AddDeviceInfo](https://cloud.tencent.com/document/api/1693/97961#AddDeviceInfo)
* [AdministrationData](https://cloud.tencent.com/document/api/1693/97961#AdministrationData)
* [AdministrativeDetail](https://cloud.tencent.com/document/api/1693/97961#AdministrativeDetail)
* [AlarmInfo](https://cloud.tencent.com/document/api/1693/97961#AlarmInfo)
* [AlarmLevelInfo](https://cloud.tencent.com/document/api/1693/97961#AlarmLevelInfo)
* [AlarmTypeDetailInfo](https://cloud.tencent.com/document/api/1693/97961#AlarmTypeDetailInfo)
* [AlarmTypeInfo](https://cloud.tencent.com/document/api/1693/97961#AlarmTypeInfo)
* [ApiContent](https://cloud.tencent.com/document/api/1693/97961#ApiContent)
* [ApiInfo](https://cloud.tencent.com/document/api/1693/97961#ApiInfo)
* [ApiInfoList](https://cloud.tencent.com/document/api/1693/97961#ApiInfoList)
* [ApplicationTokenInfo](https://cloud.tencent.com/document/api/1693/97961#ApplicationTokenInfo)
* [BatchCreateDeviceRes](https://cloud.tencent.com/document/api/1693/97961#BatchCreateDeviceRes)
* [BatchReportAppMessageRes](https://cloud.tencent.com/document/api/1693/97961#BatchReportAppMessageRes)
* [BuildingListRes](https://cloud.tencent.com/document/api/1693/97961#BuildingListRes)
* [BuildingModel](https://cloud.tencent.com/document/api/1693/97961#BuildingModel)
* [BuildingModelRes](https://cloud.tencent.com/document/api/1693/97961#BuildingModelRes)
* [BuildingProfile](https://cloud.tencent.com/document/api/1693/97961#BuildingProfile)
* [BuildingProfileRes](https://cloud.tencent.com/document/api/1693/97961#BuildingProfileRes)
* [CameraExtendInfoRes](https://cloud.tencent.com/document/api/1693/97961#CameraExtendInfoRes)
* [ControlDeviceRes](https://cloud.tencent.com/document/api/1693/97961#ControlDeviceRes)
* [ControlDeviceSet](https://cloud.tencent.com/document/api/1693/97961#ControlDeviceSet)
* [CreateDeviceFailed](https://cloud.tencent.com/document/api/1693/97961#CreateDeviceFailed)
* [CreateDeviceSucceeded](https://cloud.tencent.com/document/api/1693/97961#CreateDeviceSucceeded)
* [CustomField](https://cloud.tencent.com/document/api/1693/97961#CustomField)
* [CustomFieldInfo](https://cloud.tencent.com/document/api/1693/97961#CustomFieldInfo)
* [DescribeActionListRes](https://cloud.tencent.com/document/api/1693/97961#DescribeActionListRes)
* [DescribeAdministrationByTagRes](https://cloud.tencent.com/document/api/1693/97961#DescribeAdministrationByTagRes)
* [DescribeAlarmLevelListRes](https://cloud.tencent.com/document/api/1693/97961#DescribeAlarmLevelListRes)
* [DescribeAlarmListRes](https://cloud.tencent.com/document/api/1693/97961#DescribeAlarmListRes)
* [DescribeAlarmTypeListRes](https://cloud.tencent.com/document/api/1693/97961#DescribeAlarmTypeListRes)
* [DescribeCityWorkspaceListRes](https://cloud.tencent.com/document/api/1693/97961#DescribeCityWorkspaceListRes)
* [DescribeDeviceListRes](https://cloud.tencent.com/document/api/1693/97961#DescribeDeviceListRes)
* [DescribeEventListRes](https://cloud.tencent.com/document/api/1693/97961#DescribeEventListRes)
* [DescribeLinkRuleListRes](https://cloud.tencent.com/document/api/1693/97961#DescribeLinkRuleListRes)
* [DeviceDataInfo](https://cloud.tencent.com/document/api/1693/97961#DeviceDataInfo)
* [DeviceLocation](https://cloud.tencent.com/document/api/1693/97961#DeviceLocation)
* [DeviceModifyInfo](https://cloud.tencent.com/document/api/1693/97961#DeviceModifyInfo)
* [DeviceSpaceInfo](https://cloud.tencent.com/document/api/1693/97961#DeviceSpaceInfo)
* [DeviceSpaceInfoRes](https://cloud.tencent.com/document/api/1693/97961#DeviceSpaceInfoRes)
* [DeviceStatusInfo](https://cloud.tencent.com/document/api/1693/97961#DeviceStatusInfo)
* [DeviceStatusRes](https://cloud.tencent.com/document/api/1693/97961#DeviceStatusRes)
* [DeviceStatusStatRes](https://cloud.tencent.com/document/api/1693/97961#DeviceStatusStatRes)
* [DeviceTagInfo](https://cloud.tencent.com/document/api/1693/97961#DeviceTagInfo)
* [DeviceTagRes](https://cloud.tencent.com/document/api/1693/97961#DeviceTagRes)
* [DeviceType](https://cloud.tencent.com/document/api/1693/97961#DeviceType)
* [DeviceTypeOverview](https://cloud.tencent.com/document/api/1693/97961#DeviceTypeOverview)
* [DeviceTypeSet](https://cloud.tencent.com/document/api/1693/97961#DeviceTypeSet)
* [ElementCoordinates](https://cloud.tencent.com/document/api/1693/97961#ElementCoordinates)
* [ElementProfile](https://cloud.tencent.com/document/api/1693/97961#ElementProfile)
* [ElementProfilePageRes](https://cloud.tencent.com/document/api/1693/97961#ElementProfilePageRes)
* [ElementProfileTreeNode](https://cloud.tencent.com/document/api/1693/97961#ElementProfileTreeNode)
* [ElementProfileTreeRes](https://cloud.tencent.com/document/api/1693/97961#ElementProfileTreeRes)
* [ElementProperty](https://cloud.tencent.com/document/api/1693/97961#ElementProperty)
* [ElementPropertyRes](https://cloud.tencent.com/document/api/1693/97961#ElementPropertyRes)
* [ElementTranslate](https://cloud.tencent.com/document/api/1693/97961#ElementTranslate)
* [EmptyRes](https://cloud.tencent.com/document/api/1693/97961#EmptyRes)
* [Event](https://cloud.tencent.com/document/api/1693/97961#Event)
* [EventDetail](https://cloud.tencent.com/document/api/1693/97961#EventDetail)
* [EventObj](https://cloud.tencent.com/document/api/1693/97961#EventObj)
* [FileDownloadURL](https://cloud.tencent.com/document/api/1693/97961#FileDownloadURL)
* [FileInfo](https://cloud.tencent.com/document/api/1693/97961#FileInfo)
* [FileUploadURL](https://cloud.tencent.com/document/api/1693/97961#FileUploadURL)
* [HandleRecordInfo](https://cloud.tencent.com/document/api/1693/97961#HandleRecordInfo)
* [HandlerPersonInfo](https://cloud.tencent.com/document/api/1693/97961#HandlerPersonInfo)
* [LinkRule](https://cloud.tencent.com/document/api/1693/97961#LinkRule)
* [LinkRuleInfo](https://cloud.tencent.com/document/api/1693/97961#LinkRuleInfo)
* [MessageProfile](https://cloud.tencent.com/document/api/1693/97961#MessageProfile)
* [ModelInfo](https://cloud.tencent.com/document/api/1693/97961#ModelInfo)
* [ModelSet](https://cloud.tencent.com/document/api/1693/97961#ModelSet)
* [ProcessRecordInfo](https://cloud.tencent.com/document/api/1693/97961#ProcessRecordInfo)
* [ProductInfo](https://cloud.tencent.com/document/api/1693/97961#ProductInfo)
* [ProductSet](https://cloud.tencent.com/document/api/1693/97961#ProductSet)
* [RawInfo](https://cloud.tencent.com/document/api/1693/97961#RawInfo)
* [RecordInfo](https://cloud.tencent.com/document/api/1693/97961#RecordInfo)
* [RelatedProduct](https://cloud.tencent.com/document/api/1693/97961#RelatedProduct)
* [ReportAppMessage](https://cloud.tencent.com/document/api/1693/97961#ReportAppMessage)
* [ReportImg](https://cloud.tencent.com/document/api/1693/97961#ReportImg)
* [ReportMsgRes](https://cloud.tencent.com/document/api/1693/97961#ReportMsgRes)
* [RuleDetailRes](https://cloud.tencent.com/document/api/1693/97961#RuleDetailRes)
* [SceneInfo](https://cloud.tencent.com/document/api/1693/97961#SceneInfo)
* [SceneListRes](https://cloud.tencent.com/document/api/1693/97961#SceneListRes)
* [SpaceDataListStatsRes](https://cloud.tencent.com/document/api/1693/97961#SpaceDataListStatsRes)
* [SpaceDataStats](https://cloud.tencent.com/document/api/1693/97961#SpaceDataStats)
* [SpaceDataTotalStatsRes](https://cloud.tencent.com/document/api/1693/97961#SpaceDataTotalStatsRes)
* [SpaceDeviceIdListRes](https://cloud.tencent.com/document/api/1693/97961#SpaceDeviceIdListRes)
* [SpaceDeviceRelation](https://cloud.tencent.com/document/api/1693/97961#SpaceDeviceRelation)
* [SpaceDeviceRelationRes](https://cloud.tencent.com/document/api/1693/97961#SpaceDeviceRelationRes)
* [SpaceInfo](https://cloud.tencent.com/document/api/1693/97961#SpaceInfo)
* [SpaceRelation](https://cloud.tencent.com/document/api/1693/97961#SpaceRelation)
* [SpaceRelationRes](https://cloud.tencent.com/document/api/1693/97961#SpaceRelationRes)
* [SpaceType](https://cloud.tencent.com/document/api/1693/97961#SpaceType)
* [SpaceTypeListRes](https://cloud.tencent.com/document/api/1693/97961#SpaceTypeListRes)
* [StatDeviceType](https://cloud.tencent.com/document/api/1693/97961#StatDeviceType)
* [StatLevel](https://cloud.tencent.com/document/api/1693/97961#StatLevel)
* [VideoCloudRecordRes](https://cloud.tencent.com/document/api/1693/97961#VideoCloudRecordRes)
* [VideoRecordStreamRes](https://cloud.tencent.com/document/api/1693/97961#VideoRecordStreamRes)
* [WorkspaceInfo](https://cloud.tencent.com/document/api/1693/97961#WorkspaceInfo)
* [WorkspaceInfoList](https://cloud.tencent.com/document/api/1693/97961#WorkspaceInfoList)

### 第 3 次发布

发布时间：2023-11-14 01:34:59

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeApplicationList](https://cloud.tencent.com/document/api/1693/97958)

	* 新增入参：WorkspaceId, ApplicationToken, ApplicationId, PageNumber, PageSize

	* 新增出参：Result

* [DescribeDeviceShadowList](https://cloud.tencent.com/document/api/1693/101481)

	* 新增入参：WorkspaceId, WIDSet, PageNumber, PageSize, ApplicationToken, DeviceTypeSet, ProductIdSet, SpaceCodeSet, DeviceTagSet

	* 新增出参：Result

* [DescribeVideoRecordStream](https://cloud.tencent.com/document/api/1693/101464)

	* 新增入参：WID, Protocol, StartTime, EndTime, PlayBackRate, WorkspaceId, ApplicationToken, Stream, Env


新增数据结构：

* [ApplicationInfo](https://cloud.tencent.com/document/api/1693/97961#ApplicationInfo)
* [ApplicationList](https://cloud.tencent.com/document/api/1693/97961#ApplicationList)
* [ApplicationLogo](https://cloud.tencent.com/document/api/1693/97961#ApplicationLogo)
* [DeviceShadowInfo](https://cloud.tencent.com/document/api/1693/97961#DeviceShadowInfo)
* [DeviceShadowRes](https://cloud.tencent.com/document/api/1693/97961#DeviceShadowRes)

### 第 2 次发布

发布时间：2023-11-10 01:30:47

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [AddAlarmProcessRecord](https://cloud.tencent.com/document/api/1693/101492)
* [BatchCreateDevice](https://cloud.tencent.com/document/api/1693/101491)
* [BatchKillAlarm](https://cloud.tencent.com/document/api/1693/101490)
* [BatchReportAppMessage](https://cloud.tencent.com/document/api/1693/101489)
* [ChangeAlarmStatus](https://cloud.tencent.com/document/api/1693/101488)
* [ControlCameraPTZ](https://cloud.tencent.com/document/api/1693/101468)
* [ControlDevice](https://cloud.tencent.com/document/api/1693/101487)
* [CreateApplicationToken](https://cloud.tencent.com/document/api/1693/101495)
* [DescribeActionList](https://cloud.tencent.com/document/api/1693/101486)
* [DescribeAdministrationByTag](https://cloud.tencent.com/document/api/1693/101461)
* [DescribeAlarmLevelList](https://cloud.tencent.com/document/api/1693/101485)
* [DescribeAlarmList](https://cloud.tencent.com/document/api/1693/101484)
* [DescribeAlarmStatusList](https://cloud.tencent.com/document/api/1693/101460)
* [DescribeAlarmTypeList](https://cloud.tencent.com/document/api/1693/101483)
* [DescribeBuildingList](https://cloud.tencent.com/document/api/1693/101512)
* [DescribeBuildingModel](https://cloud.tencent.com/document/api/1693/101511)
* [DescribeBuildingProfile](https://cloud.tencent.com/document/api/1693/101510)
* [DescribeCameraExtendInfo](https://cloud.tencent.com/document/api/1693/101467)
* [DescribeCityWorkspaceList](https://cloud.tencent.com/document/api/1693/101459)
* [DescribeDeviceList](https://cloud.tencent.com/document/api/1693/101482)
* [DescribeDeviceShadowList](https://cloud.tencent.com/document/api/1693/101481)
* [DescribeDeviceStatusList](https://cloud.tencent.com/document/api/1693/101480)
* [DescribeDeviceStatusStat](https://cloud.tencent.com/document/api/1693/101479)
* [DescribeDeviceTagList](https://cloud.tencent.com/document/api/1693/101478)
* [DescribeDeviceTypeList](https://cloud.tencent.com/document/api/1693/101477)
* [DescribeElementProfilePage](https://cloud.tencent.com/document/api/1693/101509)
* [DescribeElementProfileTree](https://cloud.tencent.com/document/api/1693/101508)
* [DescribeEventList](https://cloud.tencent.com/document/api/1693/101476)
* [DescribeFileDownloadURL](https://cloud.tencent.com/document/api/1693/101494)
* [DescribeFileUploadURL](https://cloud.tencent.com/document/api/1693/101493)
* [DescribeLinkRuleList](https://cloud.tencent.com/document/api/1693/101475)
* [DescribeModelList](https://cloud.tencent.com/document/api/1693/101474)
* [DescribeProductList](https://cloud.tencent.com/document/api/1693/101473)
* [DescribePropertyList](https://cloud.tencent.com/document/api/1693/101507)
* [DescribeRuleDetail](https://cloud.tencent.com/document/api/1693/101472)
* [DescribeSceneList](https://cloud.tencent.com/document/api/1693/101506)
* [DescribeSpaceDeviceIdList](https://cloud.tencent.com/document/api/1693/101505)
* [DescribeSpaceDeviceRelationList](https://cloud.tencent.com/document/api/1693/101504)
* [DescribeSpaceInfoByDeviceId](https://cloud.tencent.com/document/api/1693/101503)
* [DescribeSpaceRelationByDeviceId](https://cloud.tencent.com/document/api/1693/101502)
* [DescribeSpaceTypeList](https://cloud.tencent.com/document/api/1693/101501)
* [DescribeTenantBuildingCountAndArea](https://cloud.tencent.com/document/api/1693/101500)
* [DescribeTenantDepartmentList](https://cloud.tencent.com/document/api/1693/101497)
* [DescribeTenantUserList](https://cloud.tencent.com/document/api/1693/101496)
* [DescribeVideoCloudRecord](https://cloud.tencent.com/document/api/1693/101466)
* [DescribeVideoLiveStream](https://cloud.tencent.com/document/api/1693/101465)
* [DescribeVideoRecordStream](https://cloud.tencent.com/document/api/1693/101464)
* [DescribeWorkSpaceBuildingCountAndArea](https://cloud.tencent.com/document/api/1693/101499)
* [ModifyDeviceName](https://cloud.tencent.com/document/api/1693/101471)
* [ReportAppMessage](https://cloud.tencent.com/document/api/1693/101470)
* [StopVideoStreaming](https://cloud.tencent.com/document/api/1693/101463)
* [UpdateWorkspaceParkAttributes](https://cloud.tencent.com/document/api/1693/101458)

新增数据结构：

* [SsoDepartment](https://cloud.tencent.com/document/api/1693/97961#SsoDepartment)
* [SsoDepartmentsResult](https://cloud.tencent.com/document/api/1693/97961#SsoDepartmentsResult)
* [SsoUser](https://cloud.tencent.com/document/api/1693/97961#SsoUser)
* [SsoUserResult](https://cloud.tencent.com/document/api/1693/97961#SsoUserResult)

### 第 1 次发布

发布时间：2023-09-12 09:30:48

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeApplicationList](https://cloud.tencent.com/document/api/1693/97958)
* [DescribeEdgeApplicationToken](https://cloud.tencent.com/document/api/1693/97957)
* [DescribeInterfaceList](https://cloud.tencent.com/document/api/1693/97956)
* [DescribeWorkspaceList](https://cloud.tencent.com/document/api/1693/97955)
* [DescribeWorkspaceUserList](https://cloud.tencent.com/document/api/1693/97960)

新增数据结构：

* [SsoTeamUser](https://cloud.tencent.com/document/api/1693/97961#SsoTeamUser)
* [SsoTeamUserResult](https://cloud.tencent.com/document/api/1693/97961#SsoTeamUserResult)




## SSL 证书(wss) 版本：2018-04-26

### 第 1 次发布

发布时间：2019-08-22 20:22:23

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DeleteCert](https://cloud.tencent.com/document/api/400/37397)
* [DescribeCertList](https://cloud.tencent.com/document/api/400/37396)
* [UploadCert](https://cloud.tencent.com/document/api/400/37395)

新增数据结构：

* [SSLCertificate](https://cloud.tencent.com/document/api/400/37398#SSLCertificate)
* [SSLProjectInfo](https://cloud.tencent.com/document/api/400/37398#SSLProjectInfo)




## 音速达直播音乐版权引擎(yinsuda) 版本：2022-05-27

### 第 19 次发布

发布时间：2024-06-05 02:38:46

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeKTVMusicAccompanySegmentUrlVip](https://cloud.tencent.com/document/api/1592/102622)

	* 新增入参：RoomId


修改数据结构：

* [LiveVipTradeInfo](https://cloud.tencent.com/document/api/1592/76191#LiveVipTradeInfo)

	* <font color="#dd0000">**修改成员**：</font>TradeSerialNo, AppName, UserId, RoomId, VipDays, Status, CreateTime

* [LiveVipUserInfo](https://cloud.tencent.com/document/api/1592/76191#LiveVipUserInfo)

	* <font color="#dd0000">**修改成员**：</font>RoomId, LiveVipEndTime, LiveVipStatus

* [UserInfo](https://cloud.tencent.com/document/api/1592/76191#UserInfo)

	* <font color="#dd0000">**修改成员**：</font>AppName, UserId, LiveVipUserInfo, UserType


### 第 18 次发布

发布时间：2023-12-26 02:06:57

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeKTVMusicAccompanySegmentUrlVip](https://cloud.tencent.com/document/api/1592/102622)
* [DescribeVipUserInfo](https://cloud.tencent.com/document/api/1592/102621)
* [RechargeVip](https://cloud.tencent.com/document/api/1592/102620)

### 第 17 次发布

发布时间：2023-08-10 01:50:27

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [TRTCJoinRoomInput](https://cloud.tencent.com/document/api/1592/76191#TRTCJoinRoomInput)

	* 新增成员：RoomIdType


### 第 16 次发布

发布时间：2023-06-22 02:06:43

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeKTVMusicAccompanySegmentUrl](https://cloud.tencent.com/document/api/1592/94247)

新增数据结构：

* [KTVOtherSegments](https://cloud.tencent.com/document/api/1592/76191#KTVOtherSegments)

### 第 15 次发布

发布时间：2023-05-25 02:13:42

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [BatchDescribeKTVMusicDetails](https://cloud.tencent.com/document/api/1592/76190)

	* 新增入参：GuestUserId, RoomId

* [RechargeLiveVip](https://cloud.tencent.com/document/api/1592/88705)

	* 新增入参：GiveType, PlayScene


### 第 14 次发布

发布时间：2023-04-28 01:49:51

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeKTVMusicsByTag](https://cloud.tencent.com/document/api/1592/80528)

	* 新增入参：MaterialFilters

* [DescribeKTVPlaylistDetail](https://cloud.tencent.com/document/api/1592/76189)

	* 新增入参：MaterialFilters

* [SearchKTVMusics](https://cloud.tencent.com/document/api/1592/76186)

	* 新增入参：MaterialFilters


### 第 13 次发布

发布时间：2023-04-19 16:26:04

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeKTVPlaylistDetail](https://cloud.tencent.com/document/api/1592/76189)

	* 新增入参：PlayScene

* [SearchKTVMusics](https://cloud.tencent.com/document/api/1592/76186)

	* 新增入参：PlayScene


### 第 12 次发布

发布时间：2023-03-16 02:35:06

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeLiveVipTradeInfos](https://cloud.tencent.com/document/api/1592/88707)
* [DescribeUserInfo](https://cloud.tencent.com/document/api/1592/88706)
* [RechargeLiveVip](https://cloud.tencent.com/document/api/1592/88705)

新增数据结构：

* [LiveVipTradeInfo](https://cloud.tencent.com/document/api/1592/76191#LiveVipTradeInfo)
* [LiveVipUserInfo](https://cloud.tencent.com/document/api/1592/76191#LiveVipUserInfo)
* [UserInfo](https://cloud.tencent.com/document/api/1592/76191#UserInfo)

### 第 11 次发布

发布时间：2023-03-15 02:26:07

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [BatchDescribeKTVMusicDetails](https://cloud.tencent.com/document/api/1592/76190)

	* 新增入参：PlayScene


### 第 10 次发布

发布时间：2023-01-09 01:59:51

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [ApplyChorus](https://cloud.tencent.com/document/api/1592/85356)

### 第 9 次发布

发布时间：2022-12-27 02:26:58

本次发布包含了以下内容：

改善已有的文档。

新增数据结构：

* [AMEMusicBaseInfo](https://cloud.tencent.com/document/api/1592/76191#AMEMusicBaseInfo)

修改数据结构：

* [KTVMatchMusic](https://cloud.tencent.com/document/api/1592/76191#KTVMatchMusic)

	* 新增成员：AMEMusicBaseInfo

* [KTVMatchRule](https://cloud.tencent.com/document/api/1592/76191#KTVMatchRule)

	* 新增成员：MusicIdToMatchAME


### 第 8 次发布

发布时间：2022-10-28 07:02:46

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeKTVPlaylists](https://cloud.tencent.com/document/api/1592/76188)

	* 新增入参：Offset, Limit

	* 新增出参：TotalCount


### 第 7 次发布

发布时间：2022-09-16 06:52:09

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeKTVMusicsByTag](https://cloud.tencent.com/document/api/1592/80528)
* [DescribeKTVTags](https://cloud.tencent.com/document/api/1592/80527)

新增数据结构：

* [KTVBPMInfo](https://cloud.tencent.com/document/api/1592/76191#KTVBPMInfo)
* [KTVTagGroupInfo](https://cloud.tencent.com/document/api/1592/76191#KTVTagGroupInfo)
* [KTVTagInfo](https://cloud.tencent.com/document/api/1592/76191#KTVTagInfo)

修改数据结构：

* [KTVMusicDetailInfo](https://cloud.tencent.com/document/api/1592/76191#KTVMusicDetailInfo)

	* 新增成员：BPMInfo


### 第 6 次发布

发布时间：2022-08-24 07:02:00

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateKTVRobot](https://cloud.tencent.com/document/api/1592/79388)
* [DescribeKTVRobots](https://cloud.tencent.com/document/api/1592/79387)
* [DestroyKTVRobot](https://cloud.tencent.com/document/api/1592/79386)
* [SyncKTVRobotCommand](https://cloud.tencent.com/document/api/1592/79385)

新增数据结构：

* [JoinRoomInput](https://cloud.tencent.com/document/api/1592/76191#JoinRoomInput)
* [KTVRobotInfo](https://cloud.tencent.com/document/api/1592/76191#KTVRobotInfo)
* [PlayCommandInput](https://cloud.tencent.com/document/api/1592/76191#PlayCommandInput)
* [SeekCommandInput](https://cloud.tencent.com/document/api/1592/76191#SeekCommandInput)
* [SendMessageCommandInput](https://cloud.tencent.com/document/api/1592/76191#SendMessageCommandInput)
* [SetAudioParamCommandInput](https://cloud.tencent.com/document/api/1592/76191#SetAudioParamCommandInput)
* [SetDestroyModeCommandInput](https://cloud.tencent.com/document/api/1592/76191#SetDestroyModeCommandInput)
* [SetPlayModeCommandInput](https://cloud.tencent.com/document/api/1592/76191#SetPlayModeCommandInput)
* [SetPlaylistCommandInput](https://cloud.tencent.com/document/api/1592/76191#SetPlaylistCommandInput)
* [SyncRobotCommand](https://cloud.tencent.com/document/api/1592/76191#SyncRobotCommand)
* [TRTCJoinRoomInput](https://cloud.tencent.com/document/api/1592/76191#TRTCJoinRoomInput)
* [TimeRange](https://cloud.tencent.com/document/api/1592/76191#TimeRange)

### 第 5 次发布

发布时间：2022-08-22 07:01:10

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeKTVMatchMusics](https://cloud.tencent.com/document/api/1592/79259)

新增数据结构：

* [KTVMatchMusic](https://cloud.tencent.com/document/api/1592/76191#KTVMatchMusic)
* [KTVMatchRule](https://cloud.tencent.com/document/api/1592/76191#KTVMatchRule)
* [KTVMatchRuleMusicInfo](https://cloud.tencent.com/document/api/1592/76191#KTVMatchRuleMusicInfo)

### 第 4 次发布

发布时间：2022-07-30 15:22:03

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeKTVPlaylists](https://cloud.tencent.com/document/api/1592/76188)

	* 新增入参：Types


### 第 3 次发布

发布时间：2022-07-20 06:16:26

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [KTVMusicBaseInfo](https://cloud.tencent.com/document/api/1592/76191#KTVMusicBaseInfo)

	* 新增成员：RecommendType


### 第 2 次发布

发布时间：2022-07-13 06:20:29

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [KTVMusicDetailInfo](https://cloud.tencent.com/document/api/1592/76191#KTVMusicDetailInfo)

	* 新增成员：PreludeInterval, GenreSet


### 第 1 次发布

发布时间：2022-06-29 15:15:26

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [BatchDescribeKTVMusicDetails](https://cloud.tencent.com/document/api/1592/76190)
* [DescribeKTVPlaylistDetail](https://cloud.tencent.com/document/api/1592/76189)
* [DescribeKTVPlaylists](https://cloud.tencent.com/document/api/1592/76188)
* [DescribeKTVSuggestions](https://cloud.tencent.com/document/api/1592/76187)
* [SearchKTVMusics](https://cloud.tencent.com/document/api/1592/76186)

新增数据结构：

* [ChorusClip](https://cloud.tencent.com/document/api/1592/76191#ChorusClip)
* [KTVMusicBaseInfo](https://cloud.tencent.com/document/api/1592/76191#KTVMusicBaseInfo)
* [KTVMusicDetailInfo](https://cloud.tencent.com/document/api/1592/76191#KTVMusicDetailInfo)
* [KTVPlaylistBaseInfo](https://cloud.tencent.com/document/api/1592/76191#KTVPlaylistBaseInfo)
* [KTVSuggestionInfo](https://cloud.tencent.com/document/api/1592/76191#KTVSuggestionInfo)
* [MusicAlbumCoverInfo](https://cloud.tencent.com/document/api/1592/76191#MusicAlbumCoverInfo)
* [MusicAlbumInfo](https://cloud.tencent.com/document/api/1592/76191#MusicAlbumInfo)




## 腾讯优Mall(youmall) 版本：2018-02-28

### 第 8 次发布

发布时间：2019-01-11 11:24:15

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [ModifyPersonFeatureInfo](https://cloud.tencent.com/document/api/860/32491)

修改数据结构：

* [CameraPersonInfo](https://cloud.tencent.com/document/api/860/18465#CameraPersonInfo)

	* 新增成员：PersonInfo

* [PersonInfo](https://cloud.tencent.com/document/api/860/18465#PersonInfo)

	* 新增成员：VisitTimes, VisitDays

* [PersonTracePoint](https://cloud.tencent.com/document/api/860/18465#PersonTracePoint)

	* 新增成员：ShoppingBagType, ShoppingBagCount


### 第 7 次发布

发布时间：2018-12-06 16:55:58

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribePersonInfoByFacePicture](https://cloud.tencent.com/document/api/860/31283)

修改接口：

* [CreateFacePicture](https://cloud.tencent.com/document/api/860/20420)

	* <font color="#dd0000">**修改入参**：</font>ShopId


### 第 6 次发布

发布时间：2018-11-22 19:41:50

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeFaceIdByTempId](https://cloud.tencent.com/document/api/860/19899)

	* 新增入参：PictureExpires

	* 新增出参：PersonInfo

* [DescribePersonVisitInfo](https://cloud.tencent.com/document/api/860/18463)

	* 新增入参：StartDateTime, EndDateTime

	* <font color="#dd0000">**修改入参**：</font>StartDate, EndDate


新增数据结构：

* [SceneInfo](https://cloud.tencent.com/document/api/860/18465#SceneInfo)

修改数据结构：

* [PersonVisitInfo](https://cloud.tencent.com/document/api/860/18465#PersonVisitInfo)

	* 新增成员：SceneInfo


### 第 5 次发布

发布时间：2018-11-15 15:43:00

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DeletePersonFeature](https://cloud.tencent.com/document/api/860/30429)
* [ModifyPersonType](https://cloud.tencent.com/document/api/860/30428)

修改接口：

* [CreateFacePicture](https://cloud.tencent.com/document/api/860/20420)

	* 新增入参：IsForceUpload

* [DescribePersonInfo](https://cloud.tencent.com/document/api/860/18464)

	* 新增入参：PersonType


修改数据结构：

* [PersonInfo](https://cloud.tencent.com/document/api/860/18465#PersonInfo)

	* 新增成员：PersonSubType

	* <font color="#dd0000">**修改成员**：</font>Gender, Age, PersonType


### 第 4 次发布

发布时间：2018-10-26 14:34:20

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeClusterPersonArrivedMall](https://cloud.tencent.com/document/api/860/30168)
* [DescribeClusterPersonTrace](https://cloud.tencent.com/document/api/860/30167)
* [DescribePerson](https://cloud.tencent.com/document/api/860/30166)
* [DescribePersonArrivedMall](https://cloud.tencent.com/document/api/860/30165)
* [DescribePersonTrace](https://cloud.tencent.com/document/api/860/30164)
* [DescribePersonTraceDetail](https://cloud.tencent.com/document/api/860/30163)

新增数据结构：

* [ArrivedMallInfo](https://cloud.tencent.com/document/api/860/18465#ArrivedMallInfo)
* [DailyTracePoint](https://cloud.tencent.com/document/api/860/18465#DailyTracePoint)
* [PersonCoordinate](https://cloud.tencent.com/document/api/860/18465#PersonCoordinate)
* [PersonProfile](https://cloud.tencent.com/document/api/860/18465#PersonProfile)
* [PersonTracePoint](https://cloud.tencent.com/document/api/860/18465#PersonTracePoint)
* [PersonTraceRoute](https://cloud.tencent.com/document/api/860/18465#PersonTraceRoute)

### 第 3 次发布

发布时间：2018-10-12 15:10:38

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateAccount](https://cloud.tencent.com/document/api/860/20421)
* [CreateFacePicture](https://cloud.tencent.com/document/api/860/20420)
* [DescribeTrajectoryData](https://cloud.tencent.com/document/api/860/20419)
* [DescribeZoneFlowAgeInfoByZoneId](https://cloud.tencent.com/document/api/860/20418)
* [DescribeZoneFlowAndStayTime](https://cloud.tencent.com/document/api/860/20417)
* [DescribeZoneFlowDailyByZoneId](https://cloud.tencent.com/document/api/860/20416)
* [DescribeZoneFlowGenderAvrStayTimeByZoneId](https://cloud.tencent.com/document/api/860/20415)
* [DescribeZoneFlowGenderInfoByZoneId](https://cloud.tencent.com/document/api/860/20414)
* [DescribeZoneFlowHourlyByZoneId](https://cloud.tencent.com/document/api/860/20413)

新增数据结构：

* [NetworkAndShopInfo](https://cloud.tencent.com/document/api/860/18465#NetworkAndShopInfo)
* [TrajectorySunData](https://cloud.tencent.com/document/api/860/18465#TrajectorySunData)
* [ZoneAgeGroupAvrStayTime](https://cloud.tencent.com/document/api/860/18465#ZoneAgeGroupAvrStayTime)
* [ZoneDayFlow](https://cloud.tencent.com/document/api/860/18465#ZoneDayFlow)
* [ZoneFlowAndAvrStayTime](https://cloud.tencent.com/document/api/860/18465#ZoneFlowAndAvrStayTime)
* [ZoneHourFlow](https://cloud.tencent.com/document/api/860/18465#ZoneHourFlow)

<font color="#dd0000">**删除数据结构**：</font>

* NetworkInfoNoShop

修改数据结构：

* [NetworkHistoryInfo](https://cloud.tencent.com/document/api/860/18465#NetworkHistoryInfo)

	* <font color="#dd0000">**修改成员**：</font>Infos

* [NetworkInfo](https://cloud.tencent.com/document/api/860/18465#NetworkInfo)

	* <font color="#dd0000">**删除成员**：</font>CompanyId, ShopId, Province, City, ShopName

* [NetworkLastInfo](https://cloud.tencent.com/document/api/860/18465#NetworkLastInfo)

	* <font color="#dd0000">**修改成员**：</font>Infos


### 第 2 次发布

发布时间：2018-09-18 18:47:12

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeCameraPerson](https://cloud.tencent.com/document/api/860/19900)
* [DescribeFaceIdByTempId](https://cloud.tencent.com/document/api/860/19899)
* [DescribeHistoryNetworkInfo](https://cloud.tencent.com/document/api/860/19897)
* [DescribeNetworkInfo](https://cloud.tencent.com/document/api/860/19896)
* [ModifyPersonTagInfo](https://cloud.tencent.com/document/api/860/19898)

修改接口：

* [DescribePersonInfo](https://cloud.tencent.com/document/api/860/18464)

	* 新增入参：PictureExpires

* [DescribePersonVisitInfo](https://cloud.tencent.com/document/api/860/18463)

	* 新增入参：PictureExpires


新增数据结构：

* [CameraPersonInfo](https://cloud.tencent.com/document/api/860/18465#CameraPersonInfo)
* [NetworkHistoryInfo](https://cloud.tencent.com/document/api/860/18465#NetworkHistoryInfo)
* [NetworkInfo](https://cloud.tencent.com/document/api/860/18465#NetworkInfo)
* [NetworkInfoNoShop](https://cloud.tencent.com/document/api/860/18465#NetworkInfoNoShop)
* [NetworkLastInfo](https://cloud.tencent.com/document/api/860/18465#NetworkLastInfo)
* [PersonTagInfo](https://cloud.tencent.com/document/api/860/18465#PersonTagInfo)

修改数据结构：

* [PersonInfo](https://cloud.tencent.com/document/api/860/18465#PersonInfo)

	* 新增成员：PersonPictureUrl

* [PersonVisitInfo](https://cloud.tencent.com/document/api/860/18465#PersonVisitInfo)

	* 新增成员：CapturedPictureUrl


### 第 1 次发布

发布时间：2018-07-23 16:30:11

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribePersonInfo](https://cloud.tencent.com/document/api/860/18464)
* [DescribePersonVisitInfo](https://cloud.tencent.com/document/api/860/18463)
* [DescribeShopHourTrafficInfo](https://cloud.tencent.com/document/api/860/18461)
* [DescribeShopInfo](https://cloud.tencent.com/document/api/860/18457)
* [DescribeShopTrafficInfo](https://cloud.tencent.com/document/api/860/18460)
* [DescribeZoneTrafficInfo](https://cloud.tencent.com/document/api/860/18459)
* [RegisterCallback](https://cloud.tencent.com/document/api/860/18456)

新增数据结构：

* [GenderAgeTrafficDetail](https://cloud.tencent.com/document/api/860/18465#GenderAgeTrafficDetail)
* [HourTrafficInfoDetail](https://cloud.tencent.com/document/api/860/18465#HourTrafficInfoDetail)
* [PersonInfo](https://cloud.tencent.com/document/api/860/18465#PersonInfo)
* [PersonVisitInfo](https://cloud.tencent.com/document/api/860/18465#PersonVisitInfo)
* [ShopDayTrafficInfo](https://cloud.tencent.com/document/api/860/18465#ShopDayTrafficInfo)
* [ShopHourTrafficInfo](https://cloud.tencent.com/document/api/860/18465#ShopHourTrafficInfo)
* [ShopInfo](https://cloud.tencent.com/document/api/860/18465#ShopInfo)
* [ZoneTrafficInfo](https://cloud.tencent.com/document/api/860/18465#ZoneTrafficInfo)
* [ZoneTrafficInfoDetail](https://cloud.tencent.com/document/api/860/18465#ZoneTrafficInfoDetail)




## (yunjing) 版本：2018-02-28

### 第 12 次发布

发布时间：2020-09-15 08:08:47

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [ExportAttackLogs](https://cloud.tencent.com/document/api/296/39572)

	* 新增出参：TaskId


### 第 11 次发布

发布时间：2020-08-28 08:06:11

本次发布包含了以下内容：

改善已有的文档。

新增数据结构：

* [RegionInfo](https://cloud.tencent.com/document/api/296/19867#RegionInfo)

修改数据结构：

* [Machine](https://cloud.tencent.com/document/api/296/19867#Machine)

	* 新增成员：RegionInfo


### 第 10 次发布

发布时间：2020-08-27 08:07:01

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [ExportNonlocalLoginPlaces](https://cloud.tencent.com/document/api/296/39581)

	* 新增出参：TaskId


### 第 9 次发布

发布时间：2020-07-20 08:20:03

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeAttackLogs](https://cloud.tencent.com/document/api/296/39573)

	* 新增入参：Uuid, Quuid

* [DescribeSecurityTrends](https://cloud.tencent.com/document/api/296/30329)

	* 新增出参：MaliciousRequests, HighRiskBashs, ReverseShells, PrivilegeEscalations, CyberAttacks

* [DescribeTags](https://cloud.tencent.com/document/api/296/39565)

	* 新增入参：MachineType, MachineRegion


修改数据结构：

* [Machine](https://cloud.tencent.com/document/api/296/19867#Machine)

	* 新增成员：BaselineNum, CyberAttackNum, SecurityStatus, InvasionNum

* [MachineTag](https://cloud.tencent.com/document/api/296/19867#MachineTag)

	* 新增成员：TagId

* [SecurityDynamic](https://cloud.tencent.com/document/api/296/19867#SecurityDynamic)

	* 新增成员：SecurityLevel


### 第 8 次发布

发布时间：2020-07-17 08:20:22

本次发布包含了以下内容：

改善已有的文档。

修改数据结构：

* [LoginWhiteLists](https://cloud.tencent.com/document/api/296/19867#LoginWhiteLists)

	* 新增成员：StartTime, EndTime

* [LoginWhiteListsRule](https://cloud.tencent.com/document/api/296/19867#LoginWhiteListsRule)

	* 新增成员：StartTime, EndTime


### 第 7 次发布

发布时间：2020-07-16 08:21:39

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateBaselineStrategy](https://cloud.tencent.com/document/api/296/46372)

### 第 6 次发布

发布时间：2020-01-16 18:29:39

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [OpenProVersion](https://cloud.tencent.com/document/api/296/41154)

修改数据结构：

* [BruteAttack](https://cloud.tencent.com/document/api/296/19867#BruteAttack)

	* 新增成员：IsProVersion, BanStatus, Quuid


### 第 5 次发布

发布时间：2019-11-22 21:54:52

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [AddLoginWhiteList](https://cloud.tencent.com/document/api/296/39602)
* [AddMachineTag](https://cloud.tencent.com/document/api/296/39571)
* [CreateOpenPortTask](https://cloud.tencent.com/document/api/296/39570)
* [DeleteAttackLogs](https://cloud.tencent.com/document/api/296/39575)
* [DeleteBashEvents](https://cloud.tencent.com/document/api/296/39601)
* [DeleteBashRules](https://cloud.tencent.com/document/api/296/39600)
* [DeleteLoginWhiteList](https://cloud.tencent.com/document/api/296/39599)
* [DeleteMachineTag](https://cloud.tencent.com/document/api/296/39569)
* [DeletePrivilegeEvents](https://cloud.tencent.com/document/api/296/39598)
* [DeletePrivilegeRules](https://cloud.tencent.com/document/api/296/39597)
* [DeleteReverseShellEvents](https://cloud.tencent.com/document/api/296/39596)
* [DeleteReverseShellRules](https://cloud.tencent.com/document/api/296/39595)
* [DeleteTags](https://cloud.tencent.com/document/api/296/39568)
* [DescribeAttackLogInfo](https://cloud.tencent.com/document/api/296/39574)
* [DescribeAttackLogs](https://cloud.tencent.com/document/api/296/39573)
* [DescribeBashEvents](https://cloud.tencent.com/document/api/296/39594)
* [DescribeBashRules](https://cloud.tencent.com/document/api/296/39593)
* [DescribeLoginWhiteList](https://cloud.tencent.com/document/api/296/39592)
* [DescribeOpenPortTaskStatus](https://cloud.tencent.com/document/api/296/39567)
* [DescribePrivilegeEvents](https://cloud.tencent.com/document/api/296/39591)
* [DescribePrivilegeRules](https://cloud.tencent.com/document/api/296/39590)
* [DescribeReverseShellEvents](https://cloud.tencent.com/document/api/296/39589)
* [DescribeReverseShellRules](https://cloud.tencent.com/document/api/296/39588)
* [DescribeTagMachines](https://cloud.tencent.com/document/api/296/39566)
* [DescribeTags](https://cloud.tencent.com/document/api/296/39565)
* [EditBashRule](https://cloud.tencent.com/document/api/296/39587)
* [EditPrivilegeRule](https://cloud.tencent.com/document/api/296/39586)
* [EditReverseShellRule](https://cloud.tencent.com/document/api/296/39585)
* [EditTags](https://cloud.tencent.com/document/api/296/39564)
* [ExportAttackLogs](https://cloud.tencent.com/document/api/296/39572)
* [ExportBashEvents](https://cloud.tencent.com/document/api/296/39584)
* [ExportBruteAttacks](https://cloud.tencent.com/document/api/296/39583)
* [ExportMalwares](https://cloud.tencent.com/document/api/296/39582)
* [ExportNonlocalLoginPlaces](https://cloud.tencent.com/document/api/296/39581)
* [ExportPrivilegeEvents](https://cloud.tencent.com/document/api/296/39580)
* [ExportReverseShellEvents](https://cloud.tencent.com/document/api/296/39579)
* [ModifyLoginWhiteList](https://cloud.tencent.com/document/api/296/39578)
* [SetBashEventsStatus](https://cloud.tencent.com/document/api/296/39577)
* [SwitchBashRules](https://cloud.tencent.com/document/api/296/39576)

修改接口：

* [DescribeMachineInfo](https://cloud.tencent.com/document/api/296/19851)

	* 新增出参：FreeMalwaresLeft, FreeVulsLeft

* [DescribeVulScanResult](https://cloud.tencent.com/document/api/296/19858)

	* 新增出参：HostNum, BasicVersionNum

* [DescribeWeeklyReportInfo](https://cloud.tencent.com/document/api/296/30325)

	* 新增出参：DownloadUrl


新增数据结构：

* [BashEvent](https://cloud.tencent.com/document/api/296/19867#BashEvent)
* [BashRule](https://cloud.tencent.com/document/api/296/19867#BashRule)
* [DefendAttackLog](https://cloud.tencent.com/document/api/296/19867#DefendAttackLog)
* [LoginWhiteLists](https://cloud.tencent.com/document/api/296/19867#LoginWhiteLists)
* [LoginWhiteListsRule](https://cloud.tencent.com/document/api/296/19867#LoginWhiteListsRule)
* [MachineTag](https://cloud.tencent.com/document/api/296/19867#MachineTag)
* [PrivilegeEscalationProcess](https://cloud.tencent.com/document/api/296/19867#PrivilegeEscalationProcess)
* [PrivilegeRule](https://cloud.tencent.com/document/api/296/19867#PrivilegeRule)
* [ReverseShell](https://cloud.tencent.com/document/api/296/19867#ReverseShell)
* [ReverseShellRule](https://cloud.tencent.com/document/api/296/19867#ReverseShellRule)
* [Tag](https://cloud.tencent.com/document/api/296/19867#Tag)
* [TagMachine](https://cloud.tencent.com/document/api/296/19867#TagMachine)

修改数据结构：

* [ImpactedHost](https://cloud.tencent.com/document/api/296/19867#ImpactedHost)

	* 新增成员：IsProVersion

* [Machine](https://cloud.tencent.com/document/api/296/19867#Machine)

	* 新增成员：MalwareNum, Tag

	* <font color="#dd0000">**修改成员**：</font>VulNum


### 第 4 次发布

发布时间：2018-12-07 20:41:12

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [InquiryPriceOpenProVersionPrepaid](https://cloud.tencent.com/document/api/296/31293)

	* 新增出参：OriginalPrice


### 第 3 次发布

发布时间：2018-12-06 16:57:40

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DeleteMaliciousRequests](https://cloud.tencent.com/document/api/296/31289)
* [DescribeMaliciousRequests](https://cloud.tencent.com/document/api/296/31288)
* [ExportMaliciousRequests](https://cloud.tencent.com/document/api/296/31287)
* [InquiryPriceOpenProVersionPrepaid](https://cloud.tencent.com/document/api/296/31293)
* [ModifyProVersionRenewFlag](https://cloud.tencent.com/document/api/296/31292)
* [OpenProVersionPrepaid](https://cloud.tencent.com/document/api/296/31291)
* [RenewProVersion](https://cloud.tencent.com/document/api/296/31290)
* [TrustMaliciousRequest](https://cloud.tencent.com/document/api/296/31286)
* [UntrustMaliciousRequest](https://cloud.tencent.com/document/api/296/31285)

新增数据结构：

* [ChargePrepaid](https://cloud.tencent.com/document/api/296/19867#ChargePrepaid)
* [MaliciousRequest](https://cloud.tencent.com/document/api/296/19867#MaliciousRequest)
* [ProVersionMachine](https://cloud.tencent.com/document/api/296/19867#ProVersionMachine)

### 第 2 次发布

发布时间：2018-11-08 17:42:06

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateProcessTask](https://cloud.tencent.com/document/api/296/30341)
* [DescribeAccountStatistics](https://cloud.tencent.com/document/api/296/30340)
* [DescribeAccounts](https://cloud.tencent.com/document/api/296/30339)
* [DescribeComponentInfo](https://cloud.tencent.com/document/api/296/30338)
* [DescribeComponentStatistics](https://cloud.tencent.com/document/api/296/30337)
* [DescribeComponents](https://cloud.tencent.com/document/api/296/30336)
* [DescribeHistoryAccounts](https://cloud.tencent.com/document/api/296/30335)
* [DescribeOpenPortStatistics](https://cloud.tencent.com/document/api/296/30328)
* [DescribeOpenPorts](https://cloud.tencent.com/document/api/296/30327)
* [DescribeProcessStatistics](https://cloud.tencent.com/document/api/296/30334)
* [DescribeProcessTaskStatus](https://cloud.tencent.com/document/api/296/30333)
* [DescribeProcesses](https://cloud.tencent.com/document/api/296/30332)
* [DescribeSecurityDynamics](https://cloud.tencent.com/document/api/296/30330)
* [DescribeSecurityTrends](https://cloud.tencent.com/document/api/296/30329)
* [DescribeWeeklyReportBruteAttacks](https://cloud.tencent.com/document/api/296/30326)
* [DescribeWeeklyReportInfo](https://cloud.tencent.com/document/api/296/30325)
* [DescribeWeeklyReportMalwares](https://cloud.tencent.com/document/api/296/30324)
* [DescribeWeeklyReportNonlocalLoginPlaces](https://cloud.tencent.com/document/api/296/30323)
* [DescribeWeeklyReportVuls](https://cloud.tencent.com/document/api/296/30322)
* [DescribeWeeklyReports](https://cloud.tencent.com/document/api/296/30321)

修改接口：

* [DescribeOverviewStatistics](https://cloud.tencent.com/document/api/296/19849)

	* 新增出参：BaseLineNum


新增数据结构：

* [Account](https://cloud.tencent.com/document/api/296/19867#Account)
* [AccountStatistics](https://cloud.tencent.com/document/api/296/19867#AccountStatistics)
* [Component](https://cloud.tencent.com/document/api/296/19867#Component)
* [ComponentStatistics](https://cloud.tencent.com/document/api/296/19867#ComponentStatistics)
* [HistoryAccount](https://cloud.tencent.com/document/api/296/19867#HistoryAccount)
* [OpenPort](https://cloud.tencent.com/document/api/296/19867#OpenPort)
* [OpenPortStatistics](https://cloud.tencent.com/document/api/296/19867#OpenPortStatistics)
* [Process](https://cloud.tencent.com/document/api/296/19867#Process)
* [ProcessStatistics](https://cloud.tencent.com/document/api/296/19867#ProcessStatistics)
* [SecurityDynamic](https://cloud.tencent.com/document/api/296/19867#SecurityDynamic)
* [SecurityTrend](https://cloud.tencent.com/document/api/296/19867#SecurityTrend)
* [WeeklyReport](https://cloud.tencent.com/document/api/296/19867#WeeklyReport)
* [WeeklyReportBruteAttack](https://cloud.tencent.com/document/api/296/19867#WeeklyReportBruteAttack)
* [WeeklyReportMalware](https://cloud.tencent.com/document/api/296/19867#WeeklyReportMalware)
* [WeeklyReportNonlocalLoginPlace](https://cloud.tencent.com/document/api/296/19867#WeeklyReportNonlocalLoginPlace)
* [WeeklyReportVul](https://cloud.tencent.com/document/api/296/19867#WeeklyReportVul)

### 第 1 次发布

发布时间：2018-09-14 14:23:54

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CloseProVersion](https://cloud.tencent.com/document/api/296/19847)
* [CreateUsualLoginPlaces](https://cloud.tencent.com/document/api/296/19846)
* [DeleteBruteAttacks](https://cloud.tencent.com/document/api/296/19845)
* [DeleteMachine](https://cloud.tencent.com/document/api/296/19844)
* [DeleteMalwares](https://cloud.tencent.com/document/api/296/19839)
* [DeleteNonlocalLoginPlaces](https://cloud.tencent.com/document/api/296/19843)
* [DeleteUsualLoginPlaces](https://cloud.tencent.com/document/api/296/19842)
* [DescribeAgentVuls](https://cloud.tencent.com/document/api/296/19861)
* [DescribeAlarmAttribute](https://cloud.tencent.com/document/api/296/19866)
* [DescribeBruteAttacks](https://cloud.tencent.com/document/api/296/19838)
* [DescribeImpactedHosts](https://cloud.tencent.com/document/api/296/19860)
* [DescribeMachineInfo](https://cloud.tencent.com/document/api/296/19851)
* [DescribeMachines](https://cloud.tencent.com/document/api/296/19850)
* [DescribeMalwares](https://cloud.tencent.com/document/api/296/19837)
* [DescribeNonlocalLoginPlaces](https://cloud.tencent.com/document/api/296/19836)
* [DescribeOverviewStatistics](https://cloud.tencent.com/document/api/296/19849)
* [DescribeProVersionInfo](https://cloud.tencent.com/document/api/296/19865)
* [DescribeUsualLoginPlaces](https://cloud.tencent.com/document/api/296/19841)
* [DescribeVulInfo](https://cloud.tencent.com/document/api/296/19859)
* [DescribeVulScanResult](https://cloud.tencent.com/document/api/296/19858)
* [DescribeVuls](https://cloud.tencent.com/document/api/296/19857)
* [IgnoreImpactedHosts](https://cloud.tencent.com/document/api/296/19856)
* [MisAlarmNonlocalLoginPlaces](https://cloud.tencent.com/document/api/296/19835)
* [ModifyAlarmAttribute](https://cloud.tencent.com/document/api/296/19864)
* [ModifyAutoOpenProVersionConfig](https://cloud.tencent.com/document/api/296/19863)
* [RecoverMalwares](https://cloud.tencent.com/document/api/296/19834)
* [RescanImpactedHost](https://cloud.tencent.com/document/api/296/19855)
* [SeparateMalwares](https://cloud.tencent.com/document/api/296/30320)
* [TrustMalwares](https://cloud.tencent.com/document/api/296/19833)
* [UntrustMalwares](https://cloud.tencent.com/document/api/296/30319)

新增数据结构：

* [AgentVul](https://cloud.tencent.com/document/api/296/19867#AgentVul)
* [BruteAttack](https://cloud.tencent.com/document/api/296/19867#BruteAttack)
* [Filter](https://cloud.tencent.com/document/api/296/19867#Filter)
* [ImpactedHost](https://cloud.tencent.com/document/api/296/19867#ImpactedHost)
* [Machine](https://cloud.tencent.com/document/api/296/19867#Machine)
* [Malware](https://cloud.tencent.com/document/api/296/19867#Malware)
* [NonLocalLoginPlace](https://cloud.tencent.com/document/api/296/19867#NonLocalLoginPlace)
* [Place](https://cloud.tencent.com/document/api/296/19867#Place)
* [UsualPlace](https://cloud.tencent.com/document/api/296/19867#UsualPlace)
* [Vul](https://cloud.tencent.com/document/api/296/19867#Vul)




## 腾讯云搜TCS(yunsou) 版本：2018-05-04

### 第 1 次发布

发布时间：2019-06-06 20:23:46

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DataManipulation](https://cloud.tencent.com/document/api/270/35303)
* [DataSearch](https://cloud.tencent.com/document/api/270/35302)



## 腾讯云搜TCS(yunsou) 版本：2019-11-15

### 第 1 次发布

发布时间：2020-03-16 08:22:02

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DataManipulation](https://cloud.tencent.com/document/api/270/42318)
* [DataSearch](https://cloud.tencent.com/document/api/270/42317)

新增数据结构：

* [DataManipulationResult](https://cloud.tencent.com/document/api/270/42319#DataManipulationResult)
* [DataManipulationResultItem](https://cloud.tencent.com/document/api/270/42319#DataManipulationResultItem)
* [SearchResult](https://cloud.tencent.com/document/api/270/42319#SearchResult)
* [SearchResultItem](https://cloud.tencent.com/document/api/270/42319#SearchResultItem)
* [SearchResultSeg](https://cloud.tencent.com/document/api/270/42319#SearchResultSeg)




